/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.Date;

import jp.co.act_inc.actservicesample.adminservice.Environ;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.UserInformation2;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.preference.PreferenceManager;
import android.text.TextUtils;

/**
 * 管理サービス関連のプリファレンスを管理します。
 * 
 * @author ishi
 * 
 */
public class AdminPrefManager {

    /**
     * 管理サービス用Environを作成します。
     * 
     * @param context
     *            コンテキスト
     * @return 管理サービス用Environ
     */
    public static Environ createAdminEnviron(Context context) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        return new Environ(
                prefs.getString(
                        context.getString(R.string.admin_pref_username_key), ""),
                prefs.getString(
                        context.getString(R.string.admin_pref_password_key), ""),
                "", "", "", 0);
    }

    /**
     * ユーザー情報を削除します。
     * 
     * @param context
     *            コンテキスト
     */
    public static void deleteUserInfo(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.remove(context
                .getString(R.string.user_info_pref_calc_area_max_dist_key));
        editor.remove(context
                .getString(R.string.user_info_pref_calc_area_max_locs_key));
        editor.remove(context
                .getString(R.string.user_info_pref_calc_area_max_time_key));
        editor.remove(context.getString(R.string.user_info_pref_calc_count_key));
        editor.remove(context
                .getString(R.string.user_info_pref_calc_interval_key));
        editor.remove(context
                .getString(R.string.user_info_pref_calc_opt_route_max_locs_key));
        editor.remove(context
                .getString(R.string.user_info_pref_calc_route_max_locs_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_i32_1_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_i32_2_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_i32_3_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_i32_4_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_str_1_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_str_2_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_str_3_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expand_str_4_key));
        editor.remove(context
                .getString(R.string.user_info_pref_expiry_date_key));
        editor.remove(context.getString(R.string.user_info_pref_geo_count_key));
        editor.remove(context
                .getString(R.string.user_info_pref_geo_enum_interval_key));
        editor.remove(context
                .getString(R.string.user_info_pref_geo_interval_key));
        editor.remove(context
                .getString(R.string.user_info_pref_geo_max_address_level_key));
        editor.remove(context
                .getString(R.string.user_info_pref_geo_max_locs_key));
        editor.remove(context
                .getString(R.string.user_info_pref_max_calc_count_key));
        editor.remove(context
                .getString(R.string.user_info_pref_max_geo_count_key));
        editor.remove(context
                .getString(R.string.user_info_pref_member_kind_key));
        editor.remove(context
                .getString(R.string.user_info_pref_access_time_key));
        editor.remove(context
                .getString(R.string.user_info_pref_last_distcalc_time_key));
        editor.remove(context
                .getString(R.string.user_info_pref_last_geocalc_time_key));
        editor.commit();
    }

    /**
     * ユーザー情報取得日時を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return ユーザー情報取得日時
     */
    public static Date getAccessTime(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        return new Date(pref.getLong(
                context.getString(R.string.user_info_pref_access_time_key), 0));
    }

    /**
     * 管理サーバーURLを取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 管理サーバーURL
     */
    public static String getAdminUrl(Context context) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        String url = prefs.getString(
                context.getString(R.string.admin_pref_admin_url_key), "");
        return url;
    }

    /**
     * 最終距離計算日時を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 最終距離計算日時
     */
    public static Date getListDistCalcTime(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        return new Date(pref.getLong(context
                .getString(R.string.user_info_pref_last_distcalc_time_key), 0));
    }

    /**
     * 最終住所検索日時を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 最終住所検索日時
     */
    public static Date getListGeoCalcTime(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        return new Date(pref.getLong(context
                .getString(R.string.user_info_pref_last_geocalc_time_key), 0));
    }

    /**
     * 地点番号を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 地点番号
     */
    public static int getLocNumber(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        return pref.getInt(
                context.getString(R.string.user_info_pref_loc_number_key), 1);
    }

    /**
     * 計算用道路データ情報を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 計算用道路データ情報
     */
    public static NWInfo getNWInfo(Context context) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context.getApplicationContext());
        NWInfo nwInfo = new NWInfo(prefs.getString(
                context.getApplicationContext().getString(
                        R.string.dcws_pref_folder_key), ""), prefs.getString(
                context.getApplicationContext().getString(
                        R.string.dcws_pref_note_key), ""), prefs.getBoolean(
                context.getApplicationContext().getString(
                        R.string.dcws_pref_is_detail_exist_key), false),
                prefs.getBoolean(
                        context.getApplicationContext().getString(
                                R.string.dcws_pref_is_toll_exist_key), false),
                prefs.getString(
                        context.getApplicationContext().getString(
                                R.string.dcws_pref_nwid_key), ""),
                prefs.getString(
                        context.getApplicationContext().getString(
                                R.string.dcws_pref_nwid_without_speed_key), ""));
        return nwInfo;
    }

    /**
     * エリア計算の基点インデックスを取得します。
     * 
     * @param context
     *            コンテキスト
     * @return エリア計算の基点インデックス
     */
    public static int getStartLocIndex(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        return pref.getInt(
                context.getString(R.string.user_info_pref_start_loc_index_key),
                -1);
    }

    /**
     * ユーザー情報を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return ユーザー情報
     */
    public static UserInformation2 getUserInfo(Context context) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        UserInformation2 info = new UserInformation2();
        info.setCalcAreaMaxDist(pref.getInt(context
                .getString(R.string.user_info_pref_calc_area_max_dist_key), -2));
        info.setCalcAreaMaxLocs(pref.getInt(context
                .getString(R.string.user_info_pref_calc_area_max_locs_key), -2));
        info.setCalcAreaMaxTime(pref.getInt(context
                .getString(R.string.user_info_pref_calc_area_max_time_key), -2));
        info.setCalcCount(pref.getInt(
                context.getString(R.string.user_info_pref_calc_count_key), -2));
        info.setCalcInterval(pref.getInt(
                context.getString(R.string.user_info_pref_calc_interval_key),
                -2));
        info.setCalcOptRouteMaxLocs(pref.getInt(
                context.getString(R.string.user_info_pref_calc_opt_route_max_locs_key),
                -2));
        info.setCalcRouteMaxLocs(pref.getInt(context
                .getString(R.string.user_info_pref_calc_route_max_locs_key), -2));
        info.setExpand_I32_1(pref.getInt(
                context.getString(R.string.user_info_pref_expand_i32_1_key), -2));
        info.setExpand_I32_2(pref.getInt(
                context.getString(R.string.user_info_pref_expand_i32_2_key), -2));
        info.setExpand_I32_3(pref.getInt(
                context.getString(R.string.user_info_pref_expand_i32_3_key), -2));
        info.setExpand_I32_4(pref.getInt(
                context.getString(R.string.user_info_pref_expand_i32_4_key), -2));
        info.setExpand_Str_1(pref.getString(
                context.getString(R.string.user_info_pref_expand_str_1_key), ""));
        info.setExpand_Str_2(pref.getString(
                context.getString(R.string.user_info_pref_expand_str_2_key), ""));
        info.setExpand_Str_3(pref.getString(
                context.getString(R.string.user_info_pref_expand_str_3_key), ""));
        info.setExpand_Str_4(pref.getString(
                context.getString(R.string.user_info_pref_expand_str_4_key), ""));
        info.setExpiryDate(pref.getString(
                context.getString(R.string.user_info_pref_expiry_date_key), ""));
        info.setGeoCount(pref.getInt(
                context.getString(R.string.user_info_pref_geo_count_key), -2));
        info.setGeoEnumInterval(pref.getInt(context
                .getString(R.string.user_info_pref_geo_enum_interval_key), -2));
        info.setGeoInterval(pref.getInt(
                context.getString(R.string.user_info_pref_geo_interval_key), -2));
        info.setGeoMaxAddressLevel(pref.getInt(context
                .getString(R.string.user_info_pref_geo_max_address_level_key),
                -2));
        info.setGeoMaxLocs(pref.getInt(
                context.getString(R.string.user_info_pref_geo_max_locs_key), -2));
        info.setMaxCalcCount(pref.getInt(
                context.getString(R.string.user_info_pref_max_calc_count_key),
                -2));
        info.setMaxGeoCount(pref.getInt(
                context.getString(R.string.user_info_pref_max_geo_count_key),
                -2));
        info.setMemberKind(pref.getString(
                context.getString(R.string.user_info_pref_member_kind_key), ""));
        if (!TextUtils.isEmpty(info.getExpiryDate())) {
            return info;
        } else {
            return null;
        }
    }

    /**
     * SSLを使用するかどうかを取得します。
     * 
     * @param context
     *            コンテキスト
     * @return SSLを使用するかどうか
     */
    public static boolean getUseSsl(Context context) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        boolean useSsl = prefs.getBoolean(
                context.getString(R.string.admin_pref_use_ssl_key), false);
        return useSsl;
    }

    /**
     * ユーザー情報取得日時を保存します。
     * 
     * @param context
     *            コンテキスト
     * @param accessTime
     *            ユーザー情報取得日時
     */
    public static void writeAccessTime(Context context, Date accessTime) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putLong(
                context.getString(R.string.user_info_pref_access_time_key),
                accessTime.getTime());
        editor.commit();
    }

    /**
     * 最終距離計算日時を保存します。
     * 
     * @param context
     *            コンテキスト
     * @param lastDistCalcTime
     *            最終距離計算日時
     */
    public static void writeLastDistCalcTime(Context context,
            Date lastDistCalcTime) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putLong(context
                .getString(R.string.user_info_pref_last_distcalc_time_key),
                lastDistCalcTime.getTime());
        editor.commit();
    }

    /**
     * 最終住所検索日時を保存します。
     * 
     * @param context
     *            コンテキスト
     * @param lastGeoCalcTime
     *            最終住所検索日時
     */
    public static void writeLastGeoCalcTime(Context context,
            Date lastGeoCalcTime) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putLong(context
                .getString(R.string.user_info_pref_last_geocalc_time_key),
                lastGeoCalcTime.getTime());
        editor.commit();
    }

    /**
     * 地点番号を保存します。
     * 
     * @param context
     *            コンテキスト
     * @param locNumber
     *            地点番号
     */
    public static void writeLocNumber(Context context, int locNumber) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putInt(
                context.getString(R.string.user_info_pref_loc_number_key),
                locNumber);
        editor.commit();
    }

    /**
     * 計算用道路データ情報を設定ファイルに書き込みます。
     * 
     * @param context
     *            コンテキスト
     * @param nwInfo
     *            計算用道路データ情報
     */
    public static void writeSelectedNWInfo(Context context, NWInfo nwInfo) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putString(context.getString(R.string.dcws_pref_folder_key),
                nwInfo.getFolder());
        editor.putString(context.getString(R.string.dcws_pref_note_key),
                nwInfo.getNote());
        editor.putBoolean(
                context.getString(R.string.dcws_pref_is_detail_exist_key),
                nwInfo.getIsDetailExist());
        editor.putBoolean(
                context.getString(R.string.dcws_pref_is_toll_exist_key),
                nwInfo.getIsTollExist());
        editor.putString(context.getString(R.string.dcws_pref_nwid_key),
                nwInfo.getNwID());
        editor.putString(
                context.getString(R.string.dcws_pref_nwid_without_speed_key),
                nwInfo.getNwID_WithoutSpeed());
        editor.commit();
    }

    /**
     * エリア計算の基点インデックスを保存します。
     * 
     * @param context
     *            コンテキスト
     * @param startLocIndex
     *            エリア計算の基点インデックス
     */
    public static void writeStartLocIndex(Context context, int startLocIndex) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putInt(
                context.getString(R.string.user_info_pref_start_loc_index_key),
                startLocIndex);
        editor.commit();
    }

    /**
     * ユーザー情報を保存します。
     * 
     * @param context
     *            コンテキスト
     * @param info
     *            ユーザー情報
     */
    public static void writeUserInfo(Context context, UserInformation2 info) {
        SharedPreferences pref = PreferenceManager
                .getDefaultSharedPreferences(context);
        Editor editor = pref.edit();
        editor.putInt(context
                .getString(R.string.user_info_pref_calc_area_max_dist_key),
                info.getCalcAreaMaxDist());
        editor.putInt(context
                .getString(R.string.user_info_pref_calc_area_max_locs_key),
                info.getCalcAreaMaxLocs());
        editor.putInt(context
                .getString(R.string.user_info_pref_calc_area_max_time_key),
                info.getCalcAreaMaxTime());
        editor.putInt(
                context.getString(R.string.user_info_pref_calc_count_key),
                info.getCalcCount());
        editor.putInt(
                context.getString(R.string.user_info_pref_calc_interval_key),
                info.getCalcInterval());
        editor.putInt(
                context.getString(R.string.user_info_pref_calc_opt_route_max_locs_key),
                info.getCalcOptRouteMaxLocs());
        editor.putInt(context
                .getString(R.string.user_info_pref_calc_route_max_locs_key),
                info.getCalcRouteMaxLocs());
        editor.putInt(
                context.getString(R.string.user_info_pref_expand_i32_1_key),
                info.getExpand_I32_1());
        editor.putInt(
                context.getString(R.string.user_info_pref_expand_i32_2_key),
                info.getExpand_I32_2());
        editor.putInt(
                context.getString(R.string.user_info_pref_expand_i32_3_key),
                info.getExpand_I32_3());
        editor.putInt(
                context.getString(R.string.user_info_pref_expand_i32_4_key),
                info.getExpand_I32_4());
        editor.putString(
                context.getString(R.string.user_info_pref_expand_str_1_key),
                info.getExpand_Str_1());
        editor.putString(
                context.getString(R.string.user_info_pref_expand_str_2_key),
                info.getExpand_Str_2());
        editor.putString(
                context.getString(R.string.user_info_pref_expand_str_3_key),
                info.getExpand_Str_3());
        editor.putString(
                context.getString(R.string.user_info_pref_expand_str_4_key),
                info.getExpand_Str_4());
        editor.putString(
                context.getString(R.string.user_info_pref_expiry_date_key),
                info.getExpiryDate());
        editor.putInt(context.getString(R.string.user_info_pref_geo_count_key),
                info.getGeoCount());
        editor.putInt(context
                .getString(R.string.user_info_pref_geo_enum_interval_key), info
                .getGeoEnumInterval());
        editor.putInt(
                context.getString(R.string.user_info_pref_geo_interval_key),
                info.getGeoInterval());
        editor.putInt(context
                .getString(R.string.user_info_pref_geo_max_address_level_key),
                info.getGeoMaxAddressLevel());
        editor.putInt(
                context.getString(R.string.user_info_pref_geo_max_locs_key),
                info.getGeoMaxLocs());
        editor.putInt(
                context.getString(R.string.user_info_pref_max_calc_count_key),
                info.getMaxCalcCount());
        editor.putInt(
                context.getString(R.string.user_info_pref_max_geo_count_key),
                info.getMaxGeoCount());
        editor.putString(
                context.getString(R.string.user_info_pref_member_kind_key),
                info.getMemberKind());
        editor.commit();
    }
}
