﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import jp.co.act_inc.actservicesample.adminservice.Constants;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaDirection;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.CalcKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.Datum;
import jp.co.act_inc.actservicesample.adminservice.Constants.HighwayOutput;
import jp.co.act_inc.actservicesample.adminservice.Constants.PolygonDetail;
import jp.co.act_inc.actservicesample.adminservice.Constants.PolygonKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.TollOutput;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.dcservice.CA3Param;
import jp.co.act_inc.actservicesample.dcservice.COW3Param;
import jp.co.act_inc.actservicesample.dcservice.DistUtils;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import jp.co.act_inc.actservicesample.dcservice.NodePnt;
import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;

/**
 * 到達圏／流入圏計算のプリファレンスを管理します。
 * 
 * @author ishi
 * 
 */
public class CalcArea3PrefManager {

    /**
     * CA3Paramを作成します。
     * 
     * @param context
     *            コンテキスト
     * @param startLoc
     *            基点となる地点
     * @return CA3Param
     */
    public static CA3Param createCA3Param(Context context, Loc startLoc) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        CA3Param param = new CA3Param();
        param.setDatum(Datum.Jgd2000);
        param.setCalcKind(CalcArea3PrefManager.getCalcKind(prefs, context));
        param.setPolygonKind(CalcArea3PrefManager
                .getPolygonKind(prefs, context));
        if (startLoc != null) {
            NodePnt startPnt = new NodePnt(startLoc.getLon(),
                    startLoc.getLat(), "");
            param.setStartPnt(startPnt);
        }
        int flag = CalcArea3PrefManager.getCATransportFlag(prefs, context);
        param.setTransport(flag);
        param.setAreaKind(CalcArea3PrefManager.getAreaKind(prefs, context));
        if (param.getAreaKind() == 1) {
            param.setAreaRange(CalcArea3PrefManager
                    .getAreaRange(prefs, context) * 60 * 10);
        } else {
            param.setAreaRange(CalcArea3PrefManager
                    .getAreaRange(prefs, context) * 1000);
        }
        param.setPolygonLevel(CalcArea3PrefManager.getPolygonLevel(prefs,
                context));
        param.setDonutPolygonLevel(CalcArea3PrefManager.getDonutPolygonLevel(
                prefs, context));
        param.setAreaDirection(CalcArea3PrefManager.getAreaDirection(prefs,
                context));
        param.setPolygonDetail(CalcArea3PrefManager.getPolygonDetail(prefs,
                context));
        return param;
    }

    /**
     * COW3Paramを作成します。
     * 
     * @param context
     *            コンテキスト
     * @param startLoc
     *            基点となる地点
     * @return COW3Param
     */
    public static COW3Param createCOW3Param(Context context, Loc startLoc) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        COW3Param param = new COW3Param();
        param.setDatum(Datum.Jgd2000);
        param.setCalcKind(CalcArea3PrefManager.getCalcKind(prefs, context));
        if (startLoc != null) {
            NodePnt startPnt = new NodePnt(startLoc.getLon(),
                    startLoc.getLat(), "");
            param.setStartPnt(startPnt);
        }
        int flag = CalcArea3PrefManager.getCATransportFlag(prefs, context);
        param.setTransport(flag);
        param.setAreaKind(CalcArea3PrefManager.getAreaKind(prefs, context));
        if (param.getAreaKind() == AreaKind.TIME) {
            param.setAreaRange(CalcArea3PrefManager
                    .getAreaRange(prefs, context) * 60 * 10);
        } else {
            param.setAreaRange(CalcArea3PrefManager
                    .getAreaRange(prefs, context) * 1000);
        }
        param.setAreaDirection(CalcArea3PrefManager.getAreaDirection(prefs,
                context));
        param.setHighwayOutput(HighwayOutput.OUTPUT);
        NWInfo nwInfo = AdminPrefManager.getNWInfo(context);
        param.setTollOutput(nwInfo.getIsTollExist() ? TollOutput.OUTPUT
                : TollOutput.NOT_OUTPUT);
        return param;
    }

    /**
     * 範囲方向を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 範囲方向
     */
    public static int getAreaDirection(SharedPreferences prefs, Context context) {
        int areaDirection = Integer.parseInt(prefs.getString(
                context.getString(R.string.calc_area3_pref_area_direction_key),
                "0"));
        return areaDirection == 0 ? AreaDirection.OUTFLOW
                : AreaDirection.INFLOW;
    }

    /**
     * 到達圏／流入圏計算種別を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 到達圏／流入圏計算種別
     */
    public static int getAreaKind(SharedPreferences prefs, Context context) {
        int areaKind = Integer
                .parseInt(prefs.getString(context
                        .getString(R.string.calc_area3_pref_area_kind_key), "0"));
        return areaKind == 0 ? AreaKind.TIME : AreaKind.DIST;
    }

    /**
     * 到達圏／流入圏範囲を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 到達圏／流入圏範囲
     */
    public static int getAreaRange(SharedPreferences prefs, Context context) {
        int areaRange = prefs.getInt(
                context.getString(R.string.calc_area3_pref_area_range_key), 10);
        return areaRange;
    }

    /**
     * 計算方法を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 計算方法
     */
    public static int getCalcKind(SharedPreferences prefs, Context context) {
        int calcKind = Integer
                .parseInt(prefs.getString(context
                        .getString(R.string.calc_area3_pref_calc_kind_key), "0"));
        return calcKind == 0 ? CalcKind.TIME : CalcKind.DIST;
    }

    /**
     * 到達圏／流入圏計算用輸送機関フラグを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 到達圏／流入圏計算用輸送機関フラグ
     */
    public static int getCATransportFlag(SharedPreferences prefs,
            Context context) {
        int flag = 0;
        String nwid = prefs.getString(
                context.getString(R.string.dcws_pref_nwid_key), "");
        if (DistUtils.isForWalker(nwid)) {
            int useRailway = CalcArea3PrefManager.getUseRailway(prefs, context);
            if (useRailway == 1) {
                flag += Constants.Transport.RAILROAD;
            }
            int useLimitedExpress = CalcArea3PrefManager.getUseLimitedExpress(
                    prefs, context);
            if (useRailway == 1 && useLimitedExpress == 1) {
                flag += Constants.Transport.LIMITED_EXPRESS_TRAIN;
            }
        } else {
            if (DistUtils.isForCar(nwid)) {
                if (CalcArea3PrefManager.getUseHighway(prefs, context) == 1) {
                    flag += Constants.Transport.HIGHWAY;
                }
            }
            if (DistUtils.isForFreightRailway(nwid)) {
                if (CalcArea3PrefManager.getUseFreightRailway(prefs, context) == 1) {
                    flag += Constants.Transport.RAILROAD;
                }
            }
            if (DistUtils.isForAirway(nwid)) {
                if (CalcArea3PrefManager.getUseAirway(prefs, context) == 1) {
                    flag += Constants.Transport.AIRWAY;
                }
            }
            if (DistUtils.isForFerry(nwid)) {
                if (CalcArea3PrefManager.getUseFerry(prefs, context) == 1) {
                    if (CalcArea3PrefManager.getUsePayRoadFerry(prefs, context) == 1) {
                        flag += Constants.Transport.PAYROAD_FERRY;
                    } else {
                        flag += Constants.Transport.FERRY;
                    }
                }
            }
            if (DistUtils.isForShip(nwid)) {
                if (CalcArea3PrefManager.getUseShip(prefs, context) == 1) {
                    flag += Constants.Transport.SHIP;
                }
            }
        }
        return flag;
    }

    /**
     * ドーナツポリゴンレベルを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ドーナツポリゴンレベル
     */
    public static int getDonutPolygonLevel(SharedPreferences prefs,
            Context context) {
        int donutPolygonLevel = prefs.getInt(context
                .getString(R.string.calc_area3_pref_donut_polygon_level_key),
                -2);
        return donutPolygonLevel;
    }

    /**
     * ポリゴン詳細を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ポリゴン詳細
     */
    public static int getPolygonDetail(SharedPreferences prefs, Context context) {
        int polygonDetail = Integer.parseInt(prefs.getString(
                context.getString(R.string.calc_area3_pref_polygon_detail_key),
                "0"));
        if (polygonDetail == 0) {
            return PolygonDetail.NONE;
        } else if (polygonDetail == 1) {
            return PolygonDetail.EXPAND_MIDDLE;
        } else if (polygonDetail == 2) {
            return PolygonDetail.EXPAND_TERMINAL;
        } else {
            return PolygonDetail.EXPAND_MIDDLE | PolygonDetail.EXPAND_TERMINAL;
        }
    }

    /**
     * ポリゴン種別を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ポリゴン種別
     */
    public static int getPolygonKind(SharedPreferences prefs, Context context) {
        int polygonKind = Integer.parseInt(prefs.getString(
                context.getString(R.string.calc_area3_pref_polygon_kind_key),
                "0"));
        return polygonKind == 0 ? PolygonKind.SIMPLE_POLYGON
                : PolygonKind.MULTI_POLYGON;
    }

    /**
     * ポリゴンレベルを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ポリゴンレベル
     */
    public static int getPolygonLevel(SharedPreferences prefs, Context context) {
        int polygonLevel = prefs.getInt(
                context.getString(R.string.calc_area3_pref_polygon_level_key),
                5);
        return polygonLevel;
    }

    /**
     * 航空機を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 航空機を使用するかどうか
     */
    public static int getUseAirway(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_area3_pref_use_airway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * フェリーを使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return フェリーを使用するかどうか
     */
    public static int getUseFerry(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_area3_pref_use_ferry_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 貨物鉄道を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 貨物鉄道を使用するかどうか
     */
    public static int getUseFreightRailway(SharedPreferences prefs,
            Context context) {
        boolean use = prefs.getBoolean(context
                .getString(R.string.calc_area3_pref_use_freight_railway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 高速道路を使用するかどうかを設定します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 高速道路を使用するかどうか
     */
    public static int getUseHighway(SharedPreferences prefs, Context context) {
        boolean useHighway = prefs.getBoolean(
                context.getString(R.string.calc_area3_pref_use_highway_key),
                false);
        return useHighway ? 1 : 0;
    }

    /**
     * 特急を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 特急を使用するかどうか
     */
    public static int getUseLimitedExpress(SharedPreferences prefs,
            Context context) {
        boolean useHighway = prefs.getBoolean(context
                .getString(R.string.calc_area3_pref_use_limited_express_key),
                false);
        return useHighway ? 1 : 0;
    }

    /**
     * 北海道～青森間、沖縄～鹿児島間のみフェリーを使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 北海道～青森間、沖縄～鹿児島間のみフェリーを使用するかどうか
     */
    public static int getUsePayRoadFerry(SharedPreferences prefs,
            Context context) {
        boolean use = prefs.getBoolean(context
                .getString(R.string.calc_area3_pref_use_pay_road_ferry_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 鉄道を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 鉄道を使用するかどうか
     */
    public static int getUseRailway(SharedPreferences prefs, Context context) {
        boolean useHighway = prefs.getBoolean(
                context.getString(R.string.calc_area3_pref_use_railway_key),
                false);
        return useHighway ? 1 : 0;
    }

    /**
     * 内航船を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 内航船を使用するかどうか
     */
    public static int getUseShip(SharedPreferences prefs, Context context) {
        boolean use = prefs
                .getBoolean(context
                        .getString(R.string.calc_area3_pref_use_ship_key),
                        false);
        return use ? 1 : 0;
    }
}
