﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import jp.co.act_inc.actservicesample.adminservice.Constants;
import jp.co.act_inc.actservicesample.adminservice.Constants.CalcKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.Datum;
import jp.co.act_inc.actservicesample.adminservice.Constants.HighwayOutput;
import jp.co.act_inc.actservicesample.adminservice.Constants.PntsOutput;
import jp.co.act_inc.actservicesample.adminservice.Constants.RnsOutput;
import jp.co.act_inc.actservicesample.adminservice.Constants.RouteKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.TollOutput;
import jp.co.act_inc.actservicesample.adminservice.Constants.TrdsOutput;
import jp.co.act_inc.actservicesample.dcservice.CRParam;
import jp.co.act_inc.actservicesample.dcservice.DistUtils;
import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;

/**
 * ルート計算のプリファレンスを管理します。
 * 
 * @author ishi
 * 
 */
public class CalcRoutePrefManager {

    /**
     * CRParamを作成します。
     * 
     * @param context
     *            コンテキスト
     * @return CRParam
     */
    public static CRParam createCRParam(Context context) {
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(context);
        CRParam param = new CRParam();
        param.setDatum(Datum.Jgd2000);
        param.setCalcKind(CalcRoutePrefManager.getCalcKind(prefs, context));
        int flag = CalcRoutePrefManager.getCRTransportFlag(prefs, context);
        param.setTransport(flag);
        param.setPntsOutput(PntsOutput.OUTPUT);
        param.setRnsOutput(RnsOutput.OUTPUT);
        param.setTrdsOutput(TrdsOutput.OUTPUT);
        param.setHighwayOutput(HighwayOutput.OUTPUT);
        param.setTollOutput(TollOutput.OUTPUT);
        param.setRouteKind(CalcRoutePrefManager.getRouteKind(prefs, context));
        return param;
    }

    /**
     * 計算方法を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 計算方法
     */
    public static int getCalcKind(SharedPreferences prefs, Context context) {
        int calcKind = Integer
                .parseInt(prefs.getString(context
                        .getString(R.string.calc_route_pref_calc_kind_key), "0"));
        return calcKind == 0 ? CalcKind.TIME : CalcKind.DIST;
    }

    /**
     * ルート計算用輸送機関フラグを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ルート計算用輸送機関フラグ
     */
    public static int getCRTransportFlag(SharedPreferences prefs,
            Context context) {
        int flag = 0;
        String nwid = prefs.getString(
                context.getString(R.string.dcws_pref_nwid_key), "");
        if (DistUtils.isForWalker(nwid)) {
            int useRailway = CalcRoutePrefManager.getUseRailway(prefs, context);
            if (useRailway == 1) {
                flag += Constants.Transport.RAILROAD;
            }
            int useLimitedExpress = CalcRoutePrefManager.getUseLimitedExpress(
                    prefs, context);
            if (useRailway == 1 && useLimitedExpress == 1) {
                flag += Constants.Transport.LIMITED_EXPRESS_TRAIN;
            }
        } else {
            if (DistUtils.isForCar(nwid)) {
                if (CalcRoutePrefManager.getUseHighway(prefs, context) == 1) {
                    flag += Constants.Transport.HIGHWAY;
                }
            }
            if (DistUtils.isForFreightRailway(nwid)) {
                if (CalcRoutePrefManager.getUseFreightRailway(prefs, context) == 1) {
                    flag += Constants.Transport.RAILROAD;
                }
            }
            if (DistUtils.isForAirway(nwid)) {
                if (CalcRoutePrefManager.getUseAirway(prefs, context) == 1) {
                    flag += Constants.Transport.AIRWAY;
                }
            }
            if (DistUtils.isForFerry(nwid)) {
                if (CalcRoutePrefManager.getUseFerry(prefs, context) == 1) {
                    if (CalcRoutePrefManager.getUsePayRoadFerry(prefs, context) == 1) {
                        flag += Constants.Transport.PAYROAD_FERRY;
                    } else {
                        flag += Constants.Transport.FERRY;
                    }
                }
            }
            if (DistUtils.isForShip(nwid)) {
                if (CalcRoutePrefManager.getUseShip(prefs, context) == 1) {
                    flag += Constants.Transport.SHIP;
                }
            }
        }
        return flag;
    }

    /**
     * ルート種別を取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return ルート種別
     */
    public static int getRouteKind(SharedPreferences prefs, Context context) {
        int routeKind = Integer
                .parseInt(prefs.getString(context
                        .getString(R.string.calc_route_pref_route_kind_key),
                        "0"));
        return routeKind == 0 ? RouteKind.SIMPLE : RouteKind.DETAIL;
    }

    /**
     * 航空機を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 航空機を使用するかどうか
     */
    public static int getUseAirway(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_route_pref_use_airway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * フェリーを使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return フェリーを使用するかどうか
     */
    public static int getUseFerry(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_route_pref_use_ferry_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 貨物鉄道を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 貨物鉄道を使用するかどうか
     */
    public static int getUseFreightRailway(SharedPreferences prefs,
            Context context) {
        boolean use = prefs.getBoolean(context
                .getString(R.string.calc_route_pref_use_freight_railway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 高速道路を使用するかどうかを設定します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 高速道路を使用するかどうか
     */
    public static int getUseHighway(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_route_pref_use_highway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 特急を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 特急を使用するかどうか
     */
    public static int getUseLimitedExpress(SharedPreferences prefs,
            Context context) {
        boolean use = prefs.getBoolean(context
                .getString(R.string.calc_route_pref_use_limited_express_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 北海道～青森間、沖縄～鹿児島間のみフェリーを使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 北海道～青森間、沖縄～鹿児島間のみフェリーを使用するかどうか
     */
    public static int getUsePayRoadFerry(SharedPreferences prefs,
            Context context) {
        boolean use = prefs.getBoolean(context
                .getString(R.string.calc_route_pref_use_pay_road_ferry_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 鉄道を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 鉄道を使用するかどうか
     */
    public static int getUseRailway(SharedPreferences prefs, Context context) {
        boolean use = prefs.getBoolean(
                context.getString(R.string.calc_route_pref_use_railway_key),
                false);
        return use ? 1 : 0;
    }

    /**
     * 内航船を使用するかどうかを取得します。
     * 
     * @param prefs
     *            共有設定
     * @param context
     *            コンテキスト
     * @return 内航船を使用するかどうか
     */
    public static int getUseShip(SharedPreferences prefs, Context context) {
        boolean use = prefs
                .getBoolean(context
                        .getString(R.string.calc_route_pref_use_ship_key),
                        false);
        return use ? 1 : 0;
    }
}
