﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import android.os.Parcel;
import android.os.Parcelable;
import jp.co.act_inc.actservicesample.adminservice.Constants.AddressLevel;
import jp.co.act_inc.actservicesample.gcservice.AddressItem;

/**
 * 住所レベル別住所データです。
 * 
 * @author ishi
 * 
 */
public class LeveledAddressItem implements Parcelable {
    /**
     * 住所区切り文字
     */
    private static final String DELIMITER = "-";

    /**
     * 都道府県住所アイテム
     */
    private AddressItem prefItem;
    /**
     * 市区町村住所アイテム
     */
    private AddressItem cityItem;
    /**
     * 大字丁目住所アイテム
     */
    private AddressItem streetItem;
    /**
     * 街区住所アイテム
     */
    private AddressItem blockItem;
    /**
     * 号住所アイテム
     */
    private AddressItem houseItem;

    public static final Parcelable.Creator<LeveledAddressItem> CREATOR = new Parcelable.Creator<LeveledAddressItem>() {
        @Override
        public LeveledAddressItem createFromParcel(Parcel in) {
            return new LeveledAddressItem(in);
        }

        @Override
        public LeveledAddressItem[] newArray(int size) {
            return new LeveledAddressItem[size];
        }
    };

    /**
     * コンストラクター
     */
    public LeveledAddressItem() {
    }

    /**
     * コンストラクター
     * 
     * @param in
     *            読み込むParcel
     */
    public LeveledAddressItem(Parcel in) {
        prefItem = in.readParcelable(null);
        cityItem = in.readParcelable(null);
        streetItem = in.readParcelable(null);
        blockItem = in.readParcelable(null);
        houseItem = in.readParcelable(null);
    }

    /**
     * クリアします。
     */
    public void clear() {
        prefItem = null;
        cityItem = null;
        streetItem = null;
        blockItem = null;
        houseItem = null;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return blockItem
     */
    public AddressItem getBlockItem() {
        return this.blockItem;
    }

    /**
     * @return cityItem
     */
    public AddressItem getCityItem() {
        return this.cityItem;
    }

    /**
     * 選択中の住所を取得します。
     * 
     * @return 住所
     */
    public String getFullAddress() {
        StringBuffer fullAddress = new StringBuffer();
        if (prefItem != null) {
            fullAddress.append(prefItem.getAddress());
        }
        if (cityItem != null) {
            fullAddress.append(cityItem.getAddress());
        }
        if (streetItem != null) {
            fullAddress.append(streetItem.getAddress());
        }
        if (blockItem != null) {
            Utilities.appendDelimiter(fullAddress, blockItem.getAddress(),
                    DELIMITER);
            fullAddress.append(blockItem.getAddress());
        }
        if (houseItem != null) {
            Utilities.appendDelimiter(fullAddress, houseItem.getAddress(),
                    DELIMITER);
            fullAddress.append(houseItem.getAddress());
        }
        return fullAddress.toString();
    }

    /**
     * @return houseItem
     */
    public AddressItem getHouseItem() {
        return this.houseItem;
    }

    /**
     * 最も下位の住所アイテムを取得します。
     * 
     * @return 最も下位の住所アイテム
     */
    public AddressItem getLowerestItem() {
        AddressItem item = null;
        if (houseItem != null) {
            item = houseItem;
        } else if (blockItem != null) {
            item = blockItem;
        } else if (streetItem != null) {
            item = streetItem;
        } else if (cityItem != null) {
            item = cityItem;
        } else if (prefItem != null) {
            item = prefItem;
        }
        return item;
    }

    /**
     * @return prefItem
     */
    public AddressItem getPrefItem() {
        return this.prefItem;
    }

    /**
     * @return streetItem
     */
    public AddressItem getStreetItem() {
        return this.streetItem;
    }

    /**
     * @param blockItem
     *            セットする blockItem
     */
    public void setBlockItem(AddressItem blockItem) {
        this.blockItem = blockItem;
    }

    /**
     * @param cityItem
     *            セットする cityItem
     */
    public void setCityItem(AddressItem cityItem) {
        this.cityItem = cityItem;
    }

    /**
     * @param houseItem
     *            セットする houseItem
     */
    public void setHouseItem(AddressItem houseItem) {
        this.houseItem = houseItem;
    }

    /**
     * 指定住所レベルにアイテムを設定します。
     * 
     * @param addressLevel
     *            住所レベル
     * @param item
     *            住所アイテム
     */
    public void setItem(int addressLevel, AddressItem item) {
        switch (addressLevel) {
        case AddressLevel.PREF:
            prefItem = item;
            break;
        case AddressLevel.CITY:
            cityItem = item;
            break;
        case AddressLevel.STREET:
            streetItem = item;
            break;
        case AddressLevel.BLOCK:
            blockItem = item;
            break;
        case AddressLevel.HOUSE:
            houseItem = item;
            break;
        default:
            break;
        }
    }

    /**
     * @param prefItem
     *            セットする prefItem
     */
    public void setPrefItem(AddressItem prefItem) {
        this.prefItem = prefItem;
    }

    /**
     * @param streetItem
     *            セットする streetItem
     */
    public void setStreetItem(AddressItem streetItem) {
        this.streetItem = streetItem;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeParcelable(prefItem, flags);
        dest.writeParcelable(cityItem, flags);
        dest.writeParcelable(streetItem, flags);
        dest.writeParcelable(blockItem, flags);
        dest.writeParcelable(houseItem, flags);
    }

}
