﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Locale;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

/**
 * 地点用レイヤーです。
 * 
 * @author ishi
 * 
 */
public class LocLayer extends MapLayer {
    /**
     * マーカーと地点を格納します。
     * 
     * @author ishi
     * 
     */
    class MarkerHolder {
        /**
         * マーカー
         */
        Marker marker;

        /**
         * 地点
         */
        Loc loc;

        /**
         * コンストラクター
         * 
         * @param marker
         *            マーカー
         * @param loc
         *            地点
         */
        MarkerHolder(Marker marker, Loc loc) {
            this.marker = marker;
            this.loc = loc;
        }
    }

    /**
     * アプリケーションクラス
     */
    private MyApp app;

    /**
     * マーカーリスト
     */
    private ArrayList<MarkerHolder> markers = new ArrayList<MarkerHolder>();

    /**
     * コンストラクター
     * 
     * @param myApp
     *            アプリケーションクラス
     */
    public LocLayer(MyApp myApp) {
        this.app = myApp;
    }

    @Override
    public void addObject(GoogleMap map) {
        clear();

        // 計算結果マーカー追加
        int startIndex = -1;
        ArrayList<Loc> resultLocs = null;
        CalcResultHolder result = app.getResult();
        if (result != null) {
            if (result.getCalcRouteResponse() != null) {
                startIndex = -1;
                result.getCalcRouteResponse().getLocs();
                resultLocs = result.getCalcRouteResponse().getLocs();
            } else if (result.getCalcOptRouteResponse() != null) {
                startIndex = -1;
                result.getCalcOptRouteResponse().getLocs();
                resultLocs = result.getCalcOptRouteResponse().getLocs();
            } else if (result.getCalcArea3Response() != null) {
                startIndex = 0;
                resultLocs = new ArrayList<Loc>();
                resultLocs.add(result.getCalcArea3Response().getStartLoc());
            } else if (result.getCalcOneWay3Response() != null) {
                startIndex = result.getCalcOneWay3Response().getStartIndex();
                resultLocs = result.getCalcOneWay3Response().getLocs();
            }
        }

        ArrayList<String> addedMarkers = new ArrayList<String>();
        if (resultLocs != null) {
            for (int i = 0; i < resultLocs.size(); ++i) {
                String title;
                String message;
                if (startIndex != i) {
                    if (resultLocs.get(i).getTime() >= 0) {
                        title = String.format(Locale.getDefault(), "%d 「%s」",
                                i + 1, resultLocs.get(i).getTag());
                        message = String.format(
                                Locale.getDefault(),
                                "%d%s %.1f%s",
                                resultLocs.get(i).getTime(),
                                app.getApplicationContext().getString(
                                        R.string.unit_minute),
                                resultLocs.get(i).getDist() / 1000.0,
                                app.getApplicationContext().getString(
                                        R.string.unit_km));
                    } else {
                        // 圏外
                        title = String.format(Locale.getDefault(), "「%s」",
                                resultLocs.get(i).getTag());
                        message = String.format(
                                Locale.getDefault(),
                                "%s",
                                app.getApplicationContext().getString(
                                        R.string.common_not_reach));
                    }
                } else {
                    // 基点
                    title = String.format(Locale.getDefault(), "「%s」",
                            resultLocs.get(i).getTag());
                    message = app.getApplicationContext().getString(
                            R.string.common_start_point);
                }
                Marker marker = map
                        .addMarker(new MarkerOptions()
                                .position(
                                        new LatLng(resultLocs.get(i).getLat(),
                                                resultLocs.get(i).getLon()))
                                .title(title)
                                .snippet(message)
                                .icon(BitmapDescriptorFactory
                                        .defaultMarker(BitmapDescriptorFactory.HUE_AZURE)));
                markers.add(new MarkerHolder(marker, resultLocs.get(i)));
                addedMarkers.add(String.format(Locale.getDefault(),
                        "%.6f-%.6f", marker.getPosition().longitude,
                        marker.getPosition().latitude));
            }
            Collections.sort(addedMarkers);
        }

        // 計算地点マーカー追加
        ArrayList<Loc> locs = null;
        locs = app.getLocs();
        if (locs == null || locs.size() == 0) {
            return;
        }

        for (Loc loc : locs) {
            if (Collections.binarySearch(
                    addedMarkers,
                    String.format(Locale.getDefault(), "%.6f-%.6f",
                            loc.getLon(), loc.getLat())) < 0) {
                Marker marker = map.addMarker(new MarkerOptions().position(
                        new LatLng(loc.getLat(), loc.getLon())).title(
                        loc.getTag()));
                marker.setDraggable(true);
                markers.add(new MarkerHolder(marker, loc));
            }
        }
    }

    @Override
    public void clear() {
        for (MarkerHolder markerHolder : this.markers) {
            markerHolder.marker.remove();
        }
        this.markers.clear();
    }

    /**
     * 地点を移動します。
     * 
     * @param marker
     *            マーカー
     */
    public void moveLoc(Marker marker) {
        for (MarkerHolder markerHolder : this.markers) {
            if (markerHolder.marker.equals(marker)) {
                markerHolder.loc.setLon(marker.getPosition().longitude);
                markerHolder.loc.setLat(marker.getPosition().latitude);
            }
        }
        this.app.writeLocs();
    }
}