﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.ArrayList;
import java.util.Date;

import jp.co.act_inc.actservicesample.adminservice.UserInformation2;
import jp.co.act_inc.actservicesample.db.LocsDBManger;
import jp.co.act_inc.actservicesample.db.ResultsDBManger;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.Loc;

import android.app.Application;

/**
 * アプリケーションクラスです。
 * 
 * @author ishi
 * 
 */
public class MyApp extends Application {
    /**
     * 計算地点リスト
     */
    private ArrayList<Loc> locs;
    /**
     * 計算結果
     */
    private CalcResultHolder result;
    /**
     * 計算結果同期オブジェクト
     */
    private Object resultLock = new Object();
    /**
     * 計算結果がロード済みかどうか
     */
    private boolean resultLoaded = false;

    /**
     * 計算地点を追加します。
     * 
     * @param loc
     *            追加する計算地点
     */
    public void addLoc(Loc loc) {
        int locNumber = AdminPrefManager.getLocNumber(getApplicationContext());
        if (loc.getTag() == null || loc.getTag().equals("")) {
            loc.setTag(Integer.toString(locNumber));
        }
        AdminPrefManager.writeLocNumber(getApplicationContext(), locNumber + 1);
        if (AdminPrefManager.getStartLocIndex(getApplicationContext()) < 0) {
            AdminPrefManager.writeStartLocIndex(getApplicationContext(), 0);
        }
        if (locs == null) {
            locs = getLocs();
        }
        locs.add(loc);
        writeLocs();
    }

    /**
     * 計算結果を追加します。
     * 
     * @param result
     *            追加する計算結果
     */
    public void addResult(CalcResultHolder result) {
        ResultsDBManger resultsMan = new ResultsDBManger(
                getApplicationContext());
        clearResult();
        resultsMan.insert(result);
        synchronized (resultLock) {
            if (this.result != null && this.result.getLayer() != null) {
                this.result.getLayer().clear();
            }
            this.result = result;
        }
    }

    /**
     * 計算地点をクリアします。
     */
    public void clearLocs() {
        LocsDBManger man = new LocsDBManger(getApplicationContext());
        man.delete();
        setStartLocIndex(-1);
        AdminPrefManager.writeLocNumber(getApplicationContext(), 1);
        locs.clear();
    }

    /**
     * 計算結果をクリアします。
     */
    public void clearResult() {
        ResultsDBManger resultsMan = new ResultsDBManger(
                getApplicationContext());
        resultsMan.deleteAll();

        synchronized (resultLock) {
            if (this.result != null && this.result.getLayer() != null) {
                this.result.getLayer().clear();
            }
            this.result = null;
        }
    }

    /**
     * ユーザーID取得日時を取得します。
     * 
     * @return ユーザーID取得日時
     */
    public Date getAccessTime() {
        return AdminPrefManager.getAccessTime(getApplicationContext());
    }

    /**
     * 最終距離計算日時を取得します。
     * 
     * @return 最終距離計算日時
     */
    public long getLastDistCalcTime() {
        return AdminPrefManager.getListDistCalcTime(getApplicationContext())
                .getTime();
    }

    /**
     * 最終住所検索日時を取得します。
     * 
     * @return 最終住所検索日時
     */
    public long getLastGeoCalcTime() {
        return AdminPrefManager.getListGeoCalcTime(getApplicationContext())
                .getTime();
    }

    /**
     * 計算地点リストを取得します。
     * 
     * @return 計算地点リスト
     */
    public ArrayList<Loc> getLocs() {
        if (locs == null) {
            LocsDBManger man = new LocsDBManger(getApplicationContext());
            locs = man.get();
        }
        return locs;
    }

    /**
     * 計算結果を取得します。
     * 
     * @return 計算結果
     */
    public CalcResultHolder getResult() {
        synchronized (resultLock) {
            return result;
        }
    }

    /**
     * 基点インデックスを取得します。
     * 
     * @return 基点インデックス
     */
    public int getStartLocIndex() {
        return AdminPrefManager.getStartLocIndex(getApplicationContext());
    }

    /**
     * ユーザー情報を取得します。
     * 
     * @return ユーザー情報
     */
    public UserInformation2 getUserInfo() {
        return AdminPrefManager.getUserInfo(getApplicationContext());
    }

    /**
     * 計算結果がロード済みかどうか取得する。
     * 
     * @return 計算結果がロード済みの場合はtrue
     */
    public boolean isResultLoaded() {
        return resultLoaded;
    }

    /**
     * 計算結果をロードします。
     * 
     */
    public void loadResult() {
        ResultsDBManger resultsMan = new ResultsDBManger(
                getApplicationContext());
        CalcResultHolder result = resultsMan.get();
        synchronized (resultLock) {
            this.result = result;
        }

        resultLoaded = true;
    }

    @Override
    public void onCreate() {
        Logger.writeDebugLog("MyApp", "onCreate");
        super.onCreate();
    }

    /**
     * 計算地点を削除します。
     * 
     * @param position
     *            削除する計算地点の位置
     */
    public void removeLoc(int position) {
        LocsDBManger man = new LocsDBManger(getApplicationContext());
        if (locs == null) {
            locs = getLocs();
        }
        locs.remove(position);
        man.delete();
        man.insert(locs);
        int startIndex = AdminPrefManager
                .getStartLocIndex(getApplicationContext());
        if (position > 0 && position <= startIndex) {
            AdminPrefManager.writeStartLocIndex(getApplicationContext(),
                    startIndex - 1);
        }
        if (locs.size() == 0) {
            AdminPrefManager.writeStartLocIndex(getApplicationContext(), -1);
        }
    }

    /**
     * 最終距離計算日時を設定します。
     * 
     * @param lastDistCalcTime
     *            最終距離計算日時
     */
    public void setLastDistCalcTime(long lastDistCalcTime) {
        Date date = new Date(lastDistCalcTime);
        AdminPrefManager.writeLastDistCalcTime(getApplicationContext(), date);
    }

    /**
     * 最終住所検索日時を設定します。
     * 
     * @param lastGeoCalcTime
     *            最終住所検索日時
     */
    public void setLastGeoCalcTime(long lastGeoCalcTime) {
        Date date = new Date(lastGeoCalcTime);
        AdminPrefManager.writeLastGeoCalcTime(getApplicationContext(), date);
    }

    /**
     * 基点インデックスを設定します。
     * 
     * @param startLocIndex
     *            基点インデックス
     */
    public void setStartLocIndex(int startLocIndex) {
        AdminPrefManager.writeStartLocIndex(getApplicationContext(),
                startLocIndex);
    }

    /**
     * ユーザー情報を設定します。
     * 
     * @param userInfo
     *            ユーザー情報
     */
    public void setUserInfo(UserInformation2 userInfo) {
        AdminPrefManager.deleteUserInfo(getApplicationContext());
        AdminPrefManager.writeUserInfo(getApplicationContext(), userInfo);
        AdminPrefManager.writeAccessTime(getApplicationContext(), new Date());
        if (AdminPrefManager.getLocNumber(getApplicationContext()) == 0) {
            AdminPrefManager.writeLocNumber(getApplicationContext(), 1);
        }
    }

    /**
     * 計算地点を更新します。
     * 
     * @param loc
     *            更新後の計算地点
     * @param position
     *            更新する計算地点の位置
     */
    public void updateLoc(Loc loc, int position) {
        LocsDBManger man = new LocsDBManger(getApplicationContext());
        man.update(loc, position);
        if (locs == null) {
            locs = getLocs();
        }
        locs.set(position, loc);
    }

    /**
     * 計算地点リストをDBに書き込みます。
     */
    public void writeLocs() {
        LocsDBManger man = new LocsDBManger(getApplicationContext());
        man.delete();
        man.insert(locs);
    }
}
