﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.Pnt;
import android.graphics.Color;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Polygon;
import com.google.android.gms.maps.model.PolygonOptions;

/**
 * ポリゴン用レイヤーです。
 * 
 * @author ishi
 * 
 */
public class PolygonLayer extends MapLayer {
    /**
     * 到達圏／流入圏の色
     */
    private static final int COLOR_AREA = Color.argb(0x00, 0x0, 0x0, 0xff);
    /**
     * 到達圏／流入圏の線の太さ
     */
    private static final int LINE_WIDTH = 4;
    /**
     * 到達圏／流入圏の線の色
     */
    private static final int COLOR_LINE = Color.argb(0x7f, 0x0, 0x0, 0xff);

    /**
     * ドーナツポリゴンの色
     */
    private static final int COLOR_DONUT = Color.argb(0x00, 0xff, 0x0, 0x0);
    /**
     * ドーナツポリゴンの線の太さ
     */
    private static final int LINE_WIDTH_DONUT = 4;
    /**
     * ドーナツポリゴンの線の色
     */
    private static final int COLOR_LINE_DONUT = Color
            .argb(0x7f, 0xff, 0x0, 0x0);

    /**
     * ポリゴンオプションリスト
     */
    private ArrayList<PolygonOptions> polygonOptionsList = new ArrayList<PolygonOptions>();

    /**
     * ポリゴンリスト
     */
    private ArrayList<Polygon> polygones = new ArrayList<Polygon>();

    /**
     * コンストラクタ
     * 
     * @param myApp
     *            アプリケーションクラス
     * @param result
     *            計算結果
     */
    public PolygonLayer(MyApp myApp, CalcResultHolder result) {
        ArrayList<Pnt> pnts;
        if (result.getCalcArea3Response() != null) {
            pnts = result.getCalcArea3Response().getPnts();
        } else if (result.getCalcOneWay3Response() != null) {
            pnts = new ArrayList<Pnt>();
        } else {
            throw new IllegalArgumentException();
        }

        float density = myApp.getApplicationContext().getResources()
                .getDisplayMetrics().density;

        // ポリゴンオプション作成
        PolygonOptions options = null;
        LinkedList<LatLng> current = new LinkedList<LatLng>();
        int delimiterCount = 0;
        boolean isPolygon = true;
        LatLng prev = null;
        for (Pnt pnt : pnts) {
            LatLng polygonPnt = new LatLng(pnt.getLat(), pnt.getLon());
            if (!(polygonPnt.latitude == 0 && polygonPnt.longitude == 0)) {
                delimiterCount = 0;
                if (prev == null
                        || !(prev.longitude == polygonPnt.longitude && prev.latitude == polygonPnt.latitude)) {
                    current.add(polygonPnt);
                    prev = polygonPnt;
                }
            } else {
                if (current.size() > 3) {
                    Collections.reverse(current);
                    if (isPolygon) {
                        options = new PolygonOptions();
                        options.fillColor(COLOR_AREA);
                        options.strokeColor(COLOR_LINE);
                        options.strokeWidth(LINE_WIDTH * density);
                        options.addAll(current);
                    } else {
                        options = new PolygonOptions();
                        options.fillColor(COLOR_DONUT);
                        options.strokeColor(COLOR_LINE_DONUT);
                        options.strokeWidth(LINE_WIDTH_DONUT * density);
                        options.addAll(current);
                    }
                }
                current = new LinkedList<LatLng>();
                prev = null;
                if (delimiterCount == 0) {
                    delimiterCount = 1;
                    isPolygon = false;
                    if (options != null) {
                        polygonOptionsList.add(options);
                        options = null;
                    }
                } else if (delimiterCount == 1) {
                    delimiterCount = 2;
                    isPolygon = true;
                } else {
                    break;
                }
            }
        }
    }

    @Override
    public void addObject(GoogleMap map) {
        clear();
        // ポリゴンを追加
        for (PolygonOptions options : polygonOptionsList) {
            polygones.add(map.addPolygon(options));
        }
    }

    @Override
    public void clear() {
        for (Polygon polygon : polygones) {
            polygon.remove();
        }
    }
}
