﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.ArrayList;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.Pnt;
import android.graphics.Color;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Polyline;
import com.google.android.gms.maps.model.PolylineOptions;

/**
 * ポリライン用レイヤーです。
 * 
 * @author ishi
 * 
 */
public class PolylineLayer extends MapLayer {
    /**
     * ルートの色
     */
    private static final int COLOR_ROUTE = Color.argb(0x7f, 0xff, 0, 0);

    /**
     * 線の太さ
     */
    private static final int LINE_WIDTH = 4;

    /**
     * 経緯度リスト
     */
    private ArrayList<LatLng> linePnts = new ArrayList<LatLng>();

    /**
     * ポリライン
     */
    private Polyline polyline;

    /**
     * 画面密度
     */
    float density;

    /**
     * コンストラクター
     * 
     * @param myApp
     *            アプリケーションクラス
     * @param result
     *            計算結果
     */
    public PolylineLayer(MyApp myApp, CalcResultHolder result) {
        density = myApp.getApplicationContext().getResources()
                .getDisplayMetrics().density;

        ArrayList<Pnt> pnts;
        if (result.getCalcRouteResponse() != null) {
            result.getCalcRouteResponse().getLocs();
            pnts = result.getCalcRouteResponse().getPnts();
        } else if (result.getCalcOptRouteResponse() != null) {
            result.getCalcOptRouteResponse().getLocs();
            pnts = result.getCalcOptRouteResponse().getPnts();
        } else {
            throw new IllegalArgumentException();
        }

        for (Pnt pnt : pnts) {
            linePnts.add(new LatLng(pnt.getLat(), pnt.getLon()));
        }
    }

    @Override
    public void addObject(GoogleMap map) {
        clear();

        // ポリライン追加
        PolylineOptions lineOptions = new PolylineOptions();
        lineOptions.color(COLOR_ROUTE);
        lineOptions.width(LINE_WIDTH * density);
        lineOptions.addAll(linePnts);
        polyline = map.addPolyline(lineOptions);
    }

    @Override
    public void clear() {
        if (polyline != null) {
            polyline.remove();
        }
    }
}
