﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/15 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import android.content.Context;
import android.preference.DialogPreference;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

/**
 * 入力範囲が指定できるエディット設定です。
 * 
 * @author ishi
 * 
 */
public class RangedEditPreference extends DialogPreference {
    private static final String ACT_NS = "http://schemas.android.com/apk/res/jp.co.act_inc.actservicesample";
    private static final String ANDROID_NS = "http://schemas.android.com/apk/res/android";
    private static final String ATTR_DEFAULT_VALUE = "defaultValue";
    private static final String ATTR_MAX = "max";
    private static final String ATTR_MIN = "min";
    private static final int DEFAULT_MAX = 100;
    private static final int DEFAULT_MIN = 0;

    /**
     * 既定値
     */
    private int defaultValue;
    /**
     * 最大値
     */
    private int max;
    /**
     * 最小値
     */
    private int min;
    private EditText value;
    private TextView labelMin;
    private TextView labelMax;
    private TextView labelValue;

    /**
     * コンストラクタ―
     * 
     * @param context
     *            コンテキスト
     * @param attrs
     *            属性
     */
    public RangedEditPreference(Context context, AttributeSet attrs) {
        super(context, attrs);

        min = attrs.getAttributeIntValue(ACT_NS, ATTR_MIN, DEFAULT_MIN);
        max = attrs.getAttributeIntValue(ANDROID_NS, ATTR_MAX, DEFAULT_MAX);
        defaultValue = attrs.getAttributeIntValue(ANDROID_NS,
                ATTR_DEFAULT_VALUE, min);
    }

    /**
     * コンストラクタ―
     * 
     * @param context
     *            コンテキスト
     * @param attrs
     *            属性
     * @param defStyle
     *            スタイル
     */
    public RangedEditPreference(Context context, AttributeSet attrs,
            int defStyle) {
        super(context, attrs, defStyle);

        min = attrs.getAttributeIntValue(ACT_NS, ATTR_MIN, DEFAULT_MIN);
        max = attrs.getAttributeIntValue(ANDROID_NS, ATTR_MAX, DEFAULT_MAX);
        defaultValue = attrs.getAttributeIntValue(ANDROID_NS,
                ATTR_DEFAULT_VALUE, min);
    }

    /**
     * @return max
     */
    public int getMax() {
        return this.max;
    }

    /**
     * @return min
     */
    public int getMin() {
        return this.min;
    }

    /**
     * @param max
     *            セットする max
     */
    public void setMax(int max) {
        this.max = max;
    }

    /**
     * @param min
     *            セットする min
     */
    public void setMin(int min) {
        this.min = min;
    }

    @Override
    protected void onBindDialogView(View view) {
        super.onBindDialogView(view);

        labelMin = (TextView) view.findViewById(R.id.textView_min);
        labelMin.setText(String.format("%s：%d",
                getContext().getString(R.string.common_min_value), min));
        labelMax = (TextView) view.findViewById(R.id.textView_max);
        labelMax.setText(String.format("%s：%d",
                getContext().getString(R.string.common_max_value), max));
        labelValue = (TextView) view.findViewById(R.id.textView_value);
        labelValue.setText(String.format("%s：%d",
                getContext().getString(R.string.common_current_value),
                getPersistedInt(defaultValue)));
        value = (EditText) view
                .findViewById(R.id.editText_ranged_edit_pref_value);
    }

    @Override
    protected View onCreateDialogView() {
        LayoutInflater inflater = (LayoutInflater) getContext()
                .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        View view = inflater.inflate(R.layout.ranged_edit_preference, null);

        return view;
    }

    @Override
    protected void onDialogClosed(boolean positiveResult) {
        if (positiveResult) {
            try {
                int num = Integer.parseInt(value.getText().toString());
                if (num >= min && num <= max) {
                    persistInt(num);
                } else {
                    Toast.makeText(
                            getContext(),
                            getContext().getString(
                                    R.string.msg_input_invalid_value),
                            Toast.LENGTH_SHORT).show();
                }
            } catch (NumberFormatException ex) {
                Toast.makeText(
                        getContext(),
                        getContext()
                                .getString(R.string.msg_input_invalid_value),
                        Toast.LENGTH_SHORT).show();
            }
        }
        super.onDialogClosed(positiveResult);
    }
}
