﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample;

import java.util.Calendar;
import java.util.Date;

import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentManager;

/**
 * ユーティリティクラスです。
 * 
 * @author ishi
 * 
 */
public class Utilities {
    /**
     * 数字が連続する場合に区切り文字を追加します。
     * 
     * @param fullAddress
     *            住所バッファー
     * @param str
     *            追加する住所
     * @param delimiter
     *            区切り文字
     */
    public static void appendDelimiter(StringBuffer fullAddress, String str,
            String delimiter) {
        boolean endIsDigit = false;
        boolean headIsDigit = false;
        if (fullAddress.length() > 0) {
            endIsDigit = Character.isDigit(fullAddress.charAt(fullAddress
                    .length() - 1));
        }
        if (str.length() > 0) {
            headIsDigit = Character.isDigit(str.charAt(0));
        }
        if (endIsDigit && headIsDigit) {
            fullAddress.append(delimiter);
        }
    }

    /**
     * 日にちを比較します。
     * 
     * @param date1
     *            比較するDate
     * @param date2
     *            比較するDate
     * @return　date1がdate2より前の場合、正の数で日数の差が返ります。 date1がdate2より後の場合、負の数で日数の差が返ります。
     */
    public static long compareDate(Date date1, Date date2) {
        Calendar cal1 = Calendar.getInstance();
        Calendar cal2 = Calendar.getInstance();
        cal1.setTime(date1);
        cal2.setTime(date2);
        long span = cal2.getTimeInMillis() - cal1.getTimeInMillis();
        return span / (1000 * 60 * 60 * 24);
    }

    /**
     * 文字列中の全角数字を半角数字に変換します。
     * 
     * @param src
     *            元になる文字列
     * @return 変換後文字列
     */
    public static String convertToHankakuNum(String src) {
        StringBuilder buffer = new StringBuilder(src);
        for (int i = 0; i < buffer.length(); ++i) {
            char c = buffer.charAt(i);
            if (0xFF10 <= c && c <= 0xFF19) {
                buffer.setCharAt(i, (char) (c - 0xFEE0));
            }
        }
        return buffer.toString();
    }

    /**
     * DialogFragmentを閉じます。
     * 
     * @param tag
     *            ダイアログのタグ名
     * @param fragmentManager
     *            FragmentManager
     */
    public static void dismissDialog(String tag, FragmentManager fragmentManager) {
        DialogFragment frag = (DialogFragment) fragmentManager
                .findFragmentByTag(tag);
        if (frag != null) {
            frag.dismiss();
        }
    }

    /**
     * DialogFragmentを表示します。
     * 
     * @param dialog
     *            ダイアログ
     * @param tag
     *            ダイアログのタグ名
     * @param fragmentManager
     *            FragmentManager
     */
    public static void showDialog(DialogFragment dialog, String tag,
            FragmentManager fragmentManager) {
        dialog.show(fragmentManager, tag);
    }
}
