﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import com.google.android.gms.common.GooglePlayServicesUtil;

import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.MenuDialogFragment;
import jp.co.act_inc.actservicesample.activity.InformationDialogFragment.OnInformationDialogListener;
import jp.co.act_inc.actservicesample.activity.MenuDialogFragment.OnMenuDialogListener;
import jp.co.act_inc.actservicesample.activity.ActMapFragment;
import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageButton;

/**
 * メイン画面です。
 * 
 * @author ishi
 * 
 */
public class ActMapActivity extends FragmentActivity implements
        OnMenuDialogListener, OnInformationDialogListener {
    /**
     * アクティビティコード
     * 
     * @author ishi
     * 
     */
    class ActivityCode {
        /**
         * ルート計算設定
         */
        public static final int CALC_ROUTE = 1;
        /**
         * 最短ルート計算設定
         */
        public static final int CALC_OPT_ROUTE = 2;
        /**
         * 到達圏計算設定
         */
        public static final int CALC_AREA3 = 3;
        /**
         * サービス設定
         */
        public static final int SERVICE_PREF = 4;
        /**
         * 地点
         */
        public static final int LOC = 5;
        /**
         * 結果一覧
         */
        public static final int RESULTS = 6;
        /**
         * 道路選択
         */
        public static final int ROAD_SELECT = 7;
        /**
         * 片道一括計算設定
         */
        public static final int CALC_ONE_WAY3 = 8;
        /**
         * 結果
         */
        public static final int RESULT = 9;
        /**
         * 住所検索
         */
        public static final int ADDRESS_SEARCH = 10;
    }

    /**
     * ダイアログID
     */
    class DialogID {
        public static final int CALC = 0;
        public static final int ABOUT = 1;
        public static final int CALC_FAILED = 5;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        private static final String CALC = "calc_dialog";
        private static final String ABOUT = "about_dialog";
        private static final String CALC_FAILED = "calc_failed_dialog";
    }

    /**
     * アプリケーションクラス
     */
    private static MyApp app;

    /**
     * 地点ボタン
     */
    private ImageButton buttoLoc;
    /**
     * ルート計算ボタン
     */
    private ImageButton buttonCalcRoute;
    /**
     * 結果ボタン
     */
    private ImageButton buttonResult;
    /**
     * 住所選択ボタン
     */
    private ImageButton buttonSelectAddress;

    /**
     * 計算開始フラグ
     */
    private int startCalc = -1;

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        boolean result = super.onCreateOptionsMenu(menu);
        getMenuInflater().inflate(R.menu.menu, menu);
        return result;
    }

    @Override
    public void onInformationDialogClose(int requestCode) {

    }

    @Override
    public void onMenuSelected(String tag, int menuPosition, int position) {
        if (tag.equals(DialogTag.CALC)) {
            Intent intent;
            switch (menuPosition) {
            case 0:
                if (!validateCalcRouteParam()) {
                    return;
                }
                intent = new Intent(getApplicationContext(),
                        CalcRouteActivity.class);
                startActivityForResult(intent, ActivityCode.CALC_ROUTE);
                break;
            case 1:
                if (!validateCalcOptRouteParam()) {
                    return;
                }
                intent = new Intent(getApplicationContext(),
                        CalcRouteActivity.class);
                startActivityForResult(intent, ActivityCode.CALC_OPT_ROUTE);
                break;
            case 2:
                if (!validateCalcArea3Param()) {
                    return;
                }
                intent = new Intent(getApplicationContext(),
                        CalcArea3Activity.class);
                startActivityForResult(intent, ActivityCode.CALC_AREA3);
                break;
            case 3:
                if (!validateCalcOneWay3Param()) {
                    return;
                }
                intent = new Intent(getApplicationContext(),
                        CalcOneWay3Activity.class);
                startActivityForResult(intent, ActivityCode.CALC_ONE_WAY3);
                break;
            }
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
        case R.id.menuitem_admin_pref:
            Intent intent = new Intent(ActMapActivity.this, MainActivity.class);
            intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
            intent.putExtra(BundleKey.MODE_KEY, true);
            startActivity(intent);
            finish();
            break;
        case R.id.menuitem_user_info:
            Intent intent2 = new Intent(ActMapActivity.this,
                    UserInfoActivity.class);
            startActivity(intent2);
            break;
        case R.id.menuitem_clear:
            app.clearLocs();
            app.clearResult();
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).updateLocs();
            break;
        case R.id.menuitem_about:
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).cancelDragMarker();
            String message = GooglePlayServicesUtil
                    .getOpenSourceSoftwareLicenseInfo(getApplicationContext());
            InformationDialogFragment infoDlg = InformationDialogFragment
                    .newInstance(DialogID.ABOUT, getString(R.string.msg_about),
                            message);
            Utilities.showDialog(infoDlg, DialogTag.ABOUT,
                    getSupportFragmentManager());
            break;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        switch (requestCode) {
        case ActivityCode.CALC_ROUTE:
            if (resultCode == RESULT_OK) {
                startCalc = ActivityCode.CALC_ROUTE;
            }
            break;
        case ActivityCode.CALC_OPT_ROUTE:
            if (resultCode == RESULT_OK) {
                startCalc = ActivityCode.CALC_OPT_ROUTE;
            }
            break;
        case ActivityCode.CALC_AREA3:
            if (resultCode == RESULT_OK) {
                startCalc = ActivityCode.CALC_AREA3;
            }
            break;
        case ActivityCode.CALC_ONE_WAY3:
            if (resultCode == RESULT_OK) {
                startCalc = ActivityCode.CALC_ONE_WAY3;
            }
            break;
        case ActivityCode.LOC:
            if (resultCode == RESULT_OK) {
                ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                        R.id.act_map_fragment)).updateLocs();
            }
            if (data != null) {
                // 中心移動
                Bundle bundle = data.getExtras();
                double lon = bundle.getDouble(BundleKey.CENTER_LON);
                double lat = bundle.getDouble(BundleKey.CENTER_LAT);
                ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                        R.id.act_map_fragment)).moveMapCenter(lon, lat);
            }
            break;
        case ActivityCode.ADDRESS_SEARCH:
            if (resultCode == RESULT_OK) {
                ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                        R.id.act_map_fragment)).updateLocs();
            }
            break;
        case ActivityCode.RESULTS:
            if (resultCode == RESULT_OK) {
                ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                        R.id.act_map_fragment)).updateLocs();
            }
            break;
        }
    }

    @Override
    protected void onCreate(Bundle arg0) {
        super.onCreate(arg0);
        Logger.writeDebugLog("ActMapActivity", "OnCreate");
        setContentView(R.layout.act_map_activity);

        app = (MyApp) getApplication();

        initializeButtonCalc();
        initializeButtonLoc();
        initializeButtonResult();
        initializeButtonSelectAddress();
    }

    @Override
    protected void onResume() {
        super.onResume();
        switch (startCalc) {
        case ActivityCode.CALC_ROUTE:
            startCalc = -1;
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).calcRoute();
            break;
        case ActivityCode.CALC_OPT_ROUTE:
            startCalc = -1;
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).calcOptRoute();
            break;
        case ActivityCode.CALC_AREA3:
            startCalc = -1;
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).calcArea3();
            break;
        case ActivityCode.CALC_ONE_WAY3:
            startCalc = -1;
            ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                    R.id.act_map_fragment)).calcOneWay3();
            break;
        }
    }

    /**
     * 計算ボタンを初期化します。
     * 
     */
    private void initializeButtonCalc() {
        this.buttonCalcRoute = (ImageButton) findViewById(R.id.button_calc);
        this.buttonCalcRoute.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                ((ActMapFragment) getSupportFragmentManager().findFragmentById(
                        R.id.act_map_fragment)).cancelDragMarker();
                String[] menu = { getString(R.string.common_calc_route),
                        getString(R.string.common_calc_opt_route),
                        getString(R.string.common_calc_area3),
                        getString(R.string.common_calc_one_way3) };
                MenuDialogFragment dialog = MenuDialogFragment.newInstance("",
                        menu, 0);
                dialog.setTargetFragment(null, DialogID.CALC);
                Utilities.showDialog(dialog, DialogTag.CALC,
                        getSupportFragmentManager());
            }
        });
    }

    /**
     * 地点ボタンを初期化します。
     * 
     */
    private void initializeButtonLoc() {
        this.buttoLoc = (ImageButton) findViewById(R.id.button_loc);
        this.buttoLoc.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getApplicationContext(),
                        LocActivity.class);
                startActivityForResult(intent, ActivityCode.LOC);
            }
        });
    }

    /**
     * 結果ボタンを初期化します。
     * 
     */
    private void initializeButtonResult() {
        this.buttonResult = (ImageButton) findViewById(R.id.button_result);
        this.buttonResult.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(ActMapActivity.this,
                        ResultActivity.class);
                startActivityForResult(intent, ActivityCode.RESULTS);
            }
        });
    }

    /**
     * 住所検索ボタンを初期化します。
     * 
     */
    private void initializeButtonSelectAddress() {
        this.buttonSelectAddress = (ImageButton) findViewById(R.id.button_select_address);
        this.buttonSelectAddress.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getApplicationContext(),
                        AddressSearchActivity.class);
                startActivityForResult(intent, ActivityCode.ADDRESS_SEARCH);
            }
        });
    }

    /**
     * エラーダイアログを表示します。
     */
    private void showErrorDialog(String message) {
        InformationDialogFragment infoDlg = InformationDialogFragment
                .newInstance(DialogID.CALC_FAILED,
                        getString(R.string.msg_error), message);
        Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                getSupportFragmentManager());
    }

    /**
     * 到達圏／流入圏計算のパラメータを検証します。
     * 
     * @return 妥当な場合true
     */
    private boolean validateCalcArea3Param() {
        if (app.getLocs().size() < 1) {
            showErrorDialog(getString(R.string.msg_loc_under_1));
            return false;
        }
        if (!app.getUserInfo().validateCalcCount()) {
            showErrorDialog(getString(R.string.msg_calc_count_over));
            return false;
        }
        if (!app.getUserInfo().validateExpireDay()) {
            showErrorDialog(getString(R.string.msg_expired));
            return false;
        }
        return true;
    }

    /**
     * 片道一括計算のパラメータを検証します。
     * 
     * @return 妥当な場合true
     */
    private boolean validateCalcOneWay3Param() {
        if (app.getLocs().size() < 2) {
            showErrorDialog(getString(R.string.msg_loc_under_2));
            return false;
        }
        if (app.getLocs().size() > app.getUserInfo().getCalcAreaMaxLocs()) {
            showErrorDialog(getString(R.string.msg_loc_over));
            return false;
        }
        if (!app.getUserInfo().validateCalcCount()) {
            showErrorDialog(getString(R.string.msg_calc_count_over));
            return false;
        }
        if (!app.getUserInfo().validateExpireDay()) {
            showErrorDialog(getString(R.string.msg_expired));
            return false;
        }
        return true;
    }

    /**
     * 最短ルート計算のパラメータを検証します。
     * 
     * @return 妥当な場合true
     */
    private boolean validateCalcOptRouteParam() {
        if (app.getLocs().size() < 2) {
            showErrorDialog(getString(R.string.msg_loc_under_2));
            return false;
        }
        if (app.getLocs().size() > app.getUserInfo().getCalcOptRouteMaxLocs()) {
            showErrorDialog(getString(R.string.msg_loc_over));
            return false;
        }
        if (!app.getUserInfo().validateCalcCount()) {
            showErrorDialog(getString(R.string.msg_calc_count_over));
            return false;
        }
        if (!app.getUserInfo().validateExpireDay()) {
            showErrorDialog(getString(R.string.msg_expired));
            return false;
        }
        return true;
    }

    /**
     * ルート計算のパラメータを検証します。
     * 
     * @return 妥当な場合true
     */
    private boolean validateCalcRouteParam() {
        if (app.getLocs().size() < 2) {
            showErrorDialog(getString(R.string.msg_loc_under_2));
            return false;
        }
        if (app.getLocs().size() > app.getUserInfo().getCalcRouteMaxLocs()) {
            showErrorDialog(getString(R.string.msg_loc_over));
            return false;
        }
        if (!app.getUserInfo().validateCalcCount()) {
            showErrorDialog(getString(R.string.msg_calc_count_over));
            return false;
        }
        if (!app.getUserInfo().validateExpireDay()) {
            showErrorDialog(getString(R.string.msg_expired));
            return false;
        }
        return true;
    }
}
