/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.net.SocketTimeoutException;
import java.util.Date;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.GoogleMap.OnMapClickListener;
import com.google.android.gms.maps.GoogleMap.OnMarkerDragListener;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;

import jp.co.act_inc.actservicesample.AdminPrefManager;
import jp.co.act_inc.actservicesample.Attachable;
import jp.co.act_inc.actservicesample.CalcArea3PrefManager;
import jp.co.act_inc.actservicesample.CalcRoutePrefManager;
import jp.co.act_inc.actservicesample.LocLayer;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.PolylineLayer;
import jp.co.act_inc.actservicesample.PolygonLayer;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.InformationDialogFragment.OnInformationDialogListener;
import jp.co.act_inc.actservicesample.adminservice.AdminService;
import jp.co.act_inc.actservicesample.adminservice.GetUsableDCServerResponse;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;
import jp.co.act_inc.actservicesample.dcservice.CA3Param;
import jp.co.act_inc.actservicesample.dcservice.COW3Param;
import jp.co.act_inc.actservicesample.dcservice.CRParam;
import jp.co.act_inc.actservicesample.dcservice.CalcArea3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOneWay3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOptRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.CalcRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.DCService;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder.CalcType;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.AsyncTask;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.View;

/**
 * 地図を表示する画面です。
 */
public class ActMapFragment extends Fragment implements OnMapClickListener,
        OnMarkerDragListener, OnInformationDialogListener {
    /**
     * 到達圏／流入圏計算用タスクです。
     * 
     * @author ishi
     * 
     */
    class CalcArea3Task extends AsyncTask<Void, String, CalcResultHolder>
            implements Attachable<ActMapFragment> {
        /**
         * 対象フラグメント
         */
        private ActMapFragment fragment = null;
        /**
         * 計算結果
         */
        private CalcResultHolder result = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public CalcArea3Task(ActMapFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(ActMapFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected CalcResultHolder doInBackground(Void... params) {
            CalcResultHolder holder = new CalcResultHolder();
            try {
                // 距離計算サーバー取得
                this.publishProgress(context
                        .getString(R.string.msg_getting_dcserver));
                GetUsableDCServerResponse getUsableDCServerResponse = getUsableDcwsServer(context);
                holder.setGetUsableDCServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // 到達圏／流入圏計算
                this.publishProgress(context
                        .getString(R.string.msg_waiting_interval));
                while (System.currentTimeMillis() - app.getLastDistCalcTime() < app
                        .getUserInfo().getCalcInterval() * 1000) {
                    Thread.sleep(1000);
                }
                this.publishProgress(context
                        .getString(R.string.msg_calcing_area));
                Loc startLoc = null;
                if (app.getStartLocIndex() != -1
                        && (app.getLocs().size() > app.getStartLocIndex())) {
                    startLoc = app.getLocs().get(app.getStartLocIndex());
                }
                CA3Param param = CalcArea3PrefManager.createCA3Param(context,
                        startLoc);
                CalcArea3Response result = DCService.calcArea3(
                        AdminPrefManager.getUseSsl(context),
                        getUsableDCServerResponse.getEnviron(), param);
                result.setStartIndex(app.getStartLocIndex());
                result.setStartLoc(app.getLocs().get(app.getStartLocIndex()));
                holder.setCalcArea3Response(result);
                holder.setCalcType(CalcType.CALC_AREA);
                holder.setDate(new Date());
                if (result != null && result.getException() == null
                        && result.getResultCode() == 0) {
                    app.addResult(holder);
                }
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(CalcResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                postExecute(result);
            } else {
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            taskCalc = this;
            app.clearResult();
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_calcing_area));
            Utilities.showDialog(progressDialog, DialogTag.PROGRESS_CALC_AREA3,
                    getFragmentManager());
        }

        @Override
        protected void onProgressUpdate(String... values) {
            super.onProgressUpdate(values);
            if (progress != null) {
                progress.setMessage(values[0]);
            }
        }

        /**
         * 計算後の処理をします。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(CalcResultHolder result) {
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_calc_area3));
            if (dlgText == null) {
                app.setLastDistCalcTime(System.currentTimeMillis());
                updateMap(false);
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_CALC_AREA3,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskCalc = null;
        }
    }

    /**
     * CalcOneWay3用タスクです。
     * 
     * @author ishi
     * 
     */
    class CalcOneWay3Task extends AsyncTask<Void, String, CalcResultHolder>
            implements Attachable<ActMapFragment> {
        /**
         * 対象フラグメント
         */
        private ActMapFragment fragment = null;
        /**
         * 計算結果
         */
        private CalcResultHolder result = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            フラグメント
         */
        public CalcOneWay3Task(ActMapFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(ActMapFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected CalcResultHolder doInBackground(Void... params) {
            CalcResultHolder holder = new CalcResultHolder();
            try {
                // 距離計算サーバー取得
                this.publishProgress(context
                        .getString(R.string.msg_getting_dcserver));
                GetUsableDCServerResponse getUsableDCServerResponse = getUsableDcwsServer(context);
                holder.setGetUsableDCServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // 片道一括計算
                this.publishProgress(context
                        .getString(R.string.msg_waiting_interval));
                while (System.currentTimeMillis() - app.getLastDistCalcTime() < app
                        .getUserInfo().getCalcInterval() * 1000) {
                    Thread.sleep(1000);
                }
                this.publishProgress(context
                        .getString(R.string.msg_calcing_one_way));
                Loc startLoc = null;
                if (app.getStartLocIndex() != -1
                        && (app.getLocs().size() > app.getStartLocIndex())) {
                    startLoc = app.getLocs().get(app.getStartLocIndex());
                }
                COW3Param param = CalcArea3PrefManager.createCOW3Param(context,
                        startLoc);
                CalcOneWay3Response result = DCService.calcOneWay3(
                        AdminPrefManager.getUseSsl(context),
                        getUsableDCServerResponse.getEnviron(), param,
                        app.getLocs());
                result.setStartIndex(app.getStartLocIndex());
                result.setStartLoc(app.getLocs().get(app.getStartLocIndex()));
                result.setParam(param);
                holder.setCalcOneWay3Response(result);
                holder.setCalcType(CalcType.CALC_ONE_WAY);
                holder.setDate(new Date());
                if (result != null && result.getException() == null
                        && result.getResultCode() == 0) {
                    app.addResult(holder);
                }
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(CalcResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                postExecute(result);
            } else {
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            taskCalc = this;
            app.clearResult();
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_calcing_one_way));
            Utilities.showDialog(progressDialog,
                    DialogTag.PROGRESS_CALC_ONE_WAY, getFragmentManager());
        }

        @Override
        protected void onProgressUpdate(String... values) {
            super.onProgressUpdate(values);
            if (progress != null) {
                progress.setMessage(values[0]);
            }
        }

        /**
         * 計算後の処理をします。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(CalcResultHolder result) {
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_calc_one_way3));
            if (dlgText == null) {
                app.setLastDistCalcTime(System.currentTimeMillis());
                updateMap(false);
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_CALC_ONE_WAY,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskCalc = null;
        }
    }

    /**
     * CalcOptRoute用タスクです。
     * 
     * @author ishi
     * 
     */
    class CalcOptRouteTask extends AsyncTask<Void, String, CalcResultHolder>
            implements Attachable<ActMapFragment> {
        /**
         * 対象フラグメント
         */
        private ActMapFragment fragment = null;
        /**
         * 計算結果
         */
        private CalcResultHolder result = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            フラグメント
         */
        public CalcOptRouteTask(ActMapFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(ActMapFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected CalcResultHolder doInBackground(Void... params) {
            CalcResultHolder holder = new CalcResultHolder();
            try {
                // 距離計算サーバー取得
                this.publishProgress(getString(R.string.msg_getting_dcserver));
                GetUsableDCServerResponse getUsableDCServerResponse = getUsableDcwsServer(context);
                holder.setGetUsableDCServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // 最短ルート計算
                this.publishProgress(context
                        .getString(R.string.msg_waiting_interval));
                while (System.currentTimeMillis() - app.getLastDistCalcTime() < app
                        .getUserInfo().getCalcInterval() * 1000) {
                    Thread.sleep(1000);
                }
                this.publishProgress(context
                        .getString(R.string.msg_calcing_opt_route));
                CRParam param = CalcRoutePrefManager.createCRParam(context);
                CalcOptRouteResponse result = DCService.calcOptRoute(
                        AdminPrefManager.getUseSsl(context),
                        getUsableDCServerResponse.getEnviron(), param,
                        app.getLocs());
                result.setParam(param);
                holder.setCalcOptRouteResponse(result);
                holder.setCalcType(CalcType.CALC_OPT_ROUTE);
                holder.setDate(new Date());
                if (result != null && result.getException() == null
                        && result.getResultCode() == 0) {
                    app.addResult(holder);
                }
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(CalcResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                postExecute(result);
            } else {
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            taskCalc = this;
            app.clearResult();
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_calcing_opt_route));
            Utilities.showDialog(progressDialog,
                    DialogTag.PROGRESS_CALC_OPT_ROUTE, getFragmentManager());
        }

        @Override
        protected void onProgressUpdate(String... values) {
            super.onProgressUpdate(values);
            if (progress != null) {
                progress.setMessage(values[0]);
            }
        }

        /**
         * 計算後の処理をします。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(CalcResultHolder result) {
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_calc_opt_route));
            if (dlgText == null) {
                app.setLastDistCalcTime(System.currentTimeMillis());
                updateMap(false);
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_CALC_OPT_ROUTE,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskCalc = null;
        }
    }

    /**
     * CalcRoute用タスク
     * 
     * @author ishi
     */
    class CalcRouteTask extends AsyncTask<Void, String, CalcResultHolder>
            implements Attachable<ActMapFragment> {
        /**
         * 対象フラグメント
         */
        private ActMapFragment fragment = null;
        /**
         * 計算結果
         */
        private CalcResultHolder result = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            フラグメント
         */
        public CalcRouteTask(ActMapFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(ActMapFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected CalcResultHolder doInBackground(Void... params) {
            CalcResultHolder holder = new CalcResultHolder();
            try {
                // 距離計算サーバー取得
                this.publishProgress(getString(R.string.msg_getting_dcserver));
                GetUsableDCServerResponse getUsableDCServerResponse = getUsableDcwsServer(context);
                holder.setGetUsableDCServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // ルート計算
                this.publishProgress(context
                        .getString(R.string.msg_waiting_interval));
                while (System.currentTimeMillis() - app.getLastDistCalcTime() < app
                        .getUserInfo().getCalcInterval() * 1000) {
                    Thread.sleep(1000);
                }
                this.publishProgress(context
                        .getString(R.string.msg_calcing_route));
                CRParam param = CalcRoutePrefManager.createCRParam(context);
                CalcRouteResponse result = DCService.calcRoute(
                        AdminPrefManager.getUseSsl(context),
                        getUsableDCServerResponse.getEnviron(), param,
                        app.getLocs());
                result.setParam(param);
                holder.setCalcRouteResponse(result);
                holder.setCalcType(CalcType.CALC_ROUTE);
                holder.setDate(new Date());
                if (result != null && result.getException() == null
                        && result.getResultCode() == 0) {
                    app.addResult(holder);
                }
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(CalcResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                postExecute(result);
            } else {
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            taskCalc = this;
            app.clearResult();
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_calcing_route));
            Utilities.showDialog(progressDialog, DialogTag.PROGRESS_CALC_ROUTE,
                    getFragmentManager());
        }

        @Override
        protected void onProgressUpdate(String... values) {
            super.onProgressUpdate(values);
            if (progress != null) {
                progress.setMessage(values[0]);
            }
        }

        /**
         * 計算後の処理をします。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(CalcResultHolder result) {
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_calc_route));
            if (dlgText == null) {
                app.setLastDistCalcTime(System.currentTimeMillis());
                updateMap(false);
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_CALC_ROUTE,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskCalc = null;
        }
    }

    /**
     * ダイアログID
     */
    class DialogID {
        public static final int CALC = 0;
        public static final int CALC_ROUTE_PROGRESS = 1;
        public static final int CALC_OPT_ROUTE_PROGRESS = 2;
        public static final int CALC_AREA_PROGRESS = 3;
        public static final int CALC_ONE_WAY_PROGRESS = 4;
        public static final int CALC_FAILED = 5;
        public static final int LOAD_RESULTS_PROGRESS = 6;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        private static final String CALC_FAILED = "calc_failed_dialog";
        private static final String PROGRESS_CALC_AREA3 = "progress_calc_area3";
        private static final String PROGRESS_CALC_ONE_WAY = "progress_calc_one_way";
        private static final String PROGRESS_CALC_OPT_ROUTE = "progress_calc_opt_route";
        private static final String PROGRESS_CALC_ROUTE = "progress_calc_route";
        private static final String PROGRESS_LOAD_RESULTS = "progress_load_results";
    }

    /**
     * ダイアログの文字列を格納します。
     * 
     * @author ishi
     * 
     */
    static class DialogText {
        /**
         * タイトル
         */
        public String title;
        /**
         * メッセージ
         */
        public String message;
    }

    /**
     * 計算結果ロード用タスクです。
     * 
     * @author ishi
     * 
     */
    class LoadResultsTask extends AsyncTask<Void, Void, String> implements
            Attachable<ActMapFragment> {
        /**
         * 対象フラグメント
         */
        private ActMapFragment fragment = null;
        /**
         * 計算終了フラグ
         */
        private boolean end = false;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public LoadResultsTask(ActMapFragment fragment) {
            this.fragment = fragment;
        }

        @Override
        public void attach(ActMapFragment fragment) {
            this.fragment = fragment;
            if (end) {
                postExecute();
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected String doInBackground(Void... params) {
            try {
                app.loadResult();
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
            }
            return "";
        }

        @Override
        protected void onPostExecute(String result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                postExecute();
            } else {
                end = true;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_load_results));
            Utilities.showDialog(progressDialog,
                    DialogTag.PROGRESS_LOAD_RESULTS, getFragmentManager());
        }

        /**
         * 計算後の処理をします。
         * 
         */
        private void postExecute() {
            Utilities.dismissDialog(DialogTag.PROGRESS_LOAD_RESULTS,
                    fragment.getFragmentManager());
            progress = null;
            taskLoadResult = null;
            fragment.updateMap(true);
        }
    }

    /**
     * 地図の既定中心経度
     */
    private final static int DEFAULT_LAT = 35665431;

    /**
     * 地図の既定中心経度
     */
    private final static int DEFAULT_LON = 139755156;

    /**
     * 地図の既定縮尺レベル
     */
    private final static float DEFAULT_ZOOM = 10;

    /**
     * プログレスダイアログ
     */
    private static ProgressDialog progress = null;

    /**
     * 計算中タスク
     */
    private static Attachable<ActMapFragment> taskCalc = null;

    /**
     * 計算結果ロードタスク
     */
    private static LoadResultsTask taskLoadResult = null;

    /**
     * アプリケーションクラス
     */
    private static MyApp app;

    /**
     * 計算に失敗しているか調べます。
     * 
     * @param context
     *            コンテキスト
     * @param result
     *            計算結果
     * @param message
     *            メッセージ
     * @return 計算に失敗している場合、エラーダイアログメッセージ
     */
    private static DialogText checkCalcResult(Context context,
            CalcResultHolder result, String message) {
        DialogText dlgText = null;
        GetUsableDCServerResponse getServerResult = result
                .getGetUsableDCServerResponse();
        Response calcResult = result.getResponse();
        if (getServerResult != null
                && getServerResult.getException() instanceof SocketTimeoutException) {
            // 距離計算サーバー取得タイムアウト
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context.getString(R.string.msg_failed_timeout);
        } else if (getServerResult == null
                || getServerResult.getException() != null
                || !getServerResult.getResult()) {
            // 距離計算サーバー取得失敗
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context
                    .getString(R.string.msg_failed_get_usable_dcserver);
        } else if (calcResult != null
                && calcResult.getException() instanceof SocketTimeoutException) {
            // 距離計算タイムアウト
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context.getString(R.string.msg_failed_timeout);
        } else if (calcResult == null || calcResult.getException() != null) {
            // 距離計算失敗
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = message;
        } else if (calcResult.getResultCode() != 0) {
            // 距離計算エラー
            app.setLastDistCalcTime(System.currentTimeMillis());
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = message;
        }

        return dlgText;
    }

    /**
     * GetUsalbeDCWSServerを実行します。
     * 
     * @param context
     *            コンテキスト
     * @return GetUsableDCServerResponse
     */
    private static GetUsableDCServerResponse getUsableDcwsServer(Context context) {
        GetUsableDCServerResponse dcServer = new GetUsableDCServerResponse();
        try {
            NWInfo nwInfo = AdminPrefManager.getNWInfo(context);
            String url = AdminPrefManager.getAdminUrl(context);
            boolean useSsl = AdminPrefManager.getUseSsl(context);
            dcServer = AdminService.getUsableDCServer(url, useSsl,
                    AdminPrefManager.createAdminEnviron(context), nwInfo);
        } catch (Exception ex) {
            dcServer.setException(ex);
        }
        return dcServer;
    }

    /**
     * 地図
     */
    private GoogleMap map;

    /**
     * 地点登録用レイヤー
     */
    private LocLayer locLayer;

    /**
     * マーカードラッグフラグ
     */
    private boolean draggingMarker = false;

    /**
     * 到達圏/流入圏計算を実行します。
     */
    public void calcArea3() {
        CalcArea3Task task = new CalcArea3Task(this);
        task.execute();
    }

    /**
     * 片道一括計算を実行します。
     */
    public void calcOneWay3() {
        CalcOneWay3Task task = new CalcOneWay3Task(this);
        task.execute();
    }

    /**
     * 最短ルート計算を実行します。
     */
    public void calcOptRoute() {
        CalcOptRouteTask task = new CalcOptRouteTask(this);
        task.execute();
    }

    /**
     * ルート計算を実行します。
     */
    public void calcRoute() {
        CalcRouteTask task = new CalcRouteTask(this);
        task.execute();
    }

    /**
     * マーカードラッグをキャンセルします。
     */
    public void cancelDragMarker() {
        if (draggingMarker) {
            draggingMarker = false;
            updateLocs();
        }
    }

    /**
     * 地図の中心地点を変更します。
     * 
     * @param lon
     *            経度
     * @param lat
     *            緯度
     */
    public void moveMapCenter(double lon, double lat) {
        map.moveCamera(CameraUpdateFactory
                .newCameraPosition(new CameraPosition.Builder()
                        .target(new LatLng(lat, lon))
                        .zoom(map.getCameraPosition().zoom).build()));
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        Logger.writeDebugLog("ActMapFragment", "onActivityCreated");

        app = (MyApp) getActivity().getApplication();
        setRetainInstance(true);

        SupportMapFragment mapFragment = (SupportMapFragment) getFragmentManager()
                .findFragmentById(R.id.map);
        map = mapFragment.getMap();

        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getActivity()
                        .getApplicationContext());
        map.moveCamera(CameraUpdateFactory
                .newCameraPosition(new CameraPosition.Builder()
                        .target(new LatLng(prefs.getInt(
                                getString(R.string.map_center_lat_key),
                                DEFAULT_LAT) / 1E6, prefs.getInt(
                                getString(R.string.map_center_lon_key),
                                DEFAULT_LON) / 1E6))
                        .zoom(prefs.getFloat(
                                getString(R.string.map_zoom_level_key),
                                DEFAULT_ZOOM)).build()));
        map.getUiSettings().setTiltGesturesEnabled(false);
        map.setOnMapClickListener(this);
        map.setOnMarkerDragListener(this);
        locLayer = new LocLayer(app);
        updateMap(true);

        if (taskCalc != null) {
            taskCalc.attach(this);
        }
    }

    @Override
    public View onCreateView(android.view.LayoutInflater inflater,
            android.view.ViewGroup container, Bundle savedInstanceState) {
        Logger.writeDebugLog("ActMapFragment", "onCreateView");
        return inflater.inflate(R.layout.act_map_fragment, null, false);
    }

    @Override
    public void onInformationDialogClose(int requestCode) {

    }

    @Override
    public void onMapClick(LatLng latLng) {
        Loc loc = new Loc();
        loc.setLon(latLng.longitude);
        loc.setLat(latLng.latitude);
        app.addLoc(loc);
        updateMap(false);
    }

    @Override
    public void onMarkerDrag(Marker marker) {

    }

    @Override
    public void onMarkerDragEnd(Marker marker) {
        locLayer.moveLoc(marker);
        draggingMarker = false;
    }

    @Override
    public void onMarkerDragStart(Marker marker) {
        draggingMarker = true;
    }

    @Override
    public void onPause() {
        super.onPause();

        // 地図状態の保存
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getActivity()
                        .getApplicationContext());
        Editor editor = prefs.edit();
        editor.putInt(getString(R.string.map_center_lon_key),
                (int) (map.getCameraPosition().target.longitude * 1E6));
        editor.putInt(getString(R.string.map_center_lat_key),
                (int) (map.getCameraPosition().target.latitude * 1E6));
        editor.putFloat(getString(R.string.map_zoom_level_key),
                map.getCameraPosition().zoom);
        editor.commit();

        if (taskCalc != null) {
            taskCalc.detach();
        }

        if (taskLoadResult != null) {
            taskLoadResult.detach();
        }

        cancelDragMarker();
    }

    @Override
    public void onResume() {
        super.onResume();

        if (taskCalc != null) {
            taskCalc.attach(this);
        }

        if (taskLoadResult != null) {
            taskLoadResult.attach(this);
        } else {
            if (!app.isResultLoaded()) {
                if (taskLoadResult == null) {
                    taskLoadResult = new LoadResultsTask(this);
                    taskLoadResult.execute();
                }
            }
        }
    }

    /**
     * 地図上の計算地点を更新します。
     */
    public void updateLocs() {
        locLayer.addObject(map);
        draggingMarker = false;
    }

    /**
     * 地図上のオブジェクトを更新します。
     * 
     * @param force
     *            強制的にオブジェクトを地図に追加するフラグ
     */
    public void updateMap(boolean force) {
        CalcResultHolder result = app.getResult();
        if (result != null) {
            if (result.getLayer() == null) {
                switch (result.getCalcType()) {
                case CalcType.CALC_ROUTE:
                case CalcType.CALC_OPT_ROUTE:
                    result.setLayer(new PolylineLayer(app, result));
                    result.getLayer().addObject(map);
                    break;
                case CalcType.CALC_AREA:
                case CalcType.CALC_ONE_WAY:
                    result.setLayer(new PolygonLayer(app, result));
                    result.getLayer().addObject(map);
                    break;
                }
            } else {
                if (force) {
                    result.getLayer().addObject(map);
                }
            }
        }
        updateLocs();
    }
}
