/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.net.SocketTimeoutException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import jp.co.act_inc.actservicesample.AdminPrefManager;
import jp.co.act_inc.actservicesample.Attachable;
import jp.co.act_inc.actservicesample.LeveledAddressItem;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.InformationDialogFragment.OnInformationDialogListener;
import jp.co.act_inc.actservicesample.activity.MenuDialogFragment.OnMenuDialogListener;
import jp.co.act_inc.actservicesample.adminservice.AdminService;
import jp.co.act_inc.actservicesample.adminservice.GetUsableGeoServerResponse;
import jp.co.act_inc.actservicesample.adminservice.Response;
import jp.co.act_inc.actservicesample.adminservice.Constants.Datum;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import jp.co.act_inc.actservicesample.gcservice.AddressItem;
import jp.co.act_inc.actservicesample.gcservice.CommonParam;
import jp.co.act_inc.actservicesample.gcservice.EnumAddressByZipResponse;
import jp.co.act_inc.actservicesample.gcservice.EnumLowerAddressByCodeResponse;
import jp.co.act_inc.actservicesample.gcservice.GeoResultHolder;
import jp.co.act_inc.actservicesample.gcservice.GCService;
import jp.co.act_inc.actservicesample.gcservice.GeoUtils;
import jp.co.act_inc.actservicesample.gcservice.SearchAddressItem;
import jp.co.act_inc.actservicesample.gcservice.SearchAddressResponse;
import jp.co.act_inc.actservicesample.gcservice.ZipItem;
import jp.co.act_inc.actservicesample.gcservice.GeoResultHolder.GeoCalcType;
import android.app.Activity;
import android.content.Context;
import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.view.WindowManager.LayoutParams;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.GridView;
import android.widget.SimpleAdapter;
import android.widget.TextView;

/**
 * 住所検索画面です。
 * 
 * @author ishi
 * 
 */
public class AddressSearchFragment extends Fragment implements
        OnInformationDialogListener, OnMenuDialogListener {
    /**
     * ダイアログIDです。
     * 
     * @author ishi
     * 
     */
    class DialogID {
        static final int PROGRESS_ENUM_ZIP = 0;
        static final int PROGRESS_ENUM_ADDRESS = 1;
        static final int PROGRESS_SEARCH_ADDRESS = 2;
        static final int SELECT_ADDRESS = 3;
        static final int CALC_FAILED = 4;
        static final int INFO = 5;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        private static final String CALC_FAILED = "calc_failed_dialog";
        private static final String SELECT_ADDRESS = "select_address_dialog";
        private static final String PROGRESS_ENUM_ADDRESS = "progress_enum_address";
        private static final String PROGRESS_ENUM_ZIP = "progress_enum_zip";
        private static final String PROGRESS_SEARCH_ADDRESS = "progress_search_address";
    }

    /**
     * ダイアログの文字列を格納します。
     * 
     * @author ishi
     * 
     */
    static class DialogText {
        /**
         * タイトル
         */
        public String title;
        /**
         * メッセージ
         */
        public String message;
    }

    /**
     * 下位住所列挙用タスクです。
     * 
     * @author ishi
     * 
     */
    class EnumAddressTask extends AsyncTask<String, String, GeoResultHolder>
            implements Attachable<AddressSearchFragment> {
        /**
         * 結果
         */
        private GeoResultHolder result = null;
        /**
         * 対象フラグメント
         */
        private AddressSearchFragment fragment = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public EnumAddressTask(AddressSearchFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(AddressSearchFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected GeoResultHolder doInBackground(String... params) {
            Logger.writeDebugLog("EnumAddressTask", "doInBackground");
            GeoResultHolder holder = new GeoResultHolder();
            try {
                // 住所検索サーバー取得
                GetUsableGeoServerResponse getUsableDCServerResponse = AdminService
                        .getUsableGeoServer(
                                AdminPrefManager.getAdminUrl(context),
                                AdminPrefManager.getUseSsl(context),
                                AdminPrefManager.createAdminEnviron(context));
                holder.setGetUsableGeoServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // 下位住所列挙
                while (System.currentTimeMillis() - app.getLastGeoCalcTime() < app
                        .getUserInfo().getGeoEnumInterval() * 1000) {
                    Thread.sleep(1000);
                }
                CommonParam param = new CommonParam(Datum.Jgd2000, 0, 0);
                EnumLowerAddressByCodeResponse result = GCService
                        .enumLowerAddressByCode(
                                AdminPrefManager.getUseSsl(context),
                                getUsableDCServerResponse.getEnviron(), param,
                                params[0]);
                holder.setEnumLowerAddressByCodeResponse(result);
                holder.setCalcType(GeoCalcType.ENUM_LOWER_ADDRESS_BY_CODE);
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(GeoResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                Logger.writeDebugLog("EnumAddressTask",
                        "onPostExecute attached");
                postExecute(result);
            } else {
                Logger.writeDebugLog("EnumAddressTask",
                        "onPostExecute detached");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("EnumAddressTask", "onPreExecute");
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_getting_address));
            Utilities.showDialog(progressDialog,
                    DialogTag.PROGRESS_ENUM_ADDRESS, getFragmentManager());
        }

        /**
         * 計算後の処理です。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(GeoResultHolder result) {
            Logger.writeDebugLog("EnumAddressTask", "postExecute");
            DialogText dlgText = checkCalcResult(
                    context,
                    result,
                    context.getString(R.string.msg_failed_enum_lower_address_by_code));
            if (dlgText == null) {
                app.setLastGeoCalcTime(System.currentTimeMillis());
                fragment.enumItems = result.getEnumLowerAddressByCodeResponse()
                        .getItems();
                fragment.data.clear();
                fragment.visibleItems.clear();
                for (AddressItem item : fragment.enumItems) {
                    Map<String, String> map = new HashMap<String, String>();
                    map.put(ADDRESS, item.getAddress());
                    fragment.data.add(map);
                    fragment.visibleItems.add(item);
                }
                fragment.gridView.setAdapter(adapter);
                fragment.editFilter.setText("");
            } else {
                checkAddressSelect.setChecked(false);
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_ENUM_ADDRESS,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskSearch = null;
        }
    }

    /**
     * 郵便番号対応住所列挙用タスクです。
     * 
     * @author ishi
     * 
     */
    class EnumZipTask extends AsyncTask<String, String, GeoResultHolder>
            implements Attachable<AddressSearchFragment> {
        /**
         * 結果
         */
        private GeoResultHolder result = null;
        /**
         * 対象フラグメント
         */
        private AddressSearchFragment fragment = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public EnumZipTask(AddressSearchFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(AddressSearchFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected GeoResultHolder doInBackground(String... params) {
            Logger.writeDebugLog("EnumZipTask", "doInBackground");
            GeoResultHolder holder = new GeoResultHolder();
            try {
                // 住所検索サーバー取得
                GetUsableGeoServerResponse getUsableDCServerResponse = AdminService
                        .getUsableGeoServer(
                                AdminPrefManager.getAdminUrl(context),
                                AdminPrefManager.getUseSsl(context),
                                AdminPrefManager.createAdminEnviron(context));
                holder.setGetUsableGeoServerResponse(getUsableDCServerResponse);
                if (getUsableDCServerResponse == null
                        || getUsableDCServerResponse.getException() != null
                        || !getUsableDCServerResponse.getResult()) {
                    return holder;
                }

                // 郵便番号住所列挙
                while (System.currentTimeMillis() - app.getLastGeoCalcTime() < app
                        .getUserInfo().getGeoEnumInterval() * 1000) {
                    Thread.sleep(1000);
                }
                CommonParam param = new CommonParam(Datum.Jgd2000, 0, 0);
                EnumAddressByZipResponse result = GCService.enumAddressByZip(
                        AdminPrefManager.getUseSsl(context),
                        getUsableDCServerResponse.getEnviron(), param,
                        params[0]);
                holder.setEnumAddressByZipResponse(result);
                holder.setCalcType(GeoCalcType.ENUM_ADDRESS_BY_ZIP);
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(GeoResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                Logger.writeDebugLog("EnumZipTask", "onPostExecute attached");
                postExecute(result);
            } else {
                Logger.writeDebugLog("EnumZipTask", "onPostExecute detached");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("EnumZipTask", "onPreExecute");
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_getting_address));
            Utilities.showDialog(progressDialog, DialogTag.PROGRESS_ENUM_ZIP,
                    getFragmentManager());
        }

        /**
         * 計算後の処理です。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(GeoResultHolder result) {
            Logger.writeDebugLog("EnumZipTask", "postExecute");
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_enum_address_by_zip));
            if (dlgText == null) {
                app.setLastGeoCalcTime(System.currentTimeMillis());
                ArrayList<ZipItem> items = result.getEnumAddressByZipResponse()
                        .getItems();
                if (items.size() == 0) {
                    dlgText = new DialogText();
                    dlgText.title = context
                            .getString(R.string.msg_failed_processing);
                    dlgText.message = context
                            .getString(R.string.msg_zip_not_found);
                } else if (items.size() == 1) {
                    fragment.zipItem = items.get(0);
                    fragment.labelAnalyzedAddress.setText(getFullAddress());
                    fragment.labelAddressLevel.setText(GeoUtils
                            .getGeoLevelName(fragment.getActivity()
                                    .getApplicationContext(), fragment.zipItem
                                    .getAddressLevel()));
                    fragment.buttonOK.setEnabled(true);
                } else {
                    tempZipItems = items;
                    String[] menu = new String[items.size()];
                    for (int i = 0; i < menu.length; ++i) {
                        menu[i] = items.get(i).getFullAddress();
                    }
                    MenuDialogFragment dialog = MenuDialogFragment.newInstance(
                            "", menu, 0);
                    dialog.setTargetFragment(AddressSearchFragment.this,
                            DialogID.SELECT_ADDRESS);
                    Utilities.showDialog(dialog, DialogTag.SELECT_ADDRESS,
                            getFragmentManager());
                }
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_ENUM_ZIP,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskSearch = null;
        }
    }

    /**
     * 住所検索用タスクです。
     * 
     * @author ishi
     * 
     */
    class SearchAddressTask extends
            AsyncTask<SearchAddressItem, String, GeoResultHolder> implements
            Attachable<AddressSearchFragment> {
        /**
         * 結果
         */
        private GeoResultHolder result = null;
        /**
         * 対象フラグメント
         */
        private AddressSearchFragment fragment = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public SearchAddressTask(AddressSearchFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(AddressSearchFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected GeoResultHolder doInBackground(SearchAddressItem... params) {
            Logger.writeDebugLog("SearchAddressTask", "doInBackground");
            GeoResultHolder holder = new GeoResultHolder();
            try {
                // 住所検索サーバー取得
                GetUsableGeoServerResponse getUsableGeoServerResponse = AdminService
                        .getUsableGeoServer(
                                AdminPrefManager.getAdminUrl(context),
                                AdminPrefManager.getUseSsl(context),
                                AdminPrefManager.createAdminEnviron(context));
                holder.setGetUsableGeoServerResponse(getUsableGeoServerResponse);
                if (getUsableGeoServerResponse == null
                        || getUsableGeoServerResponse.getException() != null
                        || !getUsableGeoServerResponse.getResult()) {
                    return holder;
                }

                // 住所検索
                while (System.currentTimeMillis() - app.getLastGeoCalcTime() < app
                        .getUserInfo().getGeoInterval() * 1000) {
                    Thread.sleep(1000);
                }
                CommonParam param = new CommonParam(1, 0, 0);
                int addressLevel = app.getUserInfo().getGeoMaxAddressLevel();
                ArrayList<SearchAddressItem> items = new ArrayList<SearchAddressItem>();
                for (SearchAddressItem item : params) {
                    items.add(item);
                }
                SearchAddressResponse result = GCService.searchAddress(
                        AdminPrefManager.getUseSsl(context),
                        getUsableGeoServerResponse.getEnviron(), param,
                        addressLevel, items);
                holder.setSearchAddressResponse(result);
                holder.setCalcType(GeoCalcType.SEARCH_ADDRESS);
            } catch (Exception e) {
                Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                        Thread.currentThread().getStackTrace()[3]
                                .getMethodName(), e);
                holder.setException(e);
            }
            return holder;
        }

        @Override
        protected void onPostExecute(GeoResultHolder result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                Logger.writeDebugLog("SearchAddressTask",
                        "onPostExecute attached");
                postExecute(result);
            } else {
                Logger.writeDebugLog("SearchAddressTask",
                        "onPostExecute detached");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("SearchAddressTask", "onPreExecute");
            ProgressDialogFragment progressDialog = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_searching_address));
            Utilities.showDialog(progressDialog,
                    DialogTag.PROGRESS_SEARCH_ADDRESS, getFragmentManager());
        }

        /**
         * 計算後の処理です。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(GeoResultHolder result) {
            Logger.writeDebugLog("SearchAddressTask", "postExecute");
            DialogText dlgText = checkCalcResult(context, result,
                    context.getString(R.string.msg_failed_search_address));
            if (dlgText == null) {
                app.setLastGeoCalcTime(System.currentTimeMillis());
                ArrayList<SearchAddressItem> items = result
                        .getSearchAddressResponse().getItems();
                if (items.get(0).getAddressLevel() != 0) {
                    fragment.item = items.get(0);
                    fragment.labelAddressLevel.setText(GeoUtils
                            .getGeoLevelName(fragment.getActivity()
                                    .getApplicationContext(), items.get(0)
                                    .getAddressLevel()));
                    fragment.labelAnalyzedAddress.setText(items.get(0)
                            .getAnalyzedAddress());
                    fragment.buttonOK.setEnabled(true);
                } else {
                    fragment.item = null;
                    fragment.labelAddressLevel.setText("");
                    fragment.labelAnalyzedAddress.setText("");
                    fragment.buttonOK.setEnabled(false);
                }
            }

            Utilities.dismissDialog(DialogTag.PROGRESS_SEARCH_ADDRESS,
                    fragment.getFragmentManager());

            if (dlgText != null) {
                InformationDialogFragment infoDlg = InformationDialogFragment
                        .newInstance(DialogID.CALC_FAILED, dlgText.title,
                                dlgText.message);
                infoDlg.setTargetFragment(fragment, DialogID.CALC_FAILED);
                Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                        fragment.getFragmentManager());
            }

            taskSearch = null;
        }
    }

    private static final String ADDRESS = "address";
    private static final String TEMP_ZIP_ITEMS = "temp_zip_items";
    private static final String ZIP_ITEM = "zip_item";
    private static final String LEVELED_ITEM = "leveled_item";
    private static final String SEARCH_ITEM = "item";
    private static final String ENUM_ITEMS = "enum_items";
    private static final String VISIBLE_ITEMS = "visible_items";

    private static MyApp app;
    private static Attachable<AddressSearchFragment> taskSearch = null;

    /**
     * 住所区切り文字
     */
    private static final String DELIMITER = "-";

    /**
     * 計算に失敗しているか調べます。
     * 
     * @param context
     *            コンテキスト
     * @param result
     *            計算結果
     * @param message
     *            メッセージ
     * @return 計算に失敗している場合、エラーダイアログメッセージ
     */
    private static DialogText checkCalcResult(Context context,
            GeoResultHolder result, String message) {
        DialogText dlgText = null;

        GetUsableGeoServerResponse getServerResult = result
                .getGetUsableGeoServerResponse();
        Response calcResult = result.getResponse();
        if (getServerResult != null
                && getServerResult.getException() instanceof SocketTimeoutException) {
            // 住所検索サーバー取得タイムアウト
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context.getString(R.string.msg_failed_timeout);
        } else if (getServerResult == null
                || getServerResult.getException() != null
                || !getServerResult.getResult()) {
            // 住所検索サーバー取得失敗
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context
                    .getString(R.string.msg_failed_get_usable_geoserver);
        } else if (calcResult != null
                && calcResult.getException() instanceof SocketTimeoutException) {
            // 住所検索タイムアウト
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = context.getString(R.string.msg_failed_timeout);
        } else if (calcResult == null || calcResult.getException() != null) {
            // 住所検索失敗
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = message;
        } else if (calcResult.getResultCode() != 0) {
            // 住所検索エラー
            app.setLastGeoCalcTime(System.currentTimeMillis());
            dlgText = new DialogText();
            dlgText.title = context.getString(R.string.msg_failed_processing);
            dlgText.message = message;
        }

        return dlgText;
    }

    /**
     * グリッド用アダプター
     */
    private SimpleAdapter adapter;
    /**
     * グリッド用データ
     */
    private ArrayList<Map<String, String>> data;
    /**
     * 絞り込み適用後の表示住所アイテム
     */
    private ArrayList<AddressItem> visibleItems = new ArrayList<AddressItem>();
    /**
     * 下位住所列挙の結果住所アイテム
     */
    private ArrayList<AddressItem> enumItems;
    /**
     * 住所検索結果アイテム
     */
    private SearchAddressItem item;
    /**
     * 住所レベル別住所アイテム
     */
    private LeveledAddressItem leveledItem = new LeveledAddressItem();
    /**
     * 郵便番号検索結果アイテム
     */
    private ZipItem zipItem;
    /**
     * 郵便番号対応住所列挙結果アイテム
     */
    private ArrayList<ZipItem> tempZipItems;
    private Button buttonAdaptFilter;
    private Button buttonClear;
    private Button buttonOK;
    private Button buttonSearch;
    private CheckBox checkAddressSelect;
    private EditText editFilter;
    private EditText editSearchAddress;
    private GridView gridView;
    private TextView labelAddressLevel;
    private TextView labelAnalyzedAddress;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        Logger.writeDebugLog("AddressSearchFragment", "onActivityCreated");
        super.onActivityCreated(savedInstanceState);
        getActivity().getWindow().setSoftInputMode(
                LayoutParams.SOFT_INPUT_STATE_ALWAYS_HIDDEN);
        app = (MyApp) getActivity().getApplication();
        setRetainInstance(true);

        initializeAddressSelectCheckBox();
        editSearchAddress = (EditText) getView().findViewById(
                R.id.editText_search_address);
        editFilter = (EditText) getView().findViewById(
                R.id.editText_address_select_filter);
        initializeAdaptButton();
        initializeSearchButton();
        initializeOKButton();
        initializeClearButton();
        labelAddressLevel = (TextView) getView().findViewById(
                R.id.textView_address_level);
        labelAnalyzedAddress = (TextView) getView().findViewById(
                R.id.textView_analyzed_address);
        initializeGridView();

        if (savedInstanceState != null) {
            visibleItems = savedInstanceState
                    .getParcelableArrayList(VISIBLE_ITEMS);
            enumItems = savedInstanceState.getParcelableArrayList(ENUM_ITEMS);
            item = savedInstanceState.getParcelable(SEARCH_ITEM);
            leveledItem = savedInstanceState.getParcelable(LEVELED_ITEM);
            zipItem = savedInstanceState.getParcelable(ZIP_ITEM);
            tempZipItems = savedInstanceState
                    .getParcelableArrayList(TEMP_ZIP_ITEMS);
        }

        labelAddressLevel.setText(GeoUtils.getGeoLevelName(getActivity()
                .getApplicationContext(), getAddressLevel()));
        labelAnalyzedAddress.setText(getFullAddress());
        if (getAddressLevel() != 0) {
            buttonOK.setEnabled(true);
        }

        for (AddressItem item : visibleItems) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(ADDRESS, item.getAddress());
            data.add(map);
        }
        adapter.notifyDataSetChanged();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        Logger.writeDebugLog("AddressSearchFragment", "onCreateView");
        return inflater.inflate(R.layout.address_search_fragment, null, false);
    }

    @Override
    public void onInformationDialogClose(int requestCode) {

    }

    @Override
    public void onMenuSelected(String key, int menuPosition, int position) {
        zipItem = tempZipItems.get(menuPosition);
        labelAnalyzedAddress.setText(zipItem.getFullAddress());
        labelAddressLevel.setText(GeoUtils.getGeoLevelName(getActivity()
                .getApplicationContext(), zipItem.getAddressLevel()));
        buttonOK.setEnabled(true);
        tempZipItems = null;
    }

    @Override
    public void onPause() {
        Logger.writeDebugLog("AddressSearchFragment", "onPause");
        super.onPause();
        if (taskSearch != null) {
            taskSearch.detach();
        }
    }

    @Override
    public void onResume() {
        Logger.writeDebugLog("AddressSearchFragment", "onResume");
        super.onResume();
        if (taskSearch != null) {
            taskSearch.attach(this);
        } else {
            Utilities.dismissDialog(DialogTag.PROGRESS_ENUM_ADDRESS,
                    getFragmentManager());
            Utilities.dismissDialog(DialogTag.PROGRESS_ENUM_ZIP,
                    getFragmentManager());
            Utilities.dismissDialog(DialogTag.PROGRESS_SEARCH_ADDRESS,
                    getFragmentManager());
        }
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {
        Logger.writeDebugLog("AddressSearchFragment", "onSaveInstanceState");
        super.onSaveInstanceState(outState);
        outState.putParcelableArrayList(VISIBLE_ITEMS, visibleItems);
        outState.putParcelableArrayList(ENUM_ITEMS, enumItems);
        outState.putParcelable(SEARCH_ITEM, item);
        outState.putParcelable(LEVELED_ITEM, leveledItem);
        outState.putParcelable(ZIP_ITEM, zipItem);
        outState.putParcelableArrayList(TEMP_ZIP_ITEMS, tempZipItems);
    }

    /**
     * 計算結果をクリアします。
     */
    private void clearResult() {
        item = null;
        leveledItem.clear();
        zipItem = null;
        tempZipItems = null;
        visibleItems.clear();
        data.clear();
        labelAnalyzedAddress.setText("");
        labelAddressLevel.setText("");
        adapter.notifyDataSetChanged();
        checkAddressSelect.setChecked(false);
    }

    /**
     * 計算結果の住所レベルを取得します。
     * 
     * @return 住所レベル
     */
    private int getAddressLevel() {
        AddressItem item = leveledItem.getLowerestItem();

        if (item == null && AddressSearchFragment.this.item == null
                && zipItem == null) {
            return 0;
        }

        int searchLevel = AddressSearchFragment.this.item != null ? AddressSearchFragment.this.item
                .getAddressLevel() : 0;
        int enumLevel = item != null ? item.getAddressLevel() : 0;
        int zipLevel = zipItem != null ? zipItem.getAddressLevel() : 0;

        if (searchLevel > enumLevel) {
            return searchLevel;
        } else if (zipLevel > enumLevel) {
            return zipLevel;
        } else {
            return enumLevel;
        }
    }

    /**
     * 計算結果の列挙用住所コードを取得します。
     * 
     * @return 下位住所列挙用住所コード
     */
    private String getEnumCode() {
        String enumCode = "";

        AddressItem item = leveledItem.getLowerestItem();

        int searchLevel = AddressSearchFragment.this.item != null ? AddressSearchFragment.this.item
                .getAddressLevel() : 0;
        int enumLevel = item != null ? item.getAddressLevel() : 0;
        int zipLevel = zipItem != null ? zipItem.getAddressLevel() : 0;

        if (item == null && AddressSearchFragment.this.item == null
                && zipItem == null) {
            //
        } else if (searchLevel > enumLevel) {
            if (searchLevel >= app.getUserInfo().getGeoMaxAddressLevel()) {
                return null;
            }
            enumCode = AddressSearchFragment.this.item.getAddressCode();
        } else if (zipLevel > enumLevel) {
            if (zipLevel >= app.getUserInfo().getGeoMaxAddressLevel()) {
                return null;
            }
            enumCode = AddressSearchFragment.this.zipItem.getAddressCode();
        } else {
            if (enumLevel >= app.getUserInfo().getGeoMaxAddressLevel()
                    || item.getLowerAddressLevel() <= 0) {
                return null;
            }
            enumCode = item.getAddressCode();
        }
        return enumCode;
    }

    /**
     * 選択中の住所を取得します。
     * 
     * @return 住所
     */
    private String getFullAddress() {
        StringBuffer fullAddress = new StringBuffer();
        if (item != null) {
            fullAddress.append(item.getAnalyzedAddress());
        }
        if (zipItem != null) {
            fullAddress.append(zipItem.getFullAddress());
        }
        Utilities.appendDelimiter(fullAddress, leveledItem.getFullAddress(),
                DELIMITER);
        fullAddress.append(leveledItem.getFullAddress());
        return fullAddress.toString();
    }

    /**
     * 適用ボタンを初期化します。
     */
    private void initializeAdaptButton() {
        buttonAdaptFilter = (Button) getView().findViewById(
                R.id.button_address_select_filter);
        buttonAdaptFilter.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                data.clear();
                visibleItems.clear();
                String s = editFilter.getText().toString();
                if (enumItems != null) {
                    if (s.equals("")) {
                        for (AddressItem item : enumItems) {
                            Map<String, String> map = new HashMap<String, String>();
                            map.put(ADDRESS, item.getAddress());
                            data.add(map);
                            visibleItems.add(item);
                        }
                    } else {
                        String hankakuStr = Utilities.convertToHankakuNum(s);
                        for (AddressItem item : enumItems) {
                            String address = Utilities.convertToHankakuNum(item
                                    .getAddress());
                            if (address.contains(hankakuStr)) {
                                Map<String, String> map = new HashMap<String, String>();
                                map.put(ADDRESS, item.getAddress());
                                data.add(map);
                                visibleItems.add(item);
                            }
                        }
                    }
                }
                adapter.notifyDataSetChanged();
            }
        });
    }

    /**
     * 絞り込みチェックボックスを初期化します。
     */
    private void initializeAddressSelectCheckBox() {
        checkAddressSelect = (CheckBox) getView().findViewById(
                R.id.checkBox_address_select);
        checkAddressSelect.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                if (checkAddressSelect.isChecked()) {
                    String enumCode = getEnumCode();
                    if (enumCode == null) {
                        return;
                    }
                    EnumAddressTask task = new EnumAddressTask(
                            AddressSearchFragment.this);
                    taskSearch = task;
                    task.execute(enumCode);
                } else {
                    visibleItems.clear();
                    data.clear();
                    adapter.notifyDataSetChanged();
                }
            }
        });
    }

    /**
     * クリアーボタンを初期化します。
     */
    private void initializeClearButton() {
        buttonClear = (Button) getView().findViewById(
                R.id.button_address_select_clear);
        buttonClear.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                clearResult();
            }
        });
    }

    /**
     * 下位住所列挙用グリッドビューを初期化します。
     */
    private void initializeGridView() {
        gridView = (GridView) getView().findViewById(
                R.id.gridView_address_select);
        data = new ArrayList<Map<String, String>>();
        adapter = new SimpleAdapter(getActivity().getApplicationContext(),
                data, R.layout.grid_item, new String[] { ADDRESS, },
                new int[] { android.R.id.text1 });
        gridView.setAdapter(adapter);
        gridView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                    int position, long id) {
                AddressItem item = visibleItems.get(position);
                int addressLevel = item.getAddressLevel();
                leveledItem.setItem(addressLevel, item);
                labelAnalyzedAddress.setText(getFullAddress());
                labelAddressLevel.setText(GeoUtils.getGeoLevelName(
                        getActivity().getApplicationContext(),
                        item.getAddressLevel()));
                buttonOK.setEnabled(true);
                if (item.getLowerAddressLevel() != 0
                        && addressLevel < app.getUserInfo()
                                .getGeoMaxAddressLevel()) {
                    EnumAddressTask task = new EnumAddressTask(
                            AddressSearchFragment.this);
                    taskSearch = task;
                    task.execute(item.getAddressCode());
                }
            }
        });
    }

    /**
     * 登録ボタンを初期化します。
     */
    private void initializeOKButton() {
        buttonOK = (Button) getView().findViewById(R.id.button_ok);
        buttonOK.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                AddressItem item = leveledItem.getLowerestItem();

                if (item == null && AddressSearchFragment.this.item == null
                        && zipItem == null) {
                    return;
                }

                int searchLevel = AddressSearchFragment.this.item != null ? AddressSearchFragment.this.item
                        .getAddressLevel() : 0;
                int enumLevel = item != null ? item.getAddressLevel() : 0;
                int zipLevel = zipItem != null ? zipItem.getAddressLevel() : 0;

                Loc loc = new Loc();
                if (searchLevel > enumLevel) {
                    loc.setLon(AddressSearchFragment.this.item.getLon());
                    loc.setLat(AddressSearchFragment.this.item.getLat());
                    loc.setTag(AddressSearchFragment.this.item
                            .getAnalyzedAddress());
                } else if (zipLevel > enumLevel) {
                    loc.setLon(zipItem.getLon());
                    loc.setLat(zipItem.getLat());
                    loc.setTag(zipItem.getFullAddress());
                } else {
                    loc.setLon(item.getLon());
                    loc.setLat(item.getLat());
                    loc.setTag(getFullAddress());
                }

                app.addLoc(loc);
                getActivity().setResult(Activity.RESULT_OK);
                getActivity().finish();
            }
        });
    }

    /**
     * 検索ボタンを初期化します。
     */
    private void initializeSearchButton() {
        buttonSearch = (Button) getView().findViewById(
                R.id.button_search_address);
        buttonSearch.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                String input = editSearchAddress.getText().toString();
                if (input.matches("[\\d]{7}")
                        || input.matches("[\\d]{3}[\\‐\\ー\\―\\－\\-][\\d]{4}")) {
                    // 郵便番号
                    clearResult();
                    EnumZipTask task = new EnumZipTask(
                            AddressSearchFragment.this);
                    taskSearch = task;
                    task.execute(input);
                } else {
                    // 住所
                    if (!validateSearchAddressParam()) {
                        return;
                    }
                    SearchAddressItem item = new SearchAddressItem();
                    item.setSearchAddress(editSearchAddress.getText()
                            .toString());
                    clearResult();
                    SearchAddressTask task = new SearchAddressTask(
                            AddressSearchFragment.this);
                    taskSearch = task;
                    task.execute(item);
                }
            }
        });
    }

    /**
     * エラーダイアログを表示します。
     */
    private void showErrorDialog(String message) {
        InformationDialogFragment infoDlg = InformationDialogFragment
                .newInstance(DialogID.CALC_FAILED,
                        getString(R.string.msg_error), message);
        Utilities.showDialog(infoDlg, DialogTag.CALC_FAILED,
                getFragmentManager());
    }

    /**
     * 住所検索のパラメータを検証します。
     * 
     * @return 妥当な場合true
     */
    private boolean validateSearchAddressParam() {
        if (1 > app.getUserInfo().getGeoMaxLocs()) {
            showErrorDialog(getString(R.string.msg_address_count_over));
            return false;
        }
        if (!app.getUserInfo().validateGeoCount()) {
            showErrorDialog(getString(R.string.msg_geo_count_over));
            return false;
        }
        if (!app.getUserInfo().validateExpireDay()) {
            showErrorDialog(getString(R.string.msg_expired));
            return false;
        }
        return true;
    }
}
