﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.CalcArea3PrefManager;
import jp.co.act_inc.actservicesample.CalcRoutePrefManager;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.RangedEditPreference;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaKind;
import jp.co.act_inc.actservicesample.dcservice.DistUtils;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.os.Bundle;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;
import android.preference.PreferenceManager;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

/**
 * 片道一括計算設定画面です。
 * 
 * @author ishi
 * 
 */
public class CalcOneWay3Activity extends PreferenceActivity implements
        OnSharedPreferenceChangeListener {
    private MyApp app;
    private Button buttonStartCalcOneWay3;
    private Preference prefAreaDirection;
    private Preference prefAreaKind;
    private Preference prefAreaRange;
    private Preference prefCalcKind;
    private Preference prefUseAirway;
    private Preference prefUseFerry;
    private Preference prefUseFreightRailway;
    private Preference prefUseHighway;
    private Preference prefUseLimitedExpress;
    private Preference prefUsePayRoadFerry;
    private Preference prefUseRailway;
    private Preference prefUseShip;

    @Override
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
            String key) {
        if (key.equals(getString(R.string.calc_area3_pref_calc_kind_key))) {
            updateCalcKindSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_highway_key))) {
            updateUseHighwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_freight_railway_key))) {
            updateUseFreightRailwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_airway_key))) {
            updateUseAirwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_ferry_key))) {
            updateUseFerrySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_pay_road_ferry_key))) {
            updateUsePayRoadFerrySummary(sharedPreferences);
        } else if (key.equals(getString(R.string.calc_area3_pref_use_ship_key))) {
            updateUseShipSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_railway_key))) {
            updateUseRailwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_use_limited_express_key))) {
            updateUseLimitedExpressSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_area_kind_key))) {
            updateAreaKindSummary(sharedPreferences);
            updateAreaRangeSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_area_range_key))) {
            updateAreaRangeSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_area3_pref_area_direction_key))) {
            updateAreaDirectionSummary(sharedPreferences);
        }
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setResult(RESULT_CANCELED);
        this.setContentView(R.layout.calc_area3_pref);
        this.addPreferencesFromResource(R.xml.calc_one_way3_preference);
        setTitle(getString(R.string.activity_title_calc_one_way3_preference));
        app = (MyApp) getApplication();

        initializeStartCalcButton();

        prefAreaDirection = findPreference(getString(R.string.calc_area3_pref_area_direction_key));
        prefAreaKind = findPreference(getString(R.string.calc_area3_pref_area_kind_key));
        prefAreaRange = findPreference(getString(R.string.calc_area3_pref_area_range_key));
        prefCalcKind = findPreference(getString(R.string.calc_area3_pref_calc_kind_key));
        prefUseHighway = findPreference(getString(R.string.calc_area3_pref_use_highway_key));
        prefUseFreightRailway = findPreference(getString(R.string.calc_area3_pref_use_freight_railway_key));
        prefUseAirway = findPreference(getString(R.string.calc_area3_pref_use_airway_key));
        prefUseFerry = findPreference(getString(R.string.calc_area3_pref_use_ferry_key));
        prefUsePayRoadFerry = findPreference(getString(R.string.calc_area3_pref_use_pay_road_ferry_key));
        prefUseShip = findPreference(getString(R.string.calc_area3_pref_use_ship_key));
        prefUseRailway = findPreference(getString(R.string.calc_area3_pref_use_railway_key));
        prefUseLimitedExpress = findPreference(getString(R.string.calc_area3_pref_use_limited_express_key));

        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getApplicationContext());
        // 最大エリア範囲を設定
        int areaKind = CalcArea3PrefManager.getAreaKind(prefs,
                getApplicationContext());
        int areaRange = CalcArea3PrefManager.getAreaRange(prefs,
                getApplicationContext());
        if (app.getUserInfo().getCalcAreaMaxTime() >= 0) {
            int value;
            if (areaKind == AreaKind.TIME) {
                value = app.getUserInfo().getCalcAreaMaxTime() / 600;
            } else {
                value = app.getUserInfo().getCalcAreaMaxDist() / 1000;
            }
            if (areaRange > value) {
                Editor editor = prefs.edit();
                editor.putInt(
                        getString(R.string.calc_area3_pref_area_range_key),
                        value);
                editor.commit();
            }
            ((RangedEditPreference) findPreference(getString(R.string.calc_area3_pref_area_range_key)))
                    .setMax(value);
        }
        // サマリー更新
        updateCalcKindSummary(prefs);
        updateUseHighwaySummary(prefs);
        updateUseFreightRailwaySummary(prefs);
        updateUseAirwaySummary(prefs);
        updateUseFerrySummary(prefs);
        updateUsePayRoadFerrySummary(prefs);
        updateUseShipSummary(prefs);
        updateAreaKindSummary(prefs);
        updateAreaRangeSummary(prefs);
        updateAreaDirectionSummary(prefs);
        updateUseRailwaySummary(prefs);
        updateUseLimitedExpressSummary(prefs);

        enableTransportFlag(prefs);
    }

    @Override
    protected void onPause() {
        super.onPause();
        getPreferenceScreen().getSharedPreferences()
                .unregisterOnSharedPreferenceChangeListener(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        getPreferenceScreen().getSharedPreferences()
                .registerOnSharedPreferenceChangeListener(this);
    }

    /**
     * 輸送機関フラグから設定コントロールの有効・無効を設定します。
     * 
     * @param prefs
     *            共有設定
     */
    private void enableTransportFlag(SharedPreferences prefs) {
        String nwid = prefs.getString(getString(R.string.dcws_pref_nwid_key),
                "");
        if (!DistUtils.isForCar(nwid)) {
            prefUseHighway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseHighway);
        }
        if (!DistUtils.isForFreightRailway(nwid)) {
            prefUseFreightRailway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseFreightRailway);
        }
        if (!DistUtils.isForAirway(nwid)) {
            prefUseAirway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseAirway);
        }
        if (!DistUtils.isForFerry(nwid)) {
            prefUseFerry.setEnabled(false);
            prefUsePayRoadFerry.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseFerry);
            category.removePreference(prefUsePayRoadFerry);
        }
        if (!DistUtils.isForShip(nwid)) {
            prefUseShip.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseShip);
        }
        if (!DistUtils.isForRailway(nwid)) {
            prefUseRailway.setEnabled(false);
            prefUseLimitedExpress.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseRailway);
            category.removePreference(prefUseLimitedExpress);
        }
    }

    /**
     * 計算開始ボタンを初期化します。
     */
    private void initializeStartCalcButton() {
        buttonStartCalcOneWay3 = (Button) findViewById(R.id.button_start_calc_area3);
        buttonStartCalcOneWay3.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View arg0) {
                setResult(RESULT_OK);
                finish();
            }
        });
    }

    /**
     * AreaDirectionのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateAreaDirectionSummary(SharedPreferences prefs) {
        int areaDirction = CalcArea3PrefManager.getAreaDirection(prefs,
                getApplicationContext());
        prefAreaDirection.setSummary(DistUtils.getAreaDirectionString(
                getApplicationContext(), areaDirction));
    }

    /**
     * AreaKindのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateAreaKindSummary(SharedPreferences prefs) {
        int areaKind = CalcArea3PrefManager.getAreaKind(prefs,
                getApplicationContext());
        prefAreaKind.setSummary(DistUtils.getAreaKindString(
                getApplicationContext(), areaKind));
    }

    /**
     * AreaRangeのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateAreaRangeSummary(SharedPreferences prefs) {
        int areaRange = CalcArea3PrefManager.getAreaRange(prefs,
                getApplicationContext());
        int areaKind = CalcArea3PrefManager.getAreaKind(prefs,
                getApplicationContext());
        prefAreaRange.setSummary(DistUtils.getAreaRangeString(
                getApplicationContext(), areaRange, areaKind));
    }

    /**
     * CalcKindのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateCalcKindSummary(SharedPreferences prefs) {
        int calcKind = CalcArea3PrefManager.getCalcKind(prefs,
                getApplicationContext());
        prefCalcKind.setSummary(DistUtils.getCalcKindString(
                getApplicationContext(), calcKind));
    }

    /**
     * UseAirwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseAirwaySummary(SharedPreferences prefs) {
        int useAirway = CalcArea3PrefManager.getUseAirway(prefs,
                getApplicationContext());
        prefUseAirway.setSummary(DistUtils.getUseAirwayString(
                getApplicationContext(), useAirway));
    }

    /**
     * UseFerryのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseFerrySummary(SharedPreferences prefs) {
        int useFerry = CalcArea3PrefManager.getUseFerry(prefs,
                getApplicationContext());
        prefUseFerry.setSummary(DistUtils.getUseFerryString(
                getApplicationContext(), useFerry));
    }

    /**
     * UseFreightRailwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseFreightRailwaySummary(SharedPreferences prefs) {
        int useFreightRailway = CalcArea3PrefManager.getUseFreightRailway(
                prefs, getApplicationContext());
        prefUseFreightRailway.setSummary(DistUtils.getUseFreightRailwayString(
                getApplicationContext(), useFreightRailway));
    }

    /**
     * UseHighwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseHighwaySummary(SharedPreferences prefs) {
        int useHighway = CalcArea3PrefManager.getUseHighway(prefs,
                getApplicationContext());
        prefUseHighway.setSummary(DistUtils.getUseHighwayString(
                getApplicationContext(), useHighway));
    }

    /**
     * UseLimitedExpressのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseLimitedExpressSummary(SharedPreferences prefs) {
        int useLimitedExpress = CalcRoutePrefManager.getUseLimitedExpress(
                prefs, getApplicationContext());
        prefUseLimitedExpress.setSummary(DistUtils.getUseLimitedExpressString(
                getApplicationContext(), useLimitedExpress));
    }

    /**
     * UsePayRoadFerryのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUsePayRoadFerrySummary(SharedPreferences prefs) {
        int usePayRoadFerry = CalcArea3PrefManager.getUsePayRoadFerry(prefs,
                getApplicationContext());
        prefUsePayRoadFerry.setSummary(DistUtils.getUsePayRoadFerryString(
                getApplicationContext(), usePayRoadFerry));
    }

    /**
     * UseRailwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseRailwaySummary(SharedPreferences prefs) {
        int useRailway = CalcRoutePrefManager.getUseRailway(prefs,
                getApplicationContext());
        prefUseRailway.setSummary(DistUtils.getUseRailwayString(
                getApplicationContext(), useRailway));
    }

    /**
     * UseShipのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseShipSummary(SharedPreferences prefs) {
        int useShip = CalcArea3PrefManager.getUseShip(prefs,
                getApplicationContext());
        prefUseShip.setSummary(DistUtils.getUseShipString(
                getApplicationContext(), useShip));
    }
}
