﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.CalcRoutePrefManager;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.dcservice.DistUtils;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.os.Bundle;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;
import android.preference.PreferenceManager;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

/**
 * ルート計算画面です。
 * 
 * @author ishi
 * 
 */
public class CalcRouteActivity extends PreferenceActivity implements
        OnSharedPreferenceChangeListener {
    private Button buttonStartCalcRoute;
    private Preference prefCalcKind;
    private Preference prefRouteKind;
    private Preference prefUseAirway;
    private Preference prefUseFerry;
    private Preference prefUseFreightRailway;
    private Preference prefUseHighway;
    private Preference prefUseLimitedExpress;
    private Preference prefUsePayRoadFerry;
    private Preference prefUseRailway;
    private Preference prefUseShip;

    @Override
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
            String key) {
        if (key.equals(getString(R.string.calc_route_pref_calc_kind_key))) {
            updateCalcKindSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_highway_key))) {
            updateUseHighwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_freight_railway_key))) {
            updateUseFreightRailwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_airway_key))) {
            updateUseAirwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_ferry_key))) {
            updateUseFerrySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_pay_road_ferry_key))) {
            updateUsePayRoadFerrySummary(sharedPreferences);
        } else if (key.equals(getString(R.string.calc_route_pref_use_ship_key))) {
            updateUseShipSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_railway_key))) {
            updateUseRailwaySummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_use_limited_express_key))) {
            updateUseLimitedExpressSummary(sharedPreferences);
        } else if (key
                .equals(getString(R.string.calc_route_pref_route_kind_key))) {
            updateRouteKindSummary(sharedPreferences);
        }
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setResult(RESULT_CANCELED);
        this.setContentView(R.layout.calc_route_pref);
        this.addPreferencesFromResource(R.xml.calc_route_preference);
        setTitle(R.string.activity_title_calc_route_preference);

        initializeStartCalcButton();

        prefCalcKind = findPreference(getString(R.string.calc_route_pref_calc_kind_key));
        prefUseHighway = findPreference(getString(R.string.calc_route_pref_use_highway_key));
        prefUseFreightRailway = findPreference(getString(R.string.calc_route_pref_use_freight_railway_key));
        prefUseAirway = findPreference(getString(R.string.calc_route_pref_use_airway_key));
        prefUseFerry = findPreference(getString(R.string.calc_route_pref_use_ferry_key));
        prefUsePayRoadFerry = findPreference(getString(R.string.calc_route_pref_use_pay_road_ferry_key));
        prefUseShip = findPreference(getString(R.string.calc_route_pref_use_ship_key));
        prefUseRailway = findPreference(getString(R.string.calc_route_pref_use_railway_key));
        prefUseLimitedExpress = findPreference(getString(R.string.calc_route_pref_use_limited_express_key));
        prefRouteKind = findPreference(getString(R.string.calc_route_pref_route_kind_key));

        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getApplicationContext());
        updateCalcKindSummary(prefs);
        updateUseHighwaySummary(prefs);
        updateUseFreightRailwaySummary(prefs);
        updateUseAirwaySummary(prefs);
        updateUseFerrySummary(prefs);
        updateUsePayRoadFerrySummary(prefs);
        updateUseShipSummary(prefs);
        updateUseRailwaySummary(prefs);
        updateUseLimitedExpressSummary(prefs);
        updateRouteKindSummary(prefs);

        enableTransportFlag(prefs);
    }

    @Override
    protected void onPause() {
        super.onPause();
        getPreferenceScreen().getSharedPreferences()
                .unregisterOnSharedPreferenceChangeListener(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        getPreferenceScreen().getSharedPreferences()
                .registerOnSharedPreferenceChangeListener(this);
    }

    /**
     * 輸送機関フラグから設定コントロールの有効・無効を設定します。
     * 
     * @param prefs
     *            共有設定
     */
    private void enableTransportFlag(SharedPreferences prefs) {
        String nwid = prefs.getString(getString(R.string.dcws_pref_nwid_key),
                "");
        if (!DistUtils.isForCar(nwid)) {
            prefUseHighway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseHighway);
        }
        if (!DistUtils.isForFreightRailway(nwid)) {
            prefUseFreightRailway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseFreightRailway);
        }
        if (!DistUtils.isForAirway(nwid)) {
            prefUseAirway.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseAirway);
        }
        if (!DistUtils.isForFerry(nwid)) {
            prefUseFerry.setEnabled(false);
            prefUsePayRoadFerry.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseFerry);
            category.removePreference(prefUsePayRoadFerry);
        }
        if (!DistUtils.isForShip(nwid)) {
            prefUseShip.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseShip);
        }
        if (!DistUtils.isForRailway(nwid)) {
            prefUseRailway.setEnabled(false);
            prefUseLimitedExpress.setEnabled(false);
            PreferenceCategory category = (PreferenceCategory) findPreference(getString(R.string.pref_category_calc_type_key));
            category.removePreference(prefUseRailway);
            category.removePreference(prefUseLimitedExpress);
        }
    }

    /**
     * 計算開始ボタンを初期化します。
     */
    private void initializeStartCalcButton() {
        buttonStartCalcRoute = (Button) findViewById(R.id.button_start_calc_route);
        buttonStartCalcRoute.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View arg0) {
                setResult(RESULT_OK);
                finish();
            }
        });
    }

    /**
     * CalcKindのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateCalcKindSummary(SharedPreferences prefs) {
        int calcKind = CalcRoutePrefManager.getCalcKind(prefs,
                getApplicationContext());
        prefCalcKind.setSummary(DistUtils.getCalcKindString(
                getApplicationContext(), calcKind));
    }

    /**
     * RouteKindのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateRouteKindSummary(SharedPreferences prefs) {
        int routeKind = CalcRoutePrefManager.getRouteKind(prefs,
                getApplicationContext());
        prefRouteKind.setSummary(DistUtils.getRouteKindString(
                getApplicationContext(), routeKind));
    }

    /**
     * UseAirwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseAirwaySummary(SharedPreferences prefs) {
        int useAirway = CalcRoutePrefManager.getUseAirway(prefs,
                getApplicationContext());
        prefUseAirway.setSummary(DistUtils.getUseAirwayString(
                getApplicationContext(), useAirway));
    }

    /**
     * UseFerryのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseFerrySummary(SharedPreferences prefs) {
        int useFerry = CalcRoutePrefManager.getUseFerry(prefs,
                getApplicationContext());
        prefUseFerry.setSummary(DistUtils.getUseFerryString(
                getApplicationContext(), useFerry));
    }

    /**
     * UseFreightRailwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseFreightRailwaySummary(SharedPreferences prefs) {
        int useFreightRailway = CalcRoutePrefManager.getUseFreightRailway(
                prefs, getApplicationContext());
        prefUseFreightRailway.setSummary(DistUtils.getUseFreightRailwayString(
                getApplicationContext(), useFreightRailway));
    }

    /**
     * UseHighwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseHighwaySummary(SharedPreferences prefs) {
        int useHighway = CalcRoutePrefManager.getUseHighway(prefs,
                getApplicationContext());
        prefUseHighway.setSummary(DistUtils.getUseHighwayString(
                getApplicationContext(), useHighway));
    }

    /**
     * UseLimitedExpressのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseLimitedExpressSummary(SharedPreferences prefs) {
        int useLimitedExpress = CalcRoutePrefManager.getUseLimitedExpress(
                prefs, getApplicationContext());
        prefUseLimitedExpress.setSummary(DistUtils.getUseLimitedExpressString(
                getApplicationContext(), useLimitedExpress));
    }

    /**
     * UsePayRoadFerryのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUsePayRoadFerrySummary(SharedPreferences prefs) {
        int usePayRoadFerry = CalcRoutePrefManager.getUsePayRoadFerry(prefs,
                getApplicationContext());
        prefUsePayRoadFerry.setSummary(DistUtils.getUsePayRoadFerryString(
                getApplicationContext(), usePayRoadFerry));
    }

    /**
     * UseRailwayのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseRailwaySummary(SharedPreferences prefs) {
        int useRailway = CalcRoutePrefManager.getUseRailway(prefs,
                getApplicationContext());
        prefUseRailway.setSummary(DistUtils.getUseRailwayString(
                getApplicationContext(), useRailway));
    }

    /**
     * UseShipのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUseShipSummary(SharedPreferences prefs) {
        int useShip = CalcRoutePrefManager.getUseShip(prefs,
                getApplicationContext());
        prefUseShip.setSummary(DistUtils.getUseShipString(
                getApplicationContext(), useShip));
    }
}
