﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.R;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.WindowManager.LayoutParams;
import android.widget.EditText;

/**
 * エディットダイアログです。
 * 
 * @author ishi
 * 
 */
public class EditDialogFragment extends DialogFragment {
    /**
     * エディットダイアログ用リスナーです。
     * 
     * @author ishi
     * 
     */
    interface OnEditDialogListener {
        /**
         * 入力が終了したときのコールバックです。
         * 
         * @param tag
         *            タグ
         * @param text
         *            入力文字列
         * @param position
         *            インデックスなどの情報（このクラスでは使用しません。）
         */
        void onEditDialogEnd(String tag, String text, int position);
    }

    /**
     * 新しいインスタンスを生成します。
     * 
     * @param title
     *            タイトル
     * @param text
     *            入力文字列
     * @param inputType
     *            入力形式
     * @param position
     *            インデックスなどの情報（このクラスでは使用しません。）
     * @return EditDialogFragment
     */
    public static EditDialogFragment newInstance(String title, String text,
            int inputType, int position) {
        EditDialogFragment dialog = new EditDialogFragment();
        Bundle args = new Bundle();
        args.putString(BundleKey.TITLE, title);
        args.putString(BundleKey.TEXT, text);
        args.putInt(BundleKey.POSITION, position);
        args.putInt(BundleKey.INPUT_TYPE, inputType);
        dialog.setArguments(args);
        return dialog;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        LayoutInflater inflater = getActivity().getLayoutInflater();
        final View view = inflater.inflate(R.layout.edit_dialog, null);
        final EditText edit = (EditText) view.findViewById(R.id.editText_value);
        edit.setText(getArguments().getString(BundleKey.TEXT));
        edit.requestFocus();
        int inputType = getArguments().getInt(BundleKey.INPUT_TYPE);
        edit.setInputType(inputType);
        String title = getArguments().getString(BundleKey.TITLE);
        final int position = getArguments().getInt(BundleKey.POSITION);
        final OnEditDialogListener listener;
        if (getTargetFragment() != null) {
            listener = (OnEditDialogListener) getTargetFragment();
        } else {
            listener = (OnEditDialogListener) getActivity();
        }
        Dialog dialog = new AlertDialog.Builder(getActivity()).setTitle(title)
                .setView(view)
                .setPositiveButton(R.string.common_ok, new OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        listener.onEditDialogEnd(getTag(), edit.getText()
                                .toString(), position);
                    }
                }).setNegativeButton(R.string.common_cancel, null).create();
        dialog.getWindow().setSoftInputMode(
                LayoutParams.SOFT_INPUT_STATE_VISIBLE);
        return dialog;
    }
}
