﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.R;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;

/**
 * メッセージダイアログです。
 * 
 * @author ishi
 * 
 */
public class InformationDialogFragment extends DialogFragment {
    /**
     * 情報ダイアログ用リスナーです。
     * 
     * @author ishi
     * 
     */
    public interface OnInformationDialogListener {
        /**
         * 閉じたときのコールバックです。
         * 
         * @param requestCode
         *            リクエストコード
         */
        public void onInformationDialogClose(int requestCode);
    }

    /**
     * インスタンスを生成します。
     * 
     * @param requestCode
     *            リクエストコード
     * @param title
     *            タイトル
     * @param message
     *            メッセージ
     * @return InformationDialogFragment
     */
    public static InformationDialogFragment newInstance(int requestCode,
            String title, String message) {
        InformationDialogFragment frag = new InformationDialogFragment();
        Bundle args = new Bundle();
        args.putInt(BundleKey.REQUEST_CODE, requestCode);
        args.putString(BundleKey.TITLE, title);
        args.putString(BundleKey.MESSAGE, message);
        frag.setArguments(args);
        return frag;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        Logger.writeDebugLog("InformationDialogFragment", "onCreateDialog");
        final int requestCode = getArguments().getInt(BundleKey.REQUEST_CODE);
        String title = getArguments().getString(BundleKey.TITLE);
        String message = getArguments().getString(BundleKey.MESSAGE);
        final OnInformationDialogListener listener;
        if (getTargetFragment() != null) {
            listener = (OnInformationDialogListener) getTargetFragment();
        } else {
            listener = (OnInformationDialogListener) getActivity();
        }
        return new AlertDialog.Builder(getActivity())
                .setTitle(title)
                .setMessage(message)
                .setPositiveButton(getString(R.string.common_ok),
                        new OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog,
                                    int which) {
                                listener.onInformationDialogClose(requestCode);
                            }
                        }).setOnCancelListener(new OnCancelListener() {
                    @Override
                    public void onCancel(DialogInterface dialog) {
                        listener.onInformationDialogClose(requestCode);
                    }
                }).create();
    }
}
