﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.Locale;

import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.EditDialogFragment.OnEditDialogListener;
import jp.co.act_inc.actservicesample.activity.MenuDialogFragment.OnMenuDialogListener;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.ListFragment;
import android.text.InputType;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

/**
 * 地点一覧画面です。
 * 
 * @author ishi
 * 
 */
public class LocFragment extends ListFragment implements OnEditDialogListener,
        OnMenuDialogListener {
    /**
     * ダイアログIDです。
     * 
     * @author ishi
     * 
     */
    class DialogID {
        static final int LOC_TAG_EDIT = 0;
        static final int FILENAME_EDIT = 1;
        static final int SELECT_FILE = 2;
        static final int MENU = 3;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        static final String MENU = "menu_dialog";
        static final String FILENAME_EDIT = "filename_edit_dialog";
        static final String LOC_TAG_EDIT = "loc_tag_edit_dialog";
        static final String SELECT_FILE = "select_file_dialog";
        static final String CALC_FAILED = "calc_failed_dialog";
    }

    /**
     * リストビュー用アダプターです。
     * 
     * @author ishi
     * 
     */
    class LocAdapter extends BaseAdapter {
        @Override
        public int getCount() {
            int count = 0;
            if (app.getLocs() != null) {
                count = app.getLocs().size();
            }
            return count;
        }

        @Override
        public Object getItem(int position) {
            if (app.getLocs() != null) {
                return app.getLocs().get(position);
            }
            return null;
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View v = convertView;
            if (v == null) {
                LayoutInflater inflater = (LayoutInflater) getActivity()
                        .getSystemService(Context.LAYOUT_INFLATER_SERVICE);
                v = inflater.inflate(R.layout.row_loc, null);
            }
            String num = "";
            String tag = "";
            String lon = "";
            String lat = "";
            String center = "";

            Loc loc = (Loc) getItem(position);
            if (loc != null) {
                num = Integer.toString(position + 1);
                tag = loc.getTag();
                lon = String.format(Locale.getDefault(), "%.6f", loc.getLon());
                lat = String.format(Locale.getDefault(), "%.6f", loc.getLat());
                center = app.getStartLocIndex() == position ? getString(R.string.common_start_point)
                        : "";
            }

            ((TextView) v.findViewById(R.id.textView_row_loc_num)).setText(num);
            ((TextView) v.findViewById(R.id.textView_row_loc_tag)).setText(tag);
            ((TextView) v.findViewById(R.id.textView_row_loc_lon)).setText(lon);
            ((TextView) v.findViewById(R.id.textView_row_loc_lat)).setText(lat);
            ((TextView) v.findViewById(R.id.textView_row_loc_center))
                    .setText(center);
            return v;
        }
    }

    static final String POSITION = "position";

    private MyApp app;
    private Button buttonClear;
    private ListView listView;
    private LocAdapter adapter;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        initializeClearButton();
        initializeListView();
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        app = (MyApp) getActivity().getApplication();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        return inflater.inflate(R.layout.loc_fragment, null, false);
    }

    @Override
    public void onEditDialogEnd(String tag, String text, int position) {
        if (tag.equals(DialogTag.LOC_TAG_EDIT)) {
            Loc loc = app.getLocs().get(position);
            loc.setTag(text);
            app.updateLoc(loc, position);
            adapter.notifyDataSetChanged();
            getActivity().setResult(Activity.RESULT_OK);
        }
    }

    @Override
    public void onMenuSelected(String key, int menuPosition, int position) {
        if (key.equals(DialogTag.MENU)) {
            switch (menuPosition) {
            case 0:
                app.setStartLocIndex(position);
                adapter.notifyDataSetChanged();
                break;
            case 1:
                showCenter(position);
                break;
            case 2:
                EditDialogFragment fragment = EditDialogFragment.newInstance(
                        getString(R.string.msg_edit_tag),
                        app.getLocs().get(position).getTag(),
                        InputType.TYPE_CLASS_TEXT
                                | InputType.TYPE_TEXT_VARIATION_NORMAL,
                        position);
                fragment.setTargetFragment(this, DialogID.LOC_TAG_EDIT);
                Utilities.showDialog(fragment, DialogTag.LOC_TAG_EDIT,
                        getFragmentManager());
                break;
            case 3:
                removeLoc(position);
                break;
            }
        }
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);
    }

    /**
     * クリアボタンを初期化します。
     */
    private void initializeClearButton() {
        buttonClear = (Button) getView().findViewById(R.id.button_clear);
        buttonClear.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                app.clearLocs();
                adapter.notifyDataSetChanged();
                getActivity().setResult(Activity.RESULT_OK);
                getActivity().finish();
            }
        });
    }

    /**
     * リストビューを初期化します。
     */
    private void initializeListView() {
        adapter = new LocAdapter();
        listView = (ListView) getView().findViewById(android.R.id.list);
        listView.setAdapter(adapter);
        listView.setOnItemClickListener(new OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                    final int position, long id) {
                String[] menu = { getString(R.string.menuitem_loc_set_start),
                        getString(R.string.menuitem_loc_center),
                        getString(R.string.menuitem_loc_edit_tag),
                        getString(R.string.menuitem_loc_delete) };
                MenuDialogFragment dialog = MenuDialogFragment.newInstance("",
                        menu, position);
                dialog.setTargetFragment(LocFragment.this, DialogID.MENU);
                Utilities.showDialog(dialog, DialogTag.MENU,
                        getFragmentManager());
            }
        });
    }

    /**
     * 地点を削除します。
     * 
     * @param position
     */
    void removeLoc(final int position) {
        app.removeLoc(position);
        adapter.notifyDataSetChanged();
        getActivity().setResult(Activity.RESULT_OK);
    }

    /**
     * 地点を地図の中心に表示します。
     * 
     * @param position
     */
    void showCenter(final int position) {
        Intent intent = new Intent();
        intent.putExtra(BundleKey.CENTER_LON, app.getLocs().get(position)
                .getLon());
        intent.putExtra(BundleKey.CENTER_LAT, app.getLocs().get(position)
                .getLat());
        getActivity().setResult(Activity.RESULT_CANCELED, intent);
        getActivity().finish();
    }
}
