﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.Date;

import jp.co.act_inc.actservicesample.AdminPrefManager;
import jp.co.act_inc.actservicesample.Attachable;
import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.QuestionDialogFragment.OnQuestionDialogListener;
import jp.co.act_inc.actservicesample.adminservice.AdminService;
import jp.co.act_inc.actservicesample.adminservice.GetUserInformation2Response;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.v4.app.FragmentActivity;
import android.text.TextUtils;

/**
 * エントリーポイントです。
 * 
 * @author ishi
 * 
 */
public class MainActivity extends FragmentActivity implements
        OnQuestionDialogListener {
    /**
     * ダイアログのIDです。
     * 
     * @author ishi
     * 
     */
    class DialogID {
        static final int INPUT = 0;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        static final String INPUT = "input_dialog";
        static final String PROGRESS = "progress_dialog";
    }

    /**
     * ユーザー情報取得タスクです。
     * 
     * @author ishi
     * 
     */
    class GetUserInfoTask extends
            AsyncTask<Void, String, GetUserInformation2Response> implements
            Attachable<MainActivity> {
        /**
         * 結果
         */
        private GetUserInformation2Response result = null;
        /**
         * 対象アクティビティ
         */
        private MainActivity activity = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param activity
         *            対象アクティビティ
         */
        public GetUserInfoTask(MainActivity activity) {
            this.activity = activity;
            this.context = activity.getApplicationContext();
        }

        @Override
        public void attach(MainActivity activity) {
            this.activity = activity;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.activity = null;
        }

        @Override
        protected GetUserInformation2Response doInBackground(Void... params) {
            Logger.writeDebugLog("GetUserInfoTask", "doInBackground");
            GetUserInformation2Response result;
            try {
                result = AdminService.getUserInformation2(
                        AdminPrefManager.getAdminUrl(context),
                        AdminPrefManager.getUseSsl(context),
                        AdminPrefManager.createAdminEnviron(context));
            } catch (Exception ex) {
                result = new GetUserInformation2Response();
                result.setException(ex);
            }
            return result;
        }

        @Override
        protected void onPostExecute(GetUserInformation2Response result) {
            super.onPostExecute(result);
            if (this.activity != null) {
                Logger.writeDebugLog("GetUserInfoTask",
                        "onPostExecute attached");
                postExecute(result);
            } else {
                Logger.writeDebugLog("GetUserInfoTask",
                        "onPostExecute detached");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("GetUserInfoTask", "onPreExecute");
            ProgressDialogFragment progress = ProgressDialogFragment
                    .newInstance(getString(R.string.msg_processing),
                            getString(R.string.msg_getting_user_info));
            Utilities.showDialog(progress, DialogTag.PROGRESS,
                    getSupportFragmentManager());
        }

        /**
         * 計算後の処理です。
         * 
         * @param result
         *            結果
         */
        private void postExecute(GetUserInformation2Response result) {
            Logger.writeDebugLog("GetUserInfoTask", "postExecute");
            Utilities.dismissDialog(DialogTag.PROGRESS,
                    activity.getSupportFragmentManager());
            if (result == null || result.getException() != null
                    || !result.getResult()) {
                // 失敗
                QuestionDialogFragment frag = QuestionDialogFragment
                        .newInstance(
                                DialogID.INPUT,
                                activity.getString(R.string.msg_failed_processing),
                                activity.getString(R.string.msg_failed_get_user_info_input_setting));
                frag.setTargetFragment(null, DialogID.INPUT);
                Utilities.showDialog(frag, DialogTag.INPUT,
                        activity.getSupportFragmentManager());
            } else {
                // 成功
                app.setUserInfo(result.getUserInfo());
                Intent intent = new Intent(activity, ActMapActivity.class);
                startActivity(intent);
            }
            taskGetUserInfo = null;
        }
    }

    static Attachable<MainActivity> taskGetUserInfo = null;
    private static MyApp app;

    @Override
    public void onQuestionDialogNegativeClick(int requestCode) {
        Logger.writeDebugLog("MainActivity", "OnNegativeClick");
        finish();
    }

    @Override
    public void onQuestionDialogPositiveClick(int requestCode) {
        Logger.writeDebugLog("MainActivity", "OnPositiveClick");
        Intent intent = new Intent(this, ServicePreferenceActivity.class);
        startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        app = (MyApp) getApplication();
        Logger.writeDebugLog("MainActivity", "OnCreate");
        System.setProperty("http.keepAlive", "false");
    }

    @Override
    protected void onPause() {
        super.onPause();

        if (taskGetUserInfo != null) {
            taskGetUserInfo.detach();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();

        if (taskGetUserInfo == null) {
            Utilities.dismissDialog(DialogTag.PROGRESS,
                    getSupportFragmentManager());
        }

        // 起動モード取得
        boolean login = false;
        Intent prevIntent = getIntent();
        if (prevIntent != null) {
            Bundle bundle = prevIntent.getExtras();
            if (bundle != null) {
                login = bundle.getBoolean(BundleKey.MODE_KEY);
            }
        }

        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getApplicationContext());
        if (login
                || TextUtils.isEmpty(prefs.getString(
                        getString(R.string.admin_pref_username_key), ""))) {
            // ログインモード　または　ユーザー名未記入
            Intent intent = new Intent(MainActivity.this,
                    ServicePreferenceActivity.class);
            startActivity(intent);
        } else if (app.getUserInfo() == null
                || Utilities.compareDate(app.getAccessTime(), new Date()) > 1) {
            // ユーザー情報なし
            if (taskGetUserInfo == null) {
                GetUserInfoTask task = new GetUserInfoTask(this);
                taskGetUserInfo = task;
                task.execute();
            } else {
                taskGetUserInfo.attach(this);
            }
        } else {
            Intent intent = new Intent(MainActivity.this, ActMapActivity.class);
            startActivity(intent);
        }
    }
}
