﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.BundleKey;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;

/**
 * メニューダイアログです。
 * 
 * @author ishi
 * 
 */
public class MenuDialogFragment extends DialogFragment {
    /**
     * メニューダイアログ用リスナーです。
     * 
     * @author ishi
     * 
     */
    interface OnMenuDialogListener {
        /**
         * メニューアイテムが選択されたときのコールバックです。
         * 
         * @param tag
         *            タグ
         * @param menuPosition
         *            選択されたメニューのインデックス
         * @param position
         *            インデックスなどの情報（このクラスでは使用しません。）
         */
        void onMenuSelected(String tag, int menuPosition, int position);
    }

    /**
     * 新しいインスタンスを生成します。
     * 
     * @param title
     *            タイトル
     * @param menuItems
     *            メニューアイテム
     * @param position
     *            インデックスなどの情報（このクラスでは使用しません。）
     * @return EditDialogFragment
     */
    static public MenuDialogFragment newInstance(String title,
            String[] menuItems, int position) {
        MenuDialogFragment dialog = new MenuDialogFragment();
        Bundle args = new Bundle();
        args.putString(BundleKey.TITLE, title);
        args.putStringArray(BundleKey.TEXT_ARRAY, menuItems);
        args.putInt(BundleKey.POSITION, position);
        dialog.setArguments(args);
        return dialog;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        String[] menu = getArguments().getStringArray(BundleKey.TEXT_ARRAY);
        String title = getArguments().getString(BundleKey.TITLE);
        final int position = getArguments().getInt(BundleKey.POSITION);
        final OnMenuDialogListener listener;
        if (getTargetFragment() != null) {
            listener = (OnMenuDialogListener) getTargetFragment();
        } else {
            listener = (OnMenuDialogListener) getActivity();
        }
        return new AlertDialog.Builder(getActivity()).setTitle(title)
                .setItems(menu, new OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        listener.onMenuSelected(getTag(), which, position);
                        dismiss();
                    }
                }).create();
    }
}
