﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.BundleKey;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.R;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;

/**
 * 選択ダイアログです。
 * 
 * @author ishi
 * 
 */
public class QuestionDialogFragment extends DialogFragment {
    /**
     * 質問ダイアログ用リスナーです。
     * 
     * @author ishi
     * 
     */
    public interface OnQuestionDialogListener {
        /**
         * 否定ボタンをクリックしたときのコールバックです。
         * 
         * @param requestCode
         *            リクエストコード
         */
        public void onQuestionDialogNegativeClick(int requestCode);

        /**
         * 肯定ボタンをクリックしたときのコールバックです。
         * 
         * @param requestCode
         *            リクエストコード
         */
        public void onQuestionDialogPositiveClick(int requestCode);
    }

    /**
     * インスタンスを生成します。
     * 
     * @param requestCode
     *            リクエストコード
     * @param title
     *            タイトル
     * @param message
     *            メッセージ
     * @return QuestionDialogFragment
     */
    public static QuestionDialogFragment newInstance(int requestCode,
            String title, String message) {
        QuestionDialogFragment frag = new QuestionDialogFragment();
        Bundle args = new Bundle();
        args.putInt(BundleKey.REQUEST_CODE, requestCode);
        args.putString(BundleKey.TITLE, title);
        args.putString(BundleKey.MESSAGE, message);
        frag.setArguments(args);
        return frag;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        Logger.writeDebugLog("QuestionDialogFragment", "onCreateDialog");
        final int requestCode = getArguments().getInt(BundleKey.REQUEST_CODE);
        String title = getArguments().getString(BundleKey.TITLE);
        String message = getArguments().getString(BundleKey.MESSAGE);
        final OnQuestionDialogListener listener;
        if (getTargetFragment() != null) {
            listener = (OnQuestionDialogListener) getTargetFragment();
        } else {
            listener = (OnQuestionDialogListener) getActivity();
        }
        return new AlertDialog.Builder(getActivity())
                .setTitle(title)
                .setMessage(message)
                .setPositiveButton(getString(R.string.common_ok),
                        new OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog,
                                    int which) {
                                listener.onQuestionDialogPositiveClick(requestCode);
                            }
                        })
                .setNegativeButton(R.string.common_cancel,
                        new OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog,
                                    int which) {
                                listener.onQuestionDialogNegativeClick(requestCode);
                            }
                        }).setOnCancelListener(new OnCancelListener() {
                    @Override
                    public void onCancel(DialogInterface dialog) {
                        listener.onQuestionDialogNegativeClick(requestCode);
                    }
                }).create();
    }
}
