﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/15 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.ArrayList;

import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;

import android.content.Context;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TabHost;

/**
 * 計算結果画面です。
 * 
 * @author ishi
 */
public class ResultActivity extends FragmentActivity implements
        TabHost.OnTabChangeListener {
    /**
     * 空のタブを作成します。
     * 
     * @author ishi
     * 
     */
    class EmptyTabFactory implements TabHost.TabContentFactory {
        private Context context;

        /**
         * コンストラクタ―
         * 
         * @param context
         *            コンテキスト
         */
        public EmptyTabFactory(Context context) {
            this.context = context;
        }

        @Override
        public View createTabContent(String tag) {
            View view = new View(context);
            view.setMinimumWidth(0);
            view.setMinimumHeight(0);
            return view;
        }
    }

    /**
     * タブ情報です。
     * 
     * @author ishi
     * 
     */
    class TabInfo {
        /**
         * タブページにするフラグメントのクラス
         */
        private final Class<?> classType;
        /**
         * タブページにするフラグメントのタグ
         */
        private final String tag;
        /**
         * タブページにするフラグメント
         */
        private Fragment fragment;

        /**
         * コンストラクタ―
         * 
         * @param classType
         *            タブページにするフラグメントのクラス
         * @param tag
         *            タブページにするフラグメントのタグ
         */
        public TabInfo(Class<?> classType, String tag) {
            this.classType = classType;
            this.tag = tag;
        }
    }

    private static final String TAG = "tag";
    private static final String TAB_LOCS = "tab_locs";
    private static final String TAB_RNS = "tab_rns";
    private static final String TAB_TRDS = "tab_trds";
    private static final String TAB_PARAMS = "tab_params";

    MyApp app;
    TabHost tabHost;
    private ArrayList<TabInfo> tabInfos = new ArrayList<TabInfo>();
    TabInfo currentTabInfo = null;
    Button buttonClear;

    @Override
    public void onTabChanged(String tabId) {
        FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
        if (currentTabInfo != null && currentTabInfo.fragment != null) {
            ft.detach(currentTabInfo.fragment);
        }
        int position = tabHost.getCurrentTab();
        TabInfo info = tabInfos.get(position);
        if (info.fragment == null) {
            info.fragment = Fragment.instantiate(this,
                    info.classType.getName(), null);
            ft.add(R.id.real_tabcontent, info.fragment, info.tag);
        } else {
            ft.attach(info.fragment);
        }
        currentTabInfo = info;
        ft.commit();
        getSupportFragmentManager().executePendingTransactions();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setTitle(R.string.activity_title_result);
        app = (MyApp) getApplication();
        if (!app.isResultLoaded()) {
            finish();
            return;
        }

        setContentView(R.layout.result_activity);

        initializeClearButton();

        tabHost = (TabHost) findViewById(android.R.id.tabhost);
        tabHost.setup();
        tabHost.setOnTabChangedListener(this);
        addTab(tabHost.newTabSpec(TAB_LOCS).setIndicator(
                getString(R.string.common_location)), TabLocsFragment.class,
                TAB_LOCS);
        addTab(tabHost.newTabSpec(TAB_RNS).setIndicator(
                getString(R.string.common_rn)), TabRnsFragment.class, TAB_RNS);
        addTab(tabHost.newTabSpec(TAB_TRDS).setIndicator(
                getString(R.string.common_trd)), TabTrdsFragment.class,
                TAB_TRDS);
        addTab(tabHost.newTabSpec(TAB_PARAMS).setIndicator(
                getString(R.string.common_param)), TabParamsFragment.class,
                TAB_PARAMS);

        if (savedInstanceState != null) {
            String tag = savedInstanceState.getString(TAG);
            tabHost.setCurrentTabByTag(tag);
        } else if (app.getResult() != null
                && app.getResult().getCalcType() == CalcResultHolder.CalcType.CALC_AREA) {
            tabHost.setCurrentTab(3);
        }
    }

    @Override
    protected void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);
        outState.putString(TAG, tabHost.getCurrentTabTag());
    }

    /**
     * タブを追加します。
     * 
     * @param tabSpec
     *            TabSpec
     * @param classType
     *            タブページにするフラグメントのクラス
     * @param tag
     *            タグ名
     */
    private void addTab(TabHost.TabSpec tabSpec, Class<?> classType, String tag) {
        Fragment fragment = getSupportFragmentManager().findFragmentByTag(tag);
        if (fragment != null) {
            FragmentTransaction ft = getSupportFragmentManager()
                    .beginTransaction();
            ft.detach(fragment);
            ft.commit();
            getSupportFragmentManager().executePendingTransactions();
        }
        TabInfo info = new TabInfo(classType, tag);
        tabInfos.add(info);
        tabSpec.setContent(new EmptyTabFactory(this));
        tabHost.addTab(tabSpec);
    }

    /**
     * クリアボタンを初期化します。
     */
    private void initializeClearButton() {
        buttonClear = (Button) findViewById(R.id.button_clear);
        buttonClear.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                app.clearResult();
                tabHost.setCurrentTab(tabHost.getCurrentTab());
                setResult(RESULT_OK);
                finish();
            }
        });
    }
}
