﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import jp.co.act_inc.actservicesample.AdminPrefManager;
import jp.co.act_inc.actservicesample.Attachable;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.Utilities;
import jp.co.act_inc.actservicesample.activity.InformationDialogFragment.OnInformationDialogListener;
import jp.co.act_inc.actservicesample.adminservice.AdminService;
import jp.co.act_inc.actservicesample.adminservice.GetUsableNWInfosResponse;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Bundle;
import android.widget.AdapterView;
import android.widget.SimpleAdapter;
import android.support.v4.app.ListFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

/**
 * 計算用道路データ選択画面です。
 * 
 * @author ishi
 * 
 */
public class RoadSelectionFragment extends ListFragment implements
        OnInformationDialogListener {
    /**
     * ダイアログのIDです。
     * 
     * @author ishi
     * 
     */
    class DialogID {
        static final int FAILED = 0;
        static final int PROGRESS = 1;
    }

    /**
     * ダイアログのタグです。
     * 
     * @author ishi
     * 
     */
    class DialogTag {
        static final String FAILED = "failed_dialog";
        static final String PROGRESS = "progress_dialog";
    }

    /**
     * 使用可能道路データ取得用タスクです。
     * 
     * @author ishi
     * 
     */
    class GetNWInfosTask extends
            AsyncTask<Void, String, GetUsableNWInfosResponse> implements
            Attachable<RoadSelectionFragment> {
        /**
         * 結果
         */
        private GetUsableNWInfosResponse result = null;
        /**
         * 対象フラグメント
         */
        private RoadSelectionFragment fragment = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ―
         * 
         * @param fragment
         *            対象フラグメント
         */
        public GetNWInfosTask(RoadSelectionFragment fragment) {
            this.fragment = fragment;
            this.context = getActivity().getApplicationContext();
        }

        @Override
        public void attach(RoadSelectionFragment fragment) {
            this.fragment = fragment;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.fragment = null;
        }

        @Override
        protected GetUsableNWInfosResponse doInBackground(Void... params) {
            Logger.writeDebugLog("GetUserInfoTask", "doInBackground");
            GetUsableNWInfosResponse result = null;
            try {
                result = AdminService.getUsableNWInfos(
                        AdminPrefManager.getAdminUrl(context),
                        AdminPrefManager.getUseSsl(context),
                        AdminPrefManager.createAdminEnviron(context));
            } catch (Exception e) {
                result = new GetUsableNWInfosResponse();
                result.setException(e);
            }
            return result;
        }

        @Override
        protected void onPostExecute(GetUsableNWInfosResponse result) {
            super.onPostExecute(result);
            if (this.fragment != null) {
                Logger.writeDebugLog("GetUserInfoTask",
                        "onPostExecute attached");
                postExecute(result);
            } else {
                Logger.writeDebugLog("GetUserInfoTask",
                        "onPostExecute detached");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("GetUserInfoTask", "onPreExecute");
            ProgressDialogFragment dialog = ProgressDialogFragment.newInstance(
                    getString(R.string.msg_processing),
                    getString(R.string.msg_getting_nwinfos));
            Utilities.showDialog(dialog, DialogTag.PROGRESS,
                    getFragmentManager());
        }

        /**
         * 計算後の処理です。
         * 
         * @param result
         *            計算結果
         */
        private void postExecute(GetUsableNWInfosResponse result) {
            Logger.writeDebugLog("GetUserInfoTask", "postExecute");
            Utilities.dismissDialog(DialogTag.PROGRESS,
                    fragment.getFragmentManager());

            if (result == null || result.getException() != null
                    || !result.getResult()) {
                InformationDialogFragment dialog = InformationDialogFragment
                        .newInstance(
                                DialogID.FAILED,
                                fragment.getString(R.string.msg_failed_processing),
                                fragment.getString(R.string.msg_failed_get_usable_nwinfos));
                dialog.setTargetFragment(fragment, DialogID.FAILED);
                Utilities.showDialog(dialog, DialogTag.FAILED,
                        fragment.getFragmentManager());
            } else {
                fragment.result = result;
                fragment.setAdapter(result);
            }

            taskGetNWinfos = null;
        }
    }

    private static final String RESULT = "result";
    private static final String NOTE = "note";
    private static final String NWID = "nwid";
    private static Attachable<RoadSelectionFragment> taskGetNWinfos;

    /**
     * GetUsableNWInfos結果
     */
    private GetUsableNWInfosResponse result;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        setRetainInstance(true);
        if (savedInstanceState != null) {
            result = savedInstanceState.getParcelable(RESULT);
        }
        if (result != null) {
            setAdapter(result);
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        return inflater.inflate(R.layout.road_selection_fragment, container,
                false);
    }

    @Override
    public void onInformationDialogClose(int requestCode) {
        getActivity().finish();
    }

    @Override
    public void onPause() {
        super.onPause();
        if (taskGetNWinfos != null) {
            taskGetNWinfos.detach();
        }
    }

    @Override
    public void onResume() {
        super.onResume();

        if (result == null) {
            if (taskGetNWinfos == null) {
                Utilities.dismissDialog(DialogTag.PROGRESS,
                        getFragmentManager());

                GetNWInfosTask task = new GetNWInfosTask(this);
                taskGetNWinfos = task;
                task.execute();
            } else {
                taskGetNWinfos.attach(this);
            }
        }
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);

        if (result != null) {
            outState.putParcelable(RESULT, result);
        }
    }

    /**
     * リストビューにアダプターを設定します。
     * 
     * @param result
     *            使用可能計算用道路データ情報取得結果
     */
    private void setAdapter(GetUsableNWInfosResponse result) {
        List<Map<String, String>> data = new ArrayList<Map<String, String>>();
        for (NWInfo info : result.getNwInfos()) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(NOTE, info.getNote());
            map.put(NWID, info.getNwID());
            data.add(map);
        }
        SimpleAdapter adapter = new SimpleAdapter(getActivity()
                .getApplicationContext(), data,
                android.R.layout.simple_list_item_2,
                new String[] { NOTE, NWID }, new int[] { android.R.id.text1,
                        android.R.id.text2 });
        setListAdapter(adapter);
        getListView().setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> parent, View view,
                            int position, long id) {
                        NWInfo nwInfo = RoadSelectionFragment.this.result
                                .getNwInfos().get(position);
                        AdminPrefManager.writeSelectedNWInfo(getActivity()
                                .getApplicationContext(), nwInfo);

                        Intent intent = new Intent(getActivity(),
                                MainActivity.class);
                        intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
                        startActivity(intent);
                        getActivity().setResult(Activity.RESULT_OK);
                        getActivity().finish();
                    }
                });
    }
}
