﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import jp.co.act_inc.actservicesample.AdminPrefManager;
import jp.co.act_inc.actservicesample.Attachable;
import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.activity.ActMapActivity.ActivityCode;
import jp.co.act_inc.actservicesample.adminservice.AdminService;
import jp.co.act_inc.actservicesample.adminservice.GetUserInformation2Response;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.os.AsyncTask;
import android.os.Bundle;
import android.preference.EditTextPreference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceManager;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

/**
 * サービス設定画面です。
 * 
 * @author ishi
 * 
 */
public class ServicePreferenceActivity extends PreferenceActivity implements
        OnSharedPreferenceChangeListener {
    /**
     * ユーザー情報取得用タスク
     * 
     * @author ishi
     * 
     */
    private class GetUserInformation2Task extends
            AsyncTask<Void, Integer, GetUserInformation2Response> implements
            Attachable<ServicePreferenceActivity> {
        /**
         * 対象アクティビティ
         */
        private ServicePreferenceActivity activity = null;
        /**
         * 計算結果
         */
        private GetUserInformation2Response result = null;
        /**
         * コンテキスト
         */
        private Context context = null;

        /**
         * コンストラクタ
         * 
         * @param activity
         *            対象アクティビティ
         */
        public GetUserInformation2Task(ServicePreferenceActivity activity) {
            this.activity = activity;
            this.context = activity.getApplicationContext();
        }

        @Override
        public void attach(ServicePreferenceActivity activity) {
            this.activity = activity;
            if (result != null) {
                postExecute(result);
            }
        }

        @Override
        public void detach() {
            this.activity = null;
        }

        @Override
        protected GetUserInformation2Response doInBackground(Void... params) {
            Logger.writeDebugLog("GetUserInformation2Task", "doInBackground");
            GetUserInformation2Response result = null;
            try {
                result = AdminService.getUserInformation2(
                        AdminPrefManager.getAdminUrl(context),
                        AdminPrefManager.getUseSsl(context),
                        AdminPrefManager.createAdminEnviron(context));
            } catch (Exception e) {
                result = new GetUserInformation2Response();
                result.setException(e);
            }
            return result;
        }

        @Override
        protected void onPostExecute(GetUserInformation2Response result) {
            super.onPostExecute(result);
            if (this.activity != null) {
                Logger.writeDebugLog("GetUserInformation2Task",
                        "onPostExecute attatched");
                postExecute(result);
            } else {
                Logger.writeDebugLog("GetUserInformation2Task",
                        "onPostExecute detatched");
                this.result = result;
            }
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            Logger.writeDebugLog("GetUserInformation2Task", "onPreExecute");
            showDialog(DialogID.PROGRESS);
        }

        /**
         * 実行後の処理です。
         * 
         * @param result
         *            結果
         */
        private void postExecute(GetUserInformation2Response result) {
            Logger.writeDebugLog("GetUserInformation2Task", "postExecute");
            activity.dismissDialog(DialogID.PROGRESS);
            if (result == null || result.getException() != null
                    || !result.getResult()) {
                activity.showDialog(DialogID.FAILED);
            } else {
                activity.app.setUserInfo(result.getUserInfo());
                Intent intent = new Intent(activity,
                        RoadSelectionActivity.class);
                activity.startActivityForResult(intent,
                        ActivityCode.ROAD_SELECT);
            }
        }
    }

    /**
     * ダイアログIDです。
     * 
     * @author ishi
     */
    static class DialogID {
        private static final int PROGRESS = 0;
        private static final int FAILED = 1;
    }

    private static Attachable<ServicePreferenceActivity> task = null;

    private MyApp app;
    private Button buttonNext;

    @Override
    public Object onRetainNonConfigurationInstance() {
        task.detach();
        return task;
    }

    @Override
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
            String key) {
        if (key.equals(getString(R.string.admin_pref_username_key))) {
            updateUsernameSummary(sharedPreferences);
        } else if (key.equals(getString(R.string.admin_pref_use_ssl_key))) {
            updateUseSslSummay(sharedPreferences);
        } else if (key.equals(getString(R.string.admin_pref_admin_url_key))) {
            updateAdminUrl(sharedPreferences);
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        switch (requestCode) {
        case ActivityCode.ROAD_SELECT:
            if (resultCode == RESULT_OK) {
                finish();
            }
            break;
        }
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Logger.writeDebugLog("ServicePreferenceActivity", "OnCreate");

        setContentView(R.layout.service_pref);
        addPreferencesFromResource(R.xml.service_preference);
        setTitle(getString(R.string.activity_title_admin_preference));
        app = (MyApp) getApplication();

        initializeNextButton();

        // サマリー更新
        SharedPreferences prefs = PreferenceManager
                .getDefaultSharedPreferences(getApplicationContext());
        updateUsernameSummary(prefs);
        updateUseSslSummay(prefs);
        updateAdminUrl(prefs);

        task = (GetUserInformation2Task) getLastNonConfigurationInstance();
        if (task != null) {
            task.attach(this);
        }
    }

    @Override
    protected Dialog onCreateDialog(int id) {
        switch (id) {
        case DialogID.PROGRESS:
            ProgressDialog progress = new ProgressDialog(
                    ServicePreferenceActivity.this);
            progress.setProgressStyle(ProgressDialog.STYLE_SPINNER);
            progress.setCancelable(false);
            progress.setTitle(getString(R.string.msg_processing));
            progress.setMessage(getString(R.string.msg_getting_user_info));
            return progress;
        case DialogID.FAILED:
            return new AlertDialog.Builder(ServicePreferenceActivity.this)
                    .setTitle(getString(R.string.msg_failed_processing))
                    .setMessage(getString(R.string.msg_failed_get_user_info))
                    .setPositiveButton(getString(R.string.common_ok), null)
                    .create();
        }

        return super.onCreateDialog(id);
    }

    @Override
    protected void onPause() {
        super.onPause();
        getPreferenceScreen().getSharedPreferences()
                .unregisterOnSharedPreferenceChangeListener(this);
        if (task != null) {
            task.detach();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        getPreferenceScreen().getSharedPreferences()
                .registerOnSharedPreferenceChangeListener(this);
        if (task != null) {
            task.attach(this);
        }
    }

    /**
     * 次へボタンを初期化します。
     */
    private void initializeNextButton() {
        buttonNext = (Button) findViewById(R.id.button_next);
        buttonNext.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                GetUserInformation2Task task = new GetUserInformation2Task(
                        ServicePreferenceActivity.this);
                ServicePreferenceActivity.task = task;
                task.execute();
            }
        });
    }

    /**
     * adminUrlのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences since 1.0
     */
    private void updateAdminUrl(SharedPreferences prefs) {
        EditTextPreference url = (EditTextPreference) findPreference(getString(R.string.admin_pref_admin_url_key));
        url.setSummary(prefs.getString(
                getString(R.string.admin_pref_admin_url_key), ""));
    }

    /**
     * usernameのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences
     */
    private void updateUsernameSummary(SharedPreferences prefs) {
        EditTextPreference username = (EditTextPreference) findPreference(getString(R.string.admin_pref_username_key));
        username.setSummary(prefs.getString(
                getString(R.string.admin_pref_username_key), ""));
    }

    /**
     * useSslのサマリーを更新します。
     * 
     * @param prefs
     *            SharedPreferences since 1.0
     */
    private void updateUseSslSummay(SharedPreferences prefs) {
        boolean useSsl = prefs.getBoolean(
                getString(R.string.admin_pref_use_ssl_key), true);
        String useSslSummary = useSsl ? getString(R.string.common_use)
                : getString(R.string.common_not_use);
        findPreference(getString(R.string.admin_pref_use_ssl_key)).setSummary(
                useSslSummary);
    }
}
