﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/15 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.Transport;
import jp.co.act_inc.actservicesample.dcservice.CA3Param;
import jp.co.act_inc.actservicesample.dcservice.COW3Param;
import jp.co.act_inc.actservicesample.dcservice.CRParam;
import jp.co.act_inc.actservicesample.dcservice.CalcArea3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOneWay3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.DistUtils;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder.CalcType;

import android.os.Bundle;
import android.support.v4.app.ListFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ListView;
import android.widget.SimpleAdapter;
import android.widget.TextView;

/**
 * 計算結果の計算設定タグ画面です。
 * 
 * @author ishi
 * 
 */
public class TabParamsFragment extends ListFragment {
    /**
     * 到達圏／流入圏計算設定用アダプターです。
     * 
     * @author ishi
     * 
     */
    class CA3ParamAdapter extends BaseAdapter {
        private static final String TITLE = "title";
        private static final String VALUE = "value";
        private int[] titlePos = { 0, 6 };
        ArrayList<Map<String, String>> data = new ArrayList<Map<String, String>>();

        /**
         * コンストラクタ―
         * 
         * @param result
         *            到達圏／流入圏計算結果
         */
        public CA3ParamAdapter(CalcArea3Response result) {
            CA3Param param = result.getParam();

            data.add(createMap(getString(R.string.common_calc_settings), ""));
            Loc startLoc = result.getStartLoc();
            data.add(createMap(getString(R.string.common_start_point), String
                    .format("%s\n %s：%.6f %s：%.6f", startLoc.getTag(),
                            getString(R.string.common_lon), startLoc.getLon(),
                            getString(R.string.common_lat), startLoc.getLat())));
            data.add(createMap(getString(R.string.calc_pref_calc_kind_title),
                    DistUtils.getCalcKindString(getActivity()
                            .getApplicationContext(), param.getCalcKind())));
            String nwid = result.getNwInfo().getNwID();
            if (DistUtils.isForCar(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_highway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.HIGHWAY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForFreightRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_freight_railway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForAirway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_airway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.AIRWAY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForFerry(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.FERRY) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_pay_road_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.PAYROAD_FERRY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 2;
            }
            if (DistUtils.isForShip(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ship_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.SHIP) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_railway_title),
                        DistUtils.getUseRailwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_limited_express_title),
                        DistUtils.getUseLimitedExpressString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.LIMITED_EXPRESS_TRAIN) != 0 ? 1
                                        : 0)));
                titlePos[1] += 2;
            }

            data.add(createMap(
                    getString(R.string.calc_pref_area_direction_title),
                    DistUtils.getAreaDirectionString(getActivity()
                            .getApplicationContext(), param.getAreaDirection())));
            data.add(createMap(getString(R.string.calc_pref_area_kind_title),
                    DistUtils.getAreaKindString(getActivity()
                            .getApplicationContext(), param.getAreaKind())));
            int areaRange = param.getAreaKind() == AreaKind.TIME ? param
                    .getAreaRange() / 600 : param.getAreaRange() / 1000;
            data.add(createMap(getString(R.string.calc_pref_area_range_title),
                    DistUtils.getAreaRangeString(getActivity()
                            .getApplicationContext(), areaRange, param
                            .getAreaKind())));

            data.add(createMap(getString(R.string.common_result_settings), ""));
            data.add(createMap(
                    getString(R.string.calc_pref_polygon_kind_title), DistUtils
                            .getPolygonKindString(getActivity()
                                    .getApplicationContext(), param
                                    .getPolygonKind())));
            data.add(createMap(
                    getString(R.string.calc_pref_polygon_level_title),
                    DistUtils.getPolygonLevelString(param.getPolygonLevel())));
            data.add(createMap(
                    getString(R.string.calc_pref_donut_polygon_level_title),
                    DistUtils.getDonutPolygonLevelString(param
                            .getDonutPolygonLevel())));
            data.add(createMap(
                    getString(R.string.calc_pref_polygon_detail_title),
                    DistUtils.getPolygonDetailString(getActivity()
                            .getApplicationContext(), param.getPolygonDetail())));
        }

        @Override
        public int getCount() {
            return data.size();
        }

        @Override
        public Object getItem(int position) {
            return data.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View view = convertView;
            if (isTitle(position)) {
                if (view == null || view.getId() != R.layout.row_title) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_title, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
            } else {
                if (view == null || view.getId() != R.layout.row_user_info) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_user_info, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                TextView value = (TextView) view
                        .findViewById(android.R.id.text2);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
                value.setText(info.get(VALUE));
            }

            return view;
        }

        @Override
        public boolean isEnabled(int position) {
            return !isTitle(position);
        }

        /**
         * リストアイテム用Mapを作成します。
         * 
         * @param title
         *            タイトル
         * @param value
         *            値
         * @return リストアイテム用Map
         */
        private Map<String, String> createMap(String title, String value) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(TITLE, title);
            map.put(VALUE, value);
            return map;
        }

        /**
         * 見出し行か判定します。
         * 
         * @param position
         *            位置
         * @return 見出し行の場合はtrue
         */
        private boolean isTitle(int position) {
            boolean result = false;
            for (int titlePosition : titlePos) {
                if (position == titlePosition) {
                    result = true;
                    break;
                }
            }
            return result;
        }
    }

    /**
     * 片道一括計算設定用アダプターです。
     * 
     * @author ishi
     * 
     */
    class COW3ParamAdapter extends BaseAdapter {
        private static final String TITLE = "title";
        private static final String VALUE = "value";
        private final int[] TITLE_POSITIONS = { 0 };
        ArrayList<Map<String, String>> data = new ArrayList<Map<String, String>>();

        /**
         * コンストラクタ―
         * 
         * @param result
         *            片道一括計算結果
         */
        public COW3ParamAdapter(CalcOneWay3Response result) {
            COW3Param param = result.getParam();
            data = new ArrayList<Map<String, String>>();

            data.add(createMap(getString(R.string.common_calc_settings), ""));
            Loc startLoc = result.getStartLoc();
            data.add(createMap(getString(R.string.common_start_point), String
                    .format("%s\n %s：%.6f %s：%.6f", startLoc.getTag(),
                            getString(R.string.common_lon), startLoc.getLon(),
                            getString(R.string.common_lat), startLoc.getLat())));
            data.add(createMap(getString(R.string.calc_pref_calc_kind_title),
                    DistUtils.getCalcKindString(getActivity()
                            .getApplicationContext(), param.getCalcKind())));

            String nwid = result.getNwInfo().getNwID();
            if (DistUtils.isForCar(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_highway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.HIGHWAY) != 0 ? 1
                                        : 0)));
            }
            if (DistUtils.isForFreightRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_freight_railway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
            }
            if (DistUtils.isForAirway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_airway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.AIRWAY) != 0 ? 1
                                        : 0)));
            }
            if (DistUtils.isForFerry(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.FERRY) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_pay_road_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.PAYROAD_FERRY) != 0 ? 1
                                        : 0)));
            }
            if (DistUtils.isForShip(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ship_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.SHIP) != 0 ? 1
                                        : 0)));
            }
            if (DistUtils.isForRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_railway_title),
                        DistUtils.getUseRailwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_limited_express_title),
                        DistUtils.getUseLimitedExpressString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.LIMITED_EXPRESS_TRAIN) != 0 ? 1
                                        : 0)));
            }

            data.add(createMap(
                    getString(R.string.calc_pref_area_direction_title),
                    DistUtils.getAreaDirectionString(getActivity()
                            .getApplicationContext(), param.getAreaDirection())));
            data.add(createMap(getString(R.string.calc_pref_area_kind_title),
                    DistUtils.getAreaKindString(getActivity()
                            .getApplicationContext(), param.getAreaKind())));
            int areaRange = param.getAreaKind() == AreaKind.TIME ? param
                    .getAreaRange() / 600 : param.getAreaRange() / 1000;
            data.add(createMap(getString(R.string.calc_pref_area_range_title),
                    DistUtils.getAreaRangeString(getActivity()
                            .getApplicationContext(), areaRange, param
                            .getAreaKind())));
        }

        @Override
        public int getCount() {
            return data.size();
        }

        @Override
        public Object getItem(int position) {
            return data.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View view = convertView;
            if (isTitle(position)) {
                if (view == null || view.getId() != R.layout.row_title) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_title, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
            } else {
                if (view == null || view.getId() != R.layout.row_user_info) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_user_info, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                TextView value = (TextView) view
                        .findViewById(android.R.id.text2);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
                value.setText(info.get(VALUE));
            }

            return view;
        }

        @Override
        public boolean isEnabled(int position) {
            return !isTitle(position);
        }

        /**
         * リストアイテム用Mapを作成します。
         * 
         * @param title
         *            タイトル
         * @param value
         *            値
         * @return リストアイテム用Map
         */
        private Map<String, String> createMap(String title, String value) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(TITLE, title);
            map.put(VALUE, value);
            return map;
        }

        /**
         * 見出し行か判定します。
         * 
         * @param position
         *            位置
         * @return 見出し行の場合はtrue
         */
        private boolean isTitle(int position) {
            boolean result = false;
            for (int titlePosition : TITLE_POSITIONS) {
                if (position == titlePosition) {
                    result = true;
                    break;
                }
            }
            return result;
        }
    }

    /**
     * ルート計算設定用アダプターです。
     * 
     * @author ishi
     * 
     */
    class CRParamAdapter extends BaseAdapter {
        private static final String TITLE = "title";
        private static final String VALUE = "value";
        private final int[] titlePos = { 0, 2 };
        ArrayList<Map<String, String>> data = new ArrayList<Map<String, String>>();

        /**
         * コンストラクタ―
         * 
         * @param param
         *            ルート計算設定
         * @param nwInfo
         *            計算用道路データ
         */
        private CRParamAdapter(CRParam param, NWInfo nwInfo) {
            data = new ArrayList<Map<String, String>>();

            data.add(createMap(getString(R.string.common_calc_settings), ""));
            data.add(createMap(getString(R.string.calc_pref_calc_kind_title),
                    DistUtils.getCalcKindString(getActivity()
                            .getApplicationContext(), param.getCalcKind())));

            String nwid = nwInfo.getNwID();
            if (DistUtils.isForCar(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_highway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.HIGHWAY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForFreightRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_freight_railway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForAirway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_airway_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.AIRWAY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForFerry(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.FERRY) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_pay_road_ferry_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.PAYROAD_FERRY) != 0 ? 1
                                        : 0)));
                titlePos[1] += 2;
            }
            if (DistUtils.isForShip(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_ship_title),
                        DistUtils.getUseHighwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.SHIP) != 0 ? 1
                                        : 0)));
                titlePos[1] += 1;
            }
            if (DistUtils.isForRailway(nwid)) {
                data.add(createMap(
                        getString(R.string.calc_pref_use_railway_title),
                        DistUtils.getUseRailwayString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.RAILROAD) != 0 ? 1
                                        : 0)));
                data.add(createMap(
                        getString(R.string.calc_pref_use_limited_express_title),
                        DistUtils.getUseLimitedExpressString(
                                getActivity().getApplicationContext(),
                                (param.getTransport() & Transport.LIMITED_EXPRESS_TRAIN) != 0 ? 1
                                        : 0)));
                titlePos[1] += 2;
            }

            data.add(createMap(getString(R.string.common_result_settings), ""));
            data.add(createMap(getString(R.string.calc_pref_route_kind_title),
                    DistUtils.getRouteKindString(getActivity()
                            .getApplicationContext(), param.getRouteKind())));

            SimpleAdapter adapter = new SimpleAdapter(getActivity()
                    .getApplicationContext(), data, R.layout.row_user_info,
                    new String[] { TITLE, VALUE }, new int[] {
                            android.R.id.text1, android.R.id.text2 });
            listView.setAdapter(adapter);
        }

        @Override
        public int getCount() {
            return data.size();
        }

        @Override
        public Object getItem(int position) {
            return data.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View view = convertView;
            if (isTitle(position)) {
                if (view == null || view.getId() != R.layout.row_title) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_title, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
            } else {
                if (view == null || view.getId() != R.layout.row_user_info) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_user_info, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                TextView value = (TextView) view
                        .findViewById(android.R.id.text2);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
                value.setText(info.get(VALUE));
            }

            return view;
        }

        @Override
        public boolean isEnabled(int position) {
            return !isTitle(position);
        }

        /**
         * リストアイテム用Mapを作成します。
         * 
         * @param title
         *            タイトル
         * @param value
         *            値
         * @return リストアイテム用Map
         */
        private Map<String, String> createMap(String title, String value) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(TITLE, title);
            map.put(VALUE, value);
            return map;
        }

        /**
         * 見出し行か判定します。
         * 
         * @param position
         *            位置
         * @return 見出し行の場合はtrue
         */
        private boolean isTitle(int position) {
            boolean result = false;
            for (int titlePosition : titlePos) {
                if (position == titlePosition) {
                    result = true;
                    break;
                }
            }
            return result;
        }
    }

    private MyApp app;
    private ListView listView;
    private CalcResultHolder result;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        app = (MyApp) getActivity().getApplication();
        result = app.getResult();

        listView = (ListView) getView().findViewById(android.R.id.list);
        if (result != null) {
            switch (result.getCalcType()) {
            case CalcType.CALC_ROUTE:
                CRParamAdapter adapterCR = new CRParamAdapter(result
                        .getCalcRouteResponse().getParam(), result
                        .getCalcRouteResponse().getNwInfo());
                listView.setAdapter(adapterCR);
                break;
            case CalcType.CALC_OPT_ROUTE:
                CRParamAdapter adapterCOR = new CRParamAdapter(result
                        .getCalcOptRouteResponse().getParam(), result
                        .getCalcOptRouteResponse().getNwInfo());
                listView.setAdapter(adapterCOR);
                break;
            case CalcType.CALC_AREA:
                CA3ParamAdapter adapterCA3 = new CA3ParamAdapter(
                        result.getCalcArea3Response());
                listView.setAdapter(adapterCA3);
                break;
            case CalcType.CALC_ONE_WAY:
                COW3ParamAdapter adapterCOW3 = new COW3ParamAdapter(
                        result.getCalcOneWay3Response());
                listView.setAdapter(adapterCOW3);
                break;
            }
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        return inflater.inflate(R.layout.tab_param, null, false);
    }
}
