﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.activity;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import jp.co.act_inc.actservicesample.MyApp;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.adminservice.UserInformation2;
import jp.co.act_inc.actservicesample.gcservice.GeoUtils;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.support.v4.app.ListFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

/**
 * ユーザー情報画面です。
 * 
 * @author ishi
 * 
 */
public class UserInfoFragment extends ListFragment {
    /**
     * ユーザー情報アダプタです。
     * 
     * @author ishi
     * 
     */
    class UserInfoAdapter extends BaseAdapter {
        private static final String TITLE = "title";
        private static final String VALUE = "value";
        private final int[] TITLE_POSITIONS = { 0, 2, 5, 14 };

        ArrayList<Map<String, String>> data = new ArrayList<Map<String, String>>();

        /**
         * コンストラクタ―です。
         */
        public UserInfoAdapter() {
            UserInformation2 userInfo = app.getUserInfo();

            // 道路データ見出し
            data.add(createMap(getString(R.string.user_info_title_nwinfo), ""));
            SharedPreferences prefs = PreferenceManager
                    .getDefaultSharedPreferences(getActivity()
                            .getApplicationContext());
            // 計算用道路データ
            String roadSummary = prefs.getString(
                    getString(R.string.dcws_pref_note_key), "");
            data.add(createMap(getString(R.string.user_info_use_nwinfo),
                    roadSummary));

            // 会員情報見出し
            data.add(createMap(getString(R.string.user_info_title_member), ""));
            // 会員種別
            data.add(createMap(getString(R.string.user_info_member_kind),
                    userInfo.getMemberKind()));
            // 期限
            data.add(createMap(getString(R.string.user_info_expiry_date),
                    userInfo.getExpiryDate()));

            // 距離計算見出し
            data.add(createMap(getString(R.string.user_info_title_dist_calc),
                    ""));
            // 計算間隔
            int calcInterval = userInfo.getCalcInterval();
            String calcIntervalSummary = calcInterval == 0 ? getString(R.string.common_no_limit)
                    : Integer.toString(calcInterval)
                            + getString(R.string.unit_second);
            data.add(createMap(getString(R.string.user_info_calc_interval),
                    calcIntervalSummary));
            // ルート計算最大地点数
            data.add(createMap(
                    getString(R.string.user_info_calc_route_max_locs),
                    Integer.toString(userInfo.getCalcRouteMaxLocs())
                            + getString(R.string.unit_location)));
            // 最短ルート計算最大値点数
            data.add(createMap(
                    getString(R.string.user_info_calc_opt_route_max_locs),
                    Integer.toString(userInfo.getCalcOptRouteMaxLocs())
                            + getString(R.string.unit_location)));
            // エリア計算最大時間
            int calcAreaMaxTime = userInfo.getCalcAreaMaxTime();
            String calcAreaMaxTimeSummary = calcAreaMaxTime == -1 ? getString(R.string.common_no_limit)
                    : Integer.toString(calcAreaMaxTime / 600)
                            + getString(R.string.unit_minute);
            data.add(createMap(
                    getString(R.string.user_info_calc_area_max_time),
                    calcAreaMaxTimeSummary));
            // エリア計算最大距離
            int calcAreaMaxDist = userInfo.getCalcAreaMaxDist();
            String calcAreaMaxDistSummary = calcAreaMaxDist == -1 ? getString(R.string.common_no_limit)
                    : Integer.toString(calcAreaMaxDist / 1000)
                            + getString(R.string.unit_km);
            data.add(createMap(
                    getString(R.string.user_info_calc_area_max_dist),
                    calcAreaMaxDistSummary));
            // エリア計算最大値点数
            data.add(createMap(
                    getString(R.string.user_info_calc_area_max_locs),
                    Integer.toString(userInfo.getCalcAreaMaxLocs())
                            + getString(R.string.unit_location)));
            // 計算回数
            data.add(createMap(getString(R.string.user_info_calc_count),
                    Integer.toString(userInfo.getCalcCount())));
            // 最大計算回数
            int maxCalcCount = userInfo.getMaxCalcCount();
            String maxCalcCountSummary = maxCalcCount == -1 ? getString(R.string.common_no_limit)
                    : Integer.toString(maxCalcCount)
                            + getString(R.string.unit_count);
            data.add(createMap(getString(R.string.user_info_max_calc_count),
                    maxCalcCountSummary));

            // 住所検索見出し
            data.add(createMap(getString(R.string.user_info_title_geo_search),
                    ""));
            // 住所レベル
            int addressLevel = userInfo.getGeoMaxAddressLevel();
            String addressLevelSummary = "";
            addressLevelSummary = GeoUtils.getGeoLevelName(getActivity()
                    .getApplicationContext(), addressLevel);
            data.add(createMap(
                    getString(R.string.user_info_geo_max_address_level),
                    addressLevelSummary));
            // 住所検索間隔
            int geoInterval = userInfo.getGeoInterval();
            String geoIntervalSummary = geoInterval == 0 ? getString(R.string.common_no_limit)
                    : Integer.toString(geoInterval)
                            + getString(R.string.unit_second);
            data.add(createMap(getString(R.string.user_info_geo_interval),
                    geoIntervalSummary));
            // 住所列挙間隔
            int geoEnumInterval = userInfo.getGeoEnumInterval();
            String geoEnumIntervalSummary = geoEnumInterval == 0 ? getString(R.string.common_no_limit)
                    : Integer.toString(geoEnumInterval)
                            + getString(R.string.unit_second);
            data.add(createMap(getString(R.string.user_info_geo_enum_interval),
                    geoEnumIntervalSummary));
            // 住所検索最大地点数
            data.add(createMap(getString(R.string.user_info_geo_max_locs),
                    Integer.toString(userInfo.getGeoMaxLocs())
                            + getString(R.string.unit_location)));
            // 住所検索回数
            data.add(createMap(getString(R.string.user_info_geo_count),
                    Integer.toString(userInfo.getGeoCount())));
            // 最大住所検索回数
            int maxGeoCount = userInfo.getMaxCalcCount();
            String maxGeoCountSummary = maxGeoCount == -1 ? getString(R.string.common_no_limit)
                    : Integer.toString(maxGeoCount)
                            + getString(R.string.unit_count);
            data.add(createMap(getString(R.string.user_info_max_geo_count),
                    maxGeoCountSummary));
        }

        @Override
        public int getCount() {
            return data.size();
        }

        @Override
        public Object getItem(int position) {
            return data.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View view = convertView;
            if (isTitle(position)) {
                if (view == null || view.getId() != R.layout.row_title) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_title, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
            } else {
                if (view == null || view.getId() != R.layout.row_user_info) {
                    view = getActivity().getLayoutInflater().inflate(
                            R.layout.row_user_info, null);
                }
                TextView title = (TextView) view
                        .findViewById(android.R.id.text1);
                TextView value = (TextView) view
                        .findViewById(android.R.id.text2);
                Map<String, String> info = data.get(position);
                title.setText(info.get(TITLE));
                value.setText(info.get(VALUE));
            }

            return view;
        }

        @Override
        public boolean isEnabled(int position) {
            return !isTitle(position);
        }

        /**
         * リストアイテム用Mapを作成します。
         * 
         * @param title
         *            タイトル
         * @param value
         *            値
         * @return リストアイテム用Map
         */
        private Map<String, String> createMap(String title, String value) {
            Map<String, String> map = new HashMap<String, String>();
            map.put(TITLE, title);
            map.put(VALUE, value);
            return map;
        }

        /**
         * 見出し行か判定します。
         * 
         * @param position
         *            位置
         * @return 見出し行の場合はtrue
         */
        private boolean isTitle(int position) {
            boolean result = false;
            for (int titlePosition : TITLE_POSITIONS) {
                if (position == titlePosition) {
                    result = true;
                    break;
                }
            }
            return result;
        }
    }

    private MyApp app;

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        UserInfoAdapter adapter = new UserInfoAdapter();
        setListAdapter(adapter);
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        app = (MyApp) getActivity().getApplication();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        return inflater.inflate(R.layout.user_info_fragment, null, false);
    }
}
