﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */

package jp.co.act_inc.actservicesample.adminservice;

import java.io.BufferedOutputStream;
import java.net.HttpURLConnection;
import jp.co.act_inc.actservicesample.Logger;

import org.xmlpull.v1.XmlSerializer;

import android.util.Log;
import android.util.Xml;

/**
 * ACT距離計算サービスの管理サービスを呼び出すクラスです。
 * 
 * @author ishi
 */
public class AdminService {
    /**
     * SOAPアクション名
     * 
     * @author ishi
     */
    class ActionName {
        private static final String GET_USER_INFORMATION2 = "GetUserInformation2";
        private static final String GET_USABLE_NW_INFOS = "GetUsableNWInfos";
        private static final String GET_USABLE_DC_SERVER = "GetUsableDCServer";
        private static final String GET_USABLE_GEO_SERVER = "GetUsableGeoServer";
    }

    /**
     * サービス名前空間
     * 
     * @author ishi
     * 
     */
    class Namespace {
        private static final String ADMIN = "http://distcalc.act-inc.co.jp/DCADMIN";
    }

    /**
     * タグ名
     * 
     * @author ishi
     */
    class Tag {
        private static final String GET_USABLE_DCSERVER_RESPONSE = "GetUsableDCServerResponse";
        private static final String GET_USABLE_GEOSERVER_RESPONSE = "GetUsableGeoServerResponse";
        private static final String GET_USABLE_NWINFOS_RESPONSE = "GetUsableNWInfosResponse";
        private static final String GET_USER_INFORMATION2_RESPONSE = "GetUserInformation2Response";

        private static final String ENVIRON = "Environ";
        private static final String NWINFO = "NWInfo";
    }

    /**
     * 使用できる距離計算サーバーを取得します。
     * 
     * @param url
     *            管理サーバーURL
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param nwInfo
     *            使用する計算用道路データ情報
     * @return 結果を格納したGetUsableDCServerResponse
     */
    public static GetUsableDCServerResponse getUsableDCServer(String url,
            boolean useSsl, Environ environ, NWInfo nwInfo) {
        Logger.writeDebugLog("getUsableDCServer", "start");
        String methodName = ActionName.GET_USABLE_DC_SERVER;
        String soapAction = Namespace.ADMIN + "/" + methodName;
        GetUsableDCServerResponse result = null;

        try {
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);
            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.ADMIN,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            nwInfo.writeXml(xmlSerializer, Tag.NWINFO);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getUsableDCServer", "connect");
                connection.connect();
                result = new GetUsableDCServerResponse();
                Logger.writeDebugLog("getUsableDCServer", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_USABLE_DCSERVER_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetUsableDCServerResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getUsableDCServer", "end");
        return result;
    }

    /**
     * 使用できる住所検索サーバーを取得します。
     * 
     * @param url
     *            管理サーバーURL
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @return 結果を格納したGetUsableGeoServerResponse
     */
    public static GetUsableGeoServerResponse getUsableGeoServer(String url,
            boolean useSsl, Environ environ) {
        Logger.writeDebugLog("getUsableGeoServer", "start");
        String methodName = ActionName.GET_USABLE_GEO_SERVER;
        String soapAction = Namespace.ADMIN + "/" + methodName;
        GetUsableGeoServerResponse result = null;

        try {
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);
            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.ADMIN,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getUsableGeoServer",
                        String.format("connect ssl:%b url:%s", useSsl, url));
                connection.connect();
                result = new GetUsableGeoServerResponse();
                Logger.writeDebugLog("getUsableGeoServer", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_USABLE_GEOSERVER_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetUsableGeoServerResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getUsableGeoServer", "end");
        return result;
    }

    /**
     * 使用可能な計算用道路データを取得します。
     * 
     * @param url
     *            管理サーバーURL
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @return 結果を格納したGetUsalbeNWInfosResponse
     */
    public static GetUsableNWInfosResponse getUsableNWInfos(String url,
            boolean useSsl, Environ environ) {
        Logger.writeDebugLog("getUsableNWInfos", "start");
        String methodName = ActionName.GET_USABLE_NW_INFOS;
        String soapAction = Namespace.ADMIN + "/" + methodName;
        GetUsableNWInfosResponse result = null;

        try {
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);
            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.ADMIN,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("getUsableNWInfos", "connect");
                connection.connect();
                result = new GetUsableNWInfosResponse();
                Logger.writeDebugLog("getUsableNWInfos", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_USABLE_NWINFOS_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetUsableNWInfosResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getUsableNWInfos", "end");
        return result;
    }

    /**
     * ユーザー情報を取得します。
     * 
     * @param url
     *            管理サーバーURL
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @return 結果を格納したGetUserInformation2Response
     */
    public static GetUserInformation2Response getUserInformation2(String url,
            boolean useSsl, Environ environ) {
        Logger.writeDebugLog("getUserInformation2", "start");
        String methodName = ActionName.GET_USER_INFORMATION2;
        String soapAction = Namespace.ADMIN + "/" + methodName;
        String userInfoTag = "UserInformation";
        GetUserInformation2Response result = null;

        try {
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);
            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.ADMIN,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            UserInformation2 userInfo = new UserInformation2();
            userInfo.writeXml(xmlSerializer, userInfoTag);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("getUserInformation2", "connection");
                connection.connect();
                result = new GetUserInformation2Response();
                Logger.writeDebugLog("getUserInformation2", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_USER_INFORMATION2_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetUserInformation2Response();
            result.setException(e);
        }
        Logger.writeDebugLog("getUserInformation2", "end");
        return result;
    }

}
