﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */

package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 環境設定を格納します。
 * 
 * @author ishi
 * 
 */
public class Environ {
    private static final String ENVIRON = "Environ";
    private static final String HOST = "Host";
    private static final String HWUID = "HWUID";
    private static final String PORT = "Port";
    private static final String USER_ID = "UserID";
    private static final String UUID = "UUID";
    private static final String WSURL = "WSURL";

    /**
     * ユーザーID
     */
    private String userID;
    /**
     * パスワード
     */
    private String uuID;
    /**
     * ハードウェアID
     */
    private String hwuID;
    /**
     * サービスURL
     */
    private String wsUrl;
    /**
     * 計算リスナーのIPアドレス
     */
    private String host;
    /**
     * 計算リスナーのポート番号
     */
    private int port;

    /**
     * コンストラクター
     * 
     */
    public Environ() {
    }

    /**
     * コンストラクター
     * 
     * @param userID
     *            ユーザーID
     * @param uuID
     *            パスワード
     * @param hwuID
     *            ハードウェアID
     * @param wsUrl
     *            サービスURL
     * @param host
     *            計算リスナーのIPアドレス
     * @param port
     *            計算リスナーのポート番号
     */
    public Environ(String userID, String uuID, String hwuID, String wsUrl,
            String host, int port) {
        this.userID = userID;
        this.uuID = uuID;
        this.hwuID = hwuID;
        this.wsUrl = wsUrl;
        this.host = host;
        this.port = port;
    }

    /**
     * 計算リスナーのIPアドレスを取得します。
     * 
     * @return 計算リスナーのIPアドレス
     */
    public String getHost() {
        return host;
    }

    /**
     * ハードウェアIDを取得します。
     * 
     * @return ハードウェアID
     */
    public String getHwuID() {
        return hwuID;
    }

    /**
     * 計算リスナーのIPアドレスを取得します。
     * 
     * @return 計算リスナーのIPアドレス
     */
    public int getPort() {
        return port;
    }

    /**
     * ユーザーIDを取得します。
     * 
     * @return ユーザーID
     */
    public String getUserID() {
        return userID;
    }

    /**
     * パスワードを取得します。
     * 
     * @return パスワード
     */
    public String getUuID() {
        return uuID;
    }

    /**
     * サービスURLを取得します。
     * 
     * @return サービスURL
     */
    public String getWsUrl() {
        return wsUrl;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(USER_ID)) {
                    String value = parser.nextText();
                    userID = value;
                } else if (startTagName.equalsIgnoreCase(UUID)) {
                    String value = parser.nextText();
                    uuID = value;
                } else if (startTagName.equalsIgnoreCase(HWUID)) {
                    String value = parser.nextText();
                    hwuID = value;
                } else if (startTagName.equalsIgnoreCase(WSURL)) {
                    String value = parser.nextText();
                    wsUrl = value;
                } else if (startTagName.equalsIgnoreCase(HOST)) {
                    String value = parser.nextText();
                    host = value;
                } else if (startTagName.equalsIgnoreCase(PORT)) {
                    String value = parser.nextText();
                    port = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = ENVIRON;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", USER_ID);
        if (userID != null) {
            xmlSerializer.text(userID);
        }
        xmlSerializer.endTag("", USER_ID);
        xmlSerializer.startTag("", UUID);
        if (uuID != null) {
            xmlSerializer.text(uuID);
        }
        xmlSerializer.endTag("", UUID);
        xmlSerializer.startTag("", HWUID);
        if (hwuID != null) {
            xmlSerializer.text(hwuID);
        }
        xmlSerializer.endTag("", HWUID);
        xmlSerializer.startTag("", WSURL);
        if (wsUrl != null) {
            xmlSerializer.text(wsUrl);
        }
        xmlSerializer.endTag("", WSURL);
        xmlSerializer.startTag("", HOST);
        if (host != null) {
            xmlSerializer.text(host);
        }
        xmlSerializer.endTag("", HOST);
        xmlSerializer.startTag("", PORT);
        xmlSerializer.text(Integer.toString(port));
        xmlSerializer.endTag("", PORT);
        xmlSerializer.endTag("", tag);
    }
}
