﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 使用可能距離計算サーバー取得の結果です。 GetUsableDCServerの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class GetUsableDCServerResponse implements Response {
    private static final String ENVIRON = "Environ";
    private static final String GET_USABLE_DC_SERVER_RESULT = "GetUsableDCServerResult";

    /**
     * 戻り値
     */
    private Boolean result;
    /**
     * 環境設定
     */
    private Environ environ;
    /**
     * 例外
     */
    private Exception exception;

    /**
     * コンストラクター
     * 
     */
    public GetUsableDCServerResponse() {
    }

    /**
     * コンストラクター
     * 
     * @param result
     *            戻り値
     * @param environ
     *            環境設定
     */
    public GetUsableDCServerResponse(Boolean result, Environ environ) {
        this.result = result;
        this.environ = environ;
    }

    /**
     * @return environ
     */
    public Environ getEnviron() {
        return this.environ;
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return result
     */
    public Boolean getResult() {
        return this.result;
    }

    @Override
    public int getResultCode() {
        return result ? 0 : 1;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(GET_USABLE_DC_SERVER_RESULT)) {
                    result = Boolean.parseBoolean(parser.nextText());
                } else if (startTagName.equalsIgnoreCase(ENVIRON)) {
                    Environ env = new Environ();
                    env.readXml(parser, ENVIRON);
                    environ = env;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

}
