﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 使用可能計算用道路データ取得の結果です。 GetUsableNWInfosの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class GetUsableNWInfosResponse implements Response, Parcelable {
    public static final Parcelable.Creator<GetUsableNWInfosResponse> CREATOR = new Parcelable.Creator<GetUsableNWInfosResponse>() {
        @Override
        public GetUsableNWInfosResponse createFromParcel(Parcel in) {
            return new GetUsableNWInfosResponse(in);
        }

        @Override
        public GetUsableNWInfosResponse[] newArray(int size) {
            return new GetUsableNWInfosResponse[size];
        }
    };

    private static final String GET_USABLE_NWINFOS_RESULT = "GetUsableNWInfosResult";
    private static final String NWINFO = "NWInfo";
    private static final String NWINFOS = "NWInfos";

    /**
     * 戻り値
     */
    private Boolean result;
    /**
     * 計算用道路データ情報リスト
     */
    private ArrayList<NWInfo> nwInfos;
    /**
     * 例外
     */
    private Exception exception;

    /**
     * コンストラクター
     * 
     */
    public GetUsableNWInfosResponse() {
    }

    /**
     * コンストラクタ―
     * 
     * @param in
     *            元となるParcel
     */
    public GetUsableNWInfosResponse(Parcel in) {
        boolean[] buf = new boolean[1];
        in.readBooleanArray(buf);
        result = buf[0];
        NWInfo[] nwInfos = (NWInfo[]) in.readParcelableArray(null);
        this.nwInfos = new ArrayList<NWInfo>(Arrays.asList(nwInfos));
    }

    @Override
    public int describeContents() {
        return 0;
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return nwInfos
     */
    public ArrayList<NWInfo> getNwInfos() {
        return this.nwInfos;
    }

    /**
     * @return result
     */
    public Boolean getResult() {
        return this.result;
    }

    @Override
    public int getResultCode() {
        return result ? 0 : 1;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inNWInfos = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inNWInfos) {
                    if (startTagName.equalsIgnoreCase(NWINFO)) {
                        NWInfo nwInfo = new NWInfo();
                        nwInfo.readXml(parser, NWINFO);
                        nwInfos.add(nwInfo);
                    }
                } else {
                    if (startTagName
                            .equalsIgnoreCase(GET_USABLE_NWINFOS_RESULT)) {
                        result = Boolean.parseBoolean(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(NWINFOS)) {
                        inNWInfos = true;
                        nwInfos = new ArrayList<NWInfo>();
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(NWINFOS)) {
                    inNWInfos = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeBooleanArray(new boolean[] { result });
        NWInfo[] nwInfos = this.nwInfos.toArray(new NWInfo[0]);
        dest.writeParcelableArray(nwInfos, 0);
    }
}
