﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 計算用道路データ情報を格納します。
 * 
 * @author ishi
 * 
 */
public class NWInfo implements Parcelable {
    public static final Parcelable.Creator<NWInfo> CREATOR = new Parcelable.Creator<NWInfo>() {
        @Override
        public NWInfo createFromParcel(Parcel in) {
            return new NWInfo(in);
        }

        @Override
        public NWInfo[] newArray(int size) {
            return new NWInfo[size];
        }
    };

    private static final String FOLDER = "Folder";
    private static final String IS_DETAIL_EXIST = "IsDetailExist";
    private static final String IS_TOLL_EXIST = "IsTollExist";
    private static final String NOTE = "Note";
    private static final String NW_INFO = "NWInfo";
    private static final String NWID = "NWID";
    private static final String NWID_WITHOUT_SPEED = "NWID_WithoutSpeed";

    /**
     * 計算用道路データの格納フォルダ
     */
    private String folder;
    /**
     * 計算用道路データの名称
     */
    private String note;
    /**
     * 詳細ルート出力可能フラグ
     */
    private Boolean isDetailExist;
    /**
     * 通行料金出力可能フラグ
     */
    private Boolean isTollExist;
    /**
     * 計算用道路データを識別するためのネットワーク ID
     */
    private String nwID;
    /**
     * 速度情報を無視した計算用道路データを識別するためのネットワーク ID 番号
     */
    private String nwID_WithoutSpeed;

    /**
     * コンストラクター
     * 
     */
    public NWInfo() {
    }

    /**
     * コンストラクタ―
     * 
     * @param in
     *            読み込むParcel
     */
    public NWInfo(Parcel in) {
        folder = in.readString();
        boolean[] buf = new boolean[1];
        in.readBooleanArray(buf);
        isDetailExist = buf[0];
        in.readBooleanArray(buf);
        isTollExist = buf[0];
        note = in.readString();
        nwID = in.readString();
        nwID_WithoutSpeed = in.readString();

    }

    /**
     * コンストラクタ
     * 
     * @param folder
     *            計算用道路データの格納フォルダ
     * @param note
     *            計算用道路データの名称
     * @param isDetailExist
     *            詳細ルート出力可能フラグ
     * @param isTollExist
     *            通行料金出力可能フラグ
     * @param nwID
     *            ネットワーク ID
     * @param nwID_WithoutSpeed
     *            速度情報を無視したデータのネットワーク ID番号
     */
    public NWInfo(String folder, String note, Boolean isDetailExist,
            Boolean isTollExist, String nwID, String nwID_WithoutSpeed) {
        this.folder = folder;
        this.note = note;
        this.isDetailExist = isDetailExist;
        this.isTollExist = isTollExist;
        this.nwID = nwID;
        this.nwID_WithoutSpeed = nwID_WithoutSpeed;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return folder
     */
    public String getFolder() {
        return this.folder;
    }

    /**
     * @return isDetailExist
     */
    public Boolean getIsDetailExist() {
        return this.isDetailExist;
    }

    /**
     * @return isTollExist
     */
    public Boolean getIsTollExist() {
        return this.isTollExist;
    }

    /**
     * @return note
     */
    public String getNote() {
        return this.note;
    }

    /**
     * @return nwID
     */
    public String getNwID() {
        return this.nwID;
    }

    /**
     * @return nwID_WithoutSpeed
     */
    public String getNwID_WithoutSpeed() {
        return this.nwID_WithoutSpeed;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(FOLDER)) {
                    String value = parser.nextText();
                    folder = value;
                } else if (startTagName.equalsIgnoreCase(NOTE)) {
                    String value = parser.nextText();
                    note = value;
                } else if (startTagName.equalsIgnoreCase(IS_DETAIL_EXIST)) {
                    String value = parser.nextText();
                    isDetailExist = Boolean.parseBoolean(value);
                } else if (startTagName.equalsIgnoreCase(IS_TOLL_EXIST)) {
                    String value = parser.nextText();
                    isTollExist = Boolean.parseBoolean(value);
                } else if (startTagName.equalsIgnoreCase(NWID)) {
                    String value = parser.nextText();
                    nwID = value;
                } else if (startTagName.equalsIgnoreCase(NWID_WITHOUT_SPEED)) {
                    String value = parser.nextText();
                    nwID_WithoutSpeed = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(folder);
        dest.writeBooleanArray(new boolean[] { isDetailExist });
        dest.writeBooleanArray(new boolean[] { isTollExist });
        dest.writeString(note);
        dest.writeString(nwID);
        dest.writeString(nwID_WithoutSpeed);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = NW_INFO;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", FOLDER);
        if (folder != null) {
            xmlSerializer.text(folder);
        }
        xmlSerializer.endTag("", FOLDER);
        xmlSerializer.startTag("", NOTE);
        if (note != null) {
            xmlSerializer.text(note);
        }
        xmlSerializer.endTag("", NOTE);
        xmlSerializer.startTag("", IS_DETAIL_EXIST);
        if (isDetailExist != null) {
            xmlSerializer.text(isDetailExist.toString());
        }
        xmlSerializer.endTag("", IS_DETAIL_EXIST);
        xmlSerializer.startTag("", IS_TOLL_EXIST);
        if (isTollExist != null) {
            xmlSerializer.text(isTollExist.toString());
        }
        xmlSerializer.endTag("", IS_TOLL_EXIST);
        xmlSerializer.startTag("", NWID);
        if (nwID != null) {
            xmlSerializer.text(nwID);
        }
        xmlSerializer.endTag("", NWID);
        xmlSerializer.startTag("", NWID_WITHOUT_SPEED);
        if (nwID_WithoutSpeed != null) {
            xmlSerializer.text(nwID_WithoutSpeed);
        }
        xmlSerializer.endTag("", NWID_WITHOUT_SPEED);
        xmlSerializer.endTag("", tag);
    }
}
