﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * SOAP例外です。
 * 
 * @author ishi
 * 
 */
public class SoapException extends Exception {
    /**
     * シリアライズ番号
     */
    private static final long serialVersionUID = -3938636188909793339L;

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @return SoapException
     * @throws XmlPullParserException
     * @throws IOException
     */
    public static SoapException readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        String faultCode = "";
        String faultString = "";
        String faultActor = "";
        String detail = "";
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase("faultcode")) {
                    String value = parser.nextText();
                    String[] parts = value.split(":");
                    faultCode = parts[parts.length - 1];
                } else if (startTagName.equalsIgnoreCase("faultstring")) {
                    String value = parser.nextText();
                    faultString = value;
                } else if (startTagName.equalsIgnoreCase("faultactor")) {
                    String value = parser.nextText();
                    faultActor = value;
                } else if (startTagName.equalsIgnoreCase("detail")) {
                    String value = parser.nextText();
                    detail = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return new SoapException(faultCode, faultString,
                            faultActor, detail);
                }
                break;
            }
            eventType = parser.next();
        }
        return new SoapException(faultCode, faultString, faultActor, detail);
    }

    /**
     * SOAP fault code
     */
    private String faultCode;
    /**
     * エラー発生原因の説明
     */
    private String faultString;
    /**
     * エラー発生原因となったアクターに関するURI
     */
    private String faultActor;
    /**
     * エラー発生原因情報
     */
    private String detail;

    /**
     * コンストラクター
     * 
     * @param faultCode
     *            SOAP fault code
     * @param faultString
     *            エラー発生原因の説明
     * @param faultActor
     *            エラー発生原因となったアクターに関するURI
     * @param detail
     *            エラー発生原因情報
     */
    public SoapException(String faultCode, String faultString,
            String faultActor, String detail) {
        this.faultCode = faultCode;
        this.faultString = faultString;
        this.faultActor = faultActor;
        this.detail = detail;
    }

    /**
     * @return detail
     */
    public String getDetail() {
        return this.detail;
    }

    /**
     * @return faultActor
     */
    public String getFaultActor() {
        return this.faultActor;
    }

    /**
     * @return faultCode
     */
    public String getFaultCode() {
        return this.faultCode;
    }

    /**
     * @return faultString
     */
    public String getFaultString() {
        return this.faultString;
    }

    @Override
    public String getMessage() {
        return this.faultString;
    }
}
