﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.adminservice;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * ユーザー情報を格納します。
 * 
 * @author ishi
 * 
 */
public class UserInformation2 {
    private static final String CALC_AREA_MAX_DIST = "CalcAreaMaxDist";
    private static final String CALC_AREA_MAX_LOCS = "CalcAreaMaxLocs";
    private static final String CALC_AREA_MAX_TIME = "CalcAreaMaxTime";
    private static final String CALC_COUNT = "CalcCount";
    private static final String CALC_INTERVAL = "CalcInterval";
    private static final String CALC_OPT_ROUTE_MAX_LOCS = "CalcOptRouteMaxLocs";
    private static final String CALC_ROUTE_MAX_LOCS = "CalcRouteMaxLocs";
    private static final String EXPAND_I32_1 = "Expand_I32_1";
    private static final String EXPAND_I32_2 = "Expand_I32_2";
    private static final String EXPAND_I32_3 = "Expand_I32_3";
    private static final String EXPAND_I32_4 = "Expand_I32_4";
    private static final String EXPAND_STR_1 = "Expand_Str_1";
    private static final String EXPAND_STR_2 = "Expand_Str_2";
    private static final String EXPAND_STR_3 = "Expand_Str_3";
    private static final String EXPAND_STR_4 = "Expand_Str_4";
    private static final String EXPIRY_DATE = "ExpiryDate";
    private static final String GEO_COUNT = "GeoCount";
    private static final String GEO_ENUM_INTERVAL = "GeoEnumInterval";
    private static final String GEO_INTERVAL = "GeoInterval";
    private static final String GEO_MAX_ADDRESS_LEVEL = "GeoMaxAddressLevel";
    private static final String GEO_MAX_LOCS = "GeoMaxLocs";
    private static final String MAX_CALC_COUNT = "MaxCalcCount";
    private static final String MAX_GEO_COUNT = "MaxGeoCount";
    private static final String MEMBER_KIND = "MemberKind";
    private static final String USER_INFORMATION2 = "UserInformation2";

    /**
     * 会員種別
     */
    private String memberKind;
    /**
     * 会員期限（YYYY/MM/DD）
     */
    private String expiryDate;
    /**
     * 距離計算間隔(単位：秒)
     */
    private int calcInterval;
    /**
     * ルート計算可能最大地点数
     */
    private int calcRouteMaxLocs;
    /**
     * 最短ルート計算可能最大地点数
     */
    private int calcOptRouteMaxLocs;
    /**
     * 到達圏／流入圏計算可能最長時間（-1 は無制限）
     */
    private int calcAreaMaxTime;
    /**
     * 到達圏／流入圏計算可能最長距離（-1 は無制限）
     */
    private int calcAreaMaxDist;
    /**
     * 到達圏／流入圏計算可能最大地点数
     */
    private int calcAreaMaxLocs;
    /**
     * 最大住所検索レベル(1:都道府県、2:市区町村、4:大字丁目、16:街区、 32:号)
     */
    private int geoMaxAddressLevel;
    /**
     * 住所検索計算間隔（単位：秒、0 は無制限）
     */
    private int geoInterval;
    /**
     * 下位住所列挙計算間隔（単位：秒、0 は無制限）
     */
    private int geoEnumInterval;
    /**
     * 住所検索可能最大地点数
     */
    private int geoMaxLocs;
    /**
     * 計算回数
     */
    private int calcCount;
    /**
     * 最大計算回数（-1 は無制限）
     */
    private int maxCalcCount;
    /**
     * 住所検索回数
     */
    private int geoCount;
    /**
     * 最大住所検索回数（-1 は無制限）
     */
    private int maxGeoCount;
    /**
     * 拡張数値１（未使用）
     */
    private int expand_I32_1;
    /**
     * 拡張数値２（未使用）
     */
    private int expand_I32_2;
    /**
     * 拡張数値３（未使用）
     */
    private int expand_I32_3;
    /**
     * 拡張数値４（未使用）
     */
    private int expand_I32_4;
    /**
     * 拡張文字列１（未使用）
     */
    private String expand_Str_1;
    /**
     * 拡張文字列２（未使用）
     */
    private String expand_Str_2;
    /**
     * 拡張文字列３（未使用）
     */
    private String expand_Str_3;
    /**
     * 拡張文字列４（未使用）
     */
    private String expand_Str_4;

    /**
     * @return calcAreaMaxDist
     */
    public int getCalcAreaMaxDist() {
        return this.calcAreaMaxDist;
    }

    /**
     * @return calcAreaMaxLocs
     */
    public int getCalcAreaMaxLocs() {
        return this.calcAreaMaxLocs;
    }

    /**
     * @return calcAreaMaxTime
     */
    public int getCalcAreaMaxTime() {
        return this.calcAreaMaxTime;
    }

    /**
     * @return calcCount
     */
    public int getCalcCount() {
        return this.calcCount;
    }

    /**
     * @return calcInterval
     */
    public int getCalcInterval() {
        return this.calcInterval;
    }

    /**
     * @return calcOptRouteMaxLocs
     */
    public int getCalcOptRouteMaxLocs() {
        return this.calcOptRouteMaxLocs;
    }

    /**
     * @return calcRouteMaxLocs
     */
    public int getCalcRouteMaxLocs() {
        return this.calcRouteMaxLocs;
    }

    /**
     * @return expand_I32_1
     */
    public int getExpand_I32_1() {
        return this.expand_I32_1;
    }

    /**
     * @return expand_I32_2
     */
    public int getExpand_I32_2() {
        return this.expand_I32_2;
    }

    /**
     * @return expand_I32_3
     */
    public int getExpand_I32_3() {
        return this.expand_I32_3;
    }

    /**
     * @return expand_I32_4
     */
    public int getExpand_I32_4() {
        return this.expand_I32_4;
    }

    /**
     * @return expand_Str_1
     */
    public String getExpand_Str_1() {
        return this.expand_Str_1;
    }

    /**
     * @return expand_Str_2
     */
    public String getExpand_Str_2() {
        return this.expand_Str_2;
    }

    /**
     * @return expand_Str_3
     */
    public String getExpand_Str_3() {
        return this.expand_Str_3;
    }

    /**
     * @return expand_Str_4
     */
    public String getExpand_Str_4() {
        return this.expand_Str_4;
    }

    /**
     * @return expiryDate
     */
    public String getExpiryDate() {
        return this.expiryDate;
    }

    /**
     * @return geoCount
     */
    public int getGeoCount() {
        return this.geoCount;
    }

    /**
     * @return geoEnumInterval
     */
    public int getGeoEnumInterval() {
        return this.geoEnumInterval;
    }

    /**
     * @return geoInterval
     */
    public int getGeoInterval() {
        return this.geoInterval;
    }

    /**
     * @return geoMaxAddressLevel
     */
    public int getGeoMaxAddressLevel() {
        return this.geoMaxAddressLevel;
    }

    /**
     * @return geoMaxLocs
     */
    public int getGeoMaxLocs() {
        return this.geoMaxLocs;
    }

    /**
     * @return maxCalcCount
     */
    public int getMaxCalcCount() {
        return this.maxCalcCount;
    }

    /**
     * @return maxGeoCount
     */
    public int getMaxGeoCount() {
        return this.maxGeoCount;
    }

    /**
     * @return memberKind
     */
    public String getMemberKind() {
        return this.memberKind;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(MEMBER_KIND)) {
                    String value = parser.nextText();
                    memberKind = value;
                } else if (startTagName.equalsIgnoreCase(EXPIRY_DATE)) {
                    String value = parser.nextText();
                    expiryDate = value;
                } else if (startTagName.equalsIgnoreCase(CALC_INTERVAL)) {
                    String value = parser.nextText();
                    calcInterval = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_ROUTE_MAX_LOCS)) {
                    String value = parser.nextText();
                    calcRouteMaxLocs = Integer.parseInt(value);
                } else if (startTagName
                        .equalsIgnoreCase(CALC_OPT_ROUTE_MAX_LOCS)) {
                    String value = parser.nextText();
                    calcOptRouteMaxLocs = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_AREA_MAX_TIME)) {
                    String value = parser.nextText();
                    calcAreaMaxTime = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_AREA_MAX_DIST)) {
                    String value = parser.nextText();
                    calcAreaMaxDist = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_AREA_MAX_LOCS)) {
                    String value = parser.nextText();
                    calcAreaMaxLocs = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(GEO_MAX_ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    geoMaxAddressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(GEO_INTERVAL)) {
                    String value = parser.nextText();
                    geoInterval = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(GEO_ENUM_INTERVAL)) {
                    String value = parser.nextText();
                    geoEnumInterval = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(GEO_MAX_LOCS)) {
                    String value = parser.nextText();
                    geoMaxLocs = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_COUNT)) {
                    String value = parser.nextText();
                    calcCount = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(MAX_CALC_COUNT)) {
                    String value = parser.nextText();
                    maxCalcCount = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(GEO_COUNT)) {
                    String value = parser.nextText();
                    geoCount = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(MAX_GEO_COUNT)) {
                    String value = parser.nextText();
                    maxGeoCount = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(EXPAND_I32_1)) {
                    String value = parser.nextText();
                    expand_I32_1 = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(EXPAND_I32_2)) {
                    String value = parser.nextText();
                    expand_I32_2 = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(EXPAND_I32_3)) {
                    String value = parser.nextText();
                    expand_I32_3 = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(EXPAND_I32_4)) {
                    String value = parser.nextText();
                    expand_I32_4 = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(EXPAND_STR_1)) {
                    String value = parser.nextText();
                    expand_Str_1 = value;
                } else if (startTagName.equalsIgnoreCase(EXPAND_STR_2)) {
                    String value = parser.nextText();
                    expand_Str_2 = value;
                } else if (startTagName.equalsIgnoreCase(EXPAND_STR_3)) {
                    String value = parser.nextText();
                    expand_Str_3 = value;
                } else if (startTagName.equalsIgnoreCase(EXPAND_STR_4)) {
                    String value = parser.nextText();
                    expand_Str_4 = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param calcAreaMaxDist
     *            セットする calcAreaMaxDist
     */
    public void setCalcAreaMaxDist(int calcAreaMaxDist) {
        this.calcAreaMaxDist = calcAreaMaxDist;
    }

    /**
     * @param calcAreaMaxLocs
     *            セットする calcAreaMaxLocs
     */
    public void setCalcAreaMaxLocs(int calcAreaMaxLocs) {
        this.calcAreaMaxLocs = calcAreaMaxLocs;
    }

    /**
     * @param calcAreaMaxTime
     *            セットする calcAreaMaxTime
     */
    public void setCalcAreaMaxTime(int calcAreaMaxTime) {
        this.calcAreaMaxTime = calcAreaMaxTime;
    }

    /**
     * @param calcCount
     *            セットする calcCount
     */
    public void setCalcCount(int calcCount) {
        this.calcCount = calcCount;
    }

    /**
     * @param calcInterval
     *            セットする calcInterval
     */
    public void setCalcInterval(int calcInterval) {
        this.calcInterval = calcInterval;
    }

    /**
     * @param calcOptRouteMaxLocs
     *            セットする calcOptRouteMaxLocs
     */
    public void setCalcOptRouteMaxLocs(int calcOptRouteMaxLocs) {
        this.calcOptRouteMaxLocs = calcOptRouteMaxLocs;
    }

    /**
     * @param calcRouteMaxLocs
     *            セットする calcRouteMaxLocs
     */
    public void setCalcRouteMaxLocs(int calcRouteMaxLocs) {
        this.calcRouteMaxLocs = calcRouteMaxLocs;
    }

    /**
     * @param expand_I32_1
     *            セットする expand_I32_1
     */
    public void setExpand_I32_1(int expand_I32_1) {
        this.expand_I32_1 = expand_I32_1;
    }

    /**
     * @param expand_I32_2
     *            セットする expand_I32_2
     */
    public void setExpand_I32_2(int expand_I32_2) {
        this.expand_I32_2 = expand_I32_2;
    }

    /**
     * @param expand_I32_3
     *            セットする expand_I32_3
     */
    public void setExpand_I32_3(int expand_I32_3) {
        this.expand_I32_3 = expand_I32_3;
    }

    /**
     * @param expand_I32_4
     *            セットする expand_I32_4
     */
    public void setExpand_I32_4(int expand_I32_4) {
        this.expand_I32_4 = expand_I32_4;
    }

    /**
     * @param expand_Str_1
     *            セットする expand_Str_1
     */
    public void setExpand_Str_1(String expand_Str_1) {
        this.expand_Str_1 = expand_Str_1;
    }

    /**
     * @param expand_Str_2
     *            セットする expand_Str_2
     */
    public void setExpand_Str_2(String expand_Str_2) {
        this.expand_Str_2 = expand_Str_2;
    }

    /**
     * @param expand_Str_3
     *            セットする expand_Str_3
     */
    public void setExpand_Str_3(String expand_Str_3) {
        this.expand_Str_3 = expand_Str_3;
    }

    /**
     * @param expand_Str_4
     *            セットする expand_Str_4
     */
    public void setExpand_Str_4(String expand_Str_4) {
        this.expand_Str_4 = expand_Str_4;
    }

    /**
     * @param expiryDate
     *            セットする expiryDate
     */
    public void setExpiryDate(String expiryDate) {
        this.expiryDate = expiryDate;
    }

    /**
     * @param geoCount
     *            セットする geoCount
     */
    public void setGeoCount(int geoCount) {
        this.geoCount = geoCount;
    }

    /**
     * @param geoEnumInterval
     *            セットする geoEnumInterval
     */
    public void setGeoEnumInterval(int geoEnumInterval) {
        this.geoEnumInterval = geoEnumInterval;
    }

    /**
     * @param geoInterval
     *            セットする geoInterval
     */
    public void setGeoInterval(int geoInterval) {
        this.geoInterval = geoInterval;
    }

    /**
     * @param geoMaxAddressLevel
     *            セットする geoMaxAddressLevel
     */
    public void setGeoMaxAddressLevel(int geoMaxAddressLevel) {
        this.geoMaxAddressLevel = geoMaxAddressLevel;
    }

    /**
     * @param geoMaxLocs
     *            セットする geoMaxLocs
     */
    public void setGeoMaxLocs(int geoMaxLocs) {
        this.geoMaxLocs = geoMaxLocs;
    }

    /**
     * @param maxCalcCount
     *            セットする maxCalcCount
     */
    public void setMaxCalcCount(int maxCalcCount) {
        this.maxCalcCount = maxCalcCount;
    }

    /**
     * @param maxGeoCount
     *            セットする maxGeoCount
     */
    public void setMaxGeoCount(int maxGeoCount) {
        this.maxGeoCount = maxGeoCount;
    }

    /**
     * @param memberKind
     *            セットする memberKind
     */
    public void setMemberKind(String memberKind) {
        this.memberKind = memberKind;
    }

    /**
     * 計算回数を検証する
     * 
     * @return 妥当な場合true
     */
    public boolean validateCalcCount() {
        return (getMaxCalcCount() == -1 || getCalcCount() < getMaxCalcCount());
    }

    /**
     * 会員期限を検証する
     * 
     * @return 妥当な場合true
     */
    public boolean validateExpireDay() {
        Date endDay = null;
        SimpleDateFormat f = new SimpleDateFormat("yyyy/MM/dd");
        try {
            endDay = f.parse(getExpiryDate());
            endDay.setHours(23);
            endDay.setMinutes(59);
            endDay.setSeconds(59);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return (endDay != null && endDay.after(new Date()));
    }

    /**
     * 住所検索回数を検証する
     * 
     * @return 妥当な場合true
     */
    public boolean validateGeoCount() {
        return (getMaxGeoCount() == -1 || getGeoCount() < getMaxGeoCount());
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = USER_INFORMATION2;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", MEMBER_KIND);
        if (memberKind != null) {
            xmlSerializer.text(memberKind);
        }
        xmlSerializer.endTag("", MEMBER_KIND);
        xmlSerializer.startTag("", EXPIRY_DATE);
        if (expiryDate != null) {
            xmlSerializer.text(expiryDate);
        }
        xmlSerializer.endTag("", EXPIRY_DATE);
        xmlSerializer.startTag("", CALC_INTERVAL);
        xmlSerializer.text(Integer.toString(calcInterval));
        xmlSerializer.endTag("", CALC_INTERVAL);
        xmlSerializer.startTag("", CALC_ROUTE_MAX_LOCS);
        xmlSerializer.text(Integer.toString(calcRouteMaxLocs));
        xmlSerializer.endTag("", CALC_ROUTE_MAX_LOCS);
        xmlSerializer.startTag("", CALC_OPT_ROUTE_MAX_LOCS);
        xmlSerializer.text(Integer.toString(calcOptRouteMaxLocs));
        xmlSerializer.endTag("", CALC_OPT_ROUTE_MAX_LOCS);
        xmlSerializer.startTag("", CALC_AREA_MAX_TIME);
        xmlSerializer.text(Integer.toString(calcAreaMaxTime));
        xmlSerializer.endTag("", CALC_AREA_MAX_TIME);
        xmlSerializer.startTag("", CALC_AREA_MAX_DIST);
        xmlSerializer.text(Integer.toString(calcAreaMaxDist));
        xmlSerializer.endTag("", CALC_AREA_MAX_DIST);
        xmlSerializer.startTag("", CALC_AREA_MAX_LOCS);
        xmlSerializer.text(Integer.toString(calcAreaMaxLocs));
        xmlSerializer.endTag("", CALC_AREA_MAX_LOCS);
        xmlSerializer.startTag("", GEO_MAX_ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(geoMaxAddressLevel));
        xmlSerializer.endTag("", GEO_MAX_ADDRESS_LEVEL);
        xmlSerializer.startTag("", GEO_INTERVAL);
        xmlSerializer.text(Integer.toString(geoInterval));
        xmlSerializer.endTag("", GEO_INTERVAL);
        xmlSerializer.startTag("", GEO_ENUM_INTERVAL);
        xmlSerializer.text(Integer.toString(geoEnumInterval));
        xmlSerializer.endTag("", GEO_ENUM_INTERVAL);
        xmlSerializer.startTag("", GEO_MAX_LOCS);
        xmlSerializer.text(Integer.toString(geoMaxLocs));
        xmlSerializer.endTag("", GEO_MAX_LOCS);
        xmlSerializer.startTag("", CALC_COUNT);
        xmlSerializer.text(Integer.toString(calcCount));
        xmlSerializer.endTag("", CALC_COUNT);
        xmlSerializer.startTag("", MAX_CALC_COUNT);
        xmlSerializer.text(Integer.toString(maxCalcCount));
        xmlSerializer.endTag("", MAX_CALC_COUNT);
        xmlSerializer.startTag("", GEO_COUNT);
        xmlSerializer.text(Integer.toString(geoCount));
        xmlSerializer.endTag("", GEO_COUNT);
        xmlSerializer.startTag("", MAX_GEO_COUNT);
        xmlSerializer.text(Integer.toString(maxGeoCount));
        xmlSerializer.endTag("", MAX_GEO_COUNT);
        xmlSerializer.startTag("", EXPAND_I32_1);
        xmlSerializer.text(Integer.toString(expand_I32_1));
        xmlSerializer.endTag("", EXPAND_I32_1);
        xmlSerializer.startTag("", EXPAND_I32_2);
        xmlSerializer.text(Integer.toString(expand_I32_2));
        xmlSerializer.endTag("", EXPAND_I32_2);
        xmlSerializer.startTag("", EXPAND_I32_3);
        xmlSerializer.text(Integer.toString(expand_I32_3));
        xmlSerializer.endTag("", EXPAND_I32_3);
        xmlSerializer.startTag("", EXPAND_I32_4);
        xmlSerializer.text(Integer.toString(expand_I32_4));
        xmlSerializer.endTag("", EXPAND_I32_4);
        xmlSerializer.startTag("", EXPAND_STR_1);
        if (expand_Str_1 != null) {
            xmlSerializer.text(expand_Str_1);
        }
        xmlSerializer.endTag("", EXPAND_STR_1);
        xmlSerializer.startTag("", EXPAND_STR_2);
        if (expand_Str_2 != null) {
            xmlSerializer.text(expand_Str_2);
        }
        xmlSerializer.endTag("", EXPAND_STR_2);
        xmlSerializer.startTag("", EXPAND_STR_3);
        if (expand_Str_3 != null) {
            xmlSerializer.text(expand_Str_3);
        }
        xmlSerializer.endTag("", EXPAND_STR_3);
        xmlSerializer.startTag("", EXPAND_STR_4);
        if (expand_Str_4 != null) {
            xmlSerializer.text(expand_Str_4);
        }
        xmlSerializer.endTag("", EXPAND_STR_4);
        xmlSerializer.endTag("", tag);
    }
}
