/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.db;

import java.util.ArrayList;

import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.database.sqlite.SQLiteDatabase.CursorFactory;

/**
 * 地点DBを管理します。
 * 
 * @author ishi
 * 
 */
public class LocsDBManger {
    /**
     * 地点テーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class LocsCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String TAG = "tag";
        static final String NODE = "node";
        static final String LON = "lon";
        static final String LAT = "lat";
        static final String TIME = "time";
        static final String DSEC = "dsec";
        static final String DIST = "dist";
        static final String HIGHWAY_TIME = "highway_time";
        static final String HIGHWAY_DSEC = "highway_dsec";
        static final String HIGHWAY_DIST = "highway_dist";
        static final String TOLL_SS = "toll_ss";
        static final String TOLL_S = "toll_s";
        static final String TOLL_M = "toll_m";
        static final String TOLL_L = "toll_l";
        static final String TOLL_LL = "toll_ll";
    }

    /**
     * SQLiteヘルパーです。
     * 
     * @author ishi
     * 
     */
    class LocsHelper extends SQLiteOpenHelper {
        public LocsHelper(Context context, String name, CursorFactory factory,
                int version) {
            super(context, name, factory, version);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {
            Logger.writeDebugLog("LocsHelper", "onCreate");
            db.execSQL("CREATE TABLE " + TABLE_LOCS + " (" + LocsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT," + LocsCol.RESULT_ID
                    + " INTEGER ," + LocsCol.POSITION + " INTEGER ,"
                    + LocsCol.TAG + " TEXT," + LocsCol.NODE + " TEXT,"
                    + LocsCol.LON + " REAL ," + LocsCol.LAT + " REAL ,"
                    + LocsCol.TIME + " INTEGER ," + LocsCol.DSEC + " INTEGER ,"
                    + LocsCol.DIST + " INTEGER ," + LocsCol.HIGHWAY_TIME
                    + " INTEGER ," + LocsCol.HIGHWAY_DSEC + " INTEGER ,"
                    + LocsCol.HIGHWAY_DIST + " INTEGER ," + LocsCol.TOLL_SS
                    + " INTEGER ," + LocsCol.TOLL_S + " INTEGER ,"
                    + LocsCol.TOLL_M + " INTEGER ," + LocsCol.TOLL_L
                    + " INTEGER ," + LocsCol.TOLL_LL + " INTEGER);");
            db.execSQL("CREATE INDEX result_index ON " + TABLE_LOCS + " ("
                    + LocsCol.RESULT_ID + ");");
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            Logger.writeDebugLog("LocsHelper", "onUpgrade");
            db.execSQL("DROP TABLE IF EXISTS " + TABLE_LOCS);
            onCreate(db);
        }
    }

    static final int VERSION = 6;
    static final String FILE_NAME = "locs.db";
    static final String TABLE_LOCS = "t_locs";

    private Context context;

    /**
     * コンストラクタ―です。
     * 
     * @param context
     *            コンテキスト
     */
    public LocsDBManger(Context context) {
        this.context = context;
    }

    /**
     * 地点を削除します。
     */
    public void delete() {
        Logger.writeDebugLog("LocsManger", "delete");
        SQLiteDatabase db;
        LocsHelper helper = new LocsHelper(context, FILE_NAME, null, VERSION);
        db = helper.getWritableDatabase();
        try {
            db.beginTransaction();
            db.delete(TABLE_LOCS, null, null);
            db.setTransactionSuccessful();
        } finally {
            db.endTransaction();
            db.close();
        }
    }

    /**
     * 地点リストを取得します。
     * 
     * @return 地点リスト
     */
    public ArrayList<Loc> get() {
        Logger.writeDebugLog("LocsManger", "get");
        ArrayList<Loc> locs = new ArrayList<Loc>();
        SQLiteDatabase db;
        LocsHelper helper = new LocsHelper(context, FILE_NAME, null, VERSION);
        db = helper.getReadableDatabase();
        Cursor c = db.query(TABLE_LOCS, null, null, null, null, null,
                LocsCol.POSITION + " asc");
        boolean hasRow = c.moveToFirst();
        while (hasRow) {
            Loc loc = new Loc();
            loc.setTag(c.getString(3));
            loc.setNode(c.getString(4));
            loc.setLon(c.getDouble(5));
            loc.setLat(c.getDouble(6));
            loc.setTime(c.getInt(7));
            loc.setDSec(c.getInt(8));
            loc.setDist(c.getInt(9));
            loc.setHighwayTime(c.getInt(10));
            loc.setHighwayDSec(c.getInt(11));
            loc.setHighwayDist(c.getInt(12));
            loc.setToll_SS(c.getInt(13));
            loc.setToll_S(c.getInt(14));
            loc.setToll_M(c.getInt(15));
            loc.setToll_L(c.getInt(16));
            loc.setToll_LL(c.getInt(17));
            locs.add(loc);
            hasRow = c.moveToNext();
        }
        c.close();
        db.close();
        return locs;
    }

    /**
     * 地点を追加します。
     * 
     * @param locs
     *            地点リスト
     */
    public void insert(ArrayList<Loc> locs) {
        Logger.writeDebugLog("LocsManger", "insert");
        SQLiteDatabase db;
        LocsHelper helper = new LocsHelper(context, FILE_NAME, null, VERSION);
        db = helper.getWritableDatabase();
        try {
            db.beginTransaction();
            for (int i = 0; i < locs.size(); ++i) {
                Loc loc = locs.get(i);
                ContentValues values = new ContentValues();
                values.put(LocsCol.RESULT_ID, 0);
                values.put(LocsCol.POSITION, i);
                values.put(LocsCol.TAG, loc.getTag());
                values.put(LocsCol.NODE, loc.getNode());
                values.put(LocsCol.LON, loc.getLon());
                values.put(LocsCol.LAT, loc.getLat());
                values.put(LocsCol.TIME, loc.getTime());
                values.put(LocsCol.DSEC, loc.getDSec());
                values.put(LocsCol.DIST, loc.getDist());
                values.put(LocsCol.HIGHWAY_TIME, loc.getHighwayTime());
                values.put(LocsCol.HIGHWAY_DSEC, loc.getHighwayDSec());
                values.put(LocsCol.HIGHWAY_DIST, loc.getHighwayDist());
                values.put(LocsCol.TOLL_SS, loc.getToll_SS());
                values.put(LocsCol.TOLL_S, loc.getToll_S());
                values.put(LocsCol.TOLL_M, loc.getToll_M());
                values.put(LocsCol.TOLL_L, loc.getToll_L());
                values.put(LocsCol.TOLL_LL, loc.getToll_LL());
                db.insert(TABLE_LOCS, null, values);
            }
            db.setTransactionSuccessful();
        } finally {
            db.endTransaction();
            db.close();
        }
    }

    /**
     * 地点を更新します。
     * 
     * @param loc
     *            更新後地点
     * @param position
     *            位置
     */
    public void update(Loc loc, int position) {
        Logger.writeDebugLog("LocsManger", "update");
        SQLiteDatabase db;
        LocsHelper helper = new LocsHelper(context, FILE_NAME, null, VERSION);
        db = helper.getWritableDatabase();
        try {
            db.beginTransaction();
            ContentValues values = new ContentValues();
            values.put(LocsCol.RESULT_ID, 0);
            values.put(LocsCol.POSITION, position);
            values.put(LocsCol.TAG, loc.getTag());
            values.put(LocsCol.NODE, loc.getNode());
            values.put(LocsCol.LON, loc.getLon());
            values.put(LocsCol.LAT, loc.getLat());
            values.put(LocsCol.TIME, loc.getTime());
            values.put(LocsCol.DSEC, loc.getDSec());
            values.put(LocsCol.DIST, loc.getDist());
            values.put(LocsCol.HIGHWAY_TIME, loc.getHighwayTime());
            values.put(LocsCol.HIGHWAY_DSEC, loc.getHighwayDSec());
            values.put(LocsCol.HIGHWAY_DIST, loc.getHighwayDist());
            values.put(LocsCol.TOLL_SS, loc.getToll_SS());
            values.put(LocsCol.TOLL_S, loc.getToll_S());
            values.put(LocsCol.TOLL_M, loc.getToll_M());
            values.put(LocsCol.TOLL_L, loc.getToll_L());
            values.put(LocsCol.TOLL_LL, loc.getToll_LL());
            db.update(TABLE_LOCS, values, LocsCol.POSITION + " = ?",
                    new String[] { Integer.toString(position) });
            db.setTransactionSuccessful();
        } finally {
            db.endTransaction();
            db.close();
        }
    }
}
