/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.db;

import java.util.ArrayList;
import java.util.Date;

import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.dcservice.CA3Param;
import jp.co.act_inc.actservicesample.dcservice.COW3Param;
import jp.co.act_inc.actservicesample.dcservice.CRParam;
import jp.co.act_inc.actservicesample.dcservice.CalcArea3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOneWay3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOptRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder;
import jp.co.act_inc.actservicesample.dcservice.CalcRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import jp.co.act_inc.actservicesample.dcservice.NodePnt;
import jp.co.act_inc.actservicesample.dcservice.Pnt;
import jp.co.act_inc.actservicesample.dcservice.Rn;
import jp.co.act_inc.actservicesample.dcservice.Trd;
import jp.co.act_inc.actservicesample.dcservice.CalcResultHolder.CalcType;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.database.sqlite.SQLiteDatabase.CursorFactory;

/**
 * 計算結果DBを管理します。
 * 
 * @author ishi
 * 
 */
public class ResultsDBManger {
    /**
     * 到達圏／流入圏計算パラメータテーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class CA3ParamCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String CALC_KIND = "calc_kind";
        static final String COORDINATE_FORMAT = "coordinate_format";
        static final String DATUM = "datum";
        static final String TRANSPORT = "transport";
        static final String AREA_DIRECTION = "area_direction";
        static final String AREA_KIND = "area_kind";
        static final String AREA_RANGE = "area_range";
        static final String DONUT_POLYGON_LEVEL = "donut_polygon_level";
        static final String POLYGON_DETAIL = "polygon_detail";
        static final String POLYGON_KIND = "polygon_kind";
        static final String POLYGON_LEVEL = "polygon_level";
        static final String START_PNT_LON = "start_pnt_lon";
        static final String START_PNT_LAT = "start_pnt_lat";
        static final String START_PNT_NODE = "start_pnt_node";
        static final String START_PNT_TAG = "start_pnt_tag";
    }

    /**
     * 片道一括計算パラメータテーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class COW3ParamCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String CALC_KIND = "calc_kind";
        static final String COORDINATE_FORMAT = "coordinate_format";
        static final String DATUM = "datum";
        static final String TRANSPORT = "transport";
        static final String AREA_DIRECTION = "AreaDirection";
        static final String AREA_KIND = "area_kind";
        static final String AREA_RANGE = "area_range";
        static final String HIGHWAY_OUTPUT = "highway_output";
        static final String TOLL_OUTPUT = "toll_output";
        static final String START_PNT_LON = "start_pnt_lon";
        static final String START_PNT_LAT = "start_pnt_lat";
        static final String START_PNT_NODE = "start_pnt_node";
        static final String START_PNT_TAG = "start_pnt_tag";
    }

    /**
     * ルート計算パラメータテーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class CRParamCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String CALC_KIND = "calc_kind";
        static final String COORDINATE_FORMAT = "coordinate_format";
        static final String DATUM = "datum";
        static final String HIGHWAY_OUTPUT = "highway_output";
        static final String PNTS_OUTPUT = "pnts_output";
        static final String RNS_OUTPUT = "rns_output";
        static final String ROUTE_KIND = "route_kind";
        static final String TOLL_OUTPUT = "toll_output";
        static final String TRANSPORT = "transport";
        static final String TRDS_OUTPUT = "trds_output";
    }

    /**
     * 地点テーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class LocsCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String TAG = "tag";
        static final String NODE = "node";
        static final String LON = "lon";
        static final String LAT = "lat";
        static final String TIME = "time";
        static final String DSEC = "dsec";
        static final String DIST = "dist";
        static final String HIGHWAY_TIME = "highway_time";
        static final String HIGHWAY_DSEC = "highway_dsec";
        static final String HIGHWAY_DIST = "highway_dist";
        static final String TOLL_SS = "toll_ss";
        static final String TOLL_S = "toll_s";
        static final String TOLL_M = "toll_m";
        static final String TOLL_L = "toll_l";
        static final String TOLL_LL = "toll_ll";
    }

    /**
     * 計算用道路データテーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class NWInfoCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String FOLDER = "folder";
        static final String IS_DETAIL_EXIST = "is_detail_exist";
        static final String IS_TOLL_EXIST = "is_toll_exist";
        static final String NOTE = "note";
        static final String NWID = "nwid";
        static final String NWID_WITHOUT_SPEED = "nwid_without_speed";
    }

    /**
     * ポイントテーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class PntsCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String LON = "lon";
        static final String LAT = "lat";
    }

    /**
     * 結果テーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class ResultsCol {
        static final String ID = "_id";
        static final String POSITION = "position";
        static final String RESULT_ID = "result_id";
        static final String CALC_TYPE = "calc_type";
        static final String DATE = "date";
        static final String TAG = "tag";
    }

    /**
     * SQLiteヘルパーです。
     * 
     * @author ishi
     * 
     */
    class ResultsHelper extends SQLiteOpenHelper {
        public ResultsHelper(Context context, String name,
                CursorFactory factory, int version) {
            super(context, name, factory, version);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {
            Logger.writeDebugLog("ResultsHelper", "onCreate");
            db.execSQL("CREATE TABLE " + Table.RESULTS + " (" + ResultsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT,"
                    + ResultsCol.POSITION + " INTEGER ," + ResultsCol.RESULT_ID
                    + " INTEGER," + ResultsCol.CALC_TYPE + " INTEGER,"
                    + ResultsCol.DATE + " INTEGER," + ResultsCol.TAG
                    + " TEXT);");
            db.execSQL("CREATE TABLE " + Table.CA3_PARAM + " ("
                    + CA3ParamCol.ID + " INTEGER PRIMARY KEY AUTOINCREMENT,"
                    + CA3ParamCol.RESULT_ID + " INTEGER ,"
                    + CA3ParamCol.CALC_KIND + " INTEGER,"
                    + CA3ParamCol.COORDINATE_FORMAT + " INTEGER,"
                    + CA3ParamCol.DATUM + " INTEGER ," + CA3ParamCol.TRANSPORT
                    + " INTEGER ," + CA3ParamCol.AREA_DIRECTION + " INTEGER ,"
                    + CA3ParamCol.AREA_KIND + " INTEGER ,"
                    + CA3ParamCol.AREA_RANGE + " INTEGER ,"
                    + CA3ParamCol.DONUT_POLYGON_LEVEL + " INTEGER ,"
                    + CA3ParamCol.POLYGON_DETAIL + " INTEGER ,"
                    + CA3ParamCol.POLYGON_KIND + " INTEGER ,"
                    + CA3ParamCol.POLYGON_LEVEL + " INTEGER ,"
                    + CA3ParamCol.START_PNT_LON + " REAL ,"
                    + CA3ParamCol.START_PNT_LAT + " REAL ,"
                    + CA3ParamCol.START_PNT_NODE + " TEXT ,"
                    + CA3ParamCol.START_PNT_TAG + " TEXT);");
            db.execSQL("CREATE TABLE " + Table.COW3_PARAM + " ("
                    + COW3ParamCol.ID + " INTEGER PRIMARY KEY AUTOINCREMENT,"
                    + COW3ParamCol.RESULT_ID + " INTEGER ,"
                    + COW3ParamCol.CALC_KIND + " INTEGER,"
                    + COW3ParamCol.COORDINATE_FORMAT + " INTEGER,"
                    + COW3ParamCol.DATUM + " INTEGER ,"
                    + COW3ParamCol.TRANSPORT + " INTEGER ,"
                    + COW3ParamCol.AREA_DIRECTION + " INTEGER ,"
                    + COW3ParamCol.AREA_KIND + " INTEGER ,"
                    + COW3ParamCol.AREA_RANGE + " INTEGER ,"
                    + COW3ParamCol.HIGHWAY_OUTPUT + " INTEGER ,"
                    + COW3ParamCol.TOLL_OUTPUT + " INTEGER ,"
                    + COW3ParamCol.START_PNT_LON + " REAL ,"
                    + COW3ParamCol.START_PNT_LAT + " REAL ,"
                    + COW3ParamCol.START_PNT_NODE + " TEXT ,"
                    + COW3ParamCol.START_PNT_TAG + " TEXT);");
            db.execSQL("CREATE TABLE " + Table.CR_PARAM + " (" + CRParamCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT,"
                    + CRParamCol.RESULT_ID + " INTEGER ,"
                    + CRParamCol.CALC_KIND + " INTEGER,"
                    + CRParamCol.COORDINATE_FORMAT + " INTEGER,"
                    + CRParamCol.DATUM + " INTEGER ,"
                    + CRParamCol.HIGHWAY_OUTPUT + " INTEGER ,"
                    + CRParamCol.PNTS_OUTPUT + " INTEGER ,"
                    + CRParamCol.RNS_OUTPUT + " INTEGER ,"
                    + CRParamCol.ROUTE_KIND + " INTEGER ,"
                    + CRParamCol.TOLL_OUTPUT + " INTEGER ,"
                    + CRParamCol.TRANSPORT + " INTEGER ,"
                    + CRParamCol.TRDS_OUTPUT + " INTEGER);");
            db.execSQL("CREATE TABLE " + Table.LOCS + " (" + LocsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT," + LocsCol.RESULT_ID
                    + " INTEGER ," + LocsCol.POSITION + " INTEGER ,"
                    + LocsCol.TAG + " TEXT," + LocsCol.NODE + " TEXT,"
                    + LocsCol.LON + " REAL ," + LocsCol.LAT + " REAL ,"
                    + LocsCol.TIME + " INTEGER ," + LocsCol.DSEC + " INTEGER ,"
                    + LocsCol.DIST + " INTEGER ," + LocsCol.HIGHWAY_TIME
                    + " INTEGER ," + LocsCol.HIGHWAY_DSEC + " INTEGER ,"
                    + LocsCol.HIGHWAY_DIST + " INTEGER ," + LocsCol.TOLL_SS
                    + " INTEGER ," + LocsCol.TOLL_S + " INTEGER ,"
                    + LocsCol.TOLL_M + " INTEGER ," + LocsCol.TOLL_L
                    + " INTEGER ," + LocsCol.TOLL_LL + " INTEGER);");
            db.execSQL("CREATE TABLE " + Table.NWINFO + " (" + NWInfoCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT,"
                    + NWInfoCol.RESULT_ID + " INTEGER ," + NWInfoCol.POSITION
                    + " INTEGER ," + NWInfoCol.FOLDER + " TEXT,"
                    + NWInfoCol.IS_DETAIL_EXIST + " INTEGER,"
                    + NWInfoCol.IS_TOLL_EXIST + " INTEGER ," + NWInfoCol.NOTE
                    + " TEXT," + NWInfoCol.NWID + " TEXT ,"
                    + NWInfoCol.NWID_WITHOUT_SPEED + " TEXT);");
            db.execSQL("CREATE TABLE " + Table.PNTS + " (" + PntsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT," + PntsCol.RESULT_ID
                    + " INTEGER ," + PntsCol.POSITION + " INTEGER ,"
                    + PntsCol.LON + " REAL ," + PntsCol.LAT + " REAL);");
            db.execSQL("CREATE TABLE " + Table.RNS + " (" + RnsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT," + RnsCol.RESULT_ID
                    + " INTEGER ," + RnsCol.POSITION + " INTEGER ,"
                    + RnsCol.NAME + " TEXT," + RnsCol.NL_CODE + " TEXT,"
                    + RnsCol.LON + " REAL ," + RnsCol.LAT + " REAL ,"
                    + RnsCol.TIME + " INTEGER ," + RnsCol.DSEC + " INTEGER ,"
                    + RnsCol.DIST + " INTEGER ," + RnsCol.IC_TYPE
                    + " INTEGER ," + RnsCol.LINK_FLAG + " INTEGER ,"
                    + RnsCol.LOC_FLAG + " INTEGER ," + RnsCol.TOLL_SS
                    + " INTEGER ," + RnsCol.TOLL_S + " INTEGER ,"
                    + RnsCol.TOLL_M + " INTEGER ," + RnsCol.TOLL_L
                    + " INTEGER ," + RnsCol.TOLL_LL + " INTEGER);");
            db.execSQL("CREATE TABLE " + Table.TRDS + " (" + TrdsCol.ID
                    + " INTEGER PRIMARY KEY AUTOINCREMENT," + TrdsCol.RESULT_ID
                    + " INTEGER ," + TrdsCol.POSITION + " INTEGER ,"
                    + TrdsCol.IN_IC_NAME + " TEXT," + TrdsCol.IN_RD_NAME
                    + " TEXT," + TrdsCol.OUT_IC_NAME + " TEXT ,"
                    + TrdsCol.OUT_RD_NAME + " TEXT ," + TrdsCol.DIST
                    + " INTEGER ," + TrdsCol.TOLL_SS + " INTEGER ,"
                    + TrdsCol.TOLL_S + " INTEGER ," + TrdsCol.TOLL_M
                    + " INTEGER ," + TrdsCol.TOLL_L + " INTEGER ,"
                    + TrdsCol.TOLL_LL + " INTEGER);");
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            Logger.writeDebugLog("ResultsHelper", "onUpgrade");
            db.execSQL("DROP TABLE IF EXISTS " + Table.RESULTS);
            db.execSQL("DROP TABLE IF EXISTS " + Table.CA3_PARAM);
            db.execSQL("DROP TABLE IF EXISTS " + Table.COW3_PARAM);
            db.execSQL("DROP TABLE IF EXISTS " + Table.CR_PARAM);
            db.execSQL("DROP TABLE IF EXISTS " + Table.LOCS);
            db.execSQL("DROP TABLE IF EXISTS " + Table.NWINFO);
            db.execSQL("DROP TABLE IF EXISTS " + Table.PNTS);
            db.execSQL("DROP TABLE IF EXISTS " + Table.RNS);
            db.execSQL("DROP TABLE IF EXISTS " + Table.TRDS);
            onCreate(db);
        }
    }

    /**
     * 経由道路テーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class RnsCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String NAME = "name";
        static final String NL_CODE = "nl_code";
        static final String LON = "lon";
        static final String LAT = "lat";
        static final String TIME = "time";
        static final String DSEC = "dsec";
        static final String DIST = "dist";
        static final String IC_TYPE = "ic_type";
        static final String LINK_FLAG = "link_flag";
        static final String LOC_FLAG = "loc_flag";
        static final String TOLL_SS = "toll_ss";
        static final String TOLL_S = "toll_s";
        static final String TOLL_M = "toll_m";
        static final String TOLL_L = "toll_l";
        static final String TOLL_LL = "toll_ll";
    }

    /**
     * テーブル名です。
     * 
     * @author ishi
     * 
     */
    class Table {
        static final String RESULTS = "t_results";
        static final String CA3_PARAM = "t_ca3param";
        static final String COW3_PARAM = "t_cow3param";
        static final String CR_PARAM = "t_crparam";
        static final String LOCS = "t_locs";
        static final String NWINFO = "t_nwinfos";
        static final String PNTS = "t_pnts";
        static final String RNS = "t_rns";
        static final String TRDS = "t_trds";
    }

    /**
     * 経由有料道路テーブルのカラムです。
     * 
     * @author ishi
     * 
     */
    class TrdsCol {
        static final String ID = "_id";
        static final String RESULT_ID = "result_id";
        static final String POSITION = "position";
        static final String IN_IC_NAME = "in_ic_name";
        static final String IN_RD_NAME = "in_rd_name";
        static final String OUT_IC_NAME = "out_ic_name";
        static final String OUT_RD_NAME = "out_rd_name";
        static final String DIST = "dist";
        static final String TOLL_SS = "toll_ss";
        static final String TOLL_S = "toll_s";
        static final String TOLL_M = "toll_m";
        static final String TOLL_L = "toll_l";
        static final String TOLL_LL = "toll_ll";
    }

    /**
     * DBバージョン番号
     */
    static final int VERSION = 6;
    /**
     * DBファイル名
     */
    static final String FILE_NAME = "results.db";
    /**
     * 計算結果ID
     */
    static final int RESULT_ID = 0;

    private Context context;

    /**
     * コンストラクタ―です。
     * 
     * @param context
     *            コンテキスト
     */
    public ResultsDBManger(Context context) {
        this.context = context;
    }

    /**
     * 全ての結果を削除します。
     */
    public void deleteAll() {
        Logger.writeDebugLog("ResultsHelper", "deleteAll");
        SQLiteDatabase db;
        ResultsHelper helper = new ResultsHelper(context, FILE_NAME, null,
                VERSION);
        db = helper.getWritableDatabase();
        try {
            db.beginTransaction();
            db.delete(Table.RESULTS, null, null);
            db.delete(Table.RESULTS, null, null);
            db.delete(Table.CA3_PARAM, null, null);
            db.delete(Table.COW3_PARAM, null, null);
            db.delete(Table.CR_PARAM, null, null);
            db.delete(Table.LOCS, null, null);
            db.delete(Table.NWINFO, null, null);
            db.delete(Table.PNTS, null, null);
            db.delete(Table.RNS, null, null);
            db.delete(Table.TRDS, null, null);
            db.setTransactionSuccessful();
        } finally {
            db.endTransaction();
            db.close();
        }
    }

    /**
     * 結果を取得します。
     * 
     * @return 計算結果
     */
    public CalcResultHolder get() {
        Logger.writeDebugLog("ResultsHelper", "get");
        CalcResultHolder result = null;
        SQLiteDatabase db;
        ResultsHelper helper = new ResultsHelper(context, FILE_NAME, null,
                VERSION);
        db = helper.getReadableDatabase();
        result = getResult(RESULT_ID, db);
        if (result != null) {
            switch (result.getCalcType()) {
            case CalcType.CALC_ROUTE:
                getCalcRouteResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_OPT_ROUTE:
                getCalcOptRouteResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_AREA:
                getCalcAreaResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_ONE_WAY:
                getCalcOneWayResult(result, RESULT_ID, db);
                break;
            }
        }
        db.close();
        return result;
    }

    /**
     * 計算結果を追加します。
     * 
     * @param result
     *            計算結果
     */
    public void insert(CalcResultHolder result) {
        Logger.writeDebugLog("ResultsHelper", "insert");
        SQLiteDatabase db;
        ResultsHelper helper = new ResultsHelper(context, FILE_NAME, null,
                VERSION);
        db = helper.getWritableDatabase();
        try {
            db.beginTransaction();
            ContentValues values = new ContentValues();
            values.put(ResultsCol.POSITION, 0);
            values.put(ResultsCol.RESULT_ID, RESULT_ID);
            values.put(ResultsCol.CALC_TYPE, result.getCalcType());
            values.put(ResultsCol.DATE, result.getDate().getTime());
            values.put(ResultsCol.TAG, result.getTag());
            db.insert(Table.RESULTS, null, values);

            switch (result.getCalcType()) {
            case CalcType.CALC_ROUTE:
                addCalcRouteResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_OPT_ROUTE:
                addCalcOptRouteResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_AREA:
                addCalcAreaResult(result, RESULT_ID, db);
                break;
            case CalcType.CALC_ONE_WAY:
                addCalcOneWayResult(result, RESULT_ID, db);
                break;
            }
            db.setTransactionSuccessful();
        } finally {
            db.endTransaction();
            db.close();
        }
    }

    /**
     * 到達圏／流入圏計算結果を追加します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void addCalcAreaResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        insertCA3Param(result.getCalcArea3Response().getParam(), result
                .getCalcArea3Response().getStartLoc().getTag(), resultID, db);
        insertPnts(result.getCalcArea3Response().getPnts(), resultID, db);
        insertNWInfo(result.getCalcArea3Response().getNwInfo(), resultID, db);
    }

    /**
     * 片道一括計算結果を追加します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void addCalcOneWayResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        insertCOW3Param(result.getCalcOneWay3Response().getParam(), result
                .getCalcOneWay3Response().getStartLoc().getTag(), resultID, db);
        insertLocs(result.getCalcOneWay3Response().getLocs(), resultID, db);
        insertNWInfo(result.getCalcOneWay3Response().getNwInfo(), resultID, db);
    }

    /**
     * 最短ルート計算結果を追加します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void addCalcOptRouteResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        insertCRParam(result.getCalcOptRouteResponse().getParam(), resultID, db);
        insertLocs(result.getCalcOptRouteResponse().getLocs(), resultID, db);
        insertPnts(result.getCalcOptRouteResponse().getPnts(), resultID, db);
        insertRns(result.getCalcOptRouteResponse().getRns(), resultID, db);
        insertTrds(result.getCalcOptRouteResponse().getTrds(), resultID, db);
        insertNWInfo(result.getCalcOptRouteResponse().getNwInfo(), resultID, db);
    }

    /**
     * ルート計算結果を追加します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void addCalcRouteResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        insertCRParam(result.getCalcRouteResponse().getParam(), resultID, db);
        insertLocs(result.getCalcRouteResponse().getLocs(), resultID, db);
        insertPnts(result.getCalcRouteResponse().getPnts(), resultID, db);
        insertRns(result.getCalcRouteResponse().getRns(), resultID, db);
        insertTrds(result.getCalcRouteResponse().getTrds(), resultID, db);
        insertNWInfo(result.getCalcRouteResponse().getNwInfo(), resultID, db);
    }

    /**
     * 到達圏／流入圏計算パラメータを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 到達圏／流入圏計算パラメータ
     */
    private CA3Param getCA3Param(long resultID, SQLiteDatabase db) {
        CA3Param param = new CA3Param();
        Cursor c = db.query(Table.CA3_PARAM, null, CA3ParamCol.RESULT_ID
                + " = ?", new String[] { Long.toString(resultID) }, null, null,
                null);
        c.moveToFirst();
        if (c.getCount() == 1) {
            param.setCalcKind(c.getInt(2));
            param.setCoordinateFormat(c.getInt(3));
            param.setDatum(c.getInt(4));
            param.setTransport(c.getInt(5));
            param.setAreaDirection(c.getInt(6));
            param.setAreaKind(c.getInt(7));
            param.setAreaRange(c.getInt(8));
            param.setDonutPolygonLevel(c.getInt(9));
            param.setPolygonDetail(c.getInt(10));
            param.setPolygonKind(c.getInt(11));
            param.setPolygonLevel(c.getInt(12));
            NodePnt startPnt = new NodePnt();
            startPnt.setLon(c.getDouble(13));
            startPnt.setLat(c.getDouble(14));
            startPnt.setNode(c.getString(15));
            startPnt.setTag(c.getString(16));
            param.setStartPnt(startPnt);
        }
        c.close();
        return param;
    }

    /**
     * 到達圏／流入圏計算結果を取得します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void getCalcAreaResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        CalcArea3Response res = new CalcArea3Response();
        res.setParam(getCA3Param(resultID, db));
        Loc loc = new Loc();
        loc.setLon(res.getParam().getStartPnt().getLon());
        loc.setLat(res.getParam().getStartPnt().getLat());
        loc.setTag(res.getParam().getStartPnt().getTag());
        res.setStartLoc(loc);
        res.setPnts(getPnts(resultID, db));
        res.setNwInfo(getNWInfo(resultID, db));
        result.setCalcArea3Response(res);
    }

    /**
     * 片道一括計算結果を取得します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void getCalcOneWayResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        CalcOneWay3Response res = new CalcOneWay3Response();
        res.setParam(getCOW3Param(resultID, db));
        Loc loc = new Loc();
        loc.setLon(res.getParam().getStartPnt().getLon());
        loc.setLat(res.getParam().getStartPnt().getLat());
        loc.setTag(res.getParam().getStartPnt().getTag());
        res.setStartLoc(loc);
        res.setLocs(getLocs(resultID, db));
        res.setNwInfo(getNWInfo(resultID, db));
        result.setCalcOneWay3Response(res);
    }

    /**
     * 最短ルート計算結果を取得します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void getCalcOptRouteResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        CalcOptRouteResponse res = new CalcOptRouteResponse();
        res.setParam(getCRParam(resultID, db));
        res.setLocs(getLocs(resultID, db));
        res.setPnts(getPnts(resultID, db));
        res.setRns(getRns(resultID, db));
        res.setTrds(getTrds(resultID, db));
        res.setNwInfo(getNWInfo(resultID, db));
        result.setCalcOptRouteResponse(res);
    }

    /**
     * ルート計算結果を取得します。
     * 
     * @param result
     *            計算結果
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void getCalcRouteResult(CalcResultHolder result, long resultID,
            SQLiteDatabase db) {
        CalcRouteResponse res = new CalcRouteResponse();
        res.setParam(getCRParam(resultID, db));
        res.setLocs(getLocs(resultID, db));
        res.setPnts(getPnts(resultID, db));
        res.setRns(getRns(resultID, db));
        res.setTrds(getTrds(resultID, db));
        res.setNwInfo(getNWInfo(resultID, db));
        result.setCalcRouteResponse(res);
    }

    /**
     * 片道一括計算パラメータを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 片道一括計算パラメータ
     */
    private COW3Param getCOW3Param(long resultID, SQLiteDatabase db) {
        COW3Param param = new COW3Param();
        Cursor c = db.query(Table.COW3_PARAM, null, COW3ParamCol.RESULT_ID
                + " = ?", new String[] { Long.toString(resultID) }, null, null,
                null);
        c.moveToFirst();
        if (c.getCount() == 1) {
            param.setCalcKind(c.getInt(2));
            param.setCoordinateFormat(c.getInt(3));
            param.setDatum(c.getInt(4));
            param.setTransport(c.getInt(5));
            param.setAreaDirection(c.getInt(6));
            param.setAreaKind(c.getInt(7));
            param.setAreaRange(c.getInt(8));
            param.setHighwayOutput(c.getInt(9));
            param.setTollOutput(c.getInt(10));
            NodePnt startPnt = new NodePnt();
            startPnt.setLon(c.getDouble(11));
            startPnt.setLat(c.getDouble(12));
            startPnt.setNode(c.getString(13));
            startPnt.setTag(c.getString(14));
            param.setStartPnt(startPnt);
        }
        c.close();
        return param;
    }

    /**
     * ルート計算パラメータを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return ルート計算パラメータ
     */
    private CRParam getCRParam(long resultID, SQLiteDatabase db) {
        CRParam param = new CRParam();
        Cursor c = db.query(Table.CR_PARAM, null,
                CRParamCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null, null);
        c.moveToFirst();
        if (c.getCount() == 1) {
            param.setCalcKind(c.getInt(2));
            param.setCoordinateFormat(c.getInt(3));
            param.setDatum(c.getInt(4));
            param.setHighwayOutput(c.getInt(5));
            param.setPntsOutput(c.getInt(6));
            param.setRnsOutput(c.getInt(7));
            param.setRouteKind(c.getInt(8));
            param.setTollOutput(c.getInt(9));
            param.setTransport(c.getInt(10));
            param.setTrdsOutput(c.getInt(11));
        }
        c.close();
        return param;
    }

    /**
     * 地点リストを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 地点リスト
     */
    private ArrayList<Loc> getLocs(long resultID, SQLiteDatabase db) {
        ArrayList<Loc> locs = new ArrayList<Loc>();
        Cursor c = db.query(Table.LOCS, null, LocsCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                LocsCol.POSITION + " asc");
        boolean hasRow = c.moveToFirst();
        while (hasRow) {
            Loc loc = new Loc();
            loc.setTag(c.getString(3));
            loc.setNode(c.getString(4));
            loc.setLon(c.getDouble(5));
            loc.setLat(c.getDouble(6));
            loc.setTime(c.getInt(7));
            loc.setDSec(c.getInt(8));
            loc.setDist(c.getInt(9));
            loc.setHighwayTime(c.getInt(10));
            loc.setHighwayDSec(c.getInt(11));
            loc.setHighwayDist(c.getInt(12));
            loc.setToll_SS(c.getInt(13));
            loc.setToll_S(c.getInt(14));
            loc.setToll_M(c.getInt(15));
            loc.setToll_L(c.getInt(16));
            loc.setToll_LL(c.getInt(17));
            locs.add(loc);
            hasRow = c.moveToNext();
        }
        c.close();
        return locs;
    }

    /**
     * 道路データ情報を取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 道路データ情報
     */
    private NWInfo getNWInfo(long resultID, SQLiteDatabase db) {
        NWInfo nwInfo = null;
        Cursor c = db.query(Table.NWINFO, null, NWInfoCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                NWInfoCol.POSITION + " asc");
        c.moveToFirst();
        if (c.getCount() == 1) {
            nwInfo = new NWInfo(c.getString(3), c.getString(6),
                    c.getInt(4) != 0, c.getInt(5) != 0, c.getString(7),
                    c.getString(8));
        }
        c.close();
        return nwInfo;
    }

    /**
     * ポイントリストを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return ポイントリスト
     */
    private ArrayList<Pnt> getPnts(long resultID, SQLiteDatabase db) {
        Logger.writeDebugLog("PntsManager", "get");
        ArrayList<Pnt> pnts = new ArrayList<Pnt>();
        Cursor c = db.query(Table.PNTS, null, PntsCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                PntsCol.POSITION + " asc");
        boolean hasRow = c.moveToFirst();
        while (hasRow) {
            Pnt loc = new Pnt();
            loc.setLon(c.getDouble(3));
            loc.setLat(c.getDouble(4));
            pnts.add(loc);
            hasRow = c.moveToNext();
        }
        c.close();
        return pnts;
    }

    /**
     * 計算結果を取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private CalcResultHolder getResult(long resultID, SQLiteDatabase db) {
        CalcResultHolder result = null;
        Cursor c = db.query(Table.RESULTS, null, ResultsCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                ResultsCol.POSITION + " asc");
        c.moveToFirst();
        if (c.getCount() == 1) {
            result = new CalcResultHolder();
            result.setCalcType(c.getInt(3));
            result.setDate(new Date(c.getLong(4)));
            result.setTag(c.getString(5));
        }
        c.close();
        return result;
    }

    /**
     * 経由道路リストを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 経由道路リスト
     */
    private ArrayList<Rn> getRns(long resultID, SQLiteDatabase db) {
        ArrayList<Rn> rns = new ArrayList<Rn>();
        Cursor c = db.query(Table.RNS, null, RnsCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                RnsCol.POSITION + " asc");
        boolean hasRow = c.moveToFirst();
        while (hasRow) {
            Rn rn = new Rn();
            rn.setName(c.getString(3));
            rn.setNlCode(c.getString(4));
            rn.setLon(c.getDouble(5));
            rn.setLat(c.getDouble(6));
            rn.setTime(c.getInt(7));
            rn.setDSec(c.getInt(8));
            rn.setDist(c.getInt(9));
            rn.setIcType(c.getInt(10));
            rn.setLinkFlag(c.getInt(11));
            rn.setLocFlag(c.getInt(12));
            rn.setToll_SS(c.getInt(13));
            rn.setToll_S(c.getInt(14));
            rn.setToll_M(c.getInt(15));
            rn.setToll_L(c.getInt(16));
            rn.setToll_LL(c.getInt(17));
            rns.add(rn);
            hasRow = c.moveToNext();
        }
        c.close();
        return rns;
    }

    /**
     * 経由有料道路リストを取得します。
     * 
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     * @return 経由有料道路リスト
     */
    private ArrayList<Trd> getTrds(long resultID, SQLiteDatabase db) {
        ArrayList<Trd> trds = new ArrayList<Trd>();
        Cursor c = db.query(Table.TRDS, null, TrdsCol.RESULT_ID + " = ?",
                new String[] { Long.toString(resultID) }, null, null,
                TrdsCol.POSITION + " asc");
        boolean hasRow = c.moveToFirst();
        while (hasRow) {
            Trd trd = new Trd();
            trd.setInICName(c.getString(3));
            trd.setInRdName(c.getString(4));
            trd.setOutICName(c.getString(5));
            trd.setOutRdName(c.getString(6));
            trd.setDist(c.getInt(7));
            trd.setToll_SS(c.getInt(8));
            trd.setToll_S(c.getInt(9));
            trd.setToll_M(c.getInt(10));
            trd.setToll_L(c.getInt(11));
            trd.setToll_LL(c.getInt(12));
            trds.add(trd);
            hasRow = c.moveToNext();
        }
        c.close();
        return trds;
    }

    /**
     * 到達圏／流入圏計算パラメータを追加します。
     * 
     * @param param
     *            到達圏／流入圏計算パラメータ
     * @param tag
     *            基点のタグ名
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertCA3Param(CA3Param param, String tag, long resultID,
            SQLiteDatabase db) {
        ContentValues values = new ContentValues();
        values.put(CA3ParamCol.RESULT_ID, resultID);
        values.put(CA3ParamCol.CALC_KIND, param.getCalcKind());
        values.put(CA3ParamCol.COORDINATE_FORMAT, param.getCoordinateFormat());
        values.put(CA3ParamCol.DATUM, param.getDatum());
        values.put(CA3ParamCol.TRANSPORT, param.getTransport());
        values.put(CA3ParamCol.AREA_DIRECTION, param.getAreaDirection());
        values.put(CA3ParamCol.AREA_KIND, param.getAreaKind());
        values.put(CA3ParamCol.AREA_RANGE, param.getAreaRange());
        values.put(CA3ParamCol.DONUT_POLYGON_LEVEL,
                param.getDonutPolygonLevel());
        values.put(CA3ParamCol.POLYGON_DETAIL, param.getPolygonDetail());
        values.put(CA3ParamCol.POLYGON_KIND, param.getPolygonKind());
        values.put(CA3ParamCol.POLYGON_LEVEL, param.getPolygonLevel());
        values.put(CA3ParamCol.START_PNT_LON, param.getStartPnt().getLon());
        values.put(CA3ParamCol.START_PNT_LAT, param.getStartPnt().getLat());
        values.put(CA3ParamCol.START_PNT_NODE, param.getStartPnt().getNode());
        values.put(CA3ParamCol.START_PNT_TAG, tag);
        db.insert(Table.CA3_PARAM, null, values);
    }

    /**
     * 片道一括計算パラメータを追加します。
     * 
     * @param param
     *            片道一括計算パラメータ
     * @param tag
     *            基点のタグ名
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertCOW3Param(COW3Param param, String tag, long resultID,
            SQLiteDatabase db) {
        ContentValues values = new ContentValues();
        values.put(COW3ParamCol.RESULT_ID, resultID);
        values.put(COW3ParamCol.CALC_KIND, param.getCalcKind());
        values.put(COW3ParamCol.COORDINATE_FORMAT, param.getCoordinateFormat());
        values.put(COW3ParamCol.DATUM, param.getDatum());
        values.put(COW3ParamCol.TRANSPORT, param.getTransport());
        values.put(COW3ParamCol.AREA_DIRECTION, param.getAreaDirection());
        values.put(COW3ParamCol.AREA_KIND, param.getAreaKind());
        values.put(COW3ParamCol.AREA_RANGE, param.getAreaRange());
        values.put(COW3ParamCol.HIGHWAY_OUTPUT, param.getHighwayOutput());
        values.put(COW3ParamCol.TOLL_OUTPUT, param.getTollOutput());
        values.put(COW3ParamCol.START_PNT_LON, param.getStartPnt().getLon());
        values.put(COW3ParamCol.START_PNT_LAT, param.getStartPnt().getLat());
        values.put(COW3ParamCol.START_PNT_NODE, param.getStartPnt().getNode());
        values.put(COW3ParamCol.START_PNT_TAG, tag);
        db.insert(Table.COW3_PARAM, null, values);
    }

    /**
     * ルート計算パラメータを追加します。
     * 
     * @param param
     *            ルート計算パラメータ
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertCRParam(CRParam param, long resultID, SQLiteDatabase db) {
        ContentValues values = new ContentValues();
        values.put(CRParamCol.RESULT_ID, resultID);
        values.put(CRParamCol.CALC_KIND, param.getCalcKind());
        values.put(CRParamCol.COORDINATE_FORMAT, param.getCoordinateFormat());
        values.put(CRParamCol.DATUM, param.getDatum());
        values.put(CRParamCol.HIGHWAY_OUTPUT, param.getHighwayOutput());
        values.put(CRParamCol.PNTS_OUTPUT, param.getPntsOutput());
        values.put(CRParamCol.RNS_OUTPUT, param.getRnsOutput());
        values.put(CRParamCol.ROUTE_KIND, param.getRouteKind());
        values.put(CRParamCol.TOLL_OUTPUT, param.getTollOutput());
        values.put(CRParamCol.TRANSPORT, param.getTransport());
        values.put(CRParamCol.TRDS_OUTPUT, param.getTrdsOutput());
        db.insert(Table.CR_PARAM, null, values);
    }

    /**
     * 地点を追加します。
     * 
     * @param locs
     *            地点リスト
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertLocs(ArrayList<Loc> locs, long resultID,
            SQLiteDatabase db) {
        for (int i = 0; i < locs.size(); ++i) {
            Loc loc = locs.get(i);
            ContentValues values = new ContentValues();
            values.put(LocsCol.RESULT_ID, resultID);
            values.put(LocsCol.POSITION, i);
            values.put(LocsCol.TAG, loc.getTag());
            values.put(LocsCol.NODE, loc.getNode());
            values.put(LocsCol.LON, loc.getLon());
            values.put(LocsCol.LAT, loc.getLat());
            values.put(LocsCol.TIME, loc.getTime());
            values.put(LocsCol.DSEC, loc.getDSec());
            values.put(LocsCol.DIST, loc.getDist());
            values.put(LocsCol.HIGHWAY_TIME, loc.getHighwayTime());
            values.put(LocsCol.HIGHWAY_DSEC, loc.getHighwayDSec());
            values.put(LocsCol.HIGHWAY_DIST, loc.getHighwayDist());
            values.put(LocsCol.TOLL_SS, loc.getToll_SS());
            values.put(LocsCol.TOLL_S, loc.getToll_S());
            values.put(LocsCol.TOLL_M, loc.getToll_M());
            values.put(LocsCol.TOLL_L, loc.getToll_L());
            values.put(LocsCol.TOLL_LL, loc.getToll_LL());
            db.insert(Table.LOCS, null, values);
        }
    }

    /**
     * 道路データ情報を追加します。
     * 
     * @param nwInfo
     *            道路データ情報
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertNWInfo(NWInfo nwInfo, long resultID, SQLiteDatabase db) {
        ContentValues values = new ContentValues();
        values.put(NWInfoCol.RESULT_ID, resultID);
        values.put(NWInfoCol.POSITION, 0);
        values.put(NWInfoCol.FOLDER, nwInfo.getFolder());
        values.put(NWInfoCol.IS_DETAIL_EXIST, nwInfo.getIsDetailExist());
        values.put(NWInfoCol.IS_TOLL_EXIST, nwInfo.getIsTollExist());
        values.put(NWInfoCol.NOTE, nwInfo.getNote());
        values.put(NWInfoCol.NWID, nwInfo.getNwID());
        values.put(NWInfoCol.NWID_WITHOUT_SPEED, nwInfo.getNwID_WithoutSpeed());
        db.insert(Table.NWINFO, null, values);
    }

    /**
     * ポイントを追加します。
     * 
     * @param Pnts
     *            ポイントリスト
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertPnts(ArrayList<Pnt> Pnts, long resultID,
            SQLiteDatabase db) {
        for (int i = 0; i < Pnts.size(); ++i) {
            Pnt pnt = Pnts.get(i);
            ContentValues values = new ContentValues();
            values.put(PntsCol.RESULT_ID, resultID);
            values.put(PntsCol.POSITION, i);
            values.put(PntsCol.LON, pnt.getLon());
            values.put(PntsCol.LAT, pnt.getLat());
            db.insert(Table.PNTS, null, values);
        }
    }

    /**
     * 経由道路を追加します。
     * 
     * @param rns
     *            経由道路リスト
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertRns(ArrayList<Rn> rns, long resultID, SQLiteDatabase db) {
        for (int i = 0; i < rns.size(); ++i) {
            Rn loc = rns.get(i);
            ContentValues values = new ContentValues();
            values.put(RnsCol.RESULT_ID, resultID);
            values.put(RnsCol.POSITION, i);
            values.put(RnsCol.NAME, loc.getName());
            values.put(RnsCol.NL_CODE, loc.getNlCode());
            values.put(RnsCol.LON, loc.getLon());
            values.put(RnsCol.LAT, loc.getLat());
            values.put(RnsCol.TIME, loc.getTime());
            values.put(RnsCol.DSEC, loc.getDSec());
            values.put(RnsCol.DIST, loc.getDist());
            values.put(RnsCol.IC_TYPE, loc.getIcType());
            values.put(RnsCol.LINK_FLAG, loc.getLinkFlag());
            values.put(RnsCol.LOC_FLAG, loc.getLocFlag());
            values.put(RnsCol.TOLL_SS, loc.getToll_SS());
            values.put(RnsCol.TOLL_S, loc.getToll_S());
            values.put(RnsCol.TOLL_M, loc.getToll_M());
            values.put(RnsCol.TOLL_L, loc.getToll_L());
            values.put(RnsCol.TOLL_LL, loc.getToll_LL());
            db.insert(Table.RNS, null, values);
        }
    }

    /**
     * 経由有料道路を追加します。
     * 
     * @param trds
     *            経由有料道路リスト
     * @param resultID
     *            計算結果ID
     * @param db
     *            データベース
     */
    private void insertTrds(ArrayList<Trd> trds, long resultID,
            SQLiteDatabase db) {
        for (int i = 0; i < trds.size(); ++i) {
            Trd loc = trds.get(i);
            ContentValues values = new ContentValues();
            values.put(TrdsCol.RESULT_ID, resultID);
            values.put(TrdsCol.POSITION, i);
            values.put(TrdsCol.IN_IC_NAME, loc.getInICName());
            values.put(TrdsCol.IN_RD_NAME, loc.getInRdName());
            values.put(TrdsCol.OUT_IC_NAME, loc.getOutICName());
            values.put(TrdsCol.OUT_RD_NAME, loc.getOutRdName());
            values.put(TrdsCol.DIST, loc.getDist());
            values.put(TrdsCol.TOLL_SS, loc.getToll_SS());
            values.put(TrdsCol.TOLL_S, loc.getToll_S());
            values.put(TrdsCol.TOLL_M, loc.getToll_M());
            values.put(TrdsCol.TOLL_L, loc.getToll_L());
            values.put(TrdsCol.TOLL_LL, loc.getToll_LL());
            db.insert(Table.TRDS, null, values);
        }
    }
}
