﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 到達圏／流入圏計算用パラメータです。
 * 
 * @author ishi
 */
public class CA3Param {
    private static final String AREA_DIRECTION = "AreaDirection";
    private static final String AREA_KIND = "AreaKind";
    private static final String AREA_RANGE = "AreaRange";
    private static final String CA3_PARAM = "CA3Param";
    private static final String CALC_KIND = "CalcKind";
    private static final String COORDINATE_FORMAT = "CoordinateFormat";
    private static final String DATUM = "Datum";
    private static final String DONUT_POLYGON_LEVEL = "DonutPolygonLevel";
    private static final String POLYGON_DETAIL = "PolygonDetail";
    private static final String POLYGON_KIND = "PolygonKind";
    private static final String POLYGON_LEVEL = "PolygonLevel";
    private static final String START_PNT = "StartPnt";
    private static final String TRANSPORT = "Transport";

    /**
     * 経緯度の座標系識別子
     */
    private int datum;
    /**
     * 経緯度の座標フォーマット識別子
     */
    private int coordinateFormat;
    /**
     * 計算方法
     */
    private int calcKind;
    /**
     * 使用交通機関フラグを取得します。
     */
    private int transport;
    /**
     * 到達圏／流入圏計算の中心地点
     */
    private NodePnt startPnt;
    /**
     * ポリゴン種別
     */
    private int polygonKind;
    /**
     * 到達圏／流入圏計算種別
     */
    private int areaKind;
    /**
     * 到達圏／流入圏範囲
     */
    private int areaRange;
    /**
     * 到達圏／流入圏ポリゴンレベル
     */
    private int polygonLevel;
    /**
     * 到達圏／流入圏ドーナツポリゴンレベル
     */
    private int donutPolygonLevel;
    /**
     * 範囲方向
     */
    private int areaDirection;
    /**
     * ポリゴン詳細設定
     */
    private int polygonDetail;

    /**
     * @return areaDirection
     */
    public int getAreaDirection() {
        return this.areaDirection;
    }

    /**
     * @return areaKind
     */
    public int getAreaKind() {
        return this.areaKind;
    }

    /**
     * @return areaRange
     */
    public int getAreaRange() {
        return this.areaRange;
    }

    /**
     * @return calcKind
     */
    public int getCalcKind() {
        return this.calcKind;
    }

    /**
     * @return coordinateFormat
     */
    public int getCoordinateFormat() {
        return this.coordinateFormat;
    }

    /**
     * @return datum
     */
    public int getDatum() {
        return this.datum;
    }

    /**
     * @return donutPolygonLevel
     */
    public int getDonutPolygonLevel() {
        return this.donutPolygonLevel;
    }

    /**
     * @return polygonDetail
     */
    public int getPolygonDetail() {
        return this.polygonDetail;
    }

    /**
     * @return polygonKind
     */
    public int getPolygonKind() {
        return this.polygonKind;
    }

    /**
     * @return polygonLevel
     */
    public int getPolygonLevel() {
        return this.polygonLevel;
    }

    /**
     * @return startPnt
     */
    public NodePnt getStartPnt() {
        return this.startPnt;
    }

    /**
     * @return transport
     */
    public int getTransport() {
        return this.transport;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(START_PNT)) {
                    startPnt = new NodePnt();
                    startPnt.readXml(parser, START_PNT);
                    eventType = parser.next();
                    continue;
                } else if (startTagName.equalsIgnoreCase(DATUM)) {
                    String value = parser.nextText();
                    datum = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(COORDINATE_FORMAT)) {
                    String value = parser.nextText();
                    coordinateFormat = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_KIND)) {
                    String value = parser.nextText();
                    calcKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TRANSPORT)) {
                    String value = parser.nextText();
                    transport = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(POLYGON_KIND)) {
                    String value = parser.nextText();
                    polygonKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_KIND)) {
                    String value = parser.nextText();
                    areaKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_RANGE)) {
                    String value = parser.nextText();
                    areaRange = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(POLYGON_LEVEL)) {
                    String value = parser.nextText();
                    polygonLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DONUT_POLYGON_LEVEL)) {
                    String value = parser.nextText();
                    donutPolygonLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_DIRECTION)) {
                    String value = parser.nextText();
                    areaDirection = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(POLYGON_DETAIL)) {
                    String value = parser.nextText();
                    polygonDetail = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param areaDirection
     *            セットする areaDirection
     */
    public void setAreaDirection(int areaDirection) {
        this.areaDirection = areaDirection;
    }

    /**
     * @param areaKind
     *            セットする areaKind
     */
    public void setAreaKind(int areaKind) {
        this.areaKind = areaKind;
    }

    /**
     * @param areaRange
     *            セットする areaRange
     */
    public void setAreaRange(int areaRange) {
        this.areaRange = areaRange;
    }

    /**
     * @param calcKind
     *            セットする calcKind
     */
    public void setCalcKind(int calcKind) {
        this.calcKind = calcKind;
    }

    /**
     * @param coordinateFormat
     *            セットする coordinateFormat
     */
    public void setCoordinateFormat(int coordinateFormat) {
        this.coordinateFormat = coordinateFormat;
    }

    /**
     * @param datum
     *            セットする datum
     */
    public void setDatum(int datum) {
        this.datum = datum;
    }

    /**
     * @param donutPolygonLevel
     *            セットする donutPolygonLevel
     */
    public void setDonutPolygonLevel(int donutPolygonLevel) {
        this.donutPolygonLevel = donutPolygonLevel;
    }

    /**
     * @param polygonDetail
     *            セットする polygonDetail
     */
    public void setPolygonDetail(int polygonDetail) {
        this.polygonDetail = polygonDetail;
    }

    /**
     * @param polygonKind
     *            セットする polygonKind
     */
    public void setPolygonKind(int polygonKind) {
        this.polygonKind = polygonKind;
    }

    /**
     * @param polygonLevel
     *            セットする polygonLevel
     */
    public void setPolygonLevel(int polygonLevel) {
        this.polygonLevel = polygonLevel;
    }

    /**
     * @param startPnt
     *            セットする startPnt
     */
    public void setStartPnt(NodePnt startPnt) {
        this.startPnt = startPnt;
    }

    /**
     * @param transport
     *            セットする transport
     */
    public void setTransport(int transport) {
        this.transport = transport;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = CA3_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", DATUM);
        xmlSerializer.text(Integer.toString(datum));
        xmlSerializer.endTag("", DATUM);
        xmlSerializer.startTag("", COORDINATE_FORMAT);
        xmlSerializer.text(Integer.toString(coordinateFormat));
        xmlSerializer.endTag("", COORDINATE_FORMAT);
        xmlSerializer.startTag("", CALC_KIND);
        xmlSerializer.text(Integer.toString(calcKind));
        xmlSerializer.endTag("", CALC_KIND);
        xmlSerializer.startTag("", TRANSPORT);
        xmlSerializer.text(Integer.toString(transport));
        xmlSerializer.endTag("", TRANSPORT);
        xmlSerializer.startTag("", POLYGON_KIND);
        xmlSerializer.text(Integer.toString(polygonKind));
        xmlSerializer.endTag("", POLYGON_KIND);
        if (startPnt != null) {
            startPnt.writeXml(xmlSerializer, START_PNT);
        }
        xmlSerializer.startTag("", AREA_KIND);
        xmlSerializer.text(Integer.toString(areaKind));
        xmlSerializer.endTag("", AREA_KIND);
        xmlSerializer.startTag("", AREA_RANGE);
        xmlSerializer.text(Integer.toString(areaRange));
        xmlSerializer.endTag("", AREA_RANGE);
        xmlSerializer.startTag("", POLYGON_LEVEL);
        xmlSerializer.text(Integer.toString(polygonLevel));
        xmlSerializer.endTag("", POLYGON_LEVEL);
        xmlSerializer.startTag("", DONUT_POLYGON_LEVEL);
        xmlSerializer.text(Integer.toString(donutPolygonLevel));
        xmlSerializer.endTag("", DONUT_POLYGON_LEVEL);
        xmlSerializer.startTag("", AREA_DIRECTION);
        xmlSerializer.text(Integer.toString(areaDirection));
        xmlSerializer.endTag("", AREA_DIRECTION);
        xmlSerializer.startTag("", POLYGON_DETAIL);
        xmlSerializer.text(Integer.toString(polygonDetail));
        xmlSerializer.endTag("", POLYGON_DETAIL);
        xmlSerializer.endTag("", tag);
    }
}
