﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 片道一括計算パラメータです。
 * 
 * @author ishi
 * 
 */
public class COW3Param {
    private static final String AREA_DIRECTION = "AreaDirection";
    private static final String AREA_KIND = "AreaKind";
    private static final String AREA_RANGE = "AreaRange";
    private static final String CALC_KIND = "CalcKind";
    private static final String COORDINATE_FORMAT = "CoordinateFormat";
    private static final String COW3_PARAM = "COWParam";
    private static final String DATUM = "Datum";
    private static final String HIGHWAY_OUTPUT = "HighwayOutput";
    private static final String START_PNT = "StartPnt";
    private static final String TOLL_OUTPUT = "TollOutput";
    private static final String TRANSPORT = "Transport";

    /**
     * 経緯度の座標系識別子
     */
    private int datum;
    /**
     * 経緯度の座標フォーマット識別子
     */
    private int coordinateFormat;
    /**
     * 計算方法
     */
    private int calcKind;
    /**
     * 使用交通機関フラグを取得します。
     */
    private int transport;
    /**
     * 到達圏／流入圏計算の中心地点
     */
    private NodePnt startPnt;
    /**
     * 到達圏／流入圏計算種別
     */
    private int areaKind;
    /**
     * 到達圏／流入圏範囲
     */
    private int areaRange;
    /**
     * 範囲方向
     */
    private int areaDirection;
    /**
     * 高速道路区間出力フラグ
     */
    private int highwayOutput;
    /**
     * 通行料金出力フラグ
     */
    private int tollOutput;

    /**
     * コンストラクター
     * 
     */
    public COW3Param() {
    }

    /**
     * @return areaDirection
     */
    public int getAreaDirection() {
        return this.areaDirection;
    }

    /**
     * @return areaKind
     */
    public int getAreaKind() {
        return this.areaKind;
    }

    /**
     * @return areaRange
     */
    public int getAreaRange() {
        return this.areaRange;
    }

    /**
     * @return calcKind
     */
    public int getCalcKind() {
        return this.calcKind;
    }

    /**
     * @return coordinateFormat
     */
    public int getCoordinateFormat() {
        return this.coordinateFormat;
    }

    /**
     * @return datum
     */
    public int getDatum() {
        return this.datum;
    }

    /**
     * @return highwayOutput
     */
    public int getHighwayOutput() {
        return this.highwayOutput;
    }

    /**
     * @return startPnt
     */
    public NodePnt getStartPnt() {
        return this.startPnt;
    }

    /**
     * @return tollOutput
     */
    public int getTollOutput() {
        return this.tollOutput;
    }

    /**
     * @return transport
     */
    public int getTransport() {
        return this.transport;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(START_PNT)) {
                    startPnt = new NodePnt();
                    startPnt.readXml(parser, START_PNT);
                    eventType = parser.next();
                } else if (startTagName.equalsIgnoreCase(DATUM)) {
                    String value = parser.nextText();
                    datum = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(COORDINATE_FORMAT)) {
                    String value = parser.nextText();
                    coordinateFormat = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_KIND)) {
                    String value = parser.nextText();
                    calcKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TRANSPORT)) {
                    String value = parser.nextText();
                    transport = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_KIND)) {
                    String value = parser.nextText();
                    areaKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_RANGE)) {
                    String value = parser.nextText();
                    areaRange = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(AREA_DIRECTION)) {
                    String value = parser.nextText();
                    areaDirection = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(HIGHWAY_OUTPUT)) {
                    String value = parser.nextText();
                    highwayOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_OUTPUT)) {
                    String value = parser.nextText();
                    tollOutput = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param areaDirection
     *            セットする areaDirection
     */
    public void setAreaDirection(int areaDirection) {
        this.areaDirection = areaDirection;
    }

    /**
     * @param areaKind
     *            セットする areaKind
     */
    public void setAreaKind(int areaKind) {
        this.areaKind = areaKind;
    }

    /**
     * @param areaRange
     *            セットする areaRange
     */
    public void setAreaRange(int areaRange) {
        this.areaRange = areaRange;
    }

    /**
     * @param calcKind
     *            セットする calcKind
     */
    public void setCalcKind(int calcKind) {
        this.calcKind = calcKind;
    }

    /**
     * @param coordinateFormat
     *            セットする coordinateFormat
     */
    public void setCoordinateFormat(int coordinateFormat) {
        this.coordinateFormat = coordinateFormat;
    }

    /**
     * @param datum
     *            セットする datum
     */
    public void setDatum(int datum) {
        this.datum = datum;
    }

    /**
     * @param highwayOutput
     *            セットする highwayOutput
     */
    public void setHighwayOutput(int highwayOutput) {
        this.highwayOutput = highwayOutput;
    }

    /**
     * @param startPnt
     *            セットする startPnt
     */
    public void setStartPnt(NodePnt startPnt) {
        this.startPnt = startPnt;
    }

    /**
     * @param tollOutput
     *            セットする tollOutput
     */
    public void setTollOutput(int tollOutput) {
        this.tollOutput = tollOutput;
    }

    /**
     * @param transport
     *            セットする transport
     */
    public void setTransport(int transport) {
        this.transport = transport;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = COW3_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", DATUM);
        xmlSerializer.text(Integer.toString(datum));
        xmlSerializer.endTag("", DATUM);
        xmlSerializer.startTag("", COORDINATE_FORMAT);
        xmlSerializer.text(Integer.toString(coordinateFormat));
        xmlSerializer.endTag("", COORDINATE_FORMAT);
        xmlSerializer.startTag("", CALC_KIND);
        xmlSerializer.text(Integer.toString(calcKind));
        xmlSerializer.endTag("", CALC_KIND);
        xmlSerializer.startTag("", TRANSPORT);
        xmlSerializer.text(Integer.toString(transport));
        xmlSerializer.endTag("", TRANSPORT);
        if (startPnt != null) {
            startPnt.writeXml(xmlSerializer, START_PNT);
        }
        xmlSerializer.startTag("", AREA_KIND);
        xmlSerializer.text(Integer.toString(areaKind));
        xmlSerializer.endTag("", AREA_KIND);
        xmlSerializer.startTag("", AREA_RANGE);
        xmlSerializer.text(Integer.toString(areaRange));
        xmlSerializer.endTag("", AREA_RANGE);
        xmlSerializer.startTag("", AREA_DIRECTION);
        xmlSerializer.text(Integer.toString(areaDirection));
        xmlSerializer.endTag("", AREA_DIRECTION);
        xmlSerializer.startTag("", HIGHWAY_OUTPUT);
        xmlSerializer.text(Integer.toString(highwayOutput));
        xmlSerializer.endTag("", HIGHWAY_OUTPUT);
        xmlSerializer.startTag("", TOLL_OUTPUT);
        xmlSerializer.text(Integer.toString(tollOutput));
        xmlSerializer.endTag("", TOLL_OUTPUT);
        xmlSerializer.endTag("", tag);
    }
}
