﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * ルート計算パラメータです。
 * 
 * @author ishi
 * 
 */
public class CRParam {
    private static final String CALC_KIND = "CalcKind";
    private static final String COORDINATE_FORMAT = "CoordinateFormat";
    private static final String CR_PARAM = "CRParam";
    private static final String DATUM = "Datum";
    private static final String HIGHWAY_OUTPUT = "HighwayOutput";
    private static final String PNTS_OUTPUT = "PntsOutput";
    private static final String RNS_OUTPUT = "RnsOutput";
    private static final String ROUTE_KIND = "RouteKind";
    private static final String TOLL_OUTPUT = "TollOutput";
    private static final String TRANSPORT = "Transport";
    private static final String TRDS_OUTPUT = "TrdsOutput";

    /**
     * 経緯度の座標系識別子
     */
    private int datum;
    /**
     * 経緯度の座標フォーマット識別子
     */
    private int coordinateFormat;
    /**
     * 計算方法
     */
    private int calcKind;
    /**
     * 使用交通機関フラグ
     */
    private int transport;
    /**
     * ポイントリスト出力フラグ
     */
    private int pntsOutput;
    /**
     * 経由道路名リスト出力フラグ
     */
    private int rnsOutput;
    /**
     * 経由有料道路リスト出力フラグ
     */
    private int trdsOutput;
    /**
     * 高速道路区間出力フラグ
     */
    private int highwayOutput;
    /**
     * 通行料金出力フラグ
     */
    private int tollOutput;
    /**
     * ルート種別指定
     */
    private int routeKind;

    /**
     * コンストラクター
     * 
     */
    public CRParam() {
    }

    /**
     * @return calcKind
     */
    public int getCalcKind() {
        return this.calcKind;
    }

    /**
     * @return coordinateFormat
     */
    public int getCoordinateFormat() {
        return this.coordinateFormat;
    }

    /**
     * @return datum
     */
    public int getDatum() {
        return this.datum;
    }

    /**
     * @return highwayOutput
     */
    public int getHighwayOutput() {
        return this.highwayOutput;
    }

    /**
     * @return pntsOutput
     */
    public int getPntsOutput() {
        return this.pntsOutput;
    }

    /**
     * @return rnsOutput
     */
    public int getRnsOutput() {
        return this.rnsOutput;
    }

    /**
     * @return routeKind
     */
    public int getRouteKind() {
        return this.routeKind;
    }

    /**
     * @return tollOutput
     */
    public int getTollOutput() {
        return this.tollOutput;
    }

    /**
     * @return transport
     */
    public int getTransport() {
        return this.transport;
    }

    /**
     * @return trdsOutput
     */
    public int getTrdsOutput() {
        return this.trdsOutput;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(DATUM)) {
                    String value = parser.nextText();
                    datum = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(COORDINATE_FORMAT)) {
                    String value = parser.nextText();
                    coordinateFormat = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(CALC_KIND)) {
                    String value = parser.nextText();
                    calcKind = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TRANSPORT)) {
                    String value = parser.nextText();
                    transport = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(PNTS_OUTPUT)) {
                    String value = parser.nextText();
                    pntsOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(RNS_OUTPUT)) {
                    String value = parser.nextText();
                    rnsOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TRDS_OUTPUT)) {
                    String value = parser.nextText();
                    trdsOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(HIGHWAY_OUTPUT)) {
                    String value = parser.nextText();
                    highwayOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_OUTPUT)) {
                    String value = parser.nextText();
                    tollOutput = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ROUTE_KIND)) {
                    String value = parser.nextText();
                    routeKind = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param calcKind
     *            セットする calcKind
     */
    public void setCalcKind(int calcKind) {
        this.calcKind = calcKind;
    }

    /**
     * @param coordinateFormat
     *            セットする coordinateFormat
     */
    public void setCoordinateFormat(int coordinateFormat) {
        this.coordinateFormat = coordinateFormat;
    }

    /**
     * @param datum
     *            セットする datum
     */
    public void setDatum(int datum) {
        this.datum = datum;
    }

    /**
     * @param highwayOutput
     *            セットする highwayOutput
     */
    public void setHighwayOutput(int highwayOutput) {
        this.highwayOutput = highwayOutput;
    }

    /**
     * @param pntsOutput
     *            セットする pntsOutput
     */
    public void setPntsOutput(int pntsOutput) {
        this.pntsOutput = pntsOutput;
    }

    /**
     * @param rnsOutput
     *            セットする rnsOutput
     */
    public void setRnsOutput(int rnsOutput) {
        this.rnsOutput = rnsOutput;
    }

    /**
     * @param routeKind
     *            セットする routeKind
     */
    public void setRouteKind(int routeKind) {
        this.routeKind = routeKind;
    }

    /**
     * @param tollOutput
     *            セットする tollOutput
     */
    public void setTollOutput(int tollOutput) {
        this.tollOutput = tollOutput;
    }

    /**
     * @param transport
     *            セットする transport
     */
    public void setTransport(int transport) {
        this.transport = transport;
    }

    /**
     * @param trdsOutput
     *            セットする trdsOutput
     */
    public void setTrdsOutput(int trdsOutput) {
        this.trdsOutput = trdsOutput;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = CR_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", DATUM);
        xmlSerializer.text(Integer.toString(datum));
        xmlSerializer.endTag("", DATUM);
        xmlSerializer.startTag("", COORDINATE_FORMAT);
        xmlSerializer.text(Integer.toString(coordinateFormat));
        xmlSerializer.endTag("", COORDINATE_FORMAT);
        xmlSerializer.startTag("", CALC_KIND);
        xmlSerializer.text(Integer.toString(calcKind));
        xmlSerializer.endTag("", CALC_KIND);
        xmlSerializer.startTag("", TRANSPORT);
        xmlSerializer.text(Integer.toString(transport));
        xmlSerializer.endTag("", TRANSPORT);
        xmlSerializer.startTag("", PNTS_OUTPUT);
        xmlSerializer.text(Integer.toString(pntsOutput));
        xmlSerializer.endTag("", PNTS_OUTPUT);
        xmlSerializer.startTag("", RNS_OUTPUT);
        xmlSerializer.text(Integer.toString(rnsOutput));
        xmlSerializer.endTag("", RNS_OUTPUT);
        xmlSerializer.startTag("", TRDS_OUTPUT);
        xmlSerializer.text(Integer.toString(trdsOutput));
        xmlSerializer.endTag("", TRDS_OUTPUT);
        xmlSerializer.startTag("", HIGHWAY_OUTPUT);
        xmlSerializer.text(Integer.toString(highwayOutput));
        xmlSerializer.endTag("", HIGHWAY_OUTPUT);
        xmlSerializer.startTag("", TOLL_OUTPUT);
        xmlSerializer.text(Integer.toString(tollOutput));
        xmlSerializer.endTag("", TOLL_OUTPUT);
        xmlSerializer.startTag("", ROUTE_KIND);
        xmlSerializer.text(Integer.toString(routeKind));
        xmlSerializer.endTag("", ROUTE_KIND);
        xmlSerializer.endTag("", tag);
    }
}
