﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 到達圏／流入圏計算の結果です。 CalcArea3の結果を格納します。
 * 
 * @author ishi
 */
public class CalcArea3Response implements Response {
    private static final String CA3_PARAM = "CA3Param";
    private static final String CALC_AREA3_RESULT = "CalcArea3Result";
    private static final String NW_INFO = "NWInfo";
    private static final String PNT = "Pnt";
    private static final String PNTS = "Pnts";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 計算パラメータ
     */
    private CA3Param param;
    /**
     * ポイントリスト
     */
    private ArrayList<Pnt> pnts;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 基点インデックス
     */
    private int startIndex;
    /**
     * 基点地点
     */
    private Loc startLoc;

    /**
     * コンストラクター
     */
    public CalcArea3Response() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return param
     */
    public CA3Param getParam() {
        return this.param;
    }

    /**
     * @return pnts
     */
    public ArrayList<Pnt> getPnts() {
        return this.pnts;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    /**
     * @return startIndex
     */
    public int getStartIndex() {
        return this.startIndex;
    }

    /**
     * @return startLoc
     */
    public Loc getStartLoc() {
        return this.startLoc;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inPnts = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inPnts) {
                    if (startTagName.equalsIgnoreCase(PNT)) {
                        Pnt pnt = new Pnt();
                        pnt.readXml(parser, PNT);
                        pnts.add(pnt);
                    }
                } else {
                    if (startTagName.equalsIgnoreCase(CALC_AREA3_RESULT)) {
                        resultCode = Integer.parseInt(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(CA3_PARAM)) {
                        param = new CA3Param();
                        getParam().readXml(parser, CA3_PARAM);
                    } else if (startTagName.equalsIgnoreCase(PNTS)) {
                        inPnts = true;
                        pnts = new ArrayList<Pnt>();
                    } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                        nwInfo = new NWInfo();
                        getNwInfo().readXml(parser, NW_INFO);
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(PNTS)) {
                    inPnts = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(CA3Param param) {
        this.param = param;
    }

    /**
     * @param pnts
     *            セットする pnts
     */
    public void setPnts(ArrayList<Pnt> pnts) {
        this.pnts = pnts;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }

    /**
     * @param startIndex
     *            セットする startIndex
     */
    public void setStartIndex(int startIndex) {
        this.startIndex = startIndex;
    }

    /**
     * @param startLoc
     *            セットする startLoc
     */
    public void setStartLoc(Loc startLoc) {
        this.startLoc = startLoc;
    }
}
