﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 片道一括計算の結果です。 CalcOneWay3の結果を格納します。
 * 
 * @author ishi
 * 
 */
public class CalcOneWay3Response implements Response {
    private static final String CALC_ONE_WAY_RESULT = "CalcOneWay3Result";
    private static final String LOC = "Loc";
    private static final String LOCS = "Locs";
    private static final String NW_INFO = "NWInfo";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 地点リスト
     */
    private ArrayList<Loc> locs;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算パラメータ
     */
    private COW3Param param;
    /**
     * 基点インデックス
     */
    private int startIndex;
    /**
     * 基点地点
     */
    private Loc startLoc;

    /**
     * コンストラクター
     * 
     */
    public CalcOneWay3Response() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return locs
     */
    public ArrayList<Loc> getLocs() {
        return this.locs;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return param
     */
    public COW3Param getParam() {
        return this.param;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    /**
     * @return startIndex
     */
    public int getStartIndex() {
        return this.startIndex;
    }

    /**
     * @return startLoc
     */
    public Loc getStartLoc() {
        return this.startLoc;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inLocs = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inLocs) {
                    if (startTagName.equalsIgnoreCase(LOC)) {
                        Loc loc = new Loc();
                        loc.readXml(parser, LOC);
                        locs.add(loc);
                    }
                } else {
                    if (startTagName.equalsIgnoreCase(CALC_ONE_WAY_RESULT)) {
                        resultCode = Integer.parseInt(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(LOCS)) {
                        inLocs = true;
                        locs = new ArrayList<Loc>();
                    } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                        nwInfo = new NWInfo();
                        getNwInfo().readXml(parser, NW_INFO);
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(LOCS)) {
                    inLocs = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param locs
     *            セットする locs
     */
    public void setLocs(ArrayList<Loc> locs) {
        this.locs = locs;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(COW3Param param) {
        this.param = param;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }

    /**
     * @param startIndex
     *            セットする startIndex
     */
    public void setStartIndex(int startIndex) {
        this.startIndex = startIndex;
    }

    /**
     * @param startLoc
     *            セットする startLoc
     */
    public void setStartLoc(Loc startLoc) {
        this.startLoc = startLoc;
    }
}
