﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.util.Date;

import jp.co.act_inc.actservicesample.MapLayer;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.adminservice.GetUsableDCServerResponse;
import jp.co.act_inc.actservicesample.adminservice.Response;
import android.content.Context;

/**
 * 距離計算結果を格納します。
 * 
 * @author ishi
 * 
 */
public class CalcResultHolder {
    /**
     * 計算種別
     * 
     * @author ishi
     * 
     */
    public class CalcType {
        /**
         * エラー
         */
        public static final int ERROR = -1;
        /**
         * ルート計算
         */
        public static final int CALC_ROUTE = 0;
        /**
         * 最短ルート計算
         */
        public static final int CALC_OPT_ROUTE = 1;
        /**
         * 到達圏／流入圏計算
         */
        public static final int CALC_AREA = 2;
        /**
         * 片道一括計算
         */
        public static final int CALC_ONE_WAY = 3;
    }

    private GetUsableDCServerResponse getUsableDCServerResponse;
    private CalcArea3Response calcArea3Response;
    private CalcOneWay3Response calcOneWay3Response;
    private CalcOptRouteResponse calcOptRouteResponse;
    private CalcRouteResponse calcRouteResponse;

    /**
     * 計算結果レイヤー
     */
    private MapLayer layer;

    /**
     * 計算日時
     */
    private Date date;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * タグ名
     */
    private String tag;
    /**
     * 計算種別
     */
    private int calcType;

    /**
     * @return calcArea3Response
     */
    public CalcArea3Response getCalcArea3Response() {
        return this.calcArea3Response;
    }

    /**
     * @return calcOneWay3Response
     */
    public CalcOneWay3Response getCalcOneWay3Response() {
        return this.calcOneWay3Response;
    }

    /**
     * @return calcOptRouteResponse
     */
    public CalcOptRouteResponse getCalcOptRouteResponse() {
        return this.calcOptRouteResponse;
    }

    /**
     * @return calcRouteResponse
     */
    public CalcRouteResponse getCalcRouteResponse() {
        return this.calcRouteResponse;
    }

    /**
     * @return calcType
     */
    public int getCalcType() {
        return this.calcType;
    }

    /**
     * 計算種別文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @return 計算種別文字列
     */
    public String getCalcTypeString(Context context) {
        switch (getCalcType()) {
        case CalcType.CALC_ROUTE:
            return context.getString(R.string.common_calc_route);
        case CalcType.CALC_OPT_ROUTE:
            return context.getString(R.string.common_calc_opt_route);
        case CalcType.CALC_AREA:
            return context.getString(R.string.common_calc_area3);
        case CalcType.CALC_ONE_WAY:
            return context.getString(R.string.common_calc_one_way3);
        default:
            return "";
        }
    }

    /**
     * @return date
     */
    public Date getDate() {
        return this.date;
    }

    /**
     * @return exception
     */
    public Exception getException() {
        return this.exception;
    }

    /**
     * @return getUsableDCServerResponse
     */
    public GetUsableDCServerResponse getGetUsableDCServerResponse() {
        return this.getUsableDCServerResponse;
    }

    /**
     * @return layer
     */
    public MapLayer getLayer() {
        return this.layer;
    }

    /**
     * 計算結果を取得します。
     * 
     * @return 計算結果
     */
    public Response getResponse() {
        switch (getCalcType()) {
        case CalcType.CALC_ROUTE:
            return calcRouteResponse;
        case CalcType.CALC_OPT_ROUTE:
            return calcOptRouteResponse;
        case CalcType.CALC_AREA:
            return calcArea3Response;
        case CalcType.CALC_ONE_WAY:
            return calcOneWay3Response;
        default:
            return null;
        }
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * @param calcArea3Response
     *            セットする calcArea3Response
     */
    public void setCalcArea3Response(CalcArea3Response calcArea3Response) {
        this.calcArea3Response = calcArea3Response;
    }

    /**
     * @param calcOneWay3Response
     *            セットする calcOneWay3Response
     */
    public void setCalcOneWay3Response(CalcOneWay3Response calcOneWay3Response) {
        this.calcOneWay3Response = calcOneWay3Response;
    }

    /**
     * @param calcOptRouteResponse
     *            セットする calcOptRouteResponse
     */
    public void setCalcOptRouteResponse(
            CalcOptRouteResponse calcOptRouteResponse) {
        this.calcOptRouteResponse = calcOptRouteResponse;
    }

    /**
     * @param calcRouteResponse
     *            セットする calcRouteResponse
     */
    public void setCalcRouteResponse(CalcRouteResponse calcRouteResponse) {
        this.calcRouteResponse = calcRouteResponse;
    }

    /**
     * @param calcType
     *            セットする calcType
     */
    public void setCalcType(int calcType) {
        this.calcType = calcType;
    }

    /**
     * @param date
     *            セットする date
     */
    public void setDate(Date date) {
        this.date = date;
    }

    /**
     * @param exception
     *            セットする exception
     */
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param getUsableDCServerResponse
     *            セットする getUsableDCServerResponse
     */
    public void setGetUsableDCServerResponse(
            GetUsableDCServerResponse getUsableDCServerResponse) {
        this.getUsableDCServerResponse = getUsableDCServerResponse;
    }

    /**
     * @param layer
     *            セットする layer
     */
    public void setLayer(MapLayer layer) {
        this.layer = layer;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }
}
