/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 直線距離計算の結果です。 CalcStraightLineの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class CalcStraightLineResponse implements Response {
    private static final String CALC_STRAIGHT_LINE_RESULT = "CalcStraightLineResult";
    private static final String LOC = "Loc";
    private static final String LOCS = "Locs";
    private static final String NW_INFO = "NWInfo";
    private static final String PNT = "Pnt";
    private static final String PNTS = "Pnts";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 地点リスト
     */
    private ArrayList<Loc> locs;
    /**
     * ポイントリスト
     */
    private ArrayList<Pnt> pnts;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算パラメータ
     */
    private CSLParam param;

    /**
     * コンストラクタ
     * 
     */
    public CalcStraightLineResponse() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return locs
     */
    public ArrayList<Loc> getLocs() {
        return this.locs;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return param
     */
    public CSLParam getParam() {
        return this.param;
    }

    /**
     * @return pnts
     */
    public ArrayList<Pnt> getPnts() {
        return this.pnts;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inLocs = false;
        boolean inPnts = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inPnts) {
                    if (startTagName.equalsIgnoreCase(PNT)) {
                        Pnt pnt = new Pnt();
                        pnt.readXml(parser, PNT);
                        pnts.add(pnt);
                    }
                } else if (inLocs) {
                    if (startTagName.equalsIgnoreCase(LOC)) {
                        Loc loc = new Loc();
                        loc.readXml(parser, LOC);
                        locs.add(loc);
                    }
                } else {
                    if (startTagName
                            .equalsIgnoreCase(CALC_STRAIGHT_LINE_RESULT)) {
                        resultCode = Integer.parseInt(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(LOCS)) {
                        inLocs = true;
                        locs = new ArrayList<Loc>();
                    } else if (startTagName.equalsIgnoreCase(PNTS)) {
                        inPnts = true;
                        pnts = new ArrayList<Pnt>();
                    } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                        nwInfo = new NWInfo();
                        getNwInfo().readXml(parser, NW_INFO);
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(LOCS)) {
                    inLocs = false;
                } else if (endTagName.equalsIgnoreCase(PNTS)) {
                    inPnts = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param locs
     *            セットする locs
     */
    public void setLocs(ArrayList<Loc> locs) {
        this.locs = locs;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(CSLParam param) {
        this.param = param;
    }

    /**
     * @param pnts
     *            セットする pnts
     */
    public void setPnts(ArrayList<Pnt> pnts) {
        this.pnts = pnts;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }
}
