﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */

package jp.co.act_inc.actservicesample.dcservice;

import java.io.BufferedOutputStream;
import java.net.HttpURLConnection;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.adminservice.ServiceUtils;
import jp.co.act_inc.actservicesample.adminservice.Environ;
import jp.co.act_inc.actservicesample.dcservice.CA3Param;
import jp.co.act_inc.actservicesample.dcservice.COW3Param;
import jp.co.act_inc.actservicesample.dcservice.CRParam;
import jp.co.act_inc.actservicesample.dcservice.CalcArea3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOneWay3Response;
import jp.co.act_inc.actservicesample.dcservice.CalcOptRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.CalcRouteResponse;
import jp.co.act_inc.actservicesample.dcservice.GetDcwsMessageResponse;
import jp.co.act_inc.actservicesample.dcservice.Loc;
import org.xmlpull.v1.XmlSerializer;

import android.util.Log;
import android.util.Xml;

/**
 * ACT距離計算サービスの距離計算サービスを呼び出すクラスです。
 * 
 * @author ishi
 */
public class DCService {
    /**
     * SOAPアクション名
     * 
     * @author ishi
     */
    class ActionName {
        private static final String GET_DCWS_MESSAGE = "GetDCWSMessage";
        private static final String CALC_ROUTE = "CalcRoute";
        private static final String CALC_OPT_ROUTE = "CalcOptRoute";
        private static final String CALC_AREA3 = "CalcArea3";
        private static final String CALC_ONE_WAY3 = "CalcOneWay3";
        private static final String CALC_STRAIGHT_LINE = "CalcStraightLine";
        private static final String ENUM_NEAR_NODE = "EnumNearNode";
        private static final String GET_NEAREST_LINK2 = "GetNearestLink2";
        private static final String GET_NEAREST_NODE = "GetNearestNode";
        private static final String GET_NETWORK_INFO = "GetNetworkInfo";
        private static final String GET_SPEED2 = "GetSpeed2";
        private static final String SET_SPEED2 = "SetSpeed2";
    }

    /**
     * サービス名前空間
     * 
     * @author ishi
     * 
     */
    class Namespace {
        private static final String DCWS = "http://distcalc.act-inc.co.jp/DCWS";
    }

    /**
     * タグ名
     * 
     * @author ishi
     */
    class Tag {
        private static final String GET_DCWS_MESSAGE_RESPONSE = "GetDCWSMessageResponse";
        private static final String CALC_AREA3_RESPONSE = "CalcArea3Response";
        private static final String CALC_ONEWAY3_RESPONSE = "CalcOneWay3Response";
        private static final String CALC_OPT_ROUTE_RESPONSE = "CalcOptRouteResponse";
        private static final String CALC_ROUTE_RESPONSE = "CalcRouteResponse";
        private static final String CALC_STRAIGHT_LINE_RESPONSE = "CalcStraightLineResponse";
        private static final String ENUM_NEAR_NODE_RESPONSE = "EnumNearNodeResponse";
        private static final String GET_NEAREST_LINK2_RESPONSE = "GetNearestLink2Response";
        private static final String GET_NEAREST_NODE_RESPONSE = "GetNearestNodeResponse";
        private static final String GET_NETWORK_INFO_RESPONSE = "GetNetworkInfoResponse";
        private static final String GET_SPEED2_RESPONSE = "GetSpeed2Response";
        private static final String SET_SPEED2_RESPONSE = "SetSpeed2Response";

        private static final String ENVIRON = "Environ";
        private static final String ENV = "Env";
        private static final String MSG_NUMBER = "MsgNumber";
        private static final String CR_PARAM = "CRParam";
        private static final String COW3_PARAM = "COW3Param";
        private static final String CA3_PARAM = "CA3Param";
        private static final String CSL_PARAM = "CSLParam";
        private static final String ENN_PARAM = "ENNParam";
        private static final String LOC = "Loc";
        private static final String LOCS = "Locs";
        private static final String GNL_PARAM = "GNLParam";
        private static final String GNN_PARAM = "GNNParam";
        private static final String GS_PARAM = "GSParam";
        private static final String SS_PARAM = "SSParam";
    }

    /**
     * 到達圏／流入圏計算を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            到達圏／流入圏計算パラメータ
     * @return 結果を格納したCalcArea3Response
     */
    public static CalcArea3Response calcArea3(boolean useSsl, Environ environ,
            CA3Param param) {
        Logger.writeDebugLog("calcArea3", "start");
        String methodName = ActionName.CALC_AREA3;
        String soapAction = Namespace.DCWS + "/" + methodName;
        CalcArea3Response result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.CA3_PARAM);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("calcArea3", "connect");
                connection.connect();
                result = new CalcArea3Response();
                Logger.writeDebugLog("calcArea3", "convert response");
                ServiceUtils.getResponse(result, Tag.CALC_AREA3_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CalcArea3Response();
            result.setException(e);
        }
        Logger.writeDebugLog("calcArea3", "end");
        return result;
    }

    /**
     * 片道一括計算を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            片道一括計算パラメータ
     * @param locs
     *            計算をする地点
     * @return 結果を格納したCalcOneWay3Response
     */
    public static CalcOneWay3Response calcOneWay3(boolean useSsl,
            Environ environ, COW3Param param, ArrayList<Loc> locs) {
        Logger.writeDebugLog("calcOneWay3", "start");
        String methodName = ActionName.CALC_ONE_WAY3;
        String soapAction = Namespace.DCWS + "/" + methodName;
        CalcOneWay3Response result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.COW3_PARAM);
            xmlSerializer.startTag("", Tag.LOCS);
            for (Loc loc : locs) {
                loc.writeXml(xmlSerializer, Tag.LOC);
            }
            xmlSerializer.endTag("", Tag.LOCS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("calcOneWay3", "connect");
                connection.connect();
                result = new CalcOneWay3Response();
                Logger.writeDebugLog("calcOneWay3", "convert response");
                ServiceUtils.getResponse(result, Tag.CALC_ONEWAY3_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CalcOneWay3Response();
            result.setException(e);
        }
        Logger.writeDebugLog("calcOneWay3", "end");
        return result;
    }

    /**
     * 最短ルート計算を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            ルート計算パラメータ
     * @param locs
     *            ルート計算をする地点
     * @return 結果を格納したCalcOptRouteResponse
     */
    public static CalcOptRouteResponse calcOptRoute(boolean useSsl,
            Environ environ, CRParam param, ArrayList<Loc> locs) {
        Logger.writeDebugLog("calcOptRoute", "start");
        String methodName = ActionName.CALC_OPT_ROUTE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        CalcOptRouteResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.CR_PARAM);
            xmlSerializer.startTag("", Tag.LOCS);
            for (Loc loc : locs) {
                loc.writeXml(xmlSerializer, Tag.LOC);
            }
            xmlSerializer.endTag("", Tag.LOCS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("calcOptRoute", "connect");
                connection.connect();
                result = new CalcOptRouteResponse();
                Logger.writeDebugLog("calcOptRoute", "convert response");
                ServiceUtils.getResponse(result, Tag.CALC_OPT_ROUTE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CalcOptRouteResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("calcOptRoute", "end");
        return result;
    }

    /**
     * ルート計算を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            ルート計算パラメータ
     * @param locs
     *            ルート計算をする地点
     * @return 結果を格納したCalcRouteResponse
     */
    public static CalcRouteResponse calcRoute(boolean useSsl, Environ environ,
            CRParam param, ArrayList<Loc> locs) {
        Logger.writeDebugLog("calcRoute", "start");
        String methodName = ActionName.CALC_ROUTE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        CalcRouteResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.CR_PARAM);
            xmlSerializer.startTag("", Tag.LOCS);
            for (Loc loc : locs) {
                loc.writeXml(xmlSerializer, Tag.LOC);
            }
            xmlSerializer.endTag("", Tag.LOCS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("calcRoute", "connect");
                connection.connect();
                result = new CalcRouteResponse();
                Logger.writeDebugLog("calcRoute", "convert response");
                ServiceUtils.getResponse(result, Tag.CALC_ROUTE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CalcRouteResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("calcRoute", "end");
        return result;
    }

    /**
     * 直線距離計算を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            直線距離計算パラメータ
     * @param locs
     *            直線距離計算をする地点
     * @return 結果を格納したCalcStraightLineResponse
     */
    public static CalcStraightLineResponse calcStraightLine(boolean useSsl,
            Environ environ, CSLParam param, ArrayList<Loc> locs) {
        Logger.writeDebugLog("calcStrightLine", "start");
        String methodName = ActionName.CALC_STRAIGHT_LINE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        CalcStraightLineResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.CSL_PARAM);
            xmlSerializer.startTag("", Tag.LOCS);
            for (Loc loc : locs) {
                loc.writeXml(xmlSerializer, Tag.LOC);
            }
            xmlSerializer.endTag("", Tag.LOCS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("calcStrightLine", "connect");
                connection.connect();
                result = new CalcStraightLineResponse();
                Logger.writeDebugLog("calcStrightLine", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.CALC_STRAIGHT_LINE_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CalcStraightLineResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("calcStrightLine", "end");
        return result;
    }

    /**
     * 近傍ノード列挙を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            近傍ノード列挙パラメータ
     * @return 結果を格納したEnumNearNodeResponse
     */
    public static EnumNearNodeResponse enumNearNode(boolean useSsl,
            Environ environ, ENNParam param) {
        Logger.writeDebugLog("enumNearNode", "start");
        String methodName = ActionName.ENUM_NEAR_NODE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        EnumNearNodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.ENN_PARAM);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("enumNearNode", "connect");
                connection.connect();
                result = new EnumNearNodeResponse();
                Logger.writeDebugLog("enumNearNode", "convert response");
                ServiceUtils.getResponse(result, Tag.ENUM_NEAR_NODE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new EnumNearNodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("enumNearNode", "end");
        return result;
    }

    /**
     * 距離計算サービスのエラーメッセージを取得します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param code
     *            エラーコード
     * @return 結果を格納したGetDcwsMessageResponse
     */
    public static GetDcwsMessageResponse getDCWSMessage(boolean useSsl,
            Environ environ, int code) {
        Logger.writeDebugLog("getDCWSMessage", "start");
        String methodName = ActionName.GET_DCWS_MESSAGE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        GetDcwsMessageResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            xmlSerializer.startTag("", Tag.MSG_NUMBER);
            xmlSerializer.text(Integer.toString(code));
            xmlSerializer.endTag("", Tag.MSG_NUMBER);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getDCWSMessage", "connect");
                connection.connect();
                result = new GetDcwsMessageResponse();
                Logger.writeDebugLog("getDCWSMessage", "convert response");
                ServiceUtils.getResponse(result, Tag.GET_DCWS_MESSAGE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetDcwsMessageResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getDCWSMessage", "end");
        return result;
    }

    /**
     * 最寄道路（リンク）取得2を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            最寄道路（リンク）取パラメータ
     * @return 結果を格納したGetNearestLink2Response
     */
    public static GetNearestLink2Response getNearestLink2(boolean useSsl,
            Environ environ, GNLParam param) {
        Logger.writeDebugLog("getNearestLink2", "start");
        String methodName = ActionName.GET_NEAREST_LINK2;
        String soapAction = Namespace.DCWS + "/" + methodName;
        GetNearestLink2Response result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENV);
            param.writeXml(xmlSerializer, Tag.GNL_PARAM);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getNearestLink2", "connect");
                connection.connect();
                result = new GetNearestLink2Response();
                Logger.writeDebugLog("getNearestLink2", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_NEAREST_LINK2_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetNearestLink2Response();
            result.setException(e);
        }
        Logger.writeDebugLog("getNearestLink2", "end");
        return result;
    }

    /**
     * 最寄ノード取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            片道一括計算パラメータ
     * @param locs
     *            計算をする地点
     * @return 結果を格納したGetNearestNodeResponse
     */
    public static GetNearestNodeResponse getNearestNode(boolean useSsl,
            Environ environ, GNNParam param, ArrayList<Loc> locs) {
        Logger.writeDebugLog("getNearestNode", "start");
        String methodName = ActionName.GET_NEAREST_NODE;
        String soapAction = Namespace.DCWS + "/" + methodName;
        GetNearestNodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.GNN_PARAM);
            xmlSerializer.startTag("", Tag.LOCS);
            for (Loc loc : locs) {
                loc.writeXml(xmlSerializer, Tag.LOC);
            }
            xmlSerializer.endTag("", Tag.LOCS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getNearestNode", "connect");
                connection.connect();
                result = new GetNearestNodeResponse();
                Logger.writeDebugLog("getNearestNode", "convert response");
                ServiceUtils.getResponse(result, Tag.GET_NEAREST_NODE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetNearestNodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getNearestNode", "end");
        return result;
    }

    /**
     * 計算用道路データ情報取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @return 結果を格納したGetNetworkInfoResponse
     */
    public static GetNetworkInfoResponse getNetworkInfo(boolean useSsl,
            Environ environ) {
        Logger.writeDebugLog("getNetworkInfo", "start");
        String methodName = ActionName.GET_NETWORK_INFO;
        String soapAction = Namespace.DCWS + "/" + methodName;
        GetNetworkInfoResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getNetworkInfo", "connect");
                connection.connect();
                result = new GetNetworkInfoResponse();
                Logger.writeDebugLog("getNetworkInfo", "convert response");
                ServiceUtils.getResponse(result, Tag.GET_NETWORK_INFO_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetNetworkInfoResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getNetworkInfo", "end");
        return result;
    }

    /**
     * 道路速度取得2を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            片道一括計算パラメータ
     * @return 結果を格納したGetSpeed2Response
     */
    public static GetSpeed2Response getSpeed2(boolean useSsl, Environ environ,
            GSParam param) {
        Logger.writeDebugLog("getSpeed2", "start");
        String methodName = ActionName.GET_SPEED2;
        String soapAction = Namespace.DCWS + "/" + methodName;
        GetSpeed2Response result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.GS_PARAM);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getSpeed2", "connect");
                connection.connect();
                result = new GetSpeed2Response();
                Logger.writeDebugLog("getSpeed2", "convert response");
                ServiceUtils.getResponse(result, Tag.GET_SPEED2_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetSpeed2Response();
            result.setException(e);
        }
        Logger.writeDebugLog("getSpeed2", "end");
        return result;
    }

    /**
     * 道路速度設定2を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            片道一括計算パラメータ
     * @return 結果を格納したSetSpeed2Response
     */
    public static SetSpeed2Response setSpeed2(boolean useSsl, Environ environ,
            SSParam param) {
        Logger.writeDebugLog("setSpeed2", "start");
        String methodName = ActionName.SET_SPEED2;
        String soapAction = Namespace.DCWS + "/" + methodName;
        SetSpeed2Response result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.DCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENV);
            param.writeXml(xmlSerializer, Tag.SS_PARAM);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("setSpeed2", "connect");
                connection.connect();
                result = new SetSpeed2Response();
                Logger.writeDebugLog("setSpeed2", "convert response");
                ServiceUtils.getResponse(result, Tag.SET_SPEED2_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new SetSpeed2Response();
            result.setException(e);
        }
        Logger.writeDebugLog("setSpeed2", "end");
        return result;
    }
}
