﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import android.content.Context;
import jp.co.act_inc.actservicesample.R;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaDirection;
import jp.co.act_inc.actservicesample.adminservice.Constants.AreaKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.CalcKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.NwidClassA;
import jp.co.act_inc.actservicesample.adminservice.Constants.PolygonKind;
import jp.co.act_inc.actservicesample.adminservice.Constants.RouteKind;

/**
 * 距離計算サービス用ユーティリティです。
 * 
 * @author ishi
 * 
 */
public class DistUtils {

    /**
     * AreaDirectionの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param areaDirction
     *            範囲方向
     * @return AreaDirectionの文字列
     */
    public static String getAreaDirectionString(Context context,
            int areaDirction) {
        String[] areaDirectionEntries = context.getResources().getStringArray(
                R.array.area_direction_entries);
        String areaDirectionString = areaDirction == AreaDirection.OUTFLOW ? areaDirectionEntries[0]
                : areaDirectionEntries[1];
        return areaDirectionString;
    }

    /**
     * AreaKindの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param areaKind
     *            到達圏／流入圏計算種別
     * @return AreaKindの文字列
     */
    public static String getAreaKindString(Context context, int areaKind) {
        String[] areaKindEntries = context.getResources().getStringArray(
                R.array.area_kind_entries);
        String areaKindString = areaKind == AreaKind.TIME ? areaKindEntries[0]
                : areaKindEntries[1];
        return areaKindString;
    }

    /**
     * AreaRangeの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param areaRange
     *            到達圏／流入圏範囲
     * @param areaKind
     *            到達圏／流入圏計算種別
     * @return AreaRangeの文字列
     */
    public static String getAreaRangeString(Context context, int areaRange,
            int areaKind) {
        String areaRangeString = areaKind == AreaKind.TIME ? Integer
                .toString(areaRange) + context.getString(R.string.unit_minute)
                : Integer.toString(areaRange)
                        + context.getString(R.string.unit_km);
        return areaRangeString;
    }

    /**
     * CalcKindの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param calcKind
     *            計算方法
     * @return CalcKindの文字列
     */
    public static String getCalcKindString(Context context, int calcKind) {
        String[] calcKindEntries = context.getResources().getStringArray(
                R.array.calc_kind_entries);
        String calcKindString = calcKind == CalcKind.TIME ? calcKindEntries[0]
                : calcKindEntries[1];
        return calcKindString;
    }

    /**
     * DonutPolygonLevelの文字列を取得します。
     * 
     * @param donutPolygonLevel
     *            ドーナツポリゴンレベル
     * @return DonutPolygonLevelの文字列
     */
    public static String getDonutPolygonLevelString(int donutPolygonLevel) {
        return Integer.toString(donutPolygonLevel);
    }

    /**
     * PolygonDetailの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param polygonDetail
     *            ポリゴン詳細
     * @return PolygonDetailの文字列
     */
    public static String getPolygonDetailString(Context context,
            int polygonDetail) {
        String[] polygonDetailEntries = context.getResources().getStringArray(
                R.array.polygon_detail_entries);
        String polygonDetailString = polygonDetailEntries[polygonDetail];
        return polygonDetailString;
    }

    /**
     * PolygonKindの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param polygonKind
     *            ポリゴン種別
     * @return PolygonKindの文字列
     */
    public static String getPolygonKindString(Context context, int polygonKind) {
        String[] polygonKindEntries = context.getResources().getStringArray(
                R.array.polygon_kind_entries);
        String polygonKindString = polygonKind == PolygonKind.SIMPLE_POLYGON ? polygonKindEntries[0]
                : polygonKindEntries[1];
        return polygonKindString;
    }

    /**
     * PolygonLevelの文字列を取得します。
     * 
     * @param polygonLevel
     *            ポリゴンレベル
     * @return PolygonLevelの文字列
     */
    public static String getPolygonLevelString(int polygonLevel) {
        return Integer.toString(polygonLevel);
    }

    /**
     * RouteKindの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param routeKind
     *            ルート種別
     * @return RouteKindの文字列
     */
    public static String getRouteKindString(Context context, int routeKind) {
        String[] routeKindEntries = context.getResources().getStringArray(
                R.array.route_kind_entries);
        String routeKindString = routeKind == RouteKind.SIMPLE ? routeKindEntries[0]
                : routeKindEntries[1];
        return routeKindString;
    }

    /**
     * UseAirwayの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useAirway
     *            航空機使用フラグ
     * @return UseAirwayの文字列
     */
    public static String getUseAirwayString(Context context, int useAirway) {
        String useAirwayString = useAirway == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useAirwayString;
    }

    /**
     * UseFerryの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useFerry
     *            フェリー使用フラグ
     * @return UseFerryの文字列
     */
    public static String getUseFerryString(Context context, int useFerry) {
        String useFerryString = useFerry == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useFerryString;
    }

    /**
     * UseFreightRailwayの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useFreightRailway
     *            貨物鉄道使用フラグ
     * @return UseFreightRailwayの文字列
     */
    public static String getUseFreightRailwayString(Context context,
            int useFreightRailway) {
        String useFreightRailwayString = useFreightRailway == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useFreightRailwayString;
    }

    /**
     * UseHighwayの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useHighway
     *            高速道路使用フラグ
     * @return UseHighwayの文字列
     */
    public static String getUseHighwayString(Context context, int useHighway) {
        String useHighwayString = useHighway == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useHighwayString;
    }

    /**
     * UseLimitedExpressの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useLimitedExpress
     *            特急使用フラグ
     * @return UseLimitedExpressの文字列
     */
    public static String getUseLimitedExpressString(Context context,
            int useLimitedExpress) {
        String useLimitedExpressString = useLimitedExpress == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useLimitedExpressString;
    }

    /**
     * UsePayRoadFerryの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param usePayRoadFerry
     *            北海道～青森、沖縄～鹿児島のみフェリー使用フラグ
     * @return UsePayRoadFerryの文字列
     */
    public static String getUsePayRoadFerryString(Context context,
            int usePayRoadFerry) {
        String usePayRoadFerryString = usePayRoadFerry == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return usePayRoadFerryString;
    }

    /**
     * UseRailwayの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useRailway
     *            鉄道使用フラグ
     * @return UseRailwayの文字列
     */
    public static String getUseRailwayString(Context context, int useRailway) {
        String useRailwayString = useRailway == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useRailwayString;
    }

    /**
     * UseShipの文字列を取得します。
     * 
     * @param context
     *            コンテキスト
     * @param useShip
     *            内航船使用フラグ
     * @return UseShipの文字列
     */
    public static String getUseShipString(Context context, int useShip) {
        String useShipString = useShip == 1 ? context
                .getString(R.string.common_use) : context
                .getString(R.string.common_not_use);
        return useShipString;
    }

    /**
     * 計算用道路データネットワークIDから航空機に対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForAirway(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.AIRWAY) != 0;
    }

    /**
     * 計算用道路データネットワークIDから自動車に対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForCar(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.CAR) != 0;
    }

    /**
     * 計算用道路データネットワークIDからフェリーに対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForFerry(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.FERRY) != 0;
    }

    /**
     * 計算用道路データネットワークIDから貨物鉄道に対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForFreightRailway(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.RAILROAD_FREIGHT) != 0;
    }

    /**
     * 計算用道路データネットワークIDから旅客鉄道に対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForRailway(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.RAILWAY) != 0;
    }

    /**
     * 計算用道路データネットワークIDから内航船に対応しているか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForShip(String nwid) {
        int flag = Integer.parseInt(nwid.substring(5, 8), 16);
        return (flag & NwidClassA.SHIP) != 0;
    }

    /**
     * 計算用道路ネットワークが歩行者向けか判定します。
     * 
     * @param nwid
     *            計算用道路データネットワークID
     * @return 対応している場合true
     */
    public static boolean isForWalker(String nwid) {
        int flag = Integer.parseInt(nwid.substring(2, 3), 16);
        return flag == 0xf;
    }

}
