/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 近傍ノード列挙の結果です。 EnumNearNodeの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class EnumNearNodeResponse implements Response {
    private static final String ENUM_NEAR_NODE_RESULT = "EnumNearNodeResult";
    private static final String LOC = "Loc";
    private static final String LOCS = "Locs";
    private static final String NW_INFO = "NWInfo";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 地点リスト
     */
    private ArrayList<Loc> locs;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算パラメータ
     */
    private ENNParam param;

    /**
     * コンストラクター
     * 
     */
    public EnumNearNodeResponse() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return locs
     */
    public ArrayList<Loc> getLocs() {
        return this.locs;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return param
     */
    public ENNParam getParam() {
        return this.param;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inLocs = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inLocs) {
                    if (startTagName.equalsIgnoreCase(LOC)) {
                        Loc loc = new Loc();
                        loc.readXml(parser, LOC);
                        locs.add(loc);
                    }
                } else {
                    if (startTagName.equalsIgnoreCase(ENUM_NEAR_NODE_RESULT)) {
                        resultCode = Integer.parseInt(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(LOCS)) {
                        inLocs = true;
                        locs = new ArrayList<Loc>();
                    } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                        nwInfo = new NWInfo();
                        getNwInfo().readXml(parser, NW_INFO);
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(LOCS)) {
                    inLocs = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param locs
     *            セットする locs
     */
    public void setLocs(ArrayList<Loc> locs) {
        this.locs = locs;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(ENNParam param) {
        this.param = param;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }
}
