/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 道路速度取得パラメータです。
 * 
 * @author ishi
 * 
 */
public class GSParam {
    private static final String GS_PARAM = "GSParam";
    private static final String COORDINATE_FORMAT = "CoordinateFormat";
    private static final String DATUM = "Datum";
    private static final String LINK_CODE = "LinkCode";
    private static final String SPEED_FLAG = "SpeedFlag";

    /**
     * 経緯度の座標系識別子
     */
    private int datum;
    /**
     * 経緯度の座標フォーマット識別子
     */
    private int coordinateFormat;
    /**
     * リンクコード
     */
    private String linkCode;
    /**
     * 速度フラグ
     */
    private int speedFlag;

    /**
     * コンストラクター
     * 
     */
    public GSParam() {
    }

    /**
     * @return coordinateFormat
     */
    public int getCoordinateFormat() {
        return this.coordinateFormat;
    }

    /**
     * @return datum
     */
    public int getDatum() {
        return this.datum;
    }

    /**
     * @return linkCode
     */
    public String getLinkCode() {
        return this.linkCode;
    }

    /**
     * @return speedFlag
     */
    public int getSpeedFlag() {
        return this.speedFlag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(DATUM)) {
                    String value = parser.nextText();
                    datum = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(COORDINATE_FORMAT)) {
                    String value = parser.nextText();
                    coordinateFormat = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(LINK_CODE)) {
                    String value = parser.nextText();
                    linkCode = value;
                } else if (startTagName.equalsIgnoreCase(SPEED_FLAG)) {
                    String value = parser.nextText();
                    speedFlag = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param coordinateFormat
     *            セットする coordinateFormat
     */
    public void setCoordinateFormat(int coordinateFormat) {
        this.coordinateFormat = coordinateFormat;
    }

    /**
     * @param datum
     *            セットする datum
     */
    public void setDatum(int datum) {
        this.datum = datum;
    }

    /**
     * @param linkCode
     *            セットする linkCode
     */
    public void setLinkCode(String linkCode) {
        this.linkCode = linkCode;
    }

    /**
     * @param speedFlag
     *            セットする speedFlag
     */
    public void setSpeedFlag(int speedFlag) {
        this.speedFlag = speedFlag;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = GS_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", DATUM);
        xmlSerializer.text(Integer.toString(datum));
        xmlSerializer.endTag("", DATUM);
        xmlSerializer.startTag("", COORDINATE_FORMAT);
        xmlSerializer.text(Integer.toString(coordinateFormat));
        xmlSerializer.endTag("", COORDINATE_FORMAT);
        xmlSerializer.startTag("", LINK_CODE);
        xmlSerializer.text(linkCode);
        xmlSerializer.endTag("", LINK_CODE);
        xmlSerializer.startTag("", SPEED_FLAG);
        xmlSerializer.text(Integer.toString(speedFlag));
        xmlSerializer.endTag("", SPEED_FLAG);
        xmlSerializer.endTag("", tag);
    }
}
