/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 計算用道路データ情報取得の結果です。 GetNetworkInfoの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class GetNetworkInfoResponse implements Response {
    private static final String GET_NETWORK_INFO_RESULT = "GetNetworkInfoResult";
    private static final String NW_INFO = "NWInfo";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;

    /**
     * コンストラクター
     * 
     */
    public GetNetworkInfoResponse() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(GET_NETWORK_INFO_RESULT)) {
                    resultCode = Integer.parseInt(parser.nextText());
                } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                    nwInfo = new NWInfo();
                    getNwInfo().readXml(parser, NW_INFO);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }
}
