/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 道路速度取得2の結果です。 GetSpeed2の結果を格納します。
 * 
 * @author ishi
 * 
 */
public class GetSpeed2Response implements Response {
    private static final String GET_SPEED2_RESULT = "GetSpeed2Result";
    private static final String SPEED_AB = "SpeedAB";
    private static final String SPEED_BA = "SpeedBA";
    private static final String NODE_A = "NodeA";
    private static final String NODE_B = "NodeB";
    private static final String NW_INFO = "NWInfo";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 順方向の速度
     */
    private int speedAB;
    /**
     * 逆方向の速度
     */
    private int speedBA;
    /**
     * ノードA
     */
    private NodePnt nodeA;
    /**
     * ノードB
     */
    private NodePnt nodeB;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算パラメータ
     */
    private GSParam param;

    /**
     * コンストラクター
     * 
     */
    public GetSpeed2Response() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return nodeA
     */
    public NodePnt getNodeA() {
        return this.nodeA;
    }

    /**
     * @return nodeB
     */
    public NodePnt getNodeB() {
        return this.nodeB;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return param
     */
    public GSParam getParam() {
        return this.param;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    /**
     * @return speedAB
     */
    public int getSpeedAB() {
        return this.speedAB;
    }

    /**
     * @return speedBA
     */
    public int getSpeedBA() {
        return this.speedBA;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(GET_SPEED2_RESULT)) {
                    resultCode = Integer.parseInt(parser.nextText());
                } else if (startTagName.equalsIgnoreCase(SPEED_AB)) {
                    String value = parser.nextText();
                    speedAB = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(SPEED_BA)) {
                    String value = parser.nextText();
                    speedBA = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(NODE_A)) {
                    nodeA = new NodePnt();
                    getNodeA().readXml(parser, NODE_A);
                } else if (startTagName.equalsIgnoreCase(NODE_B)) {
                    nodeB = new NodePnt();
                    getNodeB().readXml(parser, NODE_B);
                } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                    nwInfo = new NWInfo();
                    getNwInfo().readXml(parser, NW_INFO);
                }

                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param nodeA
     *            セットする nodeA
     */
    public void setNodeA(NodePnt nodeA) {
        this.nodeA = nodeA;
    }

    /**
     * @param nodeB
     *            セットする nodeB
     */
    public void setNodeB(NodePnt nodeB) {
        this.nodeB = nodeB;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(GSParam param) {
        this.param = param;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }

    /**
     * @param speedAB
     *            セットする speedAB
     */
    public void setSpeedAB(int speedAB) {
        this.speedAB = speedAB;
    }

    /**
     * @param speedBA
     *            セットする speedBA
     */
    public void setSpeedBA(int speedBA) {
        this.speedBA = speedBA;
    }
}
