﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 地点情報を格納します。
 * 
 * @author ishi
 * 
 */
public class Loc {
    private static final String DIST = "Dist";
    private static final String DSEC = "DSec";
    private static final String HIGHWAY_D_SEC = "HighwayDSec";
    private static final String HIGHWAY_DIST = "HighwayDist";
    private static final String HIGHWAY_TIME = "HighwayTime";
    private static final String LAT = "Lat";
    private static final String LOC = "Loc";
    private static final String LON = "Lon";
    private static final String NODE = "Node";
    private static final String TAG = "Tag";
    private static final String TIME = "Time";
    private static final String TOLL_L = "Toll_L";
    private static final String TOLL_LL = "Toll_LL";
    private static final String TOLL_M = "Toll_M";
    private static final String TOLL_S = "Toll_S";
    private static final String TOLL_SS = "Toll_SS";

    /**
     * ノードコード
     */
    private String node;
    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;
    /**
     * 所要時間（分単位）
     */
    private int time;
    /**
     * 所要時間（0.1 秒単位）
     */
    private int dSec;
    /**
     * 道のり（m 単位）
     */
    private int dist;
    /**
     * 高速道路区間の所要時間（分単位）
     */
    private int highwayTime;
    /**
     * 高速道路区間の所要時間（0.1 秒単位）
     */
    private int highwayDSec;
    /**
     * 高速道路区間の道のり（m 単位）
     */
    private int highwayDist;
    /**
     * 二輪・軽の通行料金（円単位）
     */
    private int toll_SS;
    /**
     * 普通車の通行料金（円単位）
     */
    private int toll_S;
    /**
     * 中型車の通行料金（円単位）
     */
    private int toll_M;
    /**
     * 大型車の通行料金（円単位）
     */
    private int toll_L;
    /**
     * 特大車の通行料金（円単位）
     */
    private int toll_LL;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * @return dist
     */
    public int getDist() {
        return this.dist;
    }

    /**
     * @return dSec
     */
    public int getDSec() {
        return this.dSec;
    }

    /**
     * @return highwayDist
     */
    public int getHighwayDist() {
        return this.highwayDist;
    }

    /**
     * @return highwayDSec
     */
    public int getHighwayDSec() {
        return this.highwayDSec;
    }

    /**
     * @return highwayTime
     */
    public int getHighwayTime() {
        return this.highwayTime;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return node
     */
    public String getNode() {
        return this.node;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * @return time
     */
    public int getTime() {
        return this.time;
    }

    /**
     * @return toll_L
     */
    public int getToll_L() {
        return this.toll_L;
    }

    /**
     * @return toll_LL
     */
    public int getToll_LL() {
        return this.toll_LL;
    }

    /**
     * @return toll_M
     */
    public int getToll_M() {
        return this.toll_M;
    }

    /**
     * @return toll_S
     */
    public int getToll_S() {
        return this.toll_S;
    }

    /**
     * @return toll_SS
     */
    public int getToll_SS() {
        return this.toll_SS;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(NODE)) {
                    String value = parser.nextText();
                    node = value;
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(TIME)) {
                    String value = parser.nextText();
                    time = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DSEC)) {
                    String value = parser.nextText();
                    dSec = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DIST)) {
                    String value = parser.nextText();
                    dist = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(HIGHWAY_TIME)) {
                    String value = parser.nextText();
                    highwayTime = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(HIGHWAY_D_SEC)) {
                    String value = parser.nextText();
                    highwayDSec = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(HIGHWAY_DIST)) {
                    String value = parser.nextText();
                    highwayDist = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_SS)) {
                    String value = parser.nextText();
                    toll_SS = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_S)) {
                    String value = parser.nextText();
                    toll_S = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_M)) {
                    String value = parser.nextText();
                    toll_M = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_L)) {
                    String value = parser.nextText();
                    toll_L = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_LL)) {
                    String value = parser.nextText();
                    toll_LL = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    this.tag = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param dist
     *            セットする dist
     */
    public void setDist(int dist) {
        this.dist = dist;
    }

    /**
     * @param dSec
     *            セットする dSec
     */
    public void setDSec(int dSec) {
        this.dSec = dSec;
    }

    /**
     * @param highwayDist
     *            セットする highwayDist
     */
    public void setHighwayDist(int highwayDist) {
        this.highwayDist = highwayDist;
    }

    /**
     * @param highwayDSec
     *            セットする highwayDSec
     */
    public void setHighwayDSec(int highwayDSec) {
        this.highwayDSec = highwayDSec;
    }

    /**
     * @param highwayTime
     *            セットする highwayTime
     */
    public void setHighwayTime(int highwayTime) {
        this.highwayTime = highwayTime;
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(double lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(double lon) {
        this.lon = lon;
    }

    /**
     * @param node
     *            セットする node
     */
    public void setNode(String node) {
        this.node = node;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    /**
     * @param time
     *            セットする time
     */
    public void setTime(int time) {
        this.time = time;
    }

    /**
     * @param toll_L
     *            セットする toll_L
     */
    public void setToll_L(int toll_L) {
        this.toll_L = toll_L;
    }

    /**
     * @param toll_LL
     *            セットする toll_LL
     */
    public void setToll_LL(int toll_LL) {
        this.toll_LL = toll_LL;
    }

    /**
     * @param toll_M
     *            セットする toll_M
     */
    public void setToll_M(int toll_M) {
        this.toll_M = toll_M;
    }

    /**
     * @param toll_S
     *            セットする toll_S
     */
    public void setToll_S(int toll_S) {
        this.toll_S = toll_S;
    }

    /**
     * @param toll_SS
     *            セットする toll_SS
     */
    public void setToll_SS(int toll_SS) {
        this.toll_SS = toll_SS;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = LOC;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", NODE);
        if (node != null) {
            xmlSerializer.text(node);
        }
        xmlSerializer.endTag("", NODE);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.startTag("", TIME);
        xmlSerializer.text(Integer.toString(time));
        xmlSerializer.endTag("", TIME);
        xmlSerializer.startTag("", DSEC);
        xmlSerializer.text(Integer.toString(dSec));
        xmlSerializer.endTag("", DSEC);
        xmlSerializer.startTag("", DIST);
        xmlSerializer.text(Integer.toString(dist));
        xmlSerializer.endTag("", DIST);
        xmlSerializer.startTag("", HIGHWAY_TIME);
        xmlSerializer.text(Integer.toString(highwayTime));
        xmlSerializer.endTag("", HIGHWAY_TIME);
        xmlSerializer.startTag("", HIGHWAY_D_SEC);
        xmlSerializer.text(Integer.toString(highwayDSec));
        xmlSerializer.endTag("", HIGHWAY_D_SEC);
        xmlSerializer.startTag("", HIGHWAY_DIST);
        xmlSerializer.text(Integer.toString(highwayDist));
        xmlSerializer.endTag("", HIGHWAY_DIST);
        xmlSerializer.startTag("", TOLL_SS);
        xmlSerializer.text(Integer.toString(toll_SS));
        xmlSerializer.endTag("", TOLL_SS);
        xmlSerializer.startTag("", TOLL_S);
        xmlSerializer.text(Integer.toString(toll_S));
        xmlSerializer.endTag("", TOLL_S);
        xmlSerializer.startTag("", TOLL_M);
        xmlSerializer.text(Integer.toString(toll_M));
        xmlSerializer.endTag("", TOLL_M);
        xmlSerializer.startTag("", TOLL_L);
        xmlSerializer.text(Integer.toString(toll_L));
        xmlSerializer.endTag("", TOLL_L);
        xmlSerializer.startTag("", TOLL_LL);
        xmlSerializer.text(Integer.toString(toll_LL));
        xmlSerializer.endTag("", TOLL_LL);
        xmlSerializer.startTag("", TAG);
        if (this.tag != null) {
            xmlSerializer.text(this.tag);
        }
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
