﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * ノード付きポイントです。
 * 
 * @author ishi
 * 
 */
public class NodePnt {
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String NODE = "Node";
    private static final String NODE_PNT = "NodePnt";

    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;
    /**
     * ノードコード
     */
    private String node;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ
     * 
     */
    public NodePnt() {
    }

    /**
     * コンストラクタ
     * 
     * @param lon
     *            経度
     * @param lat
     *            緯度
     * @param node
     *            ノードコード
     */
    public NodePnt(double lon, double lat, String node) {
        this.lon = lon;
        this.lat = lat;
        this.node = node;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return node
     */
    public String getNode() {
        return this.node;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(NODE)) {
                    String value = parser.nextText();
                    node = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(double lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(double lon) {
        this.lon = lon;
    }

    /**
     * @param node
     *            セットする node
     */
    public void setNode(String node) {
        this.node = node;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = NODE_PNT;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.startTag("", NODE);
        if (node != null) {
            xmlSerializer.text(node);
        }
        xmlSerializer.endTag("", NODE);
        xmlSerializer.endTag("", tag);
    }
}
