﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * ポイントです。
 * 
 * @author ishi
 * 
 */
public class Pnt {
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String PNT = "Pnt";

    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(double lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(double lon) {
        this.lon = lon;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = PNT;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.endTag("", tag);
    }
}
