﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 経由道路名です。
 * 
 * @author ishi
 * 
 */
public class Rn {
    private static final String DIST = "Dist";
    private static final String DSEC = "DSec";
    private static final String IC_TYPE = "ICType";
    private static final String LAT = "Lat";
    private static final String LINK_FLAG = "LinkFlag";
    private static final String LOC_FLAG = "LocFlag";
    private static final String LON = "Lon";
    private static final String NAME = "Name";
    private static final String NL_CODE = "NLCode";
    private static final String RN = "Rn";
    private static final String TIME = "Time";
    private static final String TOLL_L = "Toll_L";
    private static final String TOLL_LL = "Toll_LL";
    private static final String TOLL_M = "Toll_M";
    private static final String TOLL_S = "Toll_S";
    private static final String TOLL_SS = "Toll_SS";

    /**
     * ロケーションフラグ
     */
    private int locFlag;
    /**
     * リンクフラグ
     */
    private int linkFlag;
    /**
     * ノードリンク番号
     */
    private String nlCode;
    /**
     * 名称
     */
    private String name;
    /**
     * 所要時間（分単位）
     */
    private int time;
    /**
     * 所要時間（1/10秒単位）
     */
    private int dSec;
    /**
     * 道のり（m単位）
     */
    private int dist;
    /**
     * インターチェンジタイプ
     */
    private int icType;
    /**
     * 二輪・軽の通行料金（円単位）
     */
    private int toll_SS;
    /**
     * 普通車の通行料金（円単位）
     */
    private int toll_S;
    /**
     * 中型車の通行料金（円単位）
     */
    private int toll_M;
    /**
     * 大型車の通行料金（円単位）
     */
    private int toll_L;
    /**
     * 特大車の通行料金（円単位）
     */
    private int toll_LL;
    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;

    /**
     * @return dist
     */
    public int getDist() {
        return this.dist;
    }

    /**
     * @return dSec
     */
    public int getDSec() {
        return this.dSec;
    }

    /**
     * @return icType
     */
    public int getIcType() {
        return this.icType;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return linkFlag
     */
    public int getLinkFlag() {
        return this.linkFlag;
    }

    /**
     * @return locFlag
     */
    public int getLocFlag() {
        return this.locFlag;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return name
     */
    public String getName() {
        return this.name;
    }

    /**
     * @return nlCode
     */
    public String getNlCode() {
        return this.nlCode;
    }

    /**
     * @return time
     */
    public int getTime() {
        return this.time;
    }

    /**
     * @return toll_L
     */
    public int getToll_L() {
        return this.toll_L;
    }

    /**
     * @return toll_LL
     */
    public int getToll_LL() {
        return this.toll_LL;
    }

    /**
     * @return toll_M
     */
    public int getToll_M() {
        return this.toll_M;
    }

    /**
     * @return toll_S
     */
    public int getToll_S() {
        return this.toll_S;
    }

    /**
     * @return toll_SS
     */
    public int getToll_SS() {
        return this.toll_SS;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(LOC_FLAG)) {
                    String value = parser.nextText();
                    locFlag = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(LINK_FLAG)) {
                    String value = parser.nextText();
                    linkFlag = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(NL_CODE)) {
                    String value = parser.nextText();
                    nlCode = value;
                } else if (startTagName.equalsIgnoreCase(NAME)) {
                    String value = parser.nextText();
                    name = value;
                } else if (startTagName.equalsIgnoreCase(TIME)) {
                    String value = parser.nextText();
                    time = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DSEC)) {
                    String value = parser.nextText();
                    dSec = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DIST)) {
                    String value = parser.nextText();
                    dist = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(IC_TYPE)) {
                    String value = parser.nextText();
                    icType = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_SS)) {
                    String value = parser.nextText();
                    toll_SS = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_S)) {
                    String value = parser.nextText();
                    toll_S = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_M)) {
                    String value = parser.nextText();
                    toll_M = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_L)) {
                    String value = parser.nextText();
                    toll_L = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_LL)) {
                    String value = parser.nextText();
                    toll_LL = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param dist
     *            セットする dist
     */
    public void setDist(int dist) {
        this.dist = dist;
    }

    /**
     * @param dSec
     *            セットする dSec
     */
    public void setDSec(int dSec) {
        this.dSec = dSec;
    }

    /**
     * @param icType
     *            セットする icType
     */
    public void setIcType(int icType) {
        this.icType = icType;
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(double lat) {
        this.lat = lat;
    }

    /**
     * @param linkFlag
     *            セットする linkFlag
     */
    public void setLinkFlag(int linkFlag) {
        this.linkFlag = linkFlag;
    }

    /**
     * @param locFlag
     *            セットする locFlag
     */
    public void setLocFlag(int locFlag) {
        this.locFlag = locFlag;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(double lon) {
        this.lon = lon;
    }

    /**
     * @param name
     *            セットする name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @param nlCode
     *            セットする nlCode
     */
    public void setNlCode(String nlCode) {
        this.nlCode = nlCode;
    }

    /**
     * @param time
     *            セットする time
     */
    public void setTime(int time) {
        this.time = time;
    }

    /**
     * @param toll_L
     *            セットする toll_L
     */
    public void setToll_L(int toll_L) {
        this.toll_L = toll_L;
    }

    /**
     * @param toll_LL
     *            セットする toll_LL
     */
    public void setToll_LL(int toll_LL) {
        this.toll_LL = toll_LL;
    }

    /**
     * @param toll_M
     *            セットする toll_M
     */
    public void setToll_M(int toll_M) {
        this.toll_M = toll_M;
    }

    /**
     * @param toll_S
     *            セットする toll_S
     */
    public void setToll_S(int toll_S) {
        this.toll_S = toll_S;
    }

    /**
     * @param toll_SS
     *            セットする toll_SS
     */
    public void setToll_SS(int toll_SS) {
        this.toll_SS = toll_SS;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = RN;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", LOC_FLAG);
        xmlSerializer.text(Integer.toString(locFlag));
        xmlSerializer.endTag("", LOC_FLAG);
        xmlSerializer.startTag("", LINK_FLAG);
        xmlSerializer.text(Integer.toString(linkFlag));
        xmlSerializer.endTag("", LINK_FLAG);
        xmlSerializer.startTag("", NL_CODE);
        if (nlCode != null) {
            xmlSerializer.text(nlCode);
        }
        xmlSerializer.endTag("", NL_CODE);
        xmlSerializer.startTag("", NAME);
        if (name != null) {
            xmlSerializer.text(name);
        }
        xmlSerializer.endTag("", NAME);
        xmlSerializer.startTag("", TIME);
        xmlSerializer.text(Integer.toString(time));
        xmlSerializer.endTag("", TIME);
        xmlSerializer.startTag("", DSEC);
        xmlSerializer.text(Integer.toString(dSec));
        xmlSerializer.endTag("", DSEC);
        xmlSerializer.startTag("", DIST);
        xmlSerializer.text(Integer.toString(dist));
        xmlSerializer.endTag("", DIST);
        xmlSerializer.startTag("", IC_TYPE);
        xmlSerializer.text(Integer.toString(icType));
        xmlSerializer.endTag("", IC_TYPE);
        xmlSerializer.startTag("", TOLL_SS);
        xmlSerializer.text(Integer.toString(toll_SS));
        xmlSerializer.endTag("", TOLL_SS);
        xmlSerializer.startTag("", TOLL_S);
        xmlSerializer.text(Integer.toString(toll_S));
        xmlSerializer.endTag("", TOLL_S);
        xmlSerializer.startTag("", TOLL_M);
        xmlSerializer.text(Integer.toString(toll_M));
        xmlSerializer.endTag("", TOLL_M);
        xmlSerializer.startTag("", TOLL_L);
        xmlSerializer.text(Integer.toString(toll_L));
        xmlSerializer.endTag("", TOLL_L);
        xmlSerializer.startTag("", TOLL_LL);
        xmlSerializer.text(Integer.toString(toll_LL));
        xmlSerializer.endTag("", TOLL_LL);
        xmlSerializer.endTag("", tag);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.endTag("", tag);
    }
}
