/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 道路速度設定パラメータです。
 * 
 * @author ishi
 * 
 */
public class SSParam {
    private static final String SS_PARAM = "SSParam";
    private static final String LINK_CODE = "LinkCode";
    private static final String SPEED_FLAG = "SpeedFlag";
    private static final String SPEED_AB = "SpeedAB";
    private static final String SPEED_BA = "SpeedBA";

    /**
     * リンクコード
     */
    private String linkCode;
    /**
     * 速度フラグ
     */
    private int speedFlag;
    /**
     * 順方向の速度
     */
    private int speedAB;
    /**
     * 逆方向の速度
     */
    private int speedBA;

    /**
     * コンストラクター
     * 
     */
    public SSParam() {
    }

    /**
     * @return linkCode
     */
    public String getLinkCode() {
        return this.linkCode;
    }

    /**
     * @return speedAB
     */
    public int getSpeedAB() {
        return this.speedAB;
    }

    /**
     * @return speedBA
     */
    public int getSpeedBA() {
        return this.speedBA;
    }

    /**
     * @return speedFlag
     */
    public int getSpeedFlag() {
        return this.speedFlag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(LINK_CODE)) {
                    String value = parser.nextText();
                    linkCode = value;
                } else if (startTagName.equalsIgnoreCase(SPEED_FLAG)) {
                    String value = parser.nextText();
                    speedFlag = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(SPEED_AB)) {
                    String value = parser.nextText();
                    speedAB = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(SPEED_BA)) {
                    String value = parser.nextText();
                    speedBA = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param linkCode
     *            セットする linkCode
     */
    public void setLinkCode(String linkCode) {
        this.linkCode = linkCode;
    }

    /**
     * @param speedAB
     *            セットする speedAB
     */
    public void setSpeedAB(int speedAB) {
        this.speedAB = speedAB;
    }

    /**
     * @param speedBA
     *            セットする speedBA
     */
    public void setSpeedBA(int speedBA) {
        this.speedBA = speedBA;
    }

    /**
     * @param speedFlag
     *            セットする speedFlag
     */
    public void setSpeedFlag(int speedFlag) {
        this.speedFlag = speedFlag;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = SS_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", LINK_CODE);
        xmlSerializer.text(linkCode);
        xmlSerializer.endTag("", LINK_CODE);
        xmlSerializer.startTag("", SPEED_FLAG);
        xmlSerializer.text(Integer.toString(speedFlag));
        xmlSerializer.endTag("", SPEED_FLAG);
        xmlSerializer.startTag("", SPEED_AB);
        xmlSerializer.text(Integer.toString(speedAB));
        xmlSerializer.endTag("", SPEED_AB);
        xmlSerializer.startTag("", SPEED_BA);
        xmlSerializer.text(Integer.toString(speedBA));
        xmlSerializer.endTag("", SPEED_BA);
        xmlSerializer.endTag("", tag);
    }
}
