/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import jp.co.act_inc.actservicesample.adminservice.NWInfo;
import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 道路速度設定2の結果です。SetSpeed2の結果を格納します。
 * 
 * @author ishi
 * 
 */
public class SetSpeed2Response implements Response {
    private static final String SET_SPEED2_RESULT = "SetSpeed2Result";
    private static final String OLD_SPEED_AB = "OldSpeedAB";
    private static final String OLD_SPEED_BA = "OldSpeedBA";
    private static final String NW_INFO = "NWInfo";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 変更前の順方向の速度
     */
    private int oldSpeedAB;
    /**
     * 変更前の逆方向の速度
     */
    private int oldSpeedBA;
    /**
     * 計算用道路データ情報
     */
    private NWInfo nwInfo;
    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算パラメータ
     */
    private SSParam param;

    /**
     * コンストラクター
     * 
     */
    public SetSpeed2Response() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return nwInfo
     */
    public NWInfo getNwInfo() {
        return this.nwInfo;
    }

    /**
     * @return oldSpeedAB
     */
    public int getOldSpeedAB() {
        return this.oldSpeedAB;
    }

    /**
     * @return oldSpeedBA
     */
    public int getOldSpeedBA() {
        return this.oldSpeedBA;
    }

    /**
     * @return param
     */
    public SSParam getParam() {
        return this.param;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SET_SPEED2_RESULT)) {
                    resultCode = Integer.parseInt(parser.nextText());
                } else if (startTagName.equalsIgnoreCase(OLD_SPEED_AB)) {
                    String value = parser.nextText();
                    oldSpeedAB = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(OLD_SPEED_BA)) {
                    String value = parser.nextText();
                    oldSpeedBA = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(NW_INFO)) {
                    nwInfo = new NWInfo();
                    getNwInfo().readXml(parser, NW_INFO);
                }

                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param nwInfo
     *            セットする nwInfo
     */
    public void setNwInfo(NWInfo nwInfo) {
        this.nwInfo = nwInfo;
    }

    /**
     * @param oldSpeedAB
     *            セットする oldSpeedAB
     */
    public void setOldSpeedAB(int oldSpeedAB) {
        this.oldSpeedAB = oldSpeedAB;
    }

    /**
     * @param oldSpeedBA
     *            セットする oldSpeedBA
     */
    public void setOldSpeedBA(int oldSpeedBA) {
        this.oldSpeedBA = oldSpeedBA;
    }

    /**
     * @param param
     *            セットする param
     */
    public void setParam(SSParam param) {
        this.param = param;
    }

    /**
     * @param resultCode
     *            セットする resultCode
     */
    public void setResultCode(int resultCode) {
        this.resultCode = resultCode;
    }
}
