﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.dcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 経由有料道路です。
 * 
 * @author ishi
 * 
 */
public class Trd {
    private static final String DIST = "Dist";
    private static final String IN_IC_NAME = "InICName";
    private static final String IN_RD_NAME = "InRdName";
    private static final String OUT_IC_NAME = "OutICName";
    private static final String OUT_RD_NAME = "OutRdName";
    private static final String TOLL_L = "Toll_L";
    private static final String TOLL_LL = "Toll_LL";
    private static final String TOLL_M = "Toll_M";
    private static final String TOLL_S = "Toll_S";
    private static final String TOLL_SS = "Toll_SS";
    private static final String TRD = "Trd";

    /**
     * 入口または課金の有料道路名称
     */
    private String inRdName;
    /**
     * 入口または課金の料金所名称
     */
    private String inICName;
    /**
     * 出口の有料道路名称
     */
    private String outRdName;
    /**
     * 出口の料金所名称
     */
    private String outICName;
    /**
     * 二輪・軽の通行料金（円単位）
     */
    private int toll_SS;
    /**
     * 普通車の通行料金（円単位）
     */
    private int toll_S;
    /**
     * 中型車の通行料金（円単位）
     */
    private int toll_M;
    /**
     * 大型車の通行料金（円単位）
     */
    private int toll_L;
    /**
     * 特大車の通行料金（円単位）
     */
    private int toll_LL;
    /**
     * 距離（km単位）
     */
    private int dist;

    /**
     * @return dist
     */
    public int getDist() {
        return this.dist;
    }

    /**
     * @return inICName
     */
    public String getInICName() {
        return this.inICName;
    }

    /**
     * @return inRdName
     */
    public String getInRdName() {
        return this.inRdName;
    }

    /**
     * @return outICName
     */
    public String getOutICName() {
        return this.outICName;
    }

    /**
     * @return outRdName
     */
    public String getOutRdName() {
        return this.outRdName;
    }

    /**
     * @return toll_L
     */
    public int getToll_L() {
        return this.toll_L;
    }

    /**
     * @return toll_LL
     */
    public int getToll_LL() {
        return this.toll_LL;
    }

    /**
     * @return toll_M
     */
    public int getToll_M() {
        return this.toll_M;
    }

    /**
     * @return toll_S
     */
    public int getToll_S() {
        return this.toll_S;
    }

    /**
     * @return toll_SS
     */
    public int getToll_SS() {
        return this.toll_SS;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(IN_RD_NAME)) {
                    String value = parser.nextText();
                    inRdName = value;
                } else if (startTagName.equalsIgnoreCase(IN_IC_NAME)) {
                    String value = parser.nextText();
                    inICName = value;
                } else if (startTagName.equalsIgnoreCase(OUT_RD_NAME)) {
                    String value = parser.nextText();
                    outRdName = value;
                } else if (startTagName.equalsIgnoreCase(OUT_IC_NAME)) {
                    String value = parser.nextText();
                    outICName = value;
                } else if (startTagName.equalsIgnoreCase(TOLL_SS)) {
                    String value = parser.nextText();
                    toll_SS = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_S)) {
                    String value = parser.nextText();
                    toll_S = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_M)) {
                    String value = parser.nextText();
                    toll_M = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_L)) {
                    String value = parser.nextText();
                    toll_L = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(TOLL_LL)) {
                    String value = parser.nextText();
                    toll_LL = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(DIST)) {
                    String value = parser.nextText();
                    dist = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param dist
     *            セットする dist
     */
    public void setDist(int dist) {
        this.dist = dist;
    }

    /**
     * @param inICName
     *            セットする inICName
     */
    public void setInICName(String inICName) {
        this.inICName = inICName;
    }

    /**
     * @param inRdName
     *            セットする inRdName
     */
    public void setInRdName(String inRdName) {
        this.inRdName = inRdName;
    }

    /**
     * @param outICName
     *            セットする outICName
     */
    public void setOutICName(String outICName) {
        this.outICName = outICName;
    }

    /**
     * @param outRdName
     *            セットする outRdName
     */
    public void setOutRdName(String outRdName) {
        this.outRdName = outRdName;
    }

    /**
     * @param toll_L
     *            セットする toll_L
     */
    public void setToll_L(int toll_L) {
        this.toll_L = toll_L;
    }

    /**
     * @param toll_LL
     *            セットする toll_LL
     */
    public void setToll_LL(int toll_LL) {
        this.toll_LL = toll_LL;
    }

    /**
     * @param toll_M
     *            セットする toll_M
     */
    public void setToll_M(int toll_M) {
        this.toll_M = toll_M;
    }

    /**
     * @param toll_S
     *            セットする toll_S
     */
    public void setToll_S(int toll_S) {
        this.toll_S = toll_S;
    }

    /**
     * @param toll_SS
     *            セットする toll_SS
     */
    public void setToll_SS(int toll_SS) {
        this.toll_SS = toll_SS;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = TRD;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", IN_RD_NAME);
        if (inRdName != null) {
            xmlSerializer.text(inRdName);
        }
        xmlSerializer.endTag("", IN_RD_NAME);
        xmlSerializer.startTag("", IN_IC_NAME);
        if (inICName != null) {
            xmlSerializer.text(inICName);
        }
        xmlSerializer.endTag("", IN_IC_NAME);
        xmlSerializer.startTag("", OUT_RD_NAME);
        if (outRdName != null) {
            xmlSerializer.text(outRdName);
        }
        xmlSerializer.endTag("", OUT_RD_NAME);
        xmlSerializer.startTag("", OUT_IC_NAME);
        if (outICName != null) {
            xmlSerializer.text(outICName);
        }
        xmlSerializer.endTag("", OUT_IC_NAME);
        xmlSerializer.startTag("", TOLL_SS);
        xmlSerializer.text(Integer.toString(toll_SS));
        xmlSerializer.endTag("", TOLL_SS);
        xmlSerializer.startTag("", TOLL_S);
        xmlSerializer.text(Integer.toString(toll_S));
        xmlSerializer.endTag("", TOLL_S);
        xmlSerializer.startTag("", TOLL_M);
        xmlSerializer.text(Integer.toString(toll_M));
        xmlSerializer.endTag("", TOLL_M);
        xmlSerializer.startTag("", TOLL_L);
        xmlSerializer.text(Integer.toString(toll_L));
        xmlSerializer.endTag("", TOLL_L);
        xmlSerializer.startTag("", TOLL_LL);
        xmlSerializer.text(Integer.toString(toll_LL));
        xmlSerializer.endTag("", TOLL_LL);
        xmlSerializer.endTag("", tag);
        xmlSerializer.startTag("", DIST);
        xmlSerializer.text(Integer.toString(dist));
        xmlSerializer.endTag("", DIST);
        xmlSerializer.endTag("", tag);
    }
}
