﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 住所アイテムです。
 * 
 * @author ishi
 */
public class AddressItem implements Parcelable {
    public static final Parcelable.Creator<AddressItem> CREATOR = new Parcelable.Creator<AddressItem>() {
        @Override
        public AddressItem createFromParcel(Parcel in) {
            return new AddressItem(in);
        }

        @Override
        public AddressItem[] newArray(int size) {
            return new AddressItem[size];
        }
    };

    private static final String ADDRESS = "Address";
    private static final String ADDRESS_CODE = "AddressCode";
    private static final String ADDRESS_ITEM = "AddressItem";
    private static final String ADDRESS_LEVEL = "AddressLevel";
    private static final String KANA = "Kana";
    private static final String KATA_KANA = "KataKana";
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String LOWER_ADDRESS_LEVEL = "LowerAddressLevel";
    private static final String UPPER_ADDRESS_LEVEL = "UpperAddressLevel";
    private static final String ZIP = "Zip";

    /**
     * 住所コード
     */
    private String addressCode;
    /**
     * 住所レベル
     */
    private int addressLevel;
    /**
     * 上位住所レベル
     */
    private int upperAddressLevel;
    /**
     * 下位住所レベル
     */
    private int lowerAddressLevel;
    /**
     * 住所
     */
    private String address;
    /**
     * ひらがな住所
     */
    private String kana;
    /**
     * カタカナ住所
     */
    private String kataKana;
    /**
     * 郵便番号
     */
    private String zip;
    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;

    /**
     * コンストラクタ―
     */
    public AddressItem() {
    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            元になるParcel
     */
    public AddressItem(Parcel src) {
        address = src.readString();
        addressCode = src.readString();
        addressLevel = src.readInt();
        kana = src.readString();
        kataKana = src.readString();
        lat = src.readDouble();
        lon = src.readDouble();
        lowerAddressLevel = src.readInt();
        upperAddressLevel = src.readInt();
        zip = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return address
     */
    public String getAddress() {
        return this.address;
    }

    /**
     * @return addressCode
     */
    public String getAddressCode() {
        return this.addressCode;
    }

    /**
     * @return addressLevel
     */
    public int getAddressLevel() {
        return this.addressLevel;
    }

    /**
     * @return kana
     */
    public String getKana() {
        return this.kana;
    }

    /**
     * @return kataKana
     */
    public String getKataKana() {
        return this.kataKana;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return lowerAddressLevel
     */
    public int getLowerAddressLevel() {
        return this.lowerAddressLevel;
    }

    /**
     * @return upperAddressLevel
     */
    public int getUpperAddressLevel() {
        return this.upperAddressLevel;
    }

    /**
     * @return zip
     */
    public String getZip() {
        return this.zip;
    }

    /**
     * SOAPレスポンスから値を設定します。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    addressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(UPPER_ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    upperAddressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(LOWER_ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    lowerAddressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ADDRESS_CODE)) {
                    String value = parser.nextText();
                    addressCode = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS)) {
                    String value = parser.nextText();
                    address = value;
                } else if (startTagName.equalsIgnoreCase(KANA)) {
                    String value = parser.nextText();
                    kana = value;
                } else if (startTagName.equalsIgnoreCase(KATA_KANA)) {
                    String value = parser.nextText();
                    kataKana = value;
                } else if (startTagName.equalsIgnoreCase(ZIP)) {
                    String value = parser.nextText();
                    zip = value;
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(address);
        dest.writeString(addressCode);
        dest.writeInt(addressLevel);
        dest.writeString(kana);
        dest.writeString(kataKana);
        dest.writeDouble(lat);
        dest.writeDouble(lon);
        dest.writeInt(lowerAddressLevel);
        dest.writeInt(upperAddressLevel);
        dest.writeString(zip);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = ADDRESS_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(addressLevel));
        xmlSerializer.endTag("", ADDRESS_LEVEL);
        xmlSerializer.startTag("", UPPER_ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(upperAddressLevel));
        xmlSerializer.endTag("", UPPER_ADDRESS_LEVEL);
        xmlSerializer.startTag("", LOWER_ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(lowerAddressLevel));
        xmlSerializer.endTag("", LOWER_ADDRESS_LEVEL);
        xmlSerializer.startTag("", ADDRESS_CODE);
        if (addressCode != null) {
            xmlSerializer.text(addressCode);
        }
        xmlSerializer.endTag("", ADDRESS_CODE);
        xmlSerializer.startTag("", ADDRESS);
        if (address != null) {
            xmlSerializer.text(address);
        }
        xmlSerializer.endTag("", ADDRESS);
        xmlSerializer.startTag("", KANA);
        if (kana != null) {
            xmlSerializer.text(kana);
        }
        xmlSerializer.endTag("", KANA);
        xmlSerializer.startTag("", KATA_KANA);
        if (kataKana != null) {
            xmlSerializer.text(kataKana);
        }
        xmlSerializer.endTag("", KATA_KANA);
        xmlSerializer.startTag("", ZIP);
        if (zip != null) {
            xmlSerializer.text(zip);
        }
        xmlSerializer.endTag("", ZIP);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.endTag("", tag);
    }
}
