﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 住所検索用共通パラメータです。
 * 
 * @author ishi
 * 
 */
public class CommonParam {
    private static final String COMMON_PARAM = "CommonParam";
    private static final String COORDINATE_FORMAT = "CoordinateFormat";
    private static final String DATUM = "Datum";
    private static final String SEARCH_FLAG = "SearchFlag";

    /**
     * 経緯度の座標系識別子
     */
    private int datum;
    /**
     * 経緯度の座標フォーマット識別子
     */
    private int coordinateFormat;
    /**
     * 検索フラグ
     */
    private int searchFlag;

    /**
     * コンストラクター
     * 
     */
    public CommonParam() {
    }

    /**
     * コンストラクタ
     * 
     * @param datum
     *            経緯度の座標系識別子
     * @param coordinateFormat
     *            経緯度の座標フォーマット識別子
     * @param searchFlag
     *            検索フラグ
     */
    public CommonParam(int datum, int coordinateFormat, int searchFlag) {
        this.datum = datum;
        this.coordinateFormat = coordinateFormat;
        this.searchFlag = searchFlag;
    }

    /**
     * @return coordinateFormat
     */
    public int getCoordinateFormat() {
        return this.coordinateFormat;
    }

    /**
     * @return datum
     */
    public int getDatum() {
        return this.datum;
    }

    /**
     * @return searchFlag
     */
    public int getSearchFlag() {
        return this.searchFlag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(DATUM)) {
                    String value = parser.nextText();
                    datum = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(COORDINATE_FORMAT)) {
                    String value = parser.nextText();
                    coordinateFormat = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(SEARCH_FLAG)) {
                    String value = parser.nextText();
                    searchFlag = Integer.parseInt(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param coordinateFormat
     *            セットする coordinateFormat
     */
    public void setCoordinateFormat(int coordinateFormat) {
        this.coordinateFormat = coordinateFormat;
    }

    /**
     * @param datum
     *            セットする datum
     */
    public void setDatum(int datum) {
        this.datum = datum;
    }

    /**
     * @param searchFlag
     *            セットする searchFlag
     */
    public void setSearchFlag(int searchFlag) {
        this.searchFlag = searchFlag;
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = COMMON_PARAM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", DATUM);
        xmlSerializer.text(Integer.toString(datum));
        xmlSerializer.endTag("", DATUM);
        xmlSerializer.startTag("", COORDINATE_FORMAT);
        xmlSerializer.text(Integer.toString(coordinateFormat));
        xmlSerializer.endTag("", COORDINATE_FORMAT);
        xmlSerializer.startTag("", SEARCH_FLAG);
        xmlSerializer.text(Integer.toString(searchFlag));
        xmlSerializer.endTag("", SEARCH_FLAG);
        xmlSerializer.endTag("", tag);
    }
}
