/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 全住所取得アイテムです。
 * 
 * @author ishi
 * 
 */
public class CreateFullAddressByCodeItem implements Parcelable {
    public static final Parcelable.Creator<CreateFullAddressByCodeItem> CREATOR = new Parcelable.Creator<CreateFullAddressByCodeItem>() {
        @Override
        public CreateFullAddressByCodeItem createFromParcel(Parcel in) {
            return new CreateFullAddressByCodeItem(in);
        }

        @Override
        public CreateFullAddressByCodeItem[] newArray(int size) {
            return new CreateFullAddressByCodeItem[size];
        }
    };

    private static final String ADDRESS_CODE = "AddressCode";
    private static final String ADDRESS_LEVEL = "AddressLevel";
    private static final String FULL_ADDRESS = "FullAddress";
    private static final String PREF_ADDRESS = "PrefAddress";
    private static final String CITY_ADDRESS = "CityAddress";
    private static final String STREET_ADDRESS = "StreetAddress";
    private static final String BLOCK_ADDRESS = "BlockAddress";
    private static final String HOUSE_ADDRESS = "HouseAddress";
    private static final String OTHER_ADDRESS = "OtherAddress";
    private static final String SEARCH_ADDRESS_CODE = "SearchAddressCode";
    private static final String SEARCH_ADDRESS_ITEM = "SearchAddressItem";
    private static final String TAG = "Tag";

    /**
     * 検索住所コード
     */
    private String searchAddressCode;
    /**
     * 結果住所レベル
     */
    private int addressLevel;
    /**
     * 結果住所コード
     */
    private String addressCode;
    /**
     * 結果全住所
     */
    private String fullAddress;
    /**
     * 都道府県住所
     */
    private String prefAddress;
    /**
     * 市区町村住所
     */
    private String cityAddress;
    /**
     * 大字・丁目住所
     */
    private String streetAddress;
    /**
     * 番地・地番住所
     */
    private String houseAddress;
    /**
     * 号・枝番住所
     */
    private String blockAddress;
    /**
     * その他住所
     */
    private String otherAddress;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ―
     */
    public CreateFullAddressByCodeItem() {

    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            読み込むParcel
     */
    public CreateFullAddressByCodeItem(Parcel src) {
        searchAddressCode = src.readString();
        addressCode = src.readString();
        addressLevel = src.readInt();
        fullAddress = src.readString();
        prefAddress = src.readString();
        cityAddress = src.readString();
        streetAddress = src.readString();
        blockAddress = src.readString();
        houseAddress = src.readString();
        otherAddress = src.readString();
        tag = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressCode
     */
    public String getAddressCode() {
        return this.addressCode;
    }

    /**
     * @return addressLevel
     */
    public int getAddressLevel() {
        return this.addressLevel;
    }

    /**
     * @return blockAddress
     */
    public String getBlockAddress() {
        return this.blockAddress;
    }

    /**
     * @return cityAddress
     */
    public String getCityAddress() {
        return this.cityAddress;
    }

    /**
     * @return fullAddress
     */
    public String getFullAddress() {
        return this.fullAddress;
    }

    /**
     * @return houseAddress
     */
    public String getHouseAddress() {
        return this.houseAddress;
    }

    /**
     * @return otherAddress
     */
    public String getOtherAddress() {
        return this.otherAddress;
    }

    /**
     * @return prefAddress
     */
    public String getPrefAddress() {
        return this.prefAddress;
    }

    /**
     * @return searchAddressCode
     */
    public String getSearchAddressCode() {
        return this.searchAddressCode;
    }

    /**
     * @return streetAddress
     */
    public String getStreetAddress() {
        return this.streetAddress;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SEARCH_ADDRESS_CODE)) {
                    String value = parser.nextText();
                    searchAddressCode = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    addressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ADDRESS_CODE)) {
                    String value = parser.nextText();
                    addressCode = value;
                } else if (startTagName.equalsIgnoreCase(FULL_ADDRESS)) {
                    String value = parser.nextText();
                    fullAddress = (value);
                } else if (startTagName.equalsIgnoreCase(PREF_ADDRESS)) {
                    String value = parser.nextText();
                    prefAddress = (value);
                } else if (startTagName.equalsIgnoreCase(CITY_ADDRESS)) {
                    String value = parser.nextText();
                    cityAddress = (value);
                } else if (startTagName.equalsIgnoreCase(STREET_ADDRESS)) {
                    String value = parser.nextText();
                    streetAddress = (value);
                } else if (startTagName.equalsIgnoreCase(BLOCK_ADDRESS)) {
                    String value = parser.nextText();
                    blockAddress = (value);
                } else if (startTagName.equalsIgnoreCase(HOUSE_ADDRESS)) {
                    String value = parser.nextText();
                    houseAddress = (value);
                } else if (startTagName.equalsIgnoreCase(OTHER_ADDRESS)) {
                    String value = parser.nextText();
                    otherAddress = (value);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    this.tag = (value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressCode
     *            セットする addressCode
     */
    public void setAddressCode(String addressCode) {
        this.addressCode = addressCode;
    }

    /**
     * @param addressLevel
     *            セットする addressLevel
     */
    public void setAddressLevel(int addressLevel) {
        this.addressLevel = addressLevel;
    }

    /**
     * @param blockAddress
     *            セットする blockAddress
     */
    public void setBlockAddress(String blockAddress) {
        this.blockAddress = blockAddress;
    }

    /**
     * @param cityAddress
     *            セットする cityAddress
     */
    public void setCityAddress(String cityAddress) {
        this.cityAddress = cityAddress;
    }

    /**
     * @param fullAddress
     *            セットする fullAddress
     */
    public void setFullAddress(String fullAddress) {
        this.fullAddress = fullAddress;
    }

    /**
     * @param houseAddress
     *            セットする houseAddress
     */
    public void setHouseAddress(String houseAddress) {
        this.houseAddress = houseAddress;
    }

    /**
     * @param otherAddress
     *            セットする otherAddress
     */
    public void setOtherAddress(String otherAddress) {
        this.otherAddress = otherAddress;
    }

    /**
     * @param prefAddress
     *            セットする prefAddress
     */
    public void setPrefAddress(String prefAddress) {
        this.prefAddress = prefAddress;
    }

    /**
     * @param searchAddressCode
     *            セットする searchAddressCode
     */
    public void setSearchAddressCode(String searchAddressCode) {
        this.searchAddressCode = searchAddressCode;
    }

    /**
     * @param streetAddress
     *            セットする streetAddress
     */
    public void setStreetAddress(String streetAddress) {
        this.streetAddress = streetAddress;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(searchAddressCode);
        dest.writeString(addressCode);
        dest.writeInt(addressLevel);
        dest.writeString(fullAddress);
        dest.writeString(prefAddress);
        dest.writeString(cityAddress);
        dest.writeString(streetAddress);
        dest.writeString(blockAddress);
        dest.writeString(houseAddress);
        dest.writeString(otherAddress);
        dest.writeString(tag);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = SEARCH_ADDRESS_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", SEARCH_ADDRESS_CODE);
        if (searchAddressCode != null) {
            xmlSerializer.text(searchAddressCode);
        }
        xmlSerializer.endTag("", SEARCH_ADDRESS_CODE);
        xmlSerializer.startTag("", ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(addressLevel));
        xmlSerializer.endTag("", ADDRESS_LEVEL);
        xmlSerializer.startTag("", ADDRESS_CODE);
        if (addressCode != null) {
            xmlSerializer.text(addressCode);
        }
        xmlSerializer.endTag("", ADDRESS_CODE);
        xmlSerializer.startTag("", FULL_ADDRESS);
        if (fullAddress != null) {
            xmlSerializer.text(fullAddress);
        }
        xmlSerializer.endTag("", FULL_ADDRESS);
        xmlSerializer.startTag("", PREF_ADDRESS);
        if (prefAddress != null) {
            xmlSerializer.text(prefAddress);
        }
        xmlSerializer.endTag("", PREF_ADDRESS);
        xmlSerializer.startTag("", CITY_ADDRESS);
        if (cityAddress != null) {
            xmlSerializer.text(cityAddress);
        }
        xmlSerializer.endTag("", CITY_ADDRESS);
        xmlSerializer.startTag("", STREET_ADDRESS);
        if (streetAddress != null) {
            xmlSerializer.text(streetAddress);
        }
        xmlSerializer.endTag("", STREET_ADDRESS);
        xmlSerializer.startTag("", BLOCK_ADDRESS);
        if (blockAddress != null) {
            xmlSerializer.text(blockAddress);
        }
        xmlSerializer.endTag("", BLOCK_ADDRESS);
        xmlSerializer.startTag("", HOUSE_ADDRESS);
        if (houseAddress != null) {
            xmlSerializer.text(houseAddress);
        }
        xmlSerializer.endTag("", HOUSE_ADDRESS);
        xmlSerializer.startTag("", OTHER_ADDRESS);
        if (otherAddress != null) {
            xmlSerializer.text(otherAddress);
        }
        xmlSerializer.endTag("", OTHER_ADDRESS);
        xmlSerializer.startTag("", TAG);
        if (this.tag != null) {
            xmlSerializer.text(this.tag);
        }
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
