﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 下位住所列挙の結果です。 EnumLowerAddressByCodeの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class EnumLowerAddressByCodeResponse implements Response {
    private static final String ADDRESS_ITEM = "AddressItem";
    private static final String ENUM_LOWER_ADDRESS_BY_CODE_RESULT = "EnumLowerAddressByCodeResult";
    private static final String GEO_INFO = "GeoInfo";
    private static final String ITEMS = "Items";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 住所アイテム
     */
    private ArrayList<AddressItem> items;
    /**
     * 住所データ情報
     */
    private GeoInfo geoInfo;
    /**
     * 例外
     */
    private Exception exception;

    /**
     * コンストラクター
     * 
     */
    public EnumLowerAddressByCodeResponse() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return geoInfo
     */
    public GeoInfo getGeoInfo() {
        return this.geoInfo;
    }

    /**
     * @return items
     */
    public ArrayList<AddressItem> getItems() {
        return this.items;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inItems = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inItems) {
                    if (startTagName.equalsIgnoreCase(ADDRESS_ITEM)) {
                        AddressItem item = new AddressItem();
                        item.readXml(parser, ADDRESS_ITEM);
                        items.add(item);
                    }
                } else {
                    if (startTagName
                            .equalsIgnoreCase(ENUM_LOWER_ADDRESS_BY_CODE_RESULT)) {
                        String value = parser.nextText();
                        resultCode = Integer.parseInt(value);
                    } else if (startTagName.equalsIgnoreCase(ITEMS)) {
                        inItems = true;
                        items = new ArrayList<AddressItem>();
                    } else if (startTagName.equalsIgnoreCase(GEO_INFO)) {
                        geoInfo = new GeoInfo();
                        getGeoInfo().readXml(parser, GEO_INFO);
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(ITEMS)) {
                    inItems = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

}
