﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */

package jp.co.act_inc.actservicesample.gcservice;

import java.io.BufferedOutputStream;
import java.net.HttpURLConnection;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.Logger;
import jp.co.act_inc.actservicesample.adminservice.ServiceUtils;
import jp.co.act_inc.actservicesample.adminservice.Environ;
import jp.co.act_inc.actservicesample.gcservice.CommonParam;
import jp.co.act_inc.actservicesample.gcservice.EnumAddressByZipResponse;
import jp.co.act_inc.actservicesample.gcservice.EnumLowerAddressByCodeResponse;
import jp.co.act_inc.actservicesample.gcservice.GetGcwsMessageResponse;
import jp.co.act_inc.actservicesample.gcservice.SearchAddressItem;
import jp.co.act_inc.actservicesample.gcservice.SearchAddressResponse;

import org.xmlpull.v1.XmlSerializer;

import android.util.Log;
import android.util.Xml;

/**
 * ACT距離計算サービスの住所検索サービスを呼び出すクラスです。
 * 
 * @author ishi
 */
public class GCService {
    /**
     * SOAPアクション名
     * 
     * @author ishi
     */
    class ActionName {
        private static final String GET_GCWS_MESSAGE = "GetGCWSMessage";
        private static final String SEARCH_ADDRESS = "SearchAddress";
        private static final String ENUM_LOWER_ADDRESS_BY_CODE = "EnumLowerAddressByCode";
        private static final String ENUM_ADDRESS_BY_ZIP = "EnumAddressByZip";
        private static final String COUNT_ADDRESS_BY_ZIP = "CountAddressByZip";
        private static final String COUNT_LOWER_ADDRESS_BY_CODE = "CountLowerAddressByCode";
        private static final String CREATE_FULL_ADRESS_BY_CODE = "CreateFullAddressByCode";
        private static final String GET_NEAREST_ADDRESS = "GetNearestAddress";
        private static final String SEARCH_ADDRESS_CODE = "SearchAddressCode";
        private static final String SEARCH_ZIP = "SearchZip";
    }

    /**
     * サービス名前空間
     * 
     * @author ishi
     * 
     */
    class Namespace {
        private static final String GCWS = "http://distcalc.act-inc.co.jp/GCWS";
    }

    /**
     * タグ名
     * 
     * @author ishi
     */
    class Tag {
        private static final String GET_GCWS_MESSAGE_RESPONSE = "GetGCWSMessageResponse";
        private static final String SEARCH_ADDRESS_RESPONSE = "SearchAddressResponse";
        private static final String Enum_ADDRESS_BY_ZIP_RESPONSE = "EnumAddressByZipResponse";
        private static final String Enum_LOWER_ADDRESS_BY_CODE_RESPONSE = "EnumLowerAddressByCodeResponse";
        private static final String COUNT_ADDRESS_BY_ZIP_RESPONSE = "CountAddressByZipResponse";
        private static final String COUNT_LOWER_ADDRESS_BY_CODE_RESPONSE = "CountLowerAddressByCodeResponse";
        private static final String CREATE_FULL_ADDRESS_BY_CODE_RESPONSE = "CreateFullAddressByCodeResponse";
        private static final String GET_NEAREST_ADDRESS_RESPONSE = "GetNearestAddressResponse";
        private static final String SEARCH_ADDRESS_CODE_RESPONSE = "SearchAddressCodeResponse";
        private static final String SEARCH_ZIP_RESPONSE = "SearchZipResponse";

        private static final String ENVIRON = "Environ";
        private static final String MSG_NUMBER = "MsgNumber";
        private static final String PARAM = "Param";
        private static final String SEARCH_ADDRESS_CODE = "SearchAddressCode";
        private static final String SEARCH_ADDRESS_ITEM = "SearchAddressItem";
        private static final String SEARCH_ADDRESS_ITEMS = "Items";
        private static final String SEARCH_ADDRESS_LEVEL = "SearchAddressLevel";
        private static final String SEARCH_ZIP = "SearchZip";
        private static final String CREATE_FULL_ADDRESS_BY_CODE_ITEM = "CreateFullAddressByCodeItem";
        private static final String CREATE_FULL_ADDRESS_BY_CODE_ITEMS = "Items";
        private static final String GET_NEAREST_ADDRESS_ITEM = "GetNearestAddressItem";
        private static final String GET_NEAREST_ADDRESS_ITEMS = "Items";
        private static final String SEARCH_ADDRESS_CODE_ITEM = "SearchAddressCodeItem";
        private static final String SEARCH_ADDRESS_CODE_ITEMS = "Items";
        private static final String SEARCH_ZIP_ITEM = "SearchZipItem";
        private static final String SEARCH_ZIP_ITEMS = "Items";
    }

    /**
     * 郵便番号対応住所数取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param searchZip
     *            検索する郵便番号
     * @return 結果を格納したCountAddressByZipResponse
     */
    public static CountAddressByZipResponse countAddressByZip(boolean useSsl,
            Environ environ, CommonParam param, String searchZip) {
        Logger.writeDebugLog("countAddressByZip", "start");
        String methodName = ActionName.COUNT_ADDRESS_BY_ZIP;
        String soapAction = Namespace.GCWS + "/" + methodName;
        CountAddressByZipResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.PARAM);
            xmlSerializer.startTag("", Tag.SEARCH_ZIP);
            xmlSerializer.text(searchZip);
            xmlSerializer.endTag("", Tag.SEARCH_ZIP);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("countAddressByZip", "connect");
                connection.connect();
                result = new CountAddressByZipResponse();
                Logger.writeDebugLog("countAddressByZip", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.COUNT_ADDRESS_BY_ZIP_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CountAddressByZipResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("countAddressByZip", "end");
        return result;
    }

    /**
     * 下位住所数取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param searchAddressCode
     *            検索する住所コード
     * @return 結果を格納したCountLowerAddressByCodeResponse
     */
    public static CountLowerAddressByCodeResponse countLowerAddressByCode(
            boolean useSsl, Environ environ, CommonParam param,
            String searchAddressCode) {
        Logger.writeDebugLog("countLowerAddressByCode", "start");
        String methodName = ActionName.COUNT_LOWER_ADDRESS_BY_CODE;
        String soapAction = Namespace.GCWS + "/" + methodName;
        CountLowerAddressByCodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.PARAM);
            xmlSerializer.startTag("", Tag.SEARCH_ADDRESS_CODE);
            xmlSerializer.text(searchAddressCode);
            xmlSerializer.endTag("", Tag.SEARCH_ADDRESS_CODE);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("countLowerAddressByCode", "connect");
                connection.connect();
                result = new CountLowerAddressByCodeResponse();
                Logger.writeDebugLog("countLowerAddressByCode",
                        "convert response");
                ServiceUtils.getResponse(result,
                        Tag.COUNT_LOWER_ADDRESS_BY_CODE_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CountLowerAddressByCodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("countLowerAddressByCode", "end");
        return result;
    }

    /**
     * 全住所取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param items
     *            全住所取得アイテムリスト
     * @return 結果を格納したCreateFullAddressByCodeResponse
     */
    public static CreateFullAddressByCodeResponse createFullAddressByCode(
            boolean useSsl, Environ environ, CommonParam param,
            ArrayList<CreateFullAddressByCodeItem> items) {
        Logger.writeDebugLog("createFullAddressByCode", "start");
        String methodName = ActionName.CREATE_FULL_ADRESS_BY_CODE;
        String soapAction = Namespace.GCWS + "/" + methodName;
        String saParam = Tag.PARAM;
        CreateFullAddressByCodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, saParam);
            xmlSerializer.startTag("", Tag.CREATE_FULL_ADDRESS_BY_CODE_ITEMS);
            for (CreateFullAddressByCodeItem item : items) {
                item.writeXml(xmlSerializer,
                        Tag.CREATE_FULL_ADDRESS_BY_CODE_ITEM);
            }
            xmlSerializer.endTag("", Tag.CREATE_FULL_ADDRESS_BY_CODE_ITEMS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("createFullAddressByCode", "connect");
                connection.connect();
                result = new CreateFullAddressByCodeResponse();
                Logger.writeDebugLog("createFullAddressByCode",
                        "convert response");
                ServiceUtils.getResponse(result,
                        Tag.CREATE_FULL_ADDRESS_BY_CODE_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new CreateFullAddressByCodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("createFullAddressByCode", "end");
        return result;
    }

    /**
     * 郵便番号対応住所列挙を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param searchZip
     *            検索する郵便番号
     * @return 結果を格納したEnumAddressByZipResponse
     */
    public static EnumAddressByZipResponse enumAddressByZip(boolean useSsl,
            Environ environ, CommonParam param, String searchZip) {
        Logger.writeDebugLog("enumAddressByZip", "start");
        String methodName = ActionName.ENUM_ADDRESS_BY_ZIP;
        String soapAction = Namespace.GCWS + "/" + methodName;
        EnumAddressByZipResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.PARAM);
            xmlSerializer.startTag("", Tag.SEARCH_ZIP);
            xmlSerializer.text(searchZip);
            xmlSerializer.endTag("", Tag.SEARCH_ZIP);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("enumAddressByZip", "connect");
                connection.connect();
                result = new EnumAddressByZipResponse();
                Logger.writeDebugLog("enumAddressByZip", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.Enum_ADDRESS_BY_ZIP_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new EnumAddressByZipResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("enumAddressByZip", "end");
        return result;
    }

    /**
     * 下位住所列挙を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param searchAddressCode
     *            検索する住所コード
     * @return 結果を格納したEnumLowerAddressByCodeResponse
     */
    public static EnumLowerAddressByCodeResponse enumLowerAddressByCode(
            boolean useSsl, Environ environ, CommonParam param,
            String searchAddressCode) {
        Logger.writeDebugLog("enumLowerAddressByCode", "start");
        String methodName = ActionName.ENUM_LOWER_ADDRESS_BY_CODE;
        String soapAction = Namespace.GCWS + "/" + methodName;
        EnumLowerAddressByCodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, Tag.PARAM);
            xmlSerializer.startTag("", Tag.SEARCH_ADDRESS_CODE);
            xmlSerializer.text(searchAddressCode);
            xmlSerializer.endTag("", Tag.SEARCH_ADDRESS_CODE);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("enumLowerAddressByCode", "connect");
                connection.connect();
                result = new EnumLowerAddressByCodeResponse();
                Logger.writeDebugLog("enumLowerAddressByCode",
                        "convert response");
                ServiceUtils.getResponse(result,
                        Tag.Enum_LOWER_ADDRESS_BY_CODE_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new EnumLowerAddressByCodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("enumLowerAddressByCode", "end");
        return result;
    }

    /**
     * 住所検索サービスのエラーメッセージを取得します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param code
     *            エラーコード
     * @return 結果を格納したGetGcwsMessageResponse
     */
    public static GetGcwsMessageResponse getGCWSMessage(boolean useSsl,
            Environ environ, int code) {
        Logger.writeDebugLog("getGCWSMessage", "start");
        String methodName = ActionName.GET_GCWS_MESSAGE;
        String soapAction = Namespace.GCWS + "/" + methodName;
        GetGcwsMessageResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            xmlSerializer.startTag("", Tag.MSG_NUMBER);
            xmlSerializer.text(Integer.toString(code));
            xmlSerializer.endTag("", Tag.MSG_NUMBER);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);

            try {
                Logger.writeDebugLog("getGCWSMessage", "connect");
                connection.connect();
                result = new GetGcwsMessageResponse();
                Logger.writeDebugLog("getGCWSMessage", "convert response");
                ServiceUtils.getResponse(result, Tag.GET_GCWS_MESSAGE_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetGcwsMessageResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getGCWSMessage", "end");
        return result;
    }

    /**
     * 最寄住所取得を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param items
     *            最寄住所取得アイテムリスト
     * @return 結果を格納したGetNearestAddressResponse
     */
    public static GetNearestAddressResponse getNearestAddress(boolean useSsl,
            Environ environ, CommonParam param,
            ArrayList<GetNearestAddressItem> items) {
        Logger.writeDebugLog("getNearestAddress", "start");
        String methodName = ActionName.GET_NEAREST_ADDRESS;
        String soapAction = Namespace.GCWS + "/" + methodName;
        String saParam = Tag.PARAM;
        GetNearestAddressResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, saParam);
            xmlSerializer.startTag("", Tag.GET_NEAREST_ADDRESS_ITEMS);
            for (GetNearestAddressItem item : items) {
                item.writeXml(xmlSerializer, Tag.GET_NEAREST_ADDRESS_ITEM);
            }
            xmlSerializer.endTag("", Tag.GET_NEAREST_ADDRESS_ITEMS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("getNearestAddress", "connect");
                connection.connect();
                result = new GetNearestAddressResponse();
                Logger.writeDebugLog("getNearestAddress", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.GET_NEAREST_ADDRESS_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new GetNearestAddressResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("getNearestAddress", "end");
        return result;
    }

    /**
     * 住所検索を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param searchAddressLevel
     *            最大住所検索レベル
     * @param items
     *            住所検索アイテム
     * @return 結果を格納したSearchAddressResponse
     */
    public static SearchAddressResponse searchAddress(boolean useSsl,
            Environ environ, CommonParam param, int searchAddressLevel,
            ArrayList<SearchAddressItem> items) {
        Logger.writeDebugLog("searchAddress", "start");
        String methodName = ActionName.SEARCH_ADDRESS;
        String soapAction = Namespace.GCWS + "/" + methodName;
        String saParam = Tag.PARAM;
        SearchAddressResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, saParam);
            xmlSerializer.startTag("", Tag.SEARCH_ADDRESS_LEVEL);
            xmlSerializer.text(Integer.toString(searchAddressLevel));
            xmlSerializer.endTag("", Tag.SEARCH_ADDRESS_LEVEL);
            xmlSerializer.startTag("", Tag.SEARCH_ADDRESS_ITEMS);
            for (SearchAddressItem item : items) {
                item.writeXml(xmlSerializer, Tag.SEARCH_ADDRESS_ITEM);
            }
            xmlSerializer.endTag("", Tag.SEARCH_ADDRESS_ITEMS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("searchAddress", "connect");
                connection.connect();
                result = new SearchAddressResponse();
                Logger.writeDebugLog("searchAddress", "convert response");
                ServiceUtils.getResponse(result, Tag.SEARCH_ADDRESS_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new SearchAddressResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("searchAddress", "end");
        return result;
    }

    /**
     * 住所コード検索を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param items
     *            住所コード検索アイテム
     * @return 結果を格納したSearchAddressCodeResponse
     */
    public static SearchAddressCodeResponse searchAddressCode(boolean useSsl,
            Environ environ, CommonParam param,
            ArrayList<SearchAddressCodeItem> items) {
        Logger.writeDebugLog("searchAddressCode", "start");
        String methodName = ActionName.SEARCH_ADDRESS_CODE;
        String soapAction = Namespace.GCWS + "/" + methodName;
        String saParam = Tag.PARAM;
        SearchAddressCodeResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, saParam);
            xmlSerializer.startTag("", Tag.SEARCH_ADDRESS_CODE_ITEMS);
            for (SearchAddressCodeItem item : items) {
                item.writeXml(xmlSerializer, Tag.SEARCH_ADDRESS_CODE_ITEM);
            }
            xmlSerializer.endTag("", Tag.SEARCH_ADDRESS_CODE_ITEMS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("searchAddressCode", "connect");
                connection.connect();
                result = new SearchAddressCodeResponse();
                Logger.writeDebugLog("searchAddressCode", "convert response");
                ServiceUtils.getResponse(result,
                        Tag.SEARCH_ADDRESS_CODE_RESPONSE, connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new SearchAddressCodeResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("searchAddressCode", "end");
        return result;
    }

    /**
     * 郵便番号検索を実行します。
     * 
     * @param useSsl
     *            SSLを使用
     * @param environ
     *            環境設定
     * @param param
     *            住所検索用共通パラメータ
     * @param items
     *            郵便番号検索アイテム
     * @return 結果を格納したSearchZipResponse
     */
    public static SearchZipResponse searchZip(boolean useSsl, Environ environ,
            CommonParam param, ArrayList<SearchZipItem> items) {
        Logger.writeDebugLog("searchZip", "start");
        String methodName = ActionName.SEARCH_ZIP;
        String soapAction = Namespace.GCWS + "/" + methodName;
        String saParam = Tag.PARAM;
        SearchZipResponse result = null;

        try {
            String url = environ.getWsUrl();
            HttpURLConnection connection = ServiceUtils
                    .createHttpURLConnection(url, useSsl, soapAction);

            XmlSerializer xmlSerializer = Xml.newSerializer();
            xmlSerializer.setOutput(
                    new BufferedOutputStream(connection.getOutputStream()),
                    "UTF-8");
            ServiceUtils.writeStartSoapMessage(methodName, Namespace.GCWS,
                    xmlSerializer);
            environ.writeXml(xmlSerializer, Tag.ENVIRON);
            param.writeXml(xmlSerializer, saParam);
            xmlSerializer.startTag("", Tag.SEARCH_ZIP_ITEMS);
            for (SearchZipItem item : items) {
                item.writeXml(xmlSerializer, Tag.SEARCH_ZIP_ITEM);
            }
            xmlSerializer.endTag("", Tag.SEARCH_ZIP_ITEMS);
            ServiceUtils.writeEndSoapMessage(methodName, xmlSerializer);
            xmlSerializer.flush();

            try {
                Logger.writeDebugLog("searchZip", "connect");
                connection.connect();
                result = new SearchZipResponse();
                Logger.writeDebugLog("searchZip", "convert response");
                ServiceUtils.getResponse(result, Tag.SEARCH_ZIP_RESPONSE,
                        connection);
            } finally {
                connection.disconnect();
            }
        } catch (Exception e) {
            Log.w(Thread.currentThread().getStackTrace()[3].getClassName(),
                    Thread.currentThread().getStackTrace()[3].getMethodName(),
                    e);
            result = new SearchZipResponse();
            result.setException(e);
        }
        Logger.writeDebugLog("searchZip", "end");
        return result;
    }
}
