﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

/**
 * 住所データ情報です。
 * 
 * @author ishi
 * 
 */
public class GeoInfo {
    private static final String FOLDER = "Folder";
    private static final String GEO_ID = "GeoID";
    private static final String IS_DETAIL_EXIST = "IsDetailExist";
    private static final String NOTE = "Note";
    private static final String NW_INFO = "NWInfo";

    /**
     * 住所データフォルダパス
     */
    private String folder;
    /**
     * 住所データの説明
     */
    private String note;
    /**
     * 住所データID
     */
    private String geoID;

    /**
     * コンストラクタ
     * 
     */
    public GeoInfo() {
    }

    /**
     * コンストラクタ
     * 
     * @param folder
     *            住所データフォルダパス
     * @param note
     *            住所データの説明
     * @param geoID
     *            住所データID
     */
    public GeoInfo(String folder, String note, String geoID) {
        this.folder = folder;
        this.note = note;
        this.geoID = geoID;
    }

    /**
     * @return folder
     */
    public String getFolder() {
        return this.folder;
    }

    /**
     * @return geoID
     */
    public String getGeoID() {
        return this.geoID;
    }

    /**
     * @return note
     */
    public String getNote() {
        return this.note;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(FOLDER)) {
                    String value = parser.nextText();
                    folder = value;
                } else if (startTagName.equalsIgnoreCase(NOTE)) {
                    String value = parser.nextText();
                    note = value;
                } else if (startTagName.equalsIgnoreCase(GEO_ID)) {
                    String value = parser.nextText();
                    geoID = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = NW_INFO;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", FOLDER);
        if (folder != null) {
            xmlSerializer.text(folder);
        }
        xmlSerializer.endTag("", FOLDER);
        xmlSerializer.startTag("", NOTE);
        if (note != null) {
            xmlSerializer.text(note);
        }
        xmlSerializer.endTag("", NOTE);
        xmlSerializer.startTag("", IS_DETAIL_EXIST);
        xmlSerializer.startTag("", GEO_ID);
        if (geoID != null) {
            xmlSerializer.text(geoID);
        }
        xmlSerializer.endTag("", GEO_ID);
        xmlSerializer.endTag("", tag);
    }
}
