﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import jp.co.act_inc.actservicesample.adminservice.GetUsableGeoServerResponse;
import jp.co.act_inc.actservicesample.adminservice.Response;

/**
 * 住所検索結果を格納します。
 * 
 * @author ishi
 * 
 */
public class GeoResultHolder {
    /**
     * 住所検索種別
     * 
     * @author ishi
     * 
     */
    public class GeoCalcType {
        /**
         * エラー
         */
        public static final int ERROR = -1;
        /**
         * 住所検索
         */
        public static final int SEARCH_ADDRESS = 0;
        /**
         * 郵便番号対応住所列挙
         */
        public static final int ENUM_ADDRESS_BY_ZIP = 1;
        /**
         * 下位住所列挙
         */
        public static final int ENUM_LOWER_ADDRESS_BY_CODE = 2;
    }

    private GetUsableGeoServerResponse getUsableGeoServerResponse;
    private SearchAddressResponse searchAddressResponse;
    private EnumAddressByZipResponse enumAddressByZipResponse;
    private EnumLowerAddressByCodeResponse enumLowerAddressByCodeResponse;

    /**
     * 例外
     */
    private Exception exception;
    /**
     * 計算種別
     */
    private int calcType;

    /**
     * @return calcType
     */
    public int getCalcType() {
        return this.calcType;
    }

    /**
     * @return enumAddressByZipResponse
     */
    public EnumAddressByZipResponse getEnumAddressByZipResponse() {
        return this.enumAddressByZipResponse;
    }

    /**
     * @return enumLowerAddressByCodeResponse
     */
    public EnumLowerAddressByCodeResponse getEnumLowerAddressByCodeResponse() {
        return this.enumLowerAddressByCodeResponse;
    }

    /**
     * @return exception
     */
    public Exception getException() {
        return exception;
    }

    /**
     * @return getUsableGeoServerResponse
     */
    public GetUsableGeoServerResponse getGetUsableGeoServerResponse() {
        return this.getUsableGeoServerResponse;
    }

    /**
     * 計算結果を取得します。
     * 
     * @return 計算結果
     */
    public Response getResponse() {
        switch (getCalcType()) {
        case GeoCalcType.SEARCH_ADDRESS:
            return searchAddressResponse;
        case GeoCalcType.ENUM_LOWER_ADDRESS_BY_CODE:
            return enumLowerAddressByCodeResponse;
        case GeoCalcType.ENUM_ADDRESS_BY_ZIP:
            return enumAddressByZipResponse;
        default:
            return null;
        }
    }

    /**
     * @return searchAddressResponse
     */
    public SearchAddressResponse getSearchAddressResponse() {
        return this.searchAddressResponse;
    }

    /**
     * @param calcType
     *            セットする calcType
     */
    public void setCalcType(int calcType) {
        this.calcType = calcType;
    }

    /**
     * @param enumAddressByZipResponse
     *            セットする enumAddressByZipResponse
     */
    public void setEnumAddressByZipResponse(
            EnumAddressByZipResponse enumAddressByZipResponse) {
        this.enumAddressByZipResponse = enumAddressByZipResponse;
    }

    /**
     * @param enumLowerAddressByCodeResponse
     *            セットする enumLowerAddressByCodeResponse
     */
    public void setEnumLowerAddressByCodeResponse(
            EnumLowerAddressByCodeResponse enumLowerAddressByCodeResponse) {
        this.enumLowerAddressByCodeResponse = enumLowerAddressByCodeResponse;
    }

    /**
     * @param exception
     *            セットする exception
     */
    public void setException(Exception exception) {
        this.exception = exception;
    }

    /**
     * @param getUsableGeoServerResponse
     *            セットする getUsableGeoServerResponse
     */
    public void setGetUsableGeoServerResponse(
            GetUsableGeoServerResponse getUsableGeoServerResponse) {
        this.getUsableGeoServerResponse = getUsableGeoServerResponse;
    }

    /**
     * @param searchAddressResponse
     *            セットする searchAddressResponse
     */
    public void setSearchAddressResponse(
            SearchAddressResponse searchAddressResponse) {
        this.searchAddressResponse = searchAddressResponse;
    }
}
