/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 最寄住所取得アイテムです。
 * 
 * @author ishi
 */
public class GetNearestAddressItem implements Parcelable {
    public static final Parcelable.Creator<GetNearestAddressItem> CREATOR = new Parcelable.Creator<GetNearestAddressItem>() {
        @Override
        public GetNearestAddressItem createFromParcel(Parcel in) {
            return new GetNearestAddressItem(in);
        }

        @Override
        public GetNearestAddressItem[] newArray(int size) {
            return new GetNearestAddressItem[size];
        }
    };
    private static final String SEARCH_LON = "SearchLon";
    private static final String SEARCH_LAT = "SearchLat";
    private static final String FULL_ADDRESS = "FullAddress";
    private static final String ADDRESS_ITEM = "AddressItem";
    private static final String DISTANCE = "Distance";
    private static final String TAG = "Tag";

    /**
     * 検索経度（度単位）
     */
    private double searchLon;
    /**
     * 検索緯度（度単位）
     */
    private double searchLat;
    /**
     * 全住所
     */
    private String fullAddress;
    /**
     * 住所アイテム
     */
    private AddressItem addressItem;
    /**
     * 結果距離（メートル単位）　検索経緯度と結果住所の直線距離
     */
    private double distance;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ―
     */
    public GetNearestAddressItem() {
    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            元になるParcel
     */
    public GetNearestAddressItem(Parcel src) {
        searchLon = src.readInt();
        searchLat = src.readInt();
        fullAddress = src.readString();
        addressItem = src.readParcelable(null);
        distance = src.readDouble();
        tag = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressItem
     */
    public AddressItem getAddressItem() {
        return this.addressItem;
    }

    /**
     * @return distance
     */
    public double getDistance() {
        return this.distance;
    }

    /**
     * @return fullAddress
     */
    public String getFullAddress() {
        return this.fullAddress;
    }

    /**
     * @return searchLat
     */
    public double getSearchLat() {
        return this.searchLat;
    }

    /**
     * @return searchLon
     */
    public double getSearchLon() {
        return this.searchLon;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を設定します。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SEARCH_LON)) {
                    String value = parser.nextText();
                    searchLon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(SEARCH_LAT)) {
                    String value = parser.nextText();
                    searchLat = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(FULL_ADDRESS)) {
                    String value = parser.nextText();
                    fullAddress = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS_ITEM)) {
                    addressItem = new AddressItem();
                    addressItem.readXml(parser, ADDRESS_ITEM);
                } else if (startTagName.equalsIgnoreCase(DISTANCE)) {
                    String value = parser.nextText();
                    distance = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    tag = value;
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressItem
     *            セットする addressItem
     */
    public void setAddressItem(AddressItem addressItem) {
        this.addressItem = addressItem;
    }

    /**
     * @param distance
     *            セットする distance
     */
    public void setDistance(double distance) {
        this.distance = distance;
    }

    /**
     * @param fullAddress
     *            セットする fullAddress
     */
    public void setFullAddress(String fullAddress) {
        this.fullAddress = fullAddress;
    }

    /**
     * @param searchLat
     *            セットする searchLat
     */
    public void setSearchLat(double searchLat) {
        this.searchLat = searchLat;
    }

    /**
     * @param searchLon
     *            セットする searchLon
     */
    public void setSearchLon(double searchLon) {
        this.searchLon = searchLon;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeDouble(searchLon);
        dest.writeDouble(searchLat);
        dest.writeString(fullAddress);
        dest.writeParcelable(addressItem, flags);
        dest.writeDouble(distance);
        dest.writeString(tag);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = ADDRESS_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", SEARCH_LON);
        xmlSerializer.text(Double.toString(searchLon));
        xmlSerializer.endTag("", SEARCH_LON);
        xmlSerializer.startTag("", SEARCH_LAT);
        xmlSerializer.text(Double.toString(searchLat));
        xmlSerializer.endTag("", SEARCH_LAT);
        xmlSerializer.startTag("", FULL_ADDRESS);
        if (fullAddress != null) {
            xmlSerializer.text(fullAddress);
        }
        xmlSerializer.endTag("", FULL_ADDRESS);
        if (addressItem != null) {
            addressItem.writeXml(xmlSerializer, ADDRESS_ITEM);
        }
        xmlSerializer.startTag("", DISTANCE);
        xmlSerializer.text(Double.toString(distance));
        xmlSerializer.endTag("", DISTANCE);
        xmlSerializer.startTag("", TAG);
        xmlSerializer.text(tag);
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
