/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 住所コード検索アイテムです。
 * 
 * @author ishi
 * 
 */
public class SearchAddressCodeItem implements Parcelable {
    public static final Parcelable.Creator<SearchAddressCodeItem> CREATOR = new Parcelable.Creator<SearchAddressCodeItem>() {
        @Override
        public SearchAddressCodeItem createFromParcel(Parcel in) {
            return new SearchAddressCodeItem(in);
        }

        @Override
        public SearchAddressCodeItem[] newArray(int size) {
            return new SearchAddressCodeItem[size];
        }
    };

    private static final String SEARCH_ADDRESS_CODE_ITEM = "SearchAddressCodeItem";
    private static final String SEARCH_ADDRESS_CODE = "SearchAddressCode";
    private static final String ADDRESS_ITEM = "AddressItem";
    private static final String TAG = "Tag";

    /**
     * 検索住所コード
     */
    private String searchAddressCode;
    /**
     * 住所アイテム
     */
    private AddressItem addressItem;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ―
     */
    public SearchAddressCodeItem() {

    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            読み込むParcel
     */
    public SearchAddressCodeItem(Parcel src) {
        searchAddressCode = src.readString();
        addressItem = src.readParcelable(null);
        tag = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressItem
     */
    public AddressItem getAddressItem() {
        return this.addressItem;
    }

    /**
     * @return searchAddressCode
     */
    public String getSearchAddressCode() {
        return this.searchAddressCode;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SEARCH_ADDRESS_CODE)) {
                    String value = parser.nextText();
                    searchAddressCode = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS_ITEM)) {
                    addressItem = new AddressItem();
                    addressItem.readXml(parser, ADDRESS_ITEM);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    this.tag = (value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressItem
     *            セットする addressItem
     */
    public void setAddressItem(AddressItem addressItem) {
        this.addressItem = addressItem;
    }

    /**
     * @param searchAddressCode
     *            セットする searchAddressCode
     */
    public void setSearchAddressCode(String searchAddressCode) {
        this.searchAddressCode = searchAddressCode;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(searchAddressCode);
        dest.writeParcelable(addressItem, flags);
        dest.writeString(tag);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = SEARCH_ADDRESS_CODE_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", SEARCH_ADDRESS_CODE);
        if (searchAddressCode != null) {
            xmlSerializer.text(searchAddressCode);
        }
        xmlSerializer.endTag("", SEARCH_ADDRESS_CODE);
        if (addressItem != null) {
            addressItem.writeXml(xmlSerializer, SEARCH_ADDRESS_CODE_ITEM);
        }
        xmlSerializer.startTag("", TAG);
        if (this.tag != null) {
            xmlSerializer.text(this.tag);
        }
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
