﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;
import android.text.TextUtils;

/**
 * 住所検索アイテムです。
 * 
 * @author ishi
 * 
 */
public class SearchAddressItem implements Parcelable {
    public static final Parcelable.Creator<SearchAddressItem> CREATOR = new Parcelable.Creator<SearchAddressItem>() {
        @Override
        public SearchAddressItem createFromParcel(Parcel in) {
            return new SearchAddressItem(in);
        }

        @Override
        public SearchAddressItem[] newArray(int size) {
            return new SearchAddressItem[size];
        }
    };

    private static final String ADDRESS_CODE = "AddressCode";
    private static final String ADDRESS_LEVEL = "AddressLevel";
    private static final String ANALYZED_ADDRESS = "AnalyzedAddress";
    private static final String FULL_ADDRESS = "FullAddress";
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String REST_ADDRESS = "RestAddress";
    private static final String SEARCH_ADDRESS = "SearchAddress";
    private static final String SEARCH_ADDRESS_ITEM = "SearchAddressItem";
    private static final String TAG = "Tag";

    /**
     * 検索住所
     */
    private String searchAddress;
    /**
     * 解析住所
     */
    private String analyzedAddress;
    /**
     * 残住所
     */
    private String restAddress;
    /**
     * 結果住所レベル
     */
    private int addressLevel;
    /**
     * 結果住所コード
     */
    private String addressCode;
    /**
     * 結果経度（単位：度）
     */
    private double lon;
    /**
     * 結果緯度（単位：度）
     */
    private double lat;
    /**
     * 結果全住所
     */
    private String fullAddress;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ―
     */
    public SearchAddressItem() {

    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            読み込むParcel
     */
    public SearchAddressItem(Parcel src) {
        addressCode = src.readString();
        addressLevel = src.readInt();
        analyzedAddress = src.readString();
        fullAddress = src.readString();
        lat = src.readDouble();
        lon = src.readDouble();
        restAddress = src.readString();
        searchAddress = src.readString();
        tag = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressCode
     */
    public String getAddressCode() {
        return this.addressCode;
    }

    /**
     * @return addressLevel
     */
    public int getAddressLevel() {
        return this.addressLevel;
    }

    /**
     * @return analyzedAddress
     */
    public String getAnalyzedAddress() {
        return this.analyzedAddress;
    }

    /**
     * @return fullAddress
     */
    public String getFullAddress() {
        return this.fullAddress;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return restAddress
     */
    public String getRestAddress() {
        return this.restAddress;
    }

    /**
     * @return searchAddress
     */
    public String getSearchAddress() {
        return this.searchAddress;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SEARCH_ADDRESS)) {
                    String value = parser.nextText();
                    searchAddress = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    addressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ADDRESS_CODE)) {
                    String value = parser.nextText();
                    addressCode = value;
                } else if (startTagName.equalsIgnoreCase(ANALYZED_ADDRESS)) {
                    String value = parser.nextText();
                    analyzedAddress = (value);
                } else if (startTagName.equalsIgnoreCase(REST_ADDRESS)) {
                    String value = parser.nextText();
                    restAddress = (value);
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    if (!TextUtils.isEmpty(value)) {
                        lon = Double.parseDouble(value);
                    }
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    if (!TextUtils.isEmpty(value)) {
                        lat = Double.parseDouble(value);
                    }
                } else if (startTagName.equalsIgnoreCase(FULL_ADDRESS)) {
                    String value = parser.nextText();
                    fullAddress = (value);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    this.tag = (value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressCode
     *            セットする addressCode
     */
    public void setAddressCode(String addressCode) {
        this.addressCode = addressCode;
    }

    /**
     * @param addressLevel
     *            セットする addressLevel
     */
    public void setAddressLevel(int addressLevel) {
        this.addressLevel = addressLevel;
    }

    /**
     * @param analyzedAddress
     *            セットする analyzedAddress
     */
    public void setAnalyzedAddress(String analyzedAddress) {
        this.analyzedAddress = analyzedAddress;
    }

    /**
     * @param fullAddress
     *            セットする fullAddress
     */
    public void setFullAddress(String fullAddress) {
        this.fullAddress = fullAddress;
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(int lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(int lon) {
        this.lon = lon;
    }

    /**
     * @param restAddress
     *            セットする restAddress
     */
    public void setRestAddress(String restAddress) {
        this.restAddress = restAddress;
    }

    /**
     * @param searchAddress
     *            セットする searchAddress
     */
    public void setSearchAddress(String searchAddress) {
        this.searchAddress = searchAddress;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(addressCode);
        dest.writeInt(addressLevel);
        dest.writeString(analyzedAddress);
        dest.writeString(fullAddress);
        dest.writeDouble(lat);
        dest.writeDouble(lon);
        dest.writeString(restAddress);
        dest.writeString(searchAddress);
        dest.writeString(tag);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = SEARCH_ADDRESS_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", SEARCH_ADDRESS);
        if (searchAddress != null) {
            xmlSerializer.text(searchAddress);
        }
        xmlSerializer.endTag("", SEARCH_ADDRESS);
        xmlSerializer.startTag("", ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(addressLevel));
        xmlSerializer.endTag("", ADDRESS_LEVEL);
        xmlSerializer.startTag("", ADDRESS_CODE);
        if (addressCode != null) {
            xmlSerializer.text(addressCode);
        }
        xmlSerializer.endTag("", ADDRESS_CODE);
        xmlSerializer.startTag("", ANALYZED_ADDRESS);
        if (analyzedAddress != null) {
            xmlSerializer.text(analyzedAddress);
        }
        xmlSerializer.endTag("", ANALYZED_ADDRESS);
        xmlSerializer.startTag("", REST_ADDRESS);
        if (restAddress != null) {
            xmlSerializer.text(restAddress);
        }
        xmlSerializer.endTag("", REST_ADDRESS);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.startTag("", FULL_ADDRESS);
        if (fullAddress != null) {
            xmlSerializer.text(fullAddress);
        }
        xmlSerializer.endTag("", FULL_ADDRESS);
        xmlSerializer.startTag("", TAG);
        if (this.tag != null) {
            xmlSerializer.text(this.tag);
        }
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
