/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;
import android.text.TextUtils;

/**
 * 郵便番号検索アイテムです。
 * 
 * @author ishi
 * 
 */
public class SearchZipItem implements Parcelable {
    public static final Parcelable.Creator<SearchZipItem> CREATOR = new Parcelable.Creator<SearchZipItem>() {
        @Override
        public SearchZipItem createFromParcel(Parcel in) {
            return new SearchZipItem(in);
        }

        @Override
        public SearchZipItem[] newArray(int size) {
            return new SearchZipItem[size];
        }
    };

    private static final String ADDRESS_CODE = "AddressCode";
    private static final String ADDRESS_LEVEL = "AddressLevel";
    private static final String FULL_ADDRESS = "FullAddress";
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String SEARCH_ZIP = "SearchZip";
    private static final String SEARCH_ZIP_ITEM = "SearchZipItem";
    private static final String TAG = "Tag";

    /**
     * 検索郵便番号
     */
    private String searchZip;
    /**
     * 結果住所レベル
     */
    private int addressLevel;
    /**
     * 結果住所コード
     */
    private String addressCode;
    /**
     * 結果経度（単位：度）
     */
    private double lon;
    /**
     * 結果緯度（単位：度）
     */
    private double lat;
    /**
     * 結果全住所
     */
    private String fullAddress;
    /**
     * タグ情報
     */
    private String tag;

    /**
     * コンストラクタ―
     */
    public SearchZipItem() {

    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            読み込むParcel
     */
    public SearchZipItem(Parcel src) {
        searchZip = src.readString();
        addressCode = src.readString();
        addressLevel = src.readInt();
        fullAddress = src.readString();
        lat = src.readDouble();
        lon = src.readDouble();
        tag = src.readString();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressCode
     */
    public String getAddressCode() {
        return this.addressCode;
    }

    /**
     * @return addressLevel
     */
    public int getAddressLevel() {
        return this.addressLevel;
    }

    /**
     * @return fullAddress
     */
    public String getFullAddress() {
        return this.fullAddress;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return searchZip
     */
    public String getSearchZip() {
        return this.searchZip;
    }

    /**
     * @return tag
     */
    public String getTag() {
        return this.tag;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(SEARCH_ZIP)) {
                    String value = parser.nextText();
                    searchZip = value;
                } else if (startTagName.equalsIgnoreCase(ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    addressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ADDRESS_CODE)) {
                    String value = parser.nextText();
                    addressCode = value;
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    if (!TextUtils.isEmpty(value)) {
                        lon = Double.parseDouble(value);
                    }
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    if (!TextUtils.isEmpty(value)) {
                        lat = Double.parseDouble(value);
                    }
                } else if (startTagName.equalsIgnoreCase(FULL_ADDRESS)) {
                    String value = parser.nextText();
                    fullAddress = (value);
                } else if (startTagName.equalsIgnoreCase(TAG)) {
                    String value = parser.nextText();
                    this.tag = (value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressCode
     *            セットする addressCode
     */
    public void setAddressCode(String addressCode) {
        this.addressCode = addressCode;
    }

    /**
     * @param addressLevel
     *            セットする addressLevel
     */
    public void setAddressLevel(int addressLevel) {
        this.addressLevel = addressLevel;
    }

    /**
     * @param fullAddress
     *            セットする fullAddress
     */
    public void setFullAddress(String fullAddress) {
        this.fullAddress = fullAddress;
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(int lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(int lon) {
        this.lon = lon;
    }

    /**
     * @param searchZip
     *            セットする searchZip
     */
    public void setSearchZip(String searchZip) {
        this.searchZip = searchZip;
    }

    /**
     * @param tag
     *            セットする tag
     */
    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(searchZip);
        dest.writeString(addressCode);
        dest.writeInt(addressLevel);
        dest.writeString(fullAddress);
        dest.writeDouble(lat);
        dest.writeDouble(lon);
        dest.writeString(tag);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = SEARCH_ZIP_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", SEARCH_ZIP);
        if (searchZip != null) {
            xmlSerializer.text(searchZip);
        }
        xmlSerializer.endTag("", SEARCH_ZIP);
        xmlSerializer.startTag("", ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(addressLevel));
        xmlSerializer.endTag("", ADDRESS_LEVEL);
        xmlSerializer.startTag("", ADDRESS_CODE);
        if (addressCode != null) {
            xmlSerializer.text(addressCode);
        }
        xmlSerializer.endTag("", ADDRESS_CODE);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.startTag("", FULL_ADDRESS);
        if (fullAddress != null) {
            xmlSerializer.text(fullAddress);
        }
        xmlSerializer.endTag("", FULL_ADDRESS);
        xmlSerializer.startTag("", TAG);
        if (this.tag != null) {
            xmlSerializer.text(this.tag);
        }
        xmlSerializer.endTag("", TAG);
        xmlSerializer.endTag("", tag);
    }
}
