/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/12/19 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import java.util.ArrayList;

import jp.co.act_inc.actservicesample.adminservice.Response;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

/**
 * 郵便番号検索の結果です。 SearchZipの結果を格納します。
 * 
 * @author ishi
 * 
 */
public class SearchZipResponse implements Response {
    private static final String GEO_INFO = "GeoInfo";
    private static final String ITEMS = "Items";
    private static final String SEARCH_ZIP_ITEM = "SearchZipItem";
    private static final String SEARCH_ZIP_RESULT = "SearchZipResult";

    /**
     * 戻り値
     */
    private int resultCode;
    /**
     * 郵便番号検索アイテムリスト
     */
    private ArrayList<SearchZipItem> items;
    /**
     * 住所データ情報
     */
    private GeoInfo geoInfo;
    /**
     * 例外
     */
    private Exception exception;

    /**
     * コンストラクター
     * 
     */
    public SearchZipResponse() {
    }

    @Override
    public Exception getException() {
        return exception;
    }

    /**
     * @return geoInfo
     */
    public GeoInfo getGeoInfo() {
        return this.geoInfo;
    }

    /**
     * @return items
     */
    public ArrayList<SearchZipItem> getItems() {
        return this.items;
    }

    @Override
    public int getResultCode() {
        return resultCode;
    }

    @Override
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        boolean inItems = false;
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (inItems) {
                    if (startTagName.equalsIgnoreCase(SEARCH_ZIP_ITEM)) {
                        SearchZipItem item = new SearchZipItem();
                        item.readXml(parser, SEARCH_ZIP_ITEM);
                        items.add(item);
                    }
                } else {
                    if (startTagName.equalsIgnoreCase(SEARCH_ZIP_RESULT)) {
                        resultCode = Integer.parseInt(parser.nextText());
                    } else if (startTagName.equalsIgnoreCase(ITEMS)) {
                        inItems = true;
                        items = new ArrayList<SearchZipItem>();
                    } else if (startTagName.equalsIgnoreCase(GEO_INFO)) {
                        GeoInfo info = new GeoInfo();
                        info.readXml(parser, GEO_INFO);
                        geoInfo = info;
                    }
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                } else if (endTagName.equalsIgnoreCase(ITEMS)) {
                    inItems = false;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    @Override
    public void setException(Exception exception) {
        this.exception = exception;
    }

}
