﻿/**
 * Copyrights (c) 2012 Advanced Core Technologies, Inc. All rights reserved.
 * 2012/05/10 ISHI 新規作成
 */
package jp.co.act_inc.actservicesample.gcservice;

import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * 郵便番号アイテムです。
 * 
 * @author ishi
 * 
 */
public class ZipItem implements Parcelable {
    public static final Parcelable.Creator<ZipItem> CREATOR = new Parcelable.Creator<ZipItem>() {
        @Override
        public ZipItem createFromParcel(Parcel in) {
            return new ZipItem(in);
        }

        @Override
        public ZipItem[] newArray(int size) {
            return new ZipItem[size];
        }
    };

    private static final String ADDRESS_CODE = "AddressCode";
    private static final String ADDRESS_LEVEL = "AddressLevel";
    private static final String FULL_ADDRESS = "FullAddress";
    private static final String LAT = "Lat";
    private static final String LON = "Lon";
    private static final String ZIP = "Zip";
    private static final String ZIP_ITEM = "ZipItem";

    /**
     * 住所レベル
     */
    private int addressLevel;
    /**
     * 住所コード
     */
    private String addressCode;
    /**
     * 全住所
     */
    private String fullAddress;
    /**
     * 郵便番号
     */
    private String zip;
    /**
     * 経度（度単位）
     */
    private double lon;
    /**
     * 緯度（度単位）
     */
    private double lat;

    /**
     * コンストラクタ―
     */
    public ZipItem() {

    }

    /**
     * コンストラクタ―
     * 
     * @param src
     *            読み込むParcel
     */
    public ZipItem(Parcel src) {
        addressLevel = src.readInt();
        addressCode = src.readString();
        fullAddress = src.readString();
        zip = src.readString();
        lat = src.readDouble();
        lon = src.readDouble();
    }

    @Override
    public int describeContents() {
        return 0;
    }

    /**
     * @return addressCode
     */
    public String getAddressCode() {
        return this.addressCode;
    }

    /**
     * @return addressLevel
     */
    public int getAddressLevel() {
        return this.addressLevel;
    }

    /**
     * @return fullAddress
     */
    public String getFullAddress() {
        return this.fullAddress;
    }

    /**
     * @return lat
     */
    public double getLat() {
        return this.lat;
    }

    /**
     * @return lon
     */
    public double getLon() {
        return this.lon;
    }

    /**
     * @return zip
     */
    public String getZip() {
        return this.zip;
    }

    /**
     * SOAPレスポンスから値を読み取ります。
     * 
     * @param parser
     *            XMLパーサー
     * @param tag
     *            タグ名
     * @throws XmlPullParserException
     * @throws IOException
     */
    public void readXml(XmlPullParser parser, String tag)
            throws XmlPullParserException, IOException {
        int eventType = parser.getEventType();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            switch (eventType) {
            case XmlPullParser.START_TAG:
                String startTagName = parser.getName();
                if (startTagName.equalsIgnoreCase(ADDRESS_LEVEL)) {
                    String value = parser.nextText();
                    addressLevel = Integer.parseInt(value);
                } else if (startTagName.equalsIgnoreCase(ADDRESS_CODE)) {
                    String value = parser.nextText();
                    addressCode = value;
                } else if (startTagName.equalsIgnoreCase(FULL_ADDRESS)) {
                    String value = parser.nextText();
                    fullAddress = value;
                } else if (startTagName.equalsIgnoreCase(ZIP)) {
                    String value = parser.nextText();
                    zip = value;
                } else if (startTagName.equalsIgnoreCase(LON)) {
                    String value = parser.nextText();
                    lon = Double.parseDouble(value);
                } else if (startTagName.equalsIgnoreCase(LAT)) {
                    String value = parser.nextText();
                    lat = Double.parseDouble(value);
                }
                break;
            case XmlPullParser.END_TAG:
                String endTagName = parser.getName();
                if (endTagName.equalsIgnoreCase(tag)) {
                    return;
                }
                break;
            }
            eventType = parser.next();
        }
    }

    /**
     * @param addressCode
     *            セットする addressCode
     */
    public void setAddressCode(String addressCode) {
        this.addressCode = addressCode;
    }

    /**
     * @param addressLevel
     *            セットする addressLevel
     */
    public void setAddressLevel(int addressLevel) {
        this.addressLevel = addressLevel;
    }

    /**
     * @param lat
     *            セットする lat
     */
    public void setLat(double lat) {
        this.lat = lat;
    }

    /**
     * @param lon
     *            セットする lon
     */
    public void setLon(double lon) {
        this.lon = lon;
    }

    /**
     * @param zip
     *            セットする zip
     */
    public void setZip(String zip) {
        this.zip = zip;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeInt(addressLevel);
        dest.writeString(addressCode);
        dest.writeString(fullAddress);
        dest.writeString(zip);
        dest.writeDouble(lat);
        dest.writeDouble(lon);
    }

    /**
     * SOAPリクエストに値を書き込みます。
     * 
     * @param xmlSerializer
     *            XMLシリアライザー
     * @param tag
     *            タグ名
     * @throws IOException
     */
    public void writeXml(XmlSerializer xmlSerializer, String tag)
            throws IOException {
        if (tag == null || tag.equals("")) {
            tag = ZIP_ITEM;
        }
        xmlSerializer.startTag("", tag);
        xmlSerializer.startTag("", ADDRESS_LEVEL);
        xmlSerializer.text(Integer.toString(addressLevel));
        xmlSerializer.endTag("", ADDRESS_LEVEL);
        xmlSerializer.startTag("", ADDRESS_CODE);
        if (addressCode != null) {
            xmlSerializer.text(addressCode);
        }
        xmlSerializer.endTag("", ADDRESS_CODE);
        xmlSerializer.startTag("", FULL_ADDRESS);
        if (fullAddress != null) {
            xmlSerializer.text(fullAddress);
        }
        xmlSerializer.endTag("", FULL_ADDRESS);
        xmlSerializer.startTag("", ZIP);
        if (zip != null) {
            xmlSerializer.text(zip);
        }
        xmlSerializer.endTag("", ZIP);
        xmlSerializer.startTag("", LON);
        xmlSerializer.text(Double.toString(lon));
        xmlSerializer.endTag("", LON);
        xmlSerializer.startTag("", LAT);
        xmlSerializer.text(Double.toString(lat));
        xmlSerializer.endTag("", LAT);
        xmlSerializer.endTag("", tag);
    }
}
